<?php
//
// To run:
//   php EDAMTest.php myuser mypass
//

ini_set("include_path", ini_get("include_path") . ":../../../lib/php:");
require_once("autoload.php");
require_once("Thrift.php");
require_once("transport/TTransport.php");
require_once("transport/THttpClient.php");
require_once("protocol/TProtocol.php");
require_once("protocol/TBinaryProtocol.php");
require_once("packages/Types/Types_types.php");
require_once("packages/UserStore/UserStore.php");
require_once("packages/NoteStore/NoteStore.php");

$consumerKey = "en-edamtest";
$consumerSecret = "0123456789abcdef";
$evernoteHost = "sandbox.evernote.com";

$evernotePort = "443";
$evernoteScheme = "https";

if ($argc < 3) {
  print "Arguments:  <username> <password>\n";
  exit(1);
}
$username = $argv[1];
$password = $argv[2];

$userStoreHttpClient =
  new THttpClient($evernoteHost, $evernotePort, "/edam/user", $evernoteScheme);
$userStoreProtocol = new TBinaryProtocol($userStoreHttpClient);
$userStore = new UserStoreClient($userStoreProtocol, $userStoreProtocol);

$versionOK =
  $userStore->checkVersion("PHP EDAMTest",
			   $GLOBALS['UserStore_CONSTANTS']['EDAM_VERSION_MAJOR'],
			   $GLOBALS['UserStore_CONSTANTS']['EDAM_VERSION_MINOR']);
print "Is my EDAM protocol version up to date?  " . $versionOK . "\n";
if ($versionOK == 0) {
  exit(1);
}

$authResult = $userStore->authenticate($username, $password, $consumerKey, $consumerSecret);
$user = $authResult->user;
$authToken = $authResult->authenticationToken;
print "Authentication was successful for " . $user->username . "\n";
print "Authentication token = " . $authToken . "\n";

$noteStoreHttpClient =
  new THttpClient($evernoteHost, $evernotePort,
		  "/edam/note/" . $user->shardId, $evernoteScheme);
$noteStoreProtocol = new TBinaryProtocol($noteStoreHttpClient);
$noteStore = new NoteStoreClient($noteStoreProtocol, $noteStoreProtocol);

$notebooks = $noteStore->listNotebooks($authToken);
print "Found " . count($notebooks) . " notebooks\n";
foreach ($notebooks as $notebook) {
  print "    * " . $notebook->name . "\n";
  if ($notebook->defaultNotebook) {
    $defaultNotebook = $notebook;
  }
}

print"\nCreating a new note in default notebook:  " . $defaultNotebook->name . "\n\n";

$image = fread(fopen("enlogo.png", "rb"), filesize("enlogo.png"));
$hash = md5($image, 1);
$hashHex = md5($image, 0);

$data = new edam_type_Data();
$data->size = strlen($image);
$data->bodyHash = $hash;
$data->body = $image;

$resource = new edam_type_Resource();
$resource->mime = "image/png";
$resource->data = $data;

$note = new edam_type_Note();
$note->notebookGuid = $defaultNotebook->guid;
$note->title = "Test note from EDAMTest.php";
$note->content =
  '<?xml version="1.0" encoding="UTF-8"?>' .
  '<!DOCTYPE en-note SYSTEM "http://xml.evernote.com/pub/enml.dtd">' .
  '<en-note>Here is the Evernote logo:<br/>' .
  '<en-media type="image/png" hash="' . $hashHex . '"/>' .
  '</en-note>';
$note->created = time() * 1000;
$note->updated = $note->created;
$note->resources = array( $resource );

$createdNote = $noteStore->createNote($authToken, $note);

print "Note was created, GUID = " . $createdNote->guid . "\n";

?>
