#
# To run (Unix):
#   export PYTHONPATH=../../lib/python; python EDAMTest.py myuser mypass
#

import sys
import hashlib
import time
import thrift.protocol.TBinaryProtocol as TBinaryProtocol
import thrift.transport.THttpClient as THttpClient
import evernote.edam.userstore.UserStore as UserStore
import evernote.edam.userstore.constants as UserStoreConstants
import evernote.edam.notestore.NoteStore as NoteStore
import evernote.edam.type.ttypes as Types

#
# Configure these based on the API key you received from Evernote
#
consumerKey = "en-edamtest"
consumerSecret = "0123456789abcdef"
userStoreUri = "https://sandbox.evernote.com/edam/user"
noteStoreUriBase = "http://sandbox.evernote.com/edam/note/"

if len(sys.argv) < 3:
    print "Arguments:  <username> <password>";
    exit(1)

username = sys.argv[1]
password = sys.argv[2]

userStoreHttpClient = THttpClient.THttpClient(userStoreUri)
userStoreProtocol = TBinaryProtocol.TBinaryProtocol(userStoreHttpClient)
userStore = UserStore.Client(userStoreProtocol)

versionOK = userStore.checkVersion("Python EDAMTest",
                                   UserStoreConstants.EDAM_VERSION_MAJOR,
                                   UserStoreConstants.EDAM_VERSION_MINOR)

print "Is my EDAM protocol version up to date? ", str(versionOK)
if not versionOK:
    exit(1)

authResult = userStore.authenticate(username, password,
                                    consumerKey, consumerSecret)
user = authResult.user
authToken = authResult.authenticationToken
print "Authentication was successful for ", user.username
print "Authentication token = ", authToken

noteStoreUri =  noteStoreUriBase + user.shardId
noteStoreHttpClient = THttpClient.THttpClient(noteStoreUri)
noteStoreProtocol = TBinaryProtocol.TBinaryProtocol(noteStoreHttpClient)
noteStore = NoteStore.Client(noteStoreProtocol)

notebooks = noteStore.listNotebooks(authToken)
print "Found ", len(notebooks), " notebooks:"
for notebook in notebooks:
    print "  * ", notebook.name
    if notebook.defaultNotebook:
        defaultNotebook = notebook

print
print "Creating a new note in default notebook: ", defaultNotebook.name
print

# Create a note with one image resource in it ...

image = open('enlogo.png', 'rb').read()
md5 = hashlib.md5()
md5.update(image)
hashHex = md5.hexdigest()

data = Types.Data()
data.size = len(image)
data.bodyHash = hashHex
data.body = image

resource = Types.Resource()
resource.mime = 'image/png'
resource.data = data

note = Types.Note()
note.notebookGuid = defaultNotebook.guid
note.title = "Test note from EDAMTest.py"
note.content = '<?xml version="1.0" encoding="UTF-8"?>'
note.content += '<!DOCTYPE en-note SYSTEM "http://xml.evernote.com/pub/enml.dtd">'
note.content += '<en-note>Here is the Evernote logo:<br/>'
note.content += '<en-media type="image/png" hash="' + hashHex + '"/>'
note.content += '</en-note>'
note.created = int(time.time() * 1000)
note.updated = note.created
note.resources = [ resource ]

createdNote = noteStore.createNote(authToken, note)

print "Created note: ", str(createdNote)
