/**
 * Autogenerated by Thrift
 *
 * DO NOT EDIT UNLESS YOU ARE SURE THAT YOU KNOW WHAT YOU ARE DOING
 */
package com.evernote.edam.notestore;

import java.util.List;
import java.util.ArrayList;
import java.util.Map;
import java.util.HashMap;
import java.util.EnumMap;
import java.util.Set;
import java.util.HashSet;
import java.util.EnumSet;
import java.util.Collections;
import com.evernote.edam.util.BitSet;
import java.util.Arrays;

import org.apache.thrift.*;
import org.apache.thrift.meta_data.*;
import org.apache.thrift.protocol.*;

public class NoteStore {

  /**
   * Service:  NoteStore
   * <p>
   * The NoteStore service is used by EDAM clients to exchange information
   * about the collection of notes in an account.  This is primarily used for
   * synchronization, but could also be used by a "thin" client without a full
   * local cache.
   * </p><p>
   * All functions take an "authenticationToken" parameter, which is the
   * value returned by the UserStore which permits access to the account.
   * This parameter is mandatory for all functions.
   * </p>
   * 
   * Calls which require an authenticationToken may throw an EDAMUserException
   * for the following reasons:
   *  <ul>
   *   <li> AUTH_EXPIRED "authenticationToken" - token has expired
   *   </li>
   *   <li> BAD_DATA_FORMAT "authenticationToken" - token is malformed
   *   </li>
   *   <li> DATA_REQUIRED "authenticationToken" - token is empty
   *   </li>
   *   <li> INVALID_AUTH "authenticationToken" - token signature is invalid
   *   </li>
   * </ul>
   */
  public interface Iface {

    /**
     * Asks the NoteStore to provide information about the status of the user
     * account corresponding to the provided authentication token.
     * 
     * @param authenticationToken
     */
    public SyncState getSyncState(String authenticationToken) throws com.evernote.edam.error.EDAMUserException, com.evernote.edam.error.EDAMSystemException, TException;

    /**
     * Asks the NoteStore to provide the state of the account in order of
     * last modification.  This request retrieves one block of the server's
     * state so that a client can make several small requests against a large
     * account rather than getting the entire state in one big message.
     * 
     * @param afterUSN
     *   The client can pass this value to ask only for objects that
     *   have been updated after a certain point.  This allows the client to
     *   receive updates after its last checkpoint rather than doing a full
     *   synchronization on every pass.  The default value of "0" indicates
     *   that the client wants to get objects from the start of the account.
     * 
     * @param maxEntries
     *   The maximum number of modified objects that should be
     *   returned in the result SyncChunk.  This can be used to limit the size
     *   of each individual message to be friendly for network transfer.
     * 
     * @param fullSyncOnly
     *   If true, then the client only wants initial data for a full sync.
     *   In this case, the service will not return any expunged objects,
     *   and will not return any Resources, since these are also provided
     *   in their corresponding Notes.
     * 
     * @throws EDAMUserException <ul>
     *   <li> BAD_DATA_FORMAT "afterUSN" - if negative
     *   </li>
     *   <li> BAD_DATA_FORMAT "maxEntries" - if less than 1
     *   </li>
     * </ul>
     * 
     * @param authenticationToken
     * @param afterUSN
     * @param maxEntries
     * @param fullSyncOnly
     */
    public SyncChunk getSyncChunk(String authenticationToken, int afterUSN, int maxEntries, boolean fullSyncOnly) throws com.evernote.edam.error.EDAMUserException, com.evernote.edam.error.EDAMSystemException, TException;

    /**
     * Returns a list of all of the notebooks in the account.
     * 
     * @param authenticationToken
     */
    public List<com.evernote.edam.type.Notebook> listNotebooks(String authenticationToken) throws com.evernote.edam.error.EDAMUserException, com.evernote.edam.error.EDAMSystemException, TException;

    /**
     * Returns the current state of the notebook with the provided GUID.
     * The notebook may be active or deleted (but not expunged).
     * 
     * @param guid
     *   The GUID of the notebook to be retrieved.
     * 
     * @throws EDAMUserException <ul>
     *   <li> BAD_DATA_FORMAT "Notebook.guid" - if the parameter is missing
     *   </li>
     *   <li> PERMISSION_DENIED "Notebook" - private notebook, user doesn't own
     *   </li>
     * </ul>
     * 
     * @throws EDAMNotFoundException <ul>
     *   <li> "Notebook.guid" - tag not found, by GUID
     *   </li>
     * </ul>
     * 
     * @param authenticationToken
     * @param guid
     */
    public com.evernote.edam.type.Notebook getNotebook(String authenticationToken, String guid) throws com.evernote.edam.error.EDAMUserException, com.evernote.edam.error.EDAMSystemException, com.evernote.edam.error.EDAMNotFoundException, TException;

    /**
     * Returns the notebook that should be used to store new notes in the
     * user's account when no other notebooks are specified.
     * 
     * @param authenticationToken
     */
    public com.evernote.edam.type.Notebook getDefaultNotebook(String authenticationToken) throws com.evernote.edam.error.EDAMUserException, com.evernote.edam.error.EDAMSystemException, TException;

    /**
     * Asks the service to make a notebook with the provided name.
     * 
     * @param notebook
     *   The desired fields for the notebook must be provided on this
     *   object.  The name of the notebook must be set, and either the 'active'
     *   or 'defaultNotebook' fields may be set by the client at creation.
     *   If a notebook exists in the account with the same name (via
     *   case-insensitive compare), this will throw an EDAMUserException.
     * 
     * @return
     *   The newly created Notebook.  The server-side GUID will be
     *   saved in this object's 'guid' field.
     * 
     * @throws EDAMUserException <ul>
     *   <li> BAD_DATA_FORMAT "Notebook.name" - invalid length or pattern
     *   </li>
     *   <li> BAD_DATA_FORMAT "Publishing.uri" - if publishing set but bad uri
     *   </li>
     *   <li> BAD_DATA_FORMAT "Publishing.publicDescription" - if too long
     *   </li>
     *   <li> DATA_CONFLICT "Notebook.name" - name already in use
     *   </li>
     *   <li> DATA_CONFLICT "Publishing.uri" - if URI already in use
     *   </li>
     *   <li> DATA_REQUIRED "Publishing.uri" - if publishing set but uri missing
     *   </li>
     *   <li> LIMIT_REACHED "Notebook" - at max number of notebooks
     *   </li>
     * </ul>
     * 
     * @param authenticationToken
     * @param notebook
     */
    public com.evernote.edam.type.Notebook createNotebook(String authenticationToken, com.evernote.edam.type.Notebook notebook) throws com.evernote.edam.error.EDAMUserException, com.evernote.edam.error.EDAMSystemException, TException;

    /**
     * Submits notebook changes to the service.  The provided data must include
     * the notebook's guid field for identification.
     * 
     * @param notebook
     *   The notebook object containing the requested changes.
     * 
     * @return
     *   The Update Sequence Number for this change within the account.
     * 
     * @throws EDAMUserException <ul>
     *   <li> BAD_DATA_FORMAT "Notebook.name" - invalid length or pattern
     *   </li>
     *   <li> BAD_DATA_FORMAT "Publishing.uri" - if publishing set but bad uri
     *   </li>
     *   <li> BAD_DATA_FORMAT "Publishing.publicDescription" - if too long
     *   </li>
     *   <li> DATA_CONFLICT "Notebook.name" - name already in use
     *   </li>
     *   <li> DATA_CONFLICT "Publishing.uri" - if URI already in use
     *   </li>
     *   <li> DATA_REQUIRED "Publishing.uri" - if publishing set but uri missing
     *   </li>
     * </ul>
     * 
     * @throws EDAMNotFoundException <ul>
     *   <li> "Notebook.guid" - not found, by GUID
     *   </li>
     * </ul>
     * 
     * @param authenticationToken
     * @param notebook
     */
    public int updateNotebook(String authenticationToken, com.evernote.edam.type.Notebook notebook) throws com.evernote.edam.error.EDAMUserException, com.evernote.edam.error.EDAMSystemException, com.evernote.edam.error.EDAMNotFoundException, TException;

    /**
     * Permanently removes the notebook from the user's account.
     * After this action, the notebook is no longer available for undeletion, etc.
     * If the notebook contains any Notes, they will be moved to the current
     * default notebook and moved into the trash (i.e. Note.active=false).
     * 
     * @param guid
     *   The GUID of the notebook to delete.
     * 
     * @return
     *   The Update Sequence Number for this change within the account.
     * 
     * @throws EDAMUserException <ul>
     *   <li> BAD_DATA_FORMAT "Notebook.guid" - if the parameter is missing
     *   </li>
     *   <li> LIMIT_REACHED "Notebook" - trying to expunge the last Notebook
     *   </li>
     *   <li> PERMISSION_DENIED "Notebook" - private notebook, user doesn't own
     *   </li>
     * </ul>
     * 
     * @param authenticationToken
     * @param guid
     */
    public int expungeNotebook(String authenticationToken, String guid) throws com.evernote.edam.error.EDAMUserException, com.evernote.edam.error.EDAMSystemException, com.evernote.edam.error.EDAMNotFoundException, TException;

    /**
     * Returns a list of the tags in the account.  Evernote does not support
     * the undeletion of tags, so this will only include active tags.
     * 
     * @param authenticationToken
     */
    public List<com.evernote.edam.type.Tag> listTags(String authenticationToken) throws com.evernote.edam.error.EDAMUserException, com.evernote.edam.error.EDAMSystemException, TException;

    /**
     * Returns a list of the tags that are applied to at least one note within
     * the provided notebook.  If the notebook is public, the authenticationToken
     * may be ignored.
     * 
     * @param notebookGuid
     *    the GUID of the notebook to use to find tags
     * 
     * @throws EDAMNotFoundException <ul>
     *   <li> "Notebook.guid" - notebook not found by GUID
     *   </li>
     * </ul>
     * 
     * @param authenticationToken
     * @param notebookGuid
     */
    public List<com.evernote.edam.type.Tag> listTagsByNotebook(String authenticationToken, String notebookGuid) throws com.evernote.edam.error.EDAMUserException, com.evernote.edam.error.EDAMSystemException, com.evernote.edam.error.EDAMNotFoundException, TException;

    /**
     * Returns the current state of the Tag with the provided GUID.
     * 
     * @param guid
     *   The GUID of the tag to be retrieved.
     * 
     * @throws EDAMUserException <ul>
     *   <li> BAD_DATA_FORMAT "Tag.guid" - if the parameter is missing
     *   </li>
     *   <li> PERMISSION_DENIED "Tag" - private Tag, user doesn't own
     *   </li>
     * </ul>
     * 
     * @throws EDAMNotFoundException <ul>
     *   <li> "Tag.guid" - tag not found, by GUID
     *   </li>
     * </ul>
     * 
     * @param authenticationToken
     * @param guid
     */
    public com.evernote.edam.type.Tag getTag(String authenticationToken, String guid) throws com.evernote.edam.error.EDAMUserException, com.evernote.edam.error.EDAMSystemException, com.evernote.edam.error.EDAMNotFoundException, TException;

    /**
     * Asks the service to make a tag with a set of information.
     * 
     * @param tag
     *   The desired list of fields for the tag are specified in this
     *   object.  The caller must specify the tag name, and may provide
     *   the parentGUID.
     * 
     * @return
     *   The newly created Tag.  The server-side GUID will be
     *   saved in this object.
     * 
     * @throws EDAMUserException <ul>
     *   <li> BAD_DATA_FORMAT "Tag.name" - invalid length or pattern
     *   </li>
     *   <li> BAD_DATA_FORMAT "Tag.parentGuid" - malformed GUID
     *   </li>
     *   <li> DATA_CONFLICT "Tag.name" - name already in use
     *   </li>
     *   <li> LIMIT_REACHED "Tag" - at max number of tags
     *   </li>
     * </ul>
     * 
     * @throws EDAMNotFoundException <ul>
     *   <li> "Tag.parentGuid" - not found, by GUID
     *   </li>
     * </ul>
     * 
     * @param authenticationToken
     * @param tag
     */
    public com.evernote.edam.type.Tag createTag(String authenticationToken, com.evernote.edam.type.Tag tag) throws com.evernote.edam.error.EDAMUserException, com.evernote.edam.error.EDAMSystemException, com.evernote.edam.error.EDAMNotFoundException, TException;

    /**
     * Submits tag changes to the service.  The provided data must include
     * the tag's guid field for identification.  The service will apply
     * updates to the following tag fields:  name, parentGuid
     * 
     * @param tag
     *   The tag object containing the requested changes.
     * 
     * @return
     *   The Update Sequence Number for this change within the account.
     * 
     * @throws EDAMUserException <ul>
     *   <li> BAD_DATA_FORMAT "Tag.name" - invalid length or pattern
     *   </li>
     *   <li> BAD_DATA_FORMAT "Tag.parentGuid" - malformed GUID
     *   </li>
     *   <li> DATA_CONFLICT "Tag.name" - name already in use
     *   </li>
     *   <li> DATA_CONFLICT "Tag.parentGuid" - can't set parent: circular
     *   </li>
     *   <li> PERMISSION_DENIED "Tag" - user doesn't own tag
     *   </li>
     * </ul>
     * 
     * @throws EDAMNotFoundException <ul>
     *   <li> "Tag.guid" - tag not found, by GUID
     *   </li>
     *   <li> "Tag.parentGuid" - parent not found, by GUID
     *   </li>
     * </ul>
     * 
     * @param authenticationToken
     * @param tag
     */
    public int updateTag(String authenticationToken, com.evernote.edam.type.Tag tag) throws com.evernote.edam.error.EDAMUserException, com.evernote.edam.error.EDAMSystemException, com.evernote.edam.error.EDAMNotFoundException, TException;

    /**
     * Removes the provided tag from every note that is currently tagged with
     * this tag.  If this operation is successful, the tag will still be in
     * the account, but it will not be tagged on any notes.
     * 
     * This function is not indended for use by full synchronizing clients, since
     * it does not provide enough result information to the client to reconcile
     * the local state without performing a follow-up sync from the service.  This
     * is intended for "thin clients" that need to efficiently support this as
     * a UI operation.
     * 
     * @param guid
     *   The GUID of the tag to remove from all notes.
     * 
     * @throws EDAMUserException <ul>
     *   <li> BAD_DATA_FORMAT "Tag.guid" - if the guid parameter is missing
     *   </li>
     *   <li> PERMISSION_DENIED "Tag" - user doesn't own tag
     *   </li>
     * </ul>
     * 
     * @throws EDAMNotFoundException <ul>
     *   <li> "Tag.guid" - tag not found, by GUID
     *   </li>
     * </ul>
     * 
     * @param authenticationToken
     * @param guid
     */
    public void untagAll(String authenticationToken, String guid) throws com.evernote.edam.error.EDAMUserException, com.evernote.edam.error.EDAMSystemException, com.evernote.edam.error.EDAMNotFoundException, TException;

    /**
     * Permanently deletes the tag with the provided GUID, if present.
     * 
     * @param guid
     *   The GUID of the tag to delete.
     * 
     * @return
     *   The Update Sequence Number for this change within the account.
     * 
     * @throws EDAMUserException <ul>
     *   <li> BAD_DATA_FORMAT "Tag.guid" - if the guid parameter is missing
     *   </li>
     *   <li> PERMISSION_DENIED "Tag" - user doesn't own tag
     *   </li>
     * </ul>
     * 
     * @throws EDAMNotFoundException <ul>
     *   <li> "Tag.guid" - tag not found, by GUID
     *   </li>
     * </ul>
     * 
     * @param authenticationToken
     * @param guid
     */
    public int expungeTag(String authenticationToken, String guid) throws com.evernote.edam.error.EDAMUserException, com.evernote.edam.error.EDAMSystemException, com.evernote.edam.error.EDAMNotFoundException, TException;

    /**
     * Returns a list of the searches in the account.  Evernote does not support
     * the undeletion of searches, so this will only include active searches.
     * 
     * @param authenticationToken
     */
    public List<com.evernote.edam.type.SavedSearch> listSearches(String authenticationToken) throws com.evernote.edam.error.EDAMUserException, com.evernote.edam.error.EDAMSystemException, TException;

    /**
     * Returns the current state of the search with the provided GUID.
     * 
     * @param guid
     *   The GUID of the search to be retrieved.
     * 
     * @throws EDAMUserException <ul>
     *   <li> BAD_DATA_FORMAT "SavedSearch.guid" - if the parameter is missing
     *   </li>
     *   <li> PERMISSION_DENIED "SavedSearch" - private Tag, user doesn't own
     *   </li>
     * </ul>
     * 
     * @param authenticationToken
     * @param guid
     */
    public com.evernote.edam.type.SavedSearch getSearch(String authenticationToken, String guid) throws com.evernote.edam.error.EDAMUserException, com.evernote.edam.error.EDAMSystemException, com.evernote.edam.error.EDAMNotFoundException, TException;

    /**
     * Asks the service to make a saved search with a set of information.
     * 
     * @param search
     *   The desired list of fields for the search are specified in this
     *   object.  The caller must specify the
     *   name, query, and format of the search.
     * 
     * @return
     *   The newly created SavedSearch.  The server-side GUID will be
     *   saved in this object.
     * 
     * @throws EDAMUserException <ul>
     *   <li> BAD_DATA_FORMAT "SavedSearch.name" - invalid length or pattern
     *   </li>
     *   <li> BAD_DATA_FORMAT "SavedSearch.query" - invalid length
     *   </li>
     *   <li> BAD_DATA_FORMAT "SavedSearch.format" - not a valid QueryFormat value
     *   </li>
     *   <li> DATA_CONFLICT "SavedSearch.name" - name already in use
     *   </li>
     *   <li> LIMIT_REACHED "SavedSearch" - at max number of searches
     *   </li>
     * </ul>
     * 
     * @param authenticationToken
     * @param search
     */
    public com.evernote.edam.type.SavedSearch createSearch(String authenticationToken, com.evernote.edam.type.SavedSearch search) throws com.evernote.edam.error.EDAMUserException, com.evernote.edam.error.EDAMSystemException, TException;

    /**
     * Submits search changes to the service.  The provided data must include
     * the search's guid field for identification.  The service will apply
     * updates to the following search fields:  name, query, and format
     * 
     * @param search
     *   The search object containing the requested changes.
     * 
     * @return
     *   The Update Sequence Number for this change within the account.
     * 
     * @throws EDAMUserException <ul>
     *   <li> BAD_DATA_FORMAT "SavedSearch.name" - invalid length or pattern
     *   </li>
     *   <li> BAD_DATA_FORMAT "SavedSearch.query" - invalid length
     *   </li>
     *   <li> BAD_DATA_FORMAT "SavedSearch.format" - not a valid QueryFormat value
     *   </li>
     *   <li> DATA_CONFLICT "SavedSearch.name" - name already in use
     *   </li>
     *   <li> PERMISSION_DENIED "SavedSearch" - user doesn't own tag
     *   </li>
     * </ul>
     * 
     * @throws EDAMNotFoundException <ul>
     *   <li> "SavedSearch.guid" - not found, by GUID
     *   </li>
     * </ul>
     * 
     * @param authenticationToken
     * @param search
     */
    public int updateSearch(String authenticationToken, com.evernote.edam.type.SavedSearch search) throws com.evernote.edam.error.EDAMUserException, com.evernote.edam.error.EDAMSystemException, com.evernote.edam.error.EDAMNotFoundException, TException;

    /**
     * Permanently deletes the search with the provided GUID, if present.
     * 
     * @param guid
     *   The GUID of the search to delete.
     * 
     * @return
     *   The Update Sequence Number for this change within the account.
     * 
     * @throws EDAMUserException <ul>
     *   <li> BAD_DATA_FORMAT "SavedSearch.guid" - if the guid parameter is empty
     *   </li>
     *   <li> PERMISSION_DENIED "SavedSearch" - user doesn't own
     *   </li>
     * </ul>
     * 
     * @throws EDAMNotFoundException <ul>
     *   <li> "SavedSearch.guid" - not found, by GUID
     *   </li>
     * </ul>
     * 
     * @param authenticationToken
     * @param guid
     */
    public int expungeSearch(String authenticationToken, String guid) throws com.evernote.edam.error.EDAMUserException, com.evernote.edam.error.EDAMSystemException, com.evernote.edam.error.EDAMNotFoundException, TException;

    /**
     * Used to find a set of the notes from a user's account based on various
     * criteria specified via a NoteFilter object.
     * The Notes (and any embedded Resources) will have empty Data bodies for
     * contents, resource data, and resource recognition fields.  These values
     * must be retrieved individually.
     * 
     * @param authenticationToken
     *   Must be a valid token for the user's account unless the NoteFilter
     *   'notebookGuid' is the GUID of a public notebook.
     * 
     * @param filter
     *   The list of criteria that will constrain the notes to be returned.
     * 
     * @param offset
     *   The numeric index of the first note to show within the sorted
     *   results.  The numbering scheme starts with "0".  This can be used for
     *   pagination.
     * 
     * @param maxNotes
     *   The most notes to return in this query.  The service will
     *   either return this many notes or the end of the notebook, whichever is
     *   shorter.
     * 
     * @return
     *   The list of notes that match the criteria.
     * 
     * @throws EDAMUserException <ul>
     *   <li> BAD_DATA_FORMAT "offset" - not between 0 and EDAM_USER_NOTES_MAX
     *   </li>
     *   <li> BAD_DATA_FORMAT "maxNotes" - not between 0 and EDAM_USER_NOTES_MAX
     *   </li>
     *   <li> BAD_DATA_FORMAT "NoteFilter.notebookGuid" - if malformed
     *   </li>
     *   <li> BAD_DATA_FORMAT "NoteFilter.tagGuids" - if any are malformed
     *   </li>
     *   <li> BAD_DATA_FORMAT "NoteFilter.words" - if search string too long
     *   </li>
     * 
     * @throws EDAMNotFoundException <ul>
     *   <li> "Notebook.guid" - not found, by GUID
     *   </li>
     * </ul>
     * 
     * @param authenticationToken
     * @param filter
     * @param offset
     * @param maxNotes
     */
    public NoteList findNotes(String authenticationToken, NoteFilter filter, int offset, int maxNotes) throws com.evernote.edam.error.EDAMUserException, com.evernote.edam.error.EDAMSystemException, com.evernote.edam.error.EDAMNotFoundException, TException;

    /**
     * This function is used to determine how many notes are found for each
     * notebook and tag in the user's account, given a current set of filter
     * parameters that determine the current selection.  This function will
     * return a structure that gives the note count for each notebook and tag
     * that has at least one note under the requested filter.  Any notebook or
     * tag that has zero notes in the filtered set will not be listed in the
     * reply to this function (so they can be assumed to be 0).
     * 
     * @param authenticationToken
     *   Must be a valid token for the user's account unless the NoteFilter
     *   'notebookGuid' is the GUID of a public notebook.
     * 
     * @param filter
     *   The note selection filter that is currently being applied.  The note
     *   counts are to be calculated with this filter applied to the total set
     *   of notes in the user's account.
     * 
     * @param withTrash
     *   If true, then the NoteCollectionCounts.trashCount will be calculated
     *   and supplied in the reply. Otherwise, the trash value will be omitted.
     * 
     * @throws EDAMUserException <ul>
     *   <li> BAD_DATA_FORMAT "NoteFilter.notebookGuid" - if malformed
     *   </li>
     *   <li> BAD_DATA_FORMAT "NoteFilter.notebookGuids" - if any are malformed
     *   </li>
     *   <li> BAD_DATA_FORMAT "NoteFilter.words" - if search string too long
     *   </li>
     * 
     * @throws EDAMNotFoundException <ul>
     *   <li> "Notebook.guid" - not found, by GUID
     *   </li>
     * </ul>
     * 
     * @param authenticationToken
     * @param filter
     * @param withTrash
     */
    public NoteCollectionCounts findNoteCounts(String authenticationToken, NoteFilter filter, boolean withTrash) throws com.evernote.edam.error.EDAMUserException, com.evernote.edam.error.EDAMSystemException, com.evernote.edam.error.EDAMNotFoundException, TException;

    /**
     * Returns the current state of the note in the service with the provided
     * GUID.  The ENML contents of the note will only be provided if the
     * 'withContent' parameter is true.  The service will include the meta-data
     * for each resource in the note, but the binary contents of the resources
     * and their recognition data will be omitted.
     * If the Note is found in a public notebook, the authenticationToken
     * will be ignored (so it could be an empty string).
     * 
     * @param guid
     *   The GUID of the note to be retrieved.
     * 
     * @param withContent
     *   If true, the note will include the ENML contents of its
     *   'content' field.
     * 
     * @param withResourcesData
     *   If true, any Resource elements in this Note will include the binary
     *   contents of their 'data' field's body.
     * 
     * @param withResourcesRecognition
     *   If true, any Resource elements will include the binary contents of the
     *   'recognition' field's body if recognition data is present.
     * 
     * @param withResourcesAlternateData
     *   If true, any Resource elements in this Note will include the binary
     *   contents of their 'alternateData' fields' body, if an alternate form
     *   is present.
     * 
     * @throws EDAMUserException <ul>
     *   <li> BAD_DATA_FORMAT "Note.guid" - if the parameter is missing
     *   </li>
     *   <li> PERMISSION_DENIED "Note" - private note, user doesn't own
     *   </li>
     * </ul>
     * 
     * @throws EDAMNotFoundException <ul>
     *   <li> "Note.guid" - not found, by GUID
     *   </li>
     * </ul>
     * 
     * @param authenticationToken
     * @param guid
     * @param withContent
     * @param withResourcesData
     * @param withResourcesRecognition
     * @param withResourcesAlternateData
     */
    public com.evernote.edam.type.Note getNote(String authenticationToken, String guid, boolean withContent, boolean withResourcesData, boolean withResourcesRecognition, boolean withResourcesAlternateData) throws com.evernote.edam.error.EDAMUserException, com.evernote.edam.error.EDAMSystemException, com.evernote.edam.error.EDAMNotFoundException, TException;

    /**
     * Returns XHTML contents of the note with the provided GUID.
     * If the Note is found in a public notebook, the authenticationToken
     * will be ignored (so it could be an empty string).
     * 
     * @param guid
     *   The GUID of the note to be retrieved.
     * 
     * @throws EDAMUserException <ul>
     *   <li> BAD_DATA_FORMAT "Note.guid" - if the parameter is missing
     *   </li>
     *   <li> PERMISSION_DENIED "Note" - private note, user doesn't own
     *   </li>
     * </ul>
     * 
     * @throws EDAMNotFoundException <ul>
     *   <li> "Note.guid" - not found, by GUID
     *   </li>
     * </ul>
     * 
     * @param authenticationToken
     * @param guid
     */
    public String getNoteContent(String authenticationToken, String guid) throws com.evernote.edam.error.EDAMUserException, com.evernote.edam.error.EDAMSystemException, com.evernote.edam.error.EDAMNotFoundException, TException;

    /**
     * Returns a block of the extracted plain text contents of the note with the
     * provided GUID.  This text can be indexed for search purposes by a light
     * client that doesn't have capabilities to extract all of the searchable
     * text content from the note and its resources.
     * 
     * If the Note is found in a public notebook, the authenticationToken
     * will be ignored (so it could be an empty string).
     * 
     * @param guid
     *   The GUID of the note to be retrieved.
     * 
     * @throws EDAMUserException <ul>
     *   <li> BAD_DATA_FORMAT "Note.guid" - if the parameter is missing
     *   </li>
     *   <li> PERMISSION_DENIED "Note" - private note, user doesn't own
     *   </li>
     * </ul>
     * 
     * @throws EDAMNotFoundException <ul>
     *   <li> "Note.guid" - not found, by GUID
     *   </li>
     * </ul>
     * 
     * @param authenticationToken
     * @param guid
     */
    public String getNoteSearchText(String authenticationToken, String guid) throws com.evernote.edam.error.EDAMUserException, com.evernote.edam.error.EDAMSystemException, com.evernote.edam.error.EDAMNotFoundException, TException;

    /**
     * Returns a list of the names of the tags for the note with the provided
     * guid.  This can be used with authentication to get the tags for a
     * user's own note, or can be used without valid authentication to retrieve
     * the names of the tags for a note in a public notebook.
     * 
     * @throws EDAMUserException <ul>
     *   <li> BAD_DATA_FORMAT "Note.guid" - if the parameter is missing
     *   </li>
     *   <li> PERMISSION_DENIED "Note" - private note, user doesn't own
     *   </li>
     * </ul>
     * 
     * @throws EDAMNotFoundException <ul>
     *   <li> "Note.guid" - not found, by GUID
     *   </li>
     * </ul>
     * 
     * @param authenticationToken
     * @param guid
     */
    public List<String> getNoteTagNames(String authenticationToken, String guid) throws com.evernote.edam.error.EDAMUserException, com.evernote.edam.error.EDAMSystemException, com.evernote.edam.error.EDAMNotFoundException, TException;

    /**
     * Asks the service to make a note with the provided set of information.
     * 
     * @param note
     *   A Note object containing the desired fields to be populated on
     *   the service.
     * 
     * @return
     *   The newly created Note from the service.  The server-side
     *   GUIDs for the Note and any Resources will be saved in this object.
     * 
     * @throws EDAMUserException <ul>
     *   <li> BAD_DATA_FORMAT "Note.title" - invalid length or pattern
     *   </li>
     *   <li> BAD_DATA_FORMAT "Note.content" - invalid length for ENML content
     *   </li>
     *   <li> BAD_DATA_FORMAT "Resource.mime" - invalid resource MIME type
     *   </li>
     *   <li> BAD_DATA_FORMAT "NoteAttributes.*" - bad resource string
     *   </li>
     *   <li> BAD_DATA_FORMAT "ResourceAttributes.*" - bad resource string
     *   </li>
     *   <li> DATA_CONFLICT "Note.deleted" - deleted time set on active note
     *   </li>
     *   <li> DATA_REQUIRED "Resource.data" - resource data body missing
     *   </li>
     *   <li> ENML_VALIDATION "*" - note content doesn't validate against DTD
     *   </li>
     *   <li> LIMIT_REACHED "Note" - at max number per account
     *   </li>
     *   <li> LIMIT_REACHED "Note.size" - total note size too large
     *   </li>
     *   <li> LIMIT_REACHED "Note.resources" - too many resources on Note
     *   </li>
     *   <li> LIMIT_REACHED "Note.tagGuids" - too many Tags on Note
     *   </li>
     *   <li> LIMIT_REACHED "Resource.data.size" - resource too large
     *   </li>
     *   <li> LIMIT_REACHED "NoteAttribute.*" - attribute string too long
     *   </li>
     *   <li> LIMIT_REACHED "ResourceAttribute.*" - attribute string too long
     *   </li>
     *   <li> PERMISSION_DENIED "Note.notebookGuid" - NB not owned by user
     *   </li>
     *   <li> QUOTA_REACHED "Accounting.uploadLimit" - note exceeds upload quota
     *   </li>
     *   <li> BAD_DATA_FORMAT "Tag.name" - Note.tagNames was provided, and one
     *     of the specified tags had an invalid length or pattern
     *   </li>
     *   <li> LIMIT_REACHED "Tag" - Note.tagNames was provided, and the required
     *     new tags would exceed the maximum number per account
     *   </li>
     * </ul>
     * 
     * @throws EDAMNotFoundException <ul>
     *   <li> "Note.notebookGuid" - not found, by GUID
     *   </li>
     * </ul>
     * 
     * @param authenticationToken
     * @param note
     */
    public com.evernote.edam.type.Note createNote(String authenticationToken, com.evernote.edam.type.Note note) throws com.evernote.edam.error.EDAMUserException, com.evernote.edam.error.EDAMSystemException, com.evernote.edam.error.EDAMNotFoundException, TException;

    /**
     * Submit a set of changes to a note to the service.  The provided data
     * must include the note's guid field for identification.
     * 
     * @param note
     *   A Note object containing the desired fields to be populated on
     *   the service.
     * 
     * @return
     *   The metadata (no contents) for the Note on the server after the update
     * 
     * @throws EDAMUserException <ul>
     *   <li> BAD_DATA_FORMAT "Note.title" - invalid length or pattern
     *   </li>
     *   <li> BAD_DATA_FORMAT "Note.content" - invalid length for ENML body
     *   </li>
     *   <li> BAD_DATA_FORMAT "NoteAttributes.*" - bad resource string
     *   </li>
     *   <li> BAD_DATA_FORMAT "ResourceAttributes.*" - bad resource string
     *   </li>
     *   <li> BAD_DATA_FORMAT "Resource.mime" - invalid resource MIME type
     *   </li>
     *   <li> DATA_CONFLICT "Note.deleted" - deleted time set on active note
     *   </li>
     *   <li> DATA_REQUIRED "Resource.data" - resource data body missing
     *   </li>
     *   <li> ENML_VALIDATION "*" - note content doesn't validate against DTD
     *   </li>
     *   <li> LIMIT_REACHED "Note.tagGuids" - too many Tags on Note
     *   </li>
     *   <li> LIMIT_REACHED "Note.resources" - too many resources on Note
     *   </li>
     *   <li> LIMIT_REACHED "Note.size" - total note size too large
     *   </li>
     *   <li> LIMIT_REACHED "Resource.data.size" - resource too large
     *   </li>
     *   <li> LIMIT_REACHED "NoteAttribute.*" - attribute string too long
     *   </li>
     *   <li> LIMIT_REACHED "ResourceAttribute.*" - attribute string too long
     *   </li>
     *   <li> PERMISSION_DENIED "Note" - user doesn't own
     *   </li>
     *   <li> PERMISSION_DENIED "Note.notebookGuid" - user doesn't own destination
     *   </li>
     *   <li> QUOTA_REACHED "Accounting.uploadLimit" - note exceeds upload quota
     *   </li>
     *   <li> BAD_DATA_FORMAT "Tag.name" - Note.tagNames was provided, and one
     *     of the specified tags had an invalid length or pattern
     *   </li>
     *   <li> LIMIT_REACHED "Tag" - Note.tagNames was provided, and the required
     *     new tags would exceed the maximum number per account
     *   </li>
     * </ul>
     * 
     * @throws EDAMNotFoundException <ul>
     *   <li> "Note.guid" - note not found, by GUID
     *   </li>
     *   <li> "Note.notebookGuid" - if notebookGuid provided, but not found
     *   </li>
     * </ul>
     * 
     * @param authenticationToken
     * @param note
     */
    public com.evernote.edam.type.Note updateNote(String authenticationToken, com.evernote.edam.type.Note note) throws com.evernote.edam.error.EDAMUserException, com.evernote.edam.error.EDAMSystemException, com.evernote.edam.error.EDAMNotFoundException, TException;

    /**
     * Moves the note into the trash. The note may still be undeleted, unless it
     * is expunged.  This is equivalent to calling udpateNote() after setting
     * Note.active = false
     * 
     * @param guid
     *   The GUID of the note to delete.
     * 
     * @return
     *   The Update Sequence Number for this change within the account.
     * 
     * @throws EDAMUserException <ul>
     *   <li> PERMISSION_DENIED "Note" - user doesn't have permission to
     *          update the note.
     *   </li>
     * </ul>
     * 
     * @throws EDAMNotFoundException <ul>
     *   <li> "Note.guid" - not found, by GUID
     *   </li>
     * </ul>
     * 
     * @param authenticationToken
     * @param guid
     */
    public int deleteNote(String authenticationToken, String guid) throws com.evernote.edam.error.EDAMUserException, com.evernote.edam.error.EDAMSystemException, com.evernote.edam.error.EDAMNotFoundException, TException;

    /**
     * Permanently removes the Note, and all of its Resources,
     * from the service.
     * 
     * @param guid
     *   The GUID of the note to delete.
     * 
     * @return
     *   The Update Sequence Number for this change within the account.
     * 
     * @throws EDAMUserException <ul>
     *   <li> PERMISSION_DENIED "Note" - user doesn't own
     *   </li>
     * </ul>
     * 
     * @throws EDAMNotFoundException <ul>
     *   <li> "Note.guid" - not found, by GUID
     *   </li>
     * </ul>
     * 
     * @param authenticationToken
     * @param guid
     */
    public int expungeNote(String authenticationToken, String guid) throws com.evernote.edam.error.EDAMUserException, com.evernote.edam.error.EDAMSystemException, com.evernote.edam.error.EDAMNotFoundException, TException;

    /**
     * Permanently removes a list of Notes, and all of their Resources, from
     * the service.  This should be invoked with a small number of Note GUIDs
     * (e.g. 100 or less) on each call.  To expunge a larger number of notes,
     * call this method multiple times.  This should also be used to reduce the
     * number of Notes in a notebook before calling expungeNotebook() or
     * in the trash before calling expungeInactiveNotes(), since these calls may
     * be prohibitively slow if there are more than a few hundred notes.
     * If an exception is thrown for any of the GUIDs, then none of the notes
     * will be deleted.  I.e. this call can be treated as an atomic transaction.
     * 
     * @param noteGuids
     *   The list of GUIDs for the Notes to remove.
     * 
     * @return
     *   The account's updateCount at the end of this operation
     * 
     * @throws EDAMUserException <ul>
     *   <li> PERMISSION_DENIED "Note" - user doesn't own
     *   </li>
     * </ul>
     * 
     * @throws EDAMNotFoundException <ul>
     *   <li> "Note.guid" - not found, by GUID
     *   </li>
     * </ul>
     * 
     * @param authenticationToken
     * @param noteGuids
     */
    public int expungeNotes(String authenticationToken, List<String> noteGuids) throws com.evernote.edam.error.EDAMUserException, com.evernote.edam.error.EDAMSystemException, com.evernote.edam.error.EDAMNotFoundException, TException;

    /**
     * Permanently removes all of the Notes that are currently marked as
     * inactive.  This is equivalent to "emptying the trash", and these Notes
     * will be gone permanently.
     * <p/>
     * This operation may be relatively slow if the account contains a large
     * number of inactive Notes.
     * 
     * @return
     *    The number of notes that were expunged.
     * 
     * @param authenticationToken
     */
    public int expungeInactiveNotes(String authenticationToken) throws com.evernote.edam.error.EDAMUserException, com.evernote.edam.error.EDAMSystemException, TException;

    /**
     * Performs a deep copy of the Note with the provided GUID 'noteGuid' into
     * the Notebook with the provided GUID 'toNotebookGuid'.
     * The caller must be the owner of both the Note and the Notebook.
     * This creates a new Note in the destination Notebook with new content and
     * Resources that match all of the content and Resources from the original
     * Note, but with new GUID identifiers.
     * The original Note is not modified by this operation.
     * The copied note is considered as an "upload" for the purpose of upload
     * transfer limit calculation, so its size is added to the upload count for
     * the owner.
     * 
     * @param noteGuid
     *   The GUID of the Note to copy.
     * 
     * @param toNotebookGuid
     *   The GUID of the Notebook that should receive the new Note.
     * 
     * @return
     *   The metadata for the new Note that was created.  This will include the
     *   new GUID for this Note (and any copied Resources), but will not include
     *   the content body or the binary bodies of any Resources.
     * 
     * @throws EDAMUserException <ul>
     *   <li> LIMIT_REACHED "Note" - at max number per account
     *   </li>
     *   <li> PERMISSION_DENIED "Notebook.guid" - destination not owned by user
     *   </li>
     *   <li> PERMISSION_DENIED "Note" - user doesn't own
     *   </li>
     *   <li> QUOTA_REACHED "Accounting.uploadLimit" - note exceeds upload quota
     *   </li>
     * </ul>
     * 
     * @throws EDAMNotFoundException <ul>
     *   <li> "Notebook.guid" - not found, by GUID
     *   </li>
     * </ul>
     * 
     * @param authenticationToken
     * @param noteGuid
     * @param toNotebookGuid
     */
    public com.evernote.edam.type.Note copyNote(String authenticationToken, String noteGuid, String toNotebookGuid) throws com.evernote.edam.error.EDAMUserException, com.evernote.edam.error.EDAMSystemException, com.evernote.edam.error.EDAMNotFoundException, TException;

    /**
     * Returns a list of the prior versions of a particular note that are
     * saved within the service.  These prior versions are stored to provide a
     * recovery from unintentional removal of content from a note. The identifiers
     * that are returned by this call can be used with getNoteVersion to retrieve
     * the previous note.
     * 
     * @throws EDAMUserException <ul>
     *   <li> BAD_DATA_FORMAT "Note.guid" - if the parameter is missing
     *   </li>
     *   <li> PERMISSION_DENIED "Note" - private note, user doesn't own
     *   </li>
     * </ul>
     * 
     * @throws EDAMNotFoundException <ul>
     *   <li> "Note.guid" - not found, by GUID
     *   </li>
     * </ul>
     * 
     * @param authenticationToken
     * @param noteGuid
     */
    public List<NoteVersionId> listNoteVersions(String authenticationToken, String noteGuid) throws com.evernote.edam.error.EDAMUserException, com.evernote.edam.error.EDAMSystemException, com.evernote.edam.error.EDAMNotFoundException, TException;

    /**
     * This can be used to retrieve a previous version of a Note after it has been
     * updated within the service.  The caller must identify the note (via its
     * guid) and the version (via the updateSequenceNumber of that version).
     * to find a listing of the stored version USNs for a note, call
     * listNoteVersions.
     * This call is only available for notes in Premium accounts.  (I.e. access
     * to past versions of Notes is a Premium-only feature.)
     * 
     * @param guid
     *   The GUID of the note to be retrieved.
     * 
     * @param updateSequenceNum
     *   The USN of the version of the note that is being retrieved
     * 
     * @param withResourcesData
     *   If true, any Resource elements in this Note will include the binary
     *   contents of their 'data' field's body.
     * 
     * @param withResourcesRecognition
     *   If true, any Resource elements will include the binary contents of the
     *   'recognition' field's body if recognition data is present.
     * 
     * @param withResourcesAlternateData
     *   If true, any Resource elements in this Note will include the binary
     *   contents of their 'alternateData' fields' body, if an alternate form
     *   is present.
     * 
     * @throws EDAMUserException <ul>
     *   <li> BAD_DATA_FORMAT "Note.guid" - if the parameter is missing
     *   </li>
     *   <li> PERMISSION_DENIED "Note" - private note, user doesn't own
     *   </li>
     *   <li> PERMISSION_DENIED "updateSequenceNum" -
     *     The account isn't permitted to access previous versions of notes.
     *     (i.e. this is a Free account.)
     *   </li>
     * </ul>
     * 
     * @throws EDAMNotFoundException <ul>
     *   <li> "Note.guid" - not found, by GUID
     *   </li>
     *   <li> "Note.updateSequenceNumber" - the Note doesn't have a version with
     *      the corresponding USN.
     *   </li>
     * </ul>
     * 
     * @param authenticationToken
     * @param noteGuid
     * @param updateSequenceNum
     * @param withResourcesData
     * @param withResourcesRecognition
     * @param withResourcesAlternateData
     */
    public com.evernote.edam.type.Note getNoteVersion(String authenticationToken, String noteGuid, int updateSequenceNum, boolean withResourcesData, boolean withResourcesRecognition, boolean withResourcesAlternateData) throws com.evernote.edam.error.EDAMUserException, com.evernote.edam.error.EDAMSystemException, com.evernote.edam.error.EDAMNotFoundException, TException;

    /**
     * Returns the current state of the resource in the service with the
     * provided GUID.
     * If the Resource is found in a public notebook, the authenticationToken
     * will be ignored (so it could be an empty string).
     * 
     * @param guid
     *   The GUID of the resource to be retrieved.
     * 
     * @param withData
     *   If true, the Resource will include the binary contents of the
     *   'data' field's body.
     * 
     * @param withRecognition
     *   If true, the Resource will include the binary contents of the
     *   'recognition' field's body if recognition data is present.
     * 
     * @param withAttributes
     *   If true, the Resource will include the attributes
     * 
     * @param withAlternateData
     *   If true, the Resource will include the binary contents of the
     *   'alternateData' field's body, if an alternate form is present.
     * 
     * @throws EDAMUserException <ul>
     *   <li> BAD_DATA_FORMAT "Resource.guid" - if the parameter is missing
     *   </li>
     *   <li> PERMISSION_DENIED "Resource" - private resource, user doesn't own
     *   </li>
     * </ul>
     * 
     * @throws EDAMNotFoundException <ul>
     *   <li> "Resource.guid" - not found, by GUID
     *   </li>
     * </ul>
     * 
     * @param authenticationToken
     * @param guid
     * @param withData
     * @param withRecognition
     * @param withAttributes
     * @param withAlternateData
     */
    public com.evernote.edam.type.Resource getResource(String authenticationToken, String guid, boolean withData, boolean withRecognition, boolean withAttributes, boolean withAlternateData) throws com.evernote.edam.error.EDAMUserException, com.evernote.edam.error.EDAMSystemException, com.evernote.edam.error.EDAMNotFoundException, TException;

    /**
     * Submit a set of changes to a resource to the service.  This can be used
     * to update the meta-data about the resource, but cannot be used to change
     * the binary contents of the resource (including the length and hash).  These
     * cannot be changed directly without creating a new resource and removing the
     * old one via updateNote.
     * 
     * @param resource
     *   A Resource object containing the desired fields to be populated on
     *   the service.  The service will attempt to update the resource with the
     *   following fields from the client:
     *   <ul>
     *      <li>guid:  must be provided to identify the resource
     *      </li>
     *      <li>mime
     *      </li>
     *      <li>width
     *      </li>
     *      <li>height
     *      </li>
     *      <li>duration
     *      </li>
     *      <li>recognition:  if this is provided, it must include the
     *          data body for the resource recognition index data and the
     *          recoFormat must be provided.  If absent,
     *          the recognition on the server won't be changed.
     *      </li>
     *      <li>attributes:  optional.  if present, the set of attributes will
     *           be replaced.
     *      </li>
     *   </ul>
     * 
     * @return
     *   The Update Sequence Number of the resource after the changes have been
     *   applied.
     * 
     * @throws EDAMUserException <ul>
     *   <li> BAD_DATA_FORMAT "Resource.guid" - if the parameter is missing
     *   </li>
     *   <li> BAD_DATA_FORMAT "Resource.mime" - invalid resource MIME type
     *   </li>
     *   <li> BAD_DATA_FORMAT "ResourceAttributes.*" - bad resource string
     *   </li>
     *   <li> DATA_REQUIRED "Resource.data" - resource data body missing
     *   </li>
     *   <li> LIMIT_REACHED "ResourceAttribute.*" - attribute string too long
     *   </li>
     *   <li> PERMISSION_DENIED "Resource" - private resource, user doesn't own
     *   </li>
     * </ul>
     * 
     * @throws EDAMNotFoundException <ul>
     *   <li> "Resource.guid" - not found, by GUID
     *   </li>
     * </ul>
     * 
     * @param authenticationToken
     * @param resource
     */
    public int updateResource(String authenticationToken, com.evernote.edam.type.Resource resource) throws com.evernote.edam.error.EDAMUserException, com.evernote.edam.error.EDAMSystemException, com.evernote.edam.error.EDAMNotFoundException, TException;

    /**
     * Returns binary data of the resource with the provided GUID.  For
     * example, if this were an image resource, this would contain the
     * raw bits of the image.
     * If the Resource is found in a public notebook, the authenticationToken
     * will be ignored (so it could be an empty string).
     * 
     * @param guid
     *   The GUID of the resource to be retrieved.
     * 
     * @throws EDAMUserException <ul>
     *   <li> BAD_DATA_FORMAT "Resource.guid" - if the parameter is missing
     *   </li>
     *   <li> PERMISSION_DENIED "Resource" - private resource, user doesn't own
     *   </li>
     * </ul>
     * 
     * @throws EDAMNotFoundException <ul>
     *   <li> "Resource.guid" - not found, by GUID
     *   </li>
     * </ul>
     * 
     * @param authenticationToken
     * @param guid
     */
    public byte[] getResourceData(String authenticationToken, String guid) throws com.evernote.edam.error.EDAMUserException, com.evernote.edam.error.EDAMSystemException, com.evernote.edam.error.EDAMNotFoundException, TException;

    /**
     * Returns the current state of a resource, referenced by containing
     * note GUID and resource content hash.
     * 
     * @param noteGuid
     *   The GUID of the note that holds the resource to be retrieved.
     * 
     * @param contentHash
     *   The MD5 checksum of the resource within that note.
     * 
     * @param withData
     *   If true, the Resource will include the binary contents of the
     *   'data' field's body.
     * 
     * @param withRecognition
     *   If true, the Resource will include the binary contents of the
     *   'recognition' field's body.
     *   
     * @param withAlternateData
     *   If true, the Resource will include the binary contents of the
     *   'alternateData' field's body, if an alternate form is present.
     * 
     * @throws EDAMUserException <ul>
     *   <li> DATA_REQUIRED "Note.guid" - noteGuid param missing
     *   </li>
     *   <li> DATA_REQUIRED "Note.contentHash" - contentHash param missing
     *   </li>
     *   <li> PERMISSION_DENIED "Resource" - private resource, user doesn't own
     *   </li>
     * </ul>
     * 
     * @throws EDAMNotFoundException <ul>
     *   <li> "Note" - not found, by guid
     *   </li>
     *   <li> "Resource" - not found, by hash
     *   </li>
     * </ul>
     * 
     * @param authenticationToken
     * @param noteGuid
     * @param contentHash
     * @param withData
     * @param withRecognition
     * @param withAlternateData
     */
    public com.evernote.edam.type.Resource getResourceByHash(String authenticationToken, String noteGuid, byte[] contentHash, boolean withData, boolean withRecognition, boolean withAlternateData) throws com.evernote.edam.error.EDAMUserException, com.evernote.edam.error.EDAMSystemException, com.evernote.edam.error.EDAMNotFoundException, TException;

    /**
     * Returns the binary contents of the recognition index for the resource
     * with the provided GUID.  If the caller asks about a resource that has
     * no recognition data, this will throw EDAMNotFoundException.
     * If the Resource is found in a public notebook, the authenticationToken
     * will be ignored (so it could be an empty string).
     * 
     * @param guid
     *   The GUID of the resource whose recognition data should be retrieved.
     * 
     * @throws EDAMUserException <ul>
     *   <li> BAD_DATA_FORMAT "Resource.guid" - if the parameter is missing
     *   </li>
     *   <li> PERMISSION_DENIED "Resource" - private resource, user doesn't own
     *   </li>
     * </ul>
     * 
     * @throws EDAMNotFoundException <ul>
     *   <li> "Resource.guid" - not found, by GUID
     *   </li>
     *   <li> "Resource.recognition" - resource has no recognition
     *   </li>
     * </ul>
     * 
     * @param authenticationToken
     * @param guid
     */
    public byte[] getResourceRecognition(String authenticationToken, String guid) throws com.evernote.edam.error.EDAMUserException, com.evernote.edam.error.EDAMSystemException, com.evernote.edam.error.EDAMNotFoundException, TException;

    /**
     * If the Resource with the provided GUID has an alternate data representation
     * (indicated via the Resource.alternateData field), then this request can
     * be used to retrieve the binary contents of that alternate data file.
     * If the caller asks about a resource that has no alternate data form, this
     * will throw EDAMNotFoundException.
     * 
     * @param guid
     *    The GUID of the resource whose recognition data should be retrieved.
     * 
     * @throws EDAMUserException <ul>
     *   <li> BAD_DATA_FORMAT "Resource.guid" - if the parameter is missing
     *   </li>
     *   <li> PERMISSION_DENIED "Resource" - private resource, user doesn't own
     *   </li>
     * </ul>
     * 
     * @throws EDAMNotFoundException <ul>
     *   <li> "Resource.guid" - not found, by GUID
     *   </li>
     *   <li> "Resource.alternateData" - resource has no recognition
     *   </li>
     * </ul>
     * 
     * @param authenticationToken
     * @param guid
     */
    public byte[] getResourceAlternateData(String authenticationToken, String guid) throws com.evernote.edam.error.EDAMUserException, com.evernote.edam.error.EDAMSystemException, com.evernote.edam.error.EDAMNotFoundException, TException;

    /**
     * Returns the set of attributes for the Resource with the provided GUID.
     * If the Resource is found in a public notebook, the authenticationToken
     * will be ignored (so it could be an empty string).
     * 
     * @param guid
     *   The GUID of the resource whose attributes should be retrieved.
     * 
     * @throws EDAMUserException <ul>
     *   <li> BAD_DATA_FORMAT "Resource.guid" - if the parameter is missing
     *   </li>
     *   <li> PERMISSION_DENIED "Resource" - private resource, user doesn't own
     *   </li>
     * </ul>
     * 
     * @throws EDAMNotFoundException <ul>
     *   <li> "Resource.guid" - not found, by GUID
     *   </li>
     * </ul>
     * 
     * @param authenticationToken
     * @param guid
     */
    public com.evernote.edam.type.ResourceAttributes getResourceAttributes(String authenticationToken, String guid) throws com.evernote.edam.error.EDAMUserException, com.evernote.edam.error.EDAMSystemException, com.evernote.edam.error.EDAMNotFoundException, TException;

    /**
     * @deprecated -
     *   This function is deprecated, and should no longer be used.  This will
     *   always return a value of '0'.
     * 
     * @param authenticationToken
     */
    public long getAccountSize(String authenticationToken) throws com.evernote.edam.error.EDAMUserException, com.evernote.edam.error.EDAMSystemException, TException;

    /**
     * Clients should make this call once per day to receive a bundle of ads that
     * will be displayed for the subsequent 24 hour period.
     * 
     * @param adParameters
     *   A set of parameters that help the service determine which ads to return.
     * 
     * @param authenticationToken
     * @param adParameters
     */
    public List<com.evernote.edam.type.Ad> getAds(String authenticationToken, AdParameters adParameters) throws com.evernote.edam.error.EDAMUserException, com.evernote.edam.error.EDAMSystemException, TException;

    /**
     * A thin client should make this call to retrieve a single random ad for
     * immediate display.
     * 
     * @param adParameters
     *   A set of parameters to help the service determine which ad to return.
     *   The 'impression' field should either be absent (if no ads have been
     *   displayed previously), or else it should contain the identifier for
     *   the most recently-displayed ad so that the service can give a different
     *   ad.
     * 
     * @param authenticationToken
     * @param adParameters
     */
    public com.evernote.edam.type.Ad getRandomAd(String authenticationToken, AdParameters adParameters) throws com.evernote.edam.error.EDAMUserException, com.evernote.edam.error.EDAMSystemException, TException;

    /**
     * Looks for a user account with the provided userId on this NoteStore
     * shard and determines whether that account contains a public notebook
     * with the given URI.  If the account is not found, or no public notebook
     * exists with this URI, this will throw an EDAMNotFoundException,
     * otherwise this will return the information for that Notebook.
     * 
     * @throws EDAMNotFoundException <ul>
     *   <li> "Publishing.uri" - not found, by URI
     *   </li>
     * </ul>
     * 
     * @param userId
     * @param publicUri
     */
    public com.evernote.edam.type.Notebook getPublicNotebook(int userId, String publicUri) throws com.evernote.edam.error.EDAMSystemException, com.evernote.edam.error.EDAMNotFoundException, TException;

    /**
     * Used to construct a shared notebook object. The constructed notebook will
     * contain a "share key" which serve as a unique identifer and access token
     * for a user to access the notebook of the shared notebook owner.
     * 
     * @param sharedNotebook
     *   An shared notebook object populated with the email address of the share
     *   recipient, the notebook guid and the access permissions. All other
     *   attributes of the shared object are ignored.
     * @return
     *   The fully populated SharedNotebook object including the server assigned
     *   share id and shareKey which can both the used to uniquely identify the
     *   SharedNotebook.
     * 
     * @throws EDAMUserException <ul>
     *   <li> BAD_DATA_FORMAT "SharedNotebook.email" - if the  email was not valid
     *   </li>
     *   </ul>
     * @throws EDAMNotFoundException <ul>
     *   <li> Notebook.guid - if the notebookGuid is not a valid guid for the user
     *   </li>
     *   </ul>
     * 
     * @param authenticationToken
     * @param sharedNotebook
     */
    public com.evernote.edam.type.SharedNotebook createSharedNotebook(String authenticationToken, com.evernote.edam.type.SharedNotebook sharedNotebook) throws com.evernote.edam.error.EDAMUserException, com.evernote.edam.error.EDAMNotFoundException, com.evernote.edam.error.EDAMSystemException, TException;

    /**
     * Lists the collection of shared notebooks for all notebooks in the
     * users account.
     * 
     * @return
     *  The list of all SharedNotebooks for the user
     * 
     * @param authenticationToken
     */
    public List<com.evernote.edam.type.SharedNotebook> listSharedNotebooks(String authenticationToken) throws com.evernote.edam.error.EDAMUserException, com.evernote.edam.error.EDAMNotFoundException, com.evernote.edam.error.EDAMSystemException, TException;

    /**
     * Expunges the SharedNotebooks in the user's account using the
     * SharedNotebook.id as the identifier.
     * @param
     *   sharedNotebookIds - a list of ShardNotebook.id longs identifying the
     *       objects to delete permanently.
     * @return
     *   The account's update sequence number.
     * 
     * @param authenticationToken
     * @param sharedNotebookIds
     */
    public int expungeSharedNotebooks(String authenticationToken, List<Long> sharedNotebookIds) throws com.evernote.edam.error.EDAMUserException, com.evernote.edam.error.EDAMNotFoundException, com.evernote.edam.error.EDAMSystemException, TException;

    /**
     * Asks the service to make a linked notebook with the provided name, username
     * of the owner and identifiers provided. A linked notebook can be either a
     * link to a public notebook or to a private shared notebook.
     * 
     * @param linkedNotebook
     *   The desired fields for the linked notebook must be provided on this
     *   object.  The name of the linked notebook must be set. Either a username
     *   uri or a shard id and share key must be provided otherwise a
     *   EDAMUserException is thrown.
     * 
     * @return
     *   The newly created LinkedNotebook.  The server-side id will be
     *   saved in this object's 'id' field.
     * 
     * @throws EDAMUserException <ul>
     *   <li> BAD_DATA_FORMAT "LinkedNotebook.name" - invalid length or pattern
     *   </li>
     *   <li> BAD_DATA_FORMAT "LinkedNotebook.username" - bad username format
     *   </li>
     *   <li> BAD_DATA_FORMAT "LinkedNotebook.uri" -
     *     if public notebook set but bad uri
     *   </li>
     *   <li> BAD_DATA_FORMAT "LinkedNotebook.shareKey" -
     *     if private notebook set but bad shareKey
     *   </li>
     *   <li> DATA_REQUIRED "LinkedNotebook.shardId" -
     *     if private notebook but shard id not provided
     *   </li>
     * </ul>
     * 
     * @param authenticationToken
     * @param linkedNotebook
     */
    public com.evernote.edam.type.LinkedNotebook createLinkedNotebook(String authenticationToken, com.evernote.edam.type.LinkedNotebook linkedNotebook) throws com.evernote.edam.error.EDAMUserException, com.evernote.edam.error.EDAMNotFoundException, com.evernote.edam.error.EDAMSystemException, TException;

    /**
     * @param linkedNotebook
     *   Updates the name of a linked notebook.
     * 
     * @throws EDAMUserException <ul>
     *   <li> BAD_DATA_FORMAT "LinkedNotebook.name" - invalid length or pattern
     *   </li>
     * </ul>
     * 
     * @param authenticationToken
     * @param linkedNotebook
     */
    public com.evernote.edam.type.LinkedNotebook updateLinkedNotebook(String authenticationToken, com.evernote.edam.type.LinkedNotebook linkedNotebook) throws com.evernote.edam.error.EDAMUserException, com.evernote.edam.error.EDAMNotFoundException, com.evernote.edam.error.EDAMSystemException, TException;

    /**
     * Returns a list of linked notebooks
     * 
     * @param authenticationToken
     */
    public List<com.evernote.edam.type.LinkedNotebook> listLinkedNotebooks(String authenticationToken) throws com.evernote.edam.error.EDAMUserException, com.evernote.edam.error.EDAMNotFoundException, com.evernote.edam.error.EDAMSystemException, TException;

    /**
     * Permanently expunges the linked notebook from the account.
     * 
     * @param linkedNotebookId
     *   The LinkedNotebook.id field of the LinkedNotebook to permanently remove
     *   from the account.
     * 
     * @param authenticationToken
     * @param linkedNotebookId
     */
    public int expungeLinkedNotebook(String authenticationToken, long linkedNotebookId) throws com.evernote.edam.error.EDAMUserException, com.evernote.edam.error.EDAMNotFoundException, com.evernote.edam.error.EDAMSystemException, TException;

    /**
     * Asks the service to produce an authentication token that can be used to
     * access the contents of a shared notebook from someone else's account.
     * This authenticationToken can be used with the various other NoteStore
     * calls to find and retrieve notes, and if the permissions in the shared
     * notebook are sufficient, to make changes to the contents of the notebook.
     * 
     * @param shareKey
     *   The 'shareKey' identifier from the SharedNotebook that was granted to
     *   some recipient.  This string internally encodes the notebook identifier
     *   and a security signature.
     * 
     * @param authenticationToken
     *   If a non-empty string is provided, this is the full user-based
     *   authentication token that identifies the user who is currently logged in
     *   and trying to access the shared notebook.  This may be required if the
     *   notebook was created with 'requireLogin'.
     *   If this string is empty, the service will attempt to authenticate to the
     *   shared notebook without any logged in user.
     * 
     * @throws EDAMSystemException <ul>
     *   <li> BAD_DATA_FORMAT "shareKey" - invalid shareKey string
     *   </li>
     *   <li> INVALID_AUTH "shareKey" - bad signature on shareKey string
     *   </li>
     *   <li> SHARD_UNAVAILABLE - Request went to the wrong shard
     *   </li>
     * </ul>
     * 
     * @throws EDAMNotFoundException <ul>
     *   <li> "SharedNotebook.id" - the shared notebook no longer exists
     *   </li>
     * </ul>
     * 
     * @throws EDAMUserException <ul>
     *   <li> DATA_REQUIRED "authenticationToken" - the share requires login, and
     *          no valid authentication token was provided.
     *   </li>
     *   <li> PERMISSION_DENIED "SharedNotebook.username" - share requires login,
     *          and another username has already been bound to this notebook.
     *   </li>
     * </ul>
     * 
     * @param shareKey
     * @param authenticationToken
     */
    public com.evernote.edam.userstore.AuthenticationResult authenticateToSharedNotebook(String shareKey, String authenticationToken) throws com.evernote.edam.error.EDAMUserException, com.evernote.edam.error.EDAMNotFoundException, com.evernote.edam.error.EDAMSystemException, TException;

    /**
     * This function is used to retrieve extended information about a shared
     * notebook by a guest who has already authenticated to access that notebook.
     * This requires an 'authenticationToken' parameter which should be the
     * resut of a call to authenticateToSharedNotebook(...).
     * I.e. this is the token that gives access to the particular shared notebook
     * in someone else's account -- it's not the authenticationToken for the
     * owner of the notebook itself.
     * 
     * @param authenticationToken
     *   Should be the authentication token retrieved from the reply of
     *   authenticateToSharedNotebook(), proving access to a particular shared
     *   notebook.
     * 
     * @throws EDAMUserException <ul>
     *   <li> PERMISSION_DENIED "authenticationToken" -
     *          authentication token doesn't correspond to a valid shared notebook
     *   </li>
     * </ul>
     * 
     * @throws EDAMNotFoundException <ul>
     *   <li> "SharedNotebook.id" - the shared notebook no longer exists
     *   </li>
     * </ul>
     * 
     * @param authenticationToken
     */
    public com.evernote.edam.type.SharedNotebook getSharedNotebookByAuth(String authenticationToken) throws com.evernote.edam.error.EDAMUserException, com.evernote.edam.error.EDAMNotFoundException, com.evernote.edam.error.EDAMSystemException, TException;

    /**
     * Attempts to send a single note to one or more email recipients.
     * 
     * @param authenticationToken
     *    The note will be sent as the user logged in via this token, using that
     *    user's registered email address.  If the authenticated user doesn't
     *    have permission to read that note, the emailing will fail.
     * 
     * @param parameters
     *    The note must be specified either by GUID (in which case it will be
     *    sent using the existing data in the service), or else the full Note
     *    must be passed to this call.  This also specifies the additional
     *    email fields that will be used in the email.
     * 
     * @throws EDAMUserException <ul>
     *   <li> LIMIT_REACHED "NoteEmailParameters.toAddresses" -
     *     The email can't be sent because this would exceed the user's daily
     *     email limit.
     *   </li>
     *   <li> BAD_DATA_FORMAT "(email address)" -
     *     email address malformed
     *   </li>
     *   <li> DATA_REQUIRED "NoteEmailParameters.toAddresses" -
     *     if there are no To: or Cc: addresses provided.
     *   </li>
     *   <li> DATA_REQUIRED "Note.title" -
     *     if the caller provides a Note parameter with no title
     *   </li>
     *   <li> DATA_REQUIRED "Note.content" -
     *     if the caller provides a Note parameter with no content
     *   </li>
     *   <li> DATA_REQUIRED "NoteEmailParameters.note" -
     *     if no guid or note provided
     *   </li>
     *   <li> PERMISSION_DENIED "Note" - private note, user doesn't own
     *   </li>
     * </ul>
     * 
     * @throws EDAMNotFoundException <ul>
     *   <li> "Note.guid" - not found, by GUID
     *   </li>
     * </ul>
     * 
     * @param authenticationToken
     * @param parameters
     */
    public void emailNote(String authenticationToken, NoteEmailParameters parameters) throws com.evernote.edam.error.EDAMUserException, com.evernote.edam.error.EDAMNotFoundException, com.evernote.edam.error.EDAMSystemException, TException;

  }

  public static class Client implements Iface {
    public Client(TProtocol prot)
    {
      this(prot, prot);
    }

    public Client(TProtocol iprot, TProtocol oprot)
    {
      iprot_ = iprot;
      oprot_ = oprot;
    }

    protected TProtocol iprot_;
    protected TProtocol oprot_;

    protected int seqid_;

    public TProtocol getInputProtocol()
    {
      return this.iprot_;
    }

    public TProtocol getOutputProtocol()
    {
      return this.oprot_;
    }

    public SyncState getSyncState(String authenticationToken) throws com.evernote.edam.error.EDAMUserException, com.evernote.edam.error.EDAMSystemException, TException
    {
      send_getSyncState(authenticationToken);
      return recv_getSyncState();
    }

    public void send_getSyncState(String authenticationToken) throws TException
    {
      oprot_.writeMessageBegin(new TMessage("getSyncState", TMessageType.CALL, seqid_));
      getSyncState_args args = new getSyncState_args();
      args.authenticationToken = authenticationToken;
      args.write(oprot_);
      oprot_.writeMessageEnd();
      oprot_.getTransport().flush();
    }

    public SyncState recv_getSyncState() throws com.evernote.edam.error.EDAMUserException, com.evernote.edam.error.EDAMSystemException, TException
    {
      TMessage msg = iprot_.readMessageBegin();
      if (msg.type == TMessageType.EXCEPTION) {
        TApplicationException x = TApplicationException.read(iprot_);
        iprot_.readMessageEnd();
        throw x;
      }
      getSyncState_result result = new getSyncState_result();
      result.read(iprot_);
      iprot_.readMessageEnd();
      if (result.isSetSuccess()) {
        return result.success;
      }
      if (result.userException != null) {
        throw result.userException;
      }
      if (result.systemException != null) {
        throw result.systemException;
      }
      throw new TApplicationException(TApplicationException.MISSING_RESULT, "getSyncState failed: unknown result");
    }

    public SyncChunk getSyncChunk(String authenticationToken, int afterUSN, int maxEntries, boolean fullSyncOnly) throws com.evernote.edam.error.EDAMUserException, com.evernote.edam.error.EDAMSystemException, TException
    {
      send_getSyncChunk(authenticationToken, afterUSN, maxEntries, fullSyncOnly);
      return recv_getSyncChunk();
    }

    public void send_getSyncChunk(String authenticationToken, int afterUSN, int maxEntries, boolean fullSyncOnly) throws TException
    {
      oprot_.writeMessageBegin(new TMessage("getSyncChunk", TMessageType.CALL, seqid_));
      getSyncChunk_args args = new getSyncChunk_args();
      args.authenticationToken = authenticationToken;
      args.afterUSN = afterUSN;
      args.maxEntries = maxEntries;
      args.fullSyncOnly = fullSyncOnly;
      args.write(oprot_);
      oprot_.writeMessageEnd();
      oprot_.getTransport().flush();
    }

    public SyncChunk recv_getSyncChunk() throws com.evernote.edam.error.EDAMUserException, com.evernote.edam.error.EDAMSystemException, TException
    {
      TMessage msg = iprot_.readMessageBegin();
      if (msg.type == TMessageType.EXCEPTION) {
        TApplicationException x = TApplicationException.read(iprot_);
        iprot_.readMessageEnd();
        throw x;
      }
      getSyncChunk_result result = new getSyncChunk_result();
      result.read(iprot_);
      iprot_.readMessageEnd();
      if (result.isSetSuccess()) {
        return result.success;
      }
      if (result.userException != null) {
        throw result.userException;
      }
      if (result.systemException != null) {
        throw result.systemException;
      }
      throw new TApplicationException(TApplicationException.MISSING_RESULT, "getSyncChunk failed: unknown result");
    }

    public List<com.evernote.edam.type.Notebook> listNotebooks(String authenticationToken) throws com.evernote.edam.error.EDAMUserException, com.evernote.edam.error.EDAMSystemException, TException
    {
      send_listNotebooks(authenticationToken);
      return recv_listNotebooks();
    }

    public void send_listNotebooks(String authenticationToken) throws TException
    {
      oprot_.writeMessageBegin(new TMessage("listNotebooks", TMessageType.CALL, seqid_));
      listNotebooks_args args = new listNotebooks_args();
      args.authenticationToken = authenticationToken;
      args.write(oprot_);
      oprot_.writeMessageEnd();
      oprot_.getTransport().flush();
    }

    public List<com.evernote.edam.type.Notebook> recv_listNotebooks() throws com.evernote.edam.error.EDAMUserException, com.evernote.edam.error.EDAMSystemException, TException
    {
      TMessage msg = iprot_.readMessageBegin();
      if (msg.type == TMessageType.EXCEPTION) {
        TApplicationException x = TApplicationException.read(iprot_);
        iprot_.readMessageEnd();
        throw x;
      }
      listNotebooks_result result = new listNotebooks_result();
      result.read(iprot_);
      iprot_.readMessageEnd();
      if (result.isSetSuccess()) {
        return result.success;
      }
      if (result.userException != null) {
        throw result.userException;
      }
      if (result.systemException != null) {
        throw result.systemException;
      }
      throw new TApplicationException(TApplicationException.MISSING_RESULT, "listNotebooks failed: unknown result");
    }

    public com.evernote.edam.type.Notebook getNotebook(String authenticationToken, String guid) throws com.evernote.edam.error.EDAMUserException, com.evernote.edam.error.EDAMSystemException, com.evernote.edam.error.EDAMNotFoundException, TException
    {
      send_getNotebook(authenticationToken, guid);
      return recv_getNotebook();
    }

    public void send_getNotebook(String authenticationToken, String guid) throws TException
    {
      oprot_.writeMessageBegin(new TMessage("getNotebook", TMessageType.CALL, seqid_));
      getNotebook_args args = new getNotebook_args();
      args.authenticationToken = authenticationToken;
      args.guid = guid;
      args.write(oprot_);
      oprot_.writeMessageEnd();
      oprot_.getTransport().flush();
    }

    public com.evernote.edam.type.Notebook recv_getNotebook() throws com.evernote.edam.error.EDAMUserException, com.evernote.edam.error.EDAMSystemException, com.evernote.edam.error.EDAMNotFoundException, TException
    {
      TMessage msg = iprot_.readMessageBegin();
      if (msg.type == TMessageType.EXCEPTION) {
        TApplicationException x = TApplicationException.read(iprot_);
        iprot_.readMessageEnd();
        throw x;
      }
      getNotebook_result result = new getNotebook_result();
      result.read(iprot_);
      iprot_.readMessageEnd();
      if (result.isSetSuccess()) {
        return result.success;
      }
      if (result.userException != null) {
        throw result.userException;
      }
      if (result.systemException != null) {
        throw result.systemException;
      }
      if (result.notFoundException != null) {
        throw result.notFoundException;
      }
      throw new TApplicationException(TApplicationException.MISSING_RESULT, "getNotebook failed: unknown result");
    }

    public com.evernote.edam.type.Notebook getDefaultNotebook(String authenticationToken) throws com.evernote.edam.error.EDAMUserException, com.evernote.edam.error.EDAMSystemException, TException
    {
      send_getDefaultNotebook(authenticationToken);
      return recv_getDefaultNotebook();
    }

    public void send_getDefaultNotebook(String authenticationToken) throws TException
    {
      oprot_.writeMessageBegin(new TMessage("getDefaultNotebook", TMessageType.CALL, seqid_));
      getDefaultNotebook_args args = new getDefaultNotebook_args();
      args.authenticationToken = authenticationToken;
      args.write(oprot_);
      oprot_.writeMessageEnd();
      oprot_.getTransport().flush();
    }

    public com.evernote.edam.type.Notebook recv_getDefaultNotebook() throws com.evernote.edam.error.EDAMUserException, com.evernote.edam.error.EDAMSystemException, TException
    {
      TMessage msg = iprot_.readMessageBegin();
      if (msg.type == TMessageType.EXCEPTION) {
        TApplicationException x = TApplicationException.read(iprot_);
        iprot_.readMessageEnd();
        throw x;
      }
      getDefaultNotebook_result result = new getDefaultNotebook_result();
      result.read(iprot_);
      iprot_.readMessageEnd();
      if (result.isSetSuccess()) {
        return result.success;
      }
      if (result.userException != null) {
        throw result.userException;
      }
      if (result.systemException != null) {
        throw result.systemException;
      }
      throw new TApplicationException(TApplicationException.MISSING_RESULT, "getDefaultNotebook failed: unknown result");
    }

    public com.evernote.edam.type.Notebook createNotebook(String authenticationToken, com.evernote.edam.type.Notebook notebook) throws com.evernote.edam.error.EDAMUserException, com.evernote.edam.error.EDAMSystemException, TException
    {
      send_createNotebook(authenticationToken, notebook);
      return recv_createNotebook();
    }

    public void send_createNotebook(String authenticationToken, com.evernote.edam.type.Notebook notebook) throws TException
    {
      oprot_.writeMessageBegin(new TMessage("createNotebook", TMessageType.CALL, seqid_));
      createNotebook_args args = new createNotebook_args();
      args.authenticationToken = authenticationToken;
      args.notebook = notebook;
      args.write(oprot_);
      oprot_.writeMessageEnd();
      oprot_.getTransport().flush();
    }

    public com.evernote.edam.type.Notebook recv_createNotebook() throws com.evernote.edam.error.EDAMUserException, com.evernote.edam.error.EDAMSystemException, TException
    {
      TMessage msg = iprot_.readMessageBegin();
      if (msg.type == TMessageType.EXCEPTION) {
        TApplicationException x = TApplicationException.read(iprot_);
        iprot_.readMessageEnd();
        throw x;
      }
      createNotebook_result result = new createNotebook_result();
      result.read(iprot_);
      iprot_.readMessageEnd();
      if (result.isSetSuccess()) {
        return result.success;
      }
      if (result.userException != null) {
        throw result.userException;
      }
      if (result.systemException != null) {
        throw result.systemException;
      }
      throw new TApplicationException(TApplicationException.MISSING_RESULT, "createNotebook failed: unknown result");
    }

    public int updateNotebook(String authenticationToken, com.evernote.edam.type.Notebook notebook) throws com.evernote.edam.error.EDAMUserException, com.evernote.edam.error.EDAMSystemException, com.evernote.edam.error.EDAMNotFoundException, TException
    {
      send_updateNotebook(authenticationToken, notebook);
      return recv_updateNotebook();
    }

    public void send_updateNotebook(String authenticationToken, com.evernote.edam.type.Notebook notebook) throws TException
    {
      oprot_.writeMessageBegin(new TMessage("updateNotebook", TMessageType.CALL, seqid_));
      updateNotebook_args args = new updateNotebook_args();
      args.authenticationToken = authenticationToken;
      args.notebook = notebook;
      args.write(oprot_);
      oprot_.writeMessageEnd();
      oprot_.getTransport().flush();
    }

    public int recv_updateNotebook() throws com.evernote.edam.error.EDAMUserException, com.evernote.edam.error.EDAMSystemException, com.evernote.edam.error.EDAMNotFoundException, TException
    {
      TMessage msg = iprot_.readMessageBegin();
      if (msg.type == TMessageType.EXCEPTION) {
        TApplicationException x = TApplicationException.read(iprot_);
        iprot_.readMessageEnd();
        throw x;
      }
      updateNotebook_result result = new updateNotebook_result();
      result.read(iprot_);
      iprot_.readMessageEnd();
      if (result.isSetSuccess()) {
        return result.success;
      }
      if (result.userException != null) {
        throw result.userException;
      }
      if (result.systemException != null) {
        throw result.systemException;
      }
      if (result.notFoundException != null) {
        throw result.notFoundException;
      }
      throw new TApplicationException(TApplicationException.MISSING_RESULT, "updateNotebook failed: unknown result");
    }

    public int expungeNotebook(String authenticationToken, String guid) throws com.evernote.edam.error.EDAMUserException, com.evernote.edam.error.EDAMSystemException, com.evernote.edam.error.EDAMNotFoundException, TException
    {
      send_expungeNotebook(authenticationToken, guid);
      return recv_expungeNotebook();
    }

    public void send_expungeNotebook(String authenticationToken, String guid) throws TException
    {
      oprot_.writeMessageBegin(new TMessage("expungeNotebook", TMessageType.CALL, seqid_));
      expungeNotebook_args args = new expungeNotebook_args();
      args.authenticationToken = authenticationToken;
      args.guid = guid;
      args.write(oprot_);
      oprot_.writeMessageEnd();
      oprot_.getTransport().flush();
    }

    public int recv_expungeNotebook() throws com.evernote.edam.error.EDAMUserException, com.evernote.edam.error.EDAMSystemException, com.evernote.edam.error.EDAMNotFoundException, TException
    {
      TMessage msg = iprot_.readMessageBegin();
      if (msg.type == TMessageType.EXCEPTION) {
        TApplicationException x = TApplicationException.read(iprot_);
        iprot_.readMessageEnd();
        throw x;
      }
      expungeNotebook_result result = new expungeNotebook_result();
      result.read(iprot_);
      iprot_.readMessageEnd();
      if (result.isSetSuccess()) {
        return result.success;
      }
      if (result.userException != null) {
        throw result.userException;
      }
      if (result.systemException != null) {
        throw result.systemException;
      }
      if (result.notFoundException != null) {
        throw result.notFoundException;
      }
      throw new TApplicationException(TApplicationException.MISSING_RESULT, "expungeNotebook failed: unknown result");
    }

    public List<com.evernote.edam.type.Tag> listTags(String authenticationToken) throws com.evernote.edam.error.EDAMUserException, com.evernote.edam.error.EDAMSystemException, TException
    {
      send_listTags(authenticationToken);
      return recv_listTags();
    }

    public void send_listTags(String authenticationToken) throws TException
    {
      oprot_.writeMessageBegin(new TMessage("listTags", TMessageType.CALL, seqid_));
      listTags_args args = new listTags_args();
      args.authenticationToken = authenticationToken;
      args.write(oprot_);
      oprot_.writeMessageEnd();
      oprot_.getTransport().flush();
    }

    public List<com.evernote.edam.type.Tag> recv_listTags() throws com.evernote.edam.error.EDAMUserException, com.evernote.edam.error.EDAMSystemException, TException
    {
      TMessage msg = iprot_.readMessageBegin();
      if (msg.type == TMessageType.EXCEPTION) {
        TApplicationException x = TApplicationException.read(iprot_);
        iprot_.readMessageEnd();
        throw x;
      }
      listTags_result result = new listTags_result();
      result.read(iprot_);
      iprot_.readMessageEnd();
      if (result.isSetSuccess()) {
        return result.success;
      }
      if (result.userException != null) {
        throw result.userException;
      }
      if (result.systemException != null) {
        throw result.systemException;
      }
      throw new TApplicationException(TApplicationException.MISSING_RESULT, "listTags failed: unknown result");
    }

    public List<com.evernote.edam.type.Tag> listTagsByNotebook(String authenticationToken, String notebookGuid) throws com.evernote.edam.error.EDAMUserException, com.evernote.edam.error.EDAMSystemException, com.evernote.edam.error.EDAMNotFoundException, TException
    {
      send_listTagsByNotebook(authenticationToken, notebookGuid);
      return recv_listTagsByNotebook();
    }

    public void send_listTagsByNotebook(String authenticationToken, String notebookGuid) throws TException
    {
      oprot_.writeMessageBegin(new TMessage("listTagsByNotebook", TMessageType.CALL, seqid_));
      listTagsByNotebook_args args = new listTagsByNotebook_args();
      args.authenticationToken = authenticationToken;
      args.notebookGuid = notebookGuid;
      args.write(oprot_);
      oprot_.writeMessageEnd();
      oprot_.getTransport().flush();
    }

    public List<com.evernote.edam.type.Tag> recv_listTagsByNotebook() throws com.evernote.edam.error.EDAMUserException, com.evernote.edam.error.EDAMSystemException, com.evernote.edam.error.EDAMNotFoundException, TException
    {
      TMessage msg = iprot_.readMessageBegin();
      if (msg.type == TMessageType.EXCEPTION) {
        TApplicationException x = TApplicationException.read(iprot_);
        iprot_.readMessageEnd();
        throw x;
      }
      listTagsByNotebook_result result = new listTagsByNotebook_result();
      result.read(iprot_);
      iprot_.readMessageEnd();
      if (result.isSetSuccess()) {
        return result.success;
      }
      if (result.userException != null) {
        throw result.userException;
      }
      if (result.systemException != null) {
        throw result.systemException;
      }
      if (result.notFoundException != null) {
        throw result.notFoundException;
      }
      throw new TApplicationException(TApplicationException.MISSING_RESULT, "listTagsByNotebook failed: unknown result");
    }

    public com.evernote.edam.type.Tag getTag(String authenticationToken, String guid) throws com.evernote.edam.error.EDAMUserException, com.evernote.edam.error.EDAMSystemException, com.evernote.edam.error.EDAMNotFoundException, TException
    {
      send_getTag(authenticationToken, guid);
      return recv_getTag();
    }

    public void send_getTag(String authenticationToken, String guid) throws TException
    {
      oprot_.writeMessageBegin(new TMessage("getTag", TMessageType.CALL, seqid_));
      getTag_args args = new getTag_args();
      args.authenticationToken = authenticationToken;
      args.guid = guid;
      args.write(oprot_);
      oprot_.writeMessageEnd();
      oprot_.getTransport().flush();
    }

    public com.evernote.edam.type.Tag recv_getTag() throws com.evernote.edam.error.EDAMUserException, com.evernote.edam.error.EDAMSystemException, com.evernote.edam.error.EDAMNotFoundException, TException
    {
      TMessage msg = iprot_.readMessageBegin();
      if (msg.type == TMessageType.EXCEPTION) {
        TApplicationException x = TApplicationException.read(iprot_);
        iprot_.readMessageEnd();
        throw x;
      }
      getTag_result result = new getTag_result();
      result.read(iprot_);
      iprot_.readMessageEnd();
      if (result.isSetSuccess()) {
        return result.success;
      }
      if (result.userException != null) {
        throw result.userException;
      }
      if (result.systemException != null) {
        throw result.systemException;
      }
      if (result.notFoundException != null) {
        throw result.notFoundException;
      }
      throw new TApplicationException(TApplicationException.MISSING_RESULT, "getTag failed: unknown result");
    }

    public com.evernote.edam.type.Tag createTag(String authenticationToken, com.evernote.edam.type.Tag tag) throws com.evernote.edam.error.EDAMUserException, com.evernote.edam.error.EDAMSystemException, com.evernote.edam.error.EDAMNotFoundException, TException
    {
      send_createTag(authenticationToken, tag);
      return recv_createTag();
    }

    public void send_createTag(String authenticationToken, com.evernote.edam.type.Tag tag) throws TException
    {
      oprot_.writeMessageBegin(new TMessage("createTag", TMessageType.CALL, seqid_));
      createTag_args args = new createTag_args();
      args.authenticationToken = authenticationToken;
      args.tag = tag;
      args.write(oprot_);
      oprot_.writeMessageEnd();
      oprot_.getTransport().flush();
    }

    public com.evernote.edam.type.Tag recv_createTag() throws com.evernote.edam.error.EDAMUserException, com.evernote.edam.error.EDAMSystemException, com.evernote.edam.error.EDAMNotFoundException, TException
    {
      TMessage msg = iprot_.readMessageBegin();
      if (msg.type == TMessageType.EXCEPTION) {
        TApplicationException x = TApplicationException.read(iprot_);
        iprot_.readMessageEnd();
        throw x;
      }
      createTag_result result = new createTag_result();
      result.read(iprot_);
      iprot_.readMessageEnd();
      if (result.isSetSuccess()) {
        return result.success;
      }
      if (result.userException != null) {
        throw result.userException;
      }
      if (result.systemException != null) {
        throw result.systemException;
      }
      if (result.notFoundException != null) {
        throw result.notFoundException;
      }
      throw new TApplicationException(TApplicationException.MISSING_RESULT, "createTag failed: unknown result");
    }

    public int updateTag(String authenticationToken, com.evernote.edam.type.Tag tag) throws com.evernote.edam.error.EDAMUserException, com.evernote.edam.error.EDAMSystemException, com.evernote.edam.error.EDAMNotFoundException, TException
    {
      send_updateTag(authenticationToken, tag);
      return recv_updateTag();
    }

    public void send_updateTag(String authenticationToken, com.evernote.edam.type.Tag tag) throws TException
    {
      oprot_.writeMessageBegin(new TMessage("updateTag", TMessageType.CALL, seqid_));
      updateTag_args args = new updateTag_args();
      args.authenticationToken = authenticationToken;
      args.tag = tag;
      args.write(oprot_);
      oprot_.writeMessageEnd();
      oprot_.getTransport().flush();
    }

    public int recv_updateTag() throws com.evernote.edam.error.EDAMUserException, com.evernote.edam.error.EDAMSystemException, com.evernote.edam.error.EDAMNotFoundException, TException
    {
      TMessage msg = iprot_.readMessageBegin();
      if (msg.type == TMessageType.EXCEPTION) {
        TApplicationException x = TApplicationException.read(iprot_);
        iprot_.readMessageEnd();
        throw x;
      }
      updateTag_result result = new updateTag_result();
      result.read(iprot_);
      iprot_.readMessageEnd();
      if (result.isSetSuccess()) {
        return result.success;
      }
      if (result.userException != null) {
        throw result.userException;
      }
      if (result.systemException != null) {
        throw result.systemException;
      }
      if (result.notFoundException != null) {
        throw result.notFoundException;
      }
      throw new TApplicationException(TApplicationException.MISSING_RESULT, "updateTag failed: unknown result");
    }

    public void untagAll(String authenticationToken, String guid) throws com.evernote.edam.error.EDAMUserException, com.evernote.edam.error.EDAMSystemException, com.evernote.edam.error.EDAMNotFoundException, TException
    {
      send_untagAll(authenticationToken, guid);
      recv_untagAll();
    }

    public void send_untagAll(String authenticationToken, String guid) throws TException
    {
      oprot_.writeMessageBegin(new TMessage("untagAll", TMessageType.CALL, seqid_));
      untagAll_args args = new untagAll_args();
      args.authenticationToken = authenticationToken;
      args.guid = guid;
      args.write(oprot_);
      oprot_.writeMessageEnd();
      oprot_.getTransport().flush();
    }

    public void recv_untagAll() throws com.evernote.edam.error.EDAMUserException, com.evernote.edam.error.EDAMSystemException, com.evernote.edam.error.EDAMNotFoundException, TException
    {
      TMessage msg = iprot_.readMessageBegin();
      if (msg.type == TMessageType.EXCEPTION) {
        TApplicationException x = TApplicationException.read(iprot_);
        iprot_.readMessageEnd();
        throw x;
      }
      untagAll_result result = new untagAll_result();
      result.read(iprot_);
      iprot_.readMessageEnd();
      if (result.userException != null) {
        throw result.userException;
      }
      if (result.systemException != null) {
        throw result.systemException;
      }
      if (result.notFoundException != null) {
        throw result.notFoundException;
      }
      return;
    }

    public int expungeTag(String authenticationToken, String guid) throws com.evernote.edam.error.EDAMUserException, com.evernote.edam.error.EDAMSystemException, com.evernote.edam.error.EDAMNotFoundException, TException
    {
      send_expungeTag(authenticationToken, guid);
      return recv_expungeTag();
    }

    public void send_expungeTag(String authenticationToken, String guid) throws TException
    {
      oprot_.writeMessageBegin(new TMessage("expungeTag", TMessageType.CALL, seqid_));
      expungeTag_args args = new expungeTag_args();
      args.authenticationToken = authenticationToken;
      args.guid = guid;
      args.write(oprot_);
      oprot_.writeMessageEnd();
      oprot_.getTransport().flush();
    }

    public int recv_expungeTag() throws com.evernote.edam.error.EDAMUserException, com.evernote.edam.error.EDAMSystemException, com.evernote.edam.error.EDAMNotFoundException, TException
    {
      TMessage msg = iprot_.readMessageBegin();
      if (msg.type == TMessageType.EXCEPTION) {
        TApplicationException x = TApplicationException.read(iprot_);
        iprot_.readMessageEnd();
        throw x;
      }
      expungeTag_result result = new expungeTag_result();
      result.read(iprot_);
      iprot_.readMessageEnd();
      if (result.isSetSuccess()) {
        return result.success;
      }
      if (result.userException != null) {
        throw result.userException;
      }
      if (result.systemException != null) {
        throw result.systemException;
      }
      if (result.notFoundException != null) {
        throw result.notFoundException;
      }
      throw new TApplicationException(TApplicationException.MISSING_RESULT, "expungeTag failed: unknown result");
    }

    public List<com.evernote.edam.type.SavedSearch> listSearches(String authenticationToken) throws com.evernote.edam.error.EDAMUserException, com.evernote.edam.error.EDAMSystemException, TException
    {
      send_listSearches(authenticationToken);
      return recv_listSearches();
    }

    public void send_listSearches(String authenticationToken) throws TException
    {
      oprot_.writeMessageBegin(new TMessage("listSearches", TMessageType.CALL, seqid_));
      listSearches_args args = new listSearches_args();
      args.authenticationToken = authenticationToken;
      args.write(oprot_);
      oprot_.writeMessageEnd();
      oprot_.getTransport().flush();
    }

    public List<com.evernote.edam.type.SavedSearch> recv_listSearches() throws com.evernote.edam.error.EDAMUserException, com.evernote.edam.error.EDAMSystemException, TException
    {
      TMessage msg = iprot_.readMessageBegin();
      if (msg.type == TMessageType.EXCEPTION) {
        TApplicationException x = TApplicationException.read(iprot_);
        iprot_.readMessageEnd();
        throw x;
      }
      listSearches_result result = new listSearches_result();
      result.read(iprot_);
      iprot_.readMessageEnd();
      if (result.isSetSuccess()) {
        return result.success;
      }
      if (result.userException != null) {
        throw result.userException;
      }
      if (result.systemException != null) {
        throw result.systemException;
      }
      throw new TApplicationException(TApplicationException.MISSING_RESULT, "listSearches failed: unknown result");
    }

    public com.evernote.edam.type.SavedSearch getSearch(String authenticationToken, String guid) throws com.evernote.edam.error.EDAMUserException, com.evernote.edam.error.EDAMSystemException, com.evernote.edam.error.EDAMNotFoundException, TException
    {
      send_getSearch(authenticationToken, guid);
      return recv_getSearch();
    }

    public void send_getSearch(String authenticationToken, String guid) throws TException
    {
      oprot_.writeMessageBegin(new TMessage("getSearch", TMessageType.CALL, seqid_));
      getSearch_args args = new getSearch_args();
      args.authenticationToken = authenticationToken;
      args.guid = guid;
      args.write(oprot_);
      oprot_.writeMessageEnd();
      oprot_.getTransport().flush();
    }

    public com.evernote.edam.type.SavedSearch recv_getSearch() throws com.evernote.edam.error.EDAMUserException, com.evernote.edam.error.EDAMSystemException, com.evernote.edam.error.EDAMNotFoundException, TException
    {
      TMessage msg = iprot_.readMessageBegin();
      if (msg.type == TMessageType.EXCEPTION) {
        TApplicationException x = TApplicationException.read(iprot_);
        iprot_.readMessageEnd();
        throw x;
      }
      getSearch_result result = new getSearch_result();
      result.read(iprot_);
      iprot_.readMessageEnd();
      if (result.isSetSuccess()) {
        return result.success;
      }
      if (result.userException != null) {
        throw result.userException;
      }
      if (result.systemException != null) {
        throw result.systemException;
      }
      if (result.notFoundException != null) {
        throw result.notFoundException;
      }
      throw new TApplicationException(TApplicationException.MISSING_RESULT, "getSearch failed: unknown result");
    }

    public com.evernote.edam.type.SavedSearch createSearch(String authenticationToken, com.evernote.edam.type.SavedSearch search) throws com.evernote.edam.error.EDAMUserException, com.evernote.edam.error.EDAMSystemException, TException
    {
      send_createSearch(authenticationToken, search);
      return recv_createSearch();
    }

    public void send_createSearch(String authenticationToken, com.evernote.edam.type.SavedSearch search) throws TException
    {
      oprot_.writeMessageBegin(new TMessage("createSearch", TMessageType.CALL, seqid_));
      createSearch_args args = new createSearch_args();
      args.authenticationToken = authenticationToken;
      args.search = search;
      args.write(oprot_);
      oprot_.writeMessageEnd();
      oprot_.getTransport().flush();
    }

    public com.evernote.edam.type.SavedSearch recv_createSearch() throws com.evernote.edam.error.EDAMUserException, com.evernote.edam.error.EDAMSystemException, TException
    {
      TMessage msg = iprot_.readMessageBegin();
      if (msg.type == TMessageType.EXCEPTION) {
        TApplicationException x = TApplicationException.read(iprot_);
        iprot_.readMessageEnd();
        throw x;
      }
      createSearch_result result = new createSearch_result();
      result.read(iprot_);
      iprot_.readMessageEnd();
      if (result.isSetSuccess()) {
        return result.success;
      }
      if (result.userException != null) {
        throw result.userException;
      }
      if (result.systemException != null) {
        throw result.systemException;
      }
      throw new TApplicationException(TApplicationException.MISSING_RESULT, "createSearch failed: unknown result");
    }

    public int updateSearch(String authenticationToken, com.evernote.edam.type.SavedSearch search) throws com.evernote.edam.error.EDAMUserException, com.evernote.edam.error.EDAMSystemException, com.evernote.edam.error.EDAMNotFoundException, TException
    {
      send_updateSearch(authenticationToken, search);
      return recv_updateSearch();
    }

    public void send_updateSearch(String authenticationToken, com.evernote.edam.type.SavedSearch search) throws TException
    {
      oprot_.writeMessageBegin(new TMessage("updateSearch", TMessageType.CALL, seqid_));
      updateSearch_args args = new updateSearch_args();
      args.authenticationToken = authenticationToken;
      args.search = search;
      args.write(oprot_);
      oprot_.writeMessageEnd();
      oprot_.getTransport().flush();
    }

    public int recv_updateSearch() throws com.evernote.edam.error.EDAMUserException, com.evernote.edam.error.EDAMSystemException, com.evernote.edam.error.EDAMNotFoundException, TException
    {
      TMessage msg = iprot_.readMessageBegin();
      if (msg.type == TMessageType.EXCEPTION) {
        TApplicationException x = TApplicationException.read(iprot_);
        iprot_.readMessageEnd();
        throw x;
      }
      updateSearch_result result = new updateSearch_result();
      result.read(iprot_);
      iprot_.readMessageEnd();
      if (result.isSetSuccess()) {
        return result.success;
      }
      if (result.userException != null) {
        throw result.userException;
      }
      if (result.systemException != null) {
        throw result.systemException;
      }
      if (result.notFoundException != null) {
        throw result.notFoundException;
      }
      throw new TApplicationException(TApplicationException.MISSING_RESULT, "updateSearch failed: unknown result");
    }

    public int expungeSearch(String authenticationToken, String guid) throws com.evernote.edam.error.EDAMUserException, com.evernote.edam.error.EDAMSystemException, com.evernote.edam.error.EDAMNotFoundException, TException
    {
      send_expungeSearch(authenticationToken, guid);
      return recv_expungeSearch();
    }

    public void send_expungeSearch(String authenticationToken, String guid) throws TException
    {
      oprot_.writeMessageBegin(new TMessage("expungeSearch", TMessageType.CALL, seqid_));
      expungeSearch_args args = new expungeSearch_args();
      args.authenticationToken = authenticationToken;
      args.guid = guid;
      args.write(oprot_);
      oprot_.writeMessageEnd();
      oprot_.getTransport().flush();
    }

    public int recv_expungeSearch() throws com.evernote.edam.error.EDAMUserException, com.evernote.edam.error.EDAMSystemException, com.evernote.edam.error.EDAMNotFoundException, TException
    {
      TMessage msg = iprot_.readMessageBegin();
      if (msg.type == TMessageType.EXCEPTION) {
        TApplicationException x = TApplicationException.read(iprot_);
        iprot_.readMessageEnd();
        throw x;
      }
      expungeSearch_result result = new expungeSearch_result();
      result.read(iprot_);
      iprot_.readMessageEnd();
      if (result.isSetSuccess()) {
        return result.success;
      }
      if (result.userException != null) {
        throw result.userException;
      }
      if (result.systemException != null) {
        throw result.systemException;
      }
      if (result.notFoundException != null) {
        throw result.notFoundException;
      }
      throw new TApplicationException(TApplicationException.MISSING_RESULT, "expungeSearch failed: unknown result");
    }

    public NoteList findNotes(String authenticationToken, NoteFilter filter, int offset, int maxNotes) throws com.evernote.edam.error.EDAMUserException, com.evernote.edam.error.EDAMSystemException, com.evernote.edam.error.EDAMNotFoundException, TException
    {
      send_findNotes(authenticationToken, filter, offset, maxNotes);
      return recv_findNotes();
    }

    public void send_findNotes(String authenticationToken, NoteFilter filter, int offset, int maxNotes) throws TException
    {
      oprot_.writeMessageBegin(new TMessage("findNotes", TMessageType.CALL, seqid_));
      findNotes_args args = new findNotes_args();
      args.authenticationToken = authenticationToken;
      args.filter = filter;
      args.offset = offset;
      args.maxNotes = maxNotes;
      args.write(oprot_);
      oprot_.writeMessageEnd();
      oprot_.getTransport().flush();
    }

    public NoteList recv_findNotes() throws com.evernote.edam.error.EDAMUserException, com.evernote.edam.error.EDAMSystemException, com.evernote.edam.error.EDAMNotFoundException, TException
    {
      TMessage msg = iprot_.readMessageBegin();
      if (msg.type == TMessageType.EXCEPTION) {
        TApplicationException x = TApplicationException.read(iprot_);
        iprot_.readMessageEnd();
        throw x;
      }
      findNotes_result result = new findNotes_result();
      result.read(iprot_);
      iprot_.readMessageEnd();
      if (result.isSetSuccess()) {
        return result.success;
      }
      if (result.userException != null) {
        throw result.userException;
      }
      if (result.systemException != null) {
        throw result.systemException;
      }
      if (result.notFoundException != null) {
        throw result.notFoundException;
      }
      throw new TApplicationException(TApplicationException.MISSING_RESULT, "findNotes failed: unknown result");
    }

    public NoteCollectionCounts findNoteCounts(String authenticationToken, NoteFilter filter, boolean withTrash) throws com.evernote.edam.error.EDAMUserException, com.evernote.edam.error.EDAMSystemException, com.evernote.edam.error.EDAMNotFoundException, TException
    {
      send_findNoteCounts(authenticationToken, filter, withTrash);
      return recv_findNoteCounts();
    }

    public void send_findNoteCounts(String authenticationToken, NoteFilter filter, boolean withTrash) throws TException
    {
      oprot_.writeMessageBegin(new TMessage("findNoteCounts", TMessageType.CALL, seqid_));
      findNoteCounts_args args = new findNoteCounts_args();
      args.authenticationToken = authenticationToken;
      args.filter = filter;
      args.withTrash = withTrash;
      args.write(oprot_);
      oprot_.writeMessageEnd();
      oprot_.getTransport().flush();
    }

    public NoteCollectionCounts recv_findNoteCounts() throws com.evernote.edam.error.EDAMUserException, com.evernote.edam.error.EDAMSystemException, com.evernote.edam.error.EDAMNotFoundException, TException
    {
      TMessage msg = iprot_.readMessageBegin();
      if (msg.type == TMessageType.EXCEPTION) {
        TApplicationException x = TApplicationException.read(iprot_);
        iprot_.readMessageEnd();
        throw x;
      }
      findNoteCounts_result result = new findNoteCounts_result();
      result.read(iprot_);
      iprot_.readMessageEnd();
      if (result.isSetSuccess()) {
        return result.success;
      }
      if (result.userException != null) {
        throw result.userException;
      }
      if (result.systemException != null) {
        throw result.systemException;
      }
      if (result.notFoundException != null) {
        throw result.notFoundException;
      }
      throw new TApplicationException(TApplicationException.MISSING_RESULT, "findNoteCounts failed: unknown result");
    }

    public com.evernote.edam.type.Note getNote(String authenticationToken, String guid, boolean withContent, boolean withResourcesData, boolean withResourcesRecognition, boolean withResourcesAlternateData) throws com.evernote.edam.error.EDAMUserException, com.evernote.edam.error.EDAMSystemException, com.evernote.edam.error.EDAMNotFoundException, TException
    {
      send_getNote(authenticationToken, guid, withContent, withResourcesData, withResourcesRecognition, withResourcesAlternateData);
      return recv_getNote();
    }

    public void send_getNote(String authenticationToken, String guid, boolean withContent, boolean withResourcesData, boolean withResourcesRecognition, boolean withResourcesAlternateData) throws TException
    {
      oprot_.writeMessageBegin(new TMessage("getNote", TMessageType.CALL, seqid_));
      getNote_args args = new getNote_args();
      args.authenticationToken = authenticationToken;
      args.guid = guid;
      args.withContent = withContent;
      args.withResourcesData = withResourcesData;
      args.withResourcesRecognition = withResourcesRecognition;
      args.withResourcesAlternateData = withResourcesAlternateData;
      args.write(oprot_);
      oprot_.writeMessageEnd();
      oprot_.getTransport().flush();
    }

    public com.evernote.edam.type.Note recv_getNote() throws com.evernote.edam.error.EDAMUserException, com.evernote.edam.error.EDAMSystemException, com.evernote.edam.error.EDAMNotFoundException, TException
    {
      TMessage msg = iprot_.readMessageBegin();
      if (msg.type == TMessageType.EXCEPTION) {
        TApplicationException x = TApplicationException.read(iprot_);
        iprot_.readMessageEnd();
        throw x;
      }
      getNote_result result = new getNote_result();
      result.read(iprot_);
      iprot_.readMessageEnd();
      if (result.isSetSuccess()) {
        return result.success;
      }
      if (result.userException != null) {
        throw result.userException;
      }
      if (result.systemException != null) {
        throw result.systemException;
      }
      if (result.notFoundException != null) {
        throw result.notFoundException;
      }
      throw new TApplicationException(TApplicationException.MISSING_RESULT, "getNote failed: unknown result");
    }

    public String getNoteContent(String authenticationToken, String guid) throws com.evernote.edam.error.EDAMUserException, com.evernote.edam.error.EDAMSystemException, com.evernote.edam.error.EDAMNotFoundException, TException
    {
      send_getNoteContent(authenticationToken, guid);
      return recv_getNoteContent();
    }

    public void send_getNoteContent(String authenticationToken, String guid) throws TException
    {
      oprot_.writeMessageBegin(new TMessage("getNoteContent", TMessageType.CALL, seqid_));
      getNoteContent_args args = new getNoteContent_args();
      args.authenticationToken = authenticationToken;
      args.guid = guid;
      args.write(oprot_);
      oprot_.writeMessageEnd();
      oprot_.getTransport().flush();
    }

    public String recv_getNoteContent() throws com.evernote.edam.error.EDAMUserException, com.evernote.edam.error.EDAMSystemException, com.evernote.edam.error.EDAMNotFoundException, TException
    {
      TMessage msg = iprot_.readMessageBegin();
      if (msg.type == TMessageType.EXCEPTION) {
        TApplicationException x = TApplicationException.read(iprot_);
        iprot_.readMessageEnd();
        throw x;
      }
      getNoteContent_result result = new getNoteContent_result();
      result.read(iprot_);
      iprot_.readMessageEnd();
      if (result.isSetSuccess()) {
        return result.success;
      }
      if (result.userException != null) {
        throw result.userException;
      }
      if (result.systemException != null) {
        throw result.systemException;
      }
      if (result.notFoundException != null) {
        throw result.notFoundException;
      }
      throw new TApplicationException(TApplicationException.MISSING_RESULT, "getNoteContent failed: unknown result");
    }

    public String getNoteSearchText(String authenticationToken, String guid) throws com.evernote.edam.error.EDAMUserException, com.evernote.edam.error.EDAMSystemException, com.evernote.edam.error.EDAMNotFoundException, TException
    {
      send_getNoteSearchText(authenticationToken, guid);
      return recv_getNoteSearchText();
    }

    public void send_getNoteSearchText(String authenticationToken, String guid) throws TException
    {
      oprot_.writeMessageBegin(new TMessage("getNoteSearchText", TMessageType.CALL, seqid_));
      getNoteSearchText_args args = new getNoteSearchText_args();
      args.authenticationToken = authenticationToken;
      args.guid = guid;
      args.write(oprot_);
      oprot_.writeMessageEnd();
      oprot_.getTransport().flush();
    }

    public String recv_getNoteSearchText() throws com.evernote.edam.error.EDAMUserException, com.evernote.edam.error.EDAMSystemException, com.evernote.edam.error.EDAMNotFoundException, TException
    {
      TMessage msg = iprot_.readMessageBegin();
      if (msg.type == TMessageType.EXCEPTION) {
        TApplicationException x = TApplicationException.read(iprot_);
        iprot_.readMessageEnd();
        throw x;
      }
      getNoteSearchText_result result = new getNoteSearchText_result();
      result.read(iprot_);
      iprot_.readMessageEnd();
      if (result.isSetSuccess()) {
        return result.success;
      }
      if (result.userException != null) {
        throw result.userException;
      }
      if (result.systemException != null) {
        throw result.systemException;
      }
      if (result.notFoundException != null) {
        throw result.notFoundException;
      }
      throw new TApplicationException(TApplicationException.MISSING_RESULT, "getNoteSearchText failed: unknown result");
    }

    public List<String> getNoteTagNames(String authenticationToken, String guid) throws com.evernote.edam.error.EDAMUserException, com.evernote.edam.error.EDAMSystemException, com.evernote.edam.error.EDAMNotFoundException, TException
    {
      send_getNoteTagNames(authenticationToken, guid);
      return recv_getNoteTagNames();
    }

    public void send_getNoteTagNames(String authenticationToken, String guid) throws TException
    {
      oprot_.writeMessageBegin(new TMessage("getNoteTagNames", TMessageType.CALL, seqid_));
      getNoteTagNames_args args = new getNoteTagNames_args();
      args.authenticationToken = authenticationToken;
      args.guid = guid;
      args.write(oprot_);
      oprot_.writeMessageEnd();
      oprot_.getTransport().flush();
    }

    public List<String> recv_getNoteTagNames() throws com.evernote.edam.error.EDAMUserException, com.evernote.edam.error.EDAMSystemException, com.evernote.edam.error.EDAMNotFoundException, TException
    {
      TMessage msg = iprot_.readMessageBegin();
      if (msg.type == TMessageType.EXCEPTION) {
        TApplicationException x = TApplicationException.read(iprot_);
        iprot_.readMessageEnd();
        throw x;
      }
      getNoteTagNames_result result = new getNoteTagNames_result();
      result.read(iprot_);
      iprot_.readMessageEnd();
      if (result.isSetSuccess()) {
        return result.success;
      }
      if (result.userException != null) {
        throw result.userException;
      }
      if (result.systemException != null) {
        throw result.systemException;
      }
      if (result.notFoundException != null) {
        throw result.notFoundException;
      }
      throw new TApplicationException(TApplicationException.MISSING_RESULT, "getNoteTagNames failed: unknown result");
    }

    public com.evernote.edam.type.Note createNote(String authenticationToken, com.evernote.edam.type.Note note) throws com.evernote.edam.error.EDAMUserException, com.evernote.edam.error.EDAMSystemException, com.evernote.edam.error.EDAMNotFoundException, TException
    {
      send_createNote(authenticationToken, note);
      return recv_createNote();
    }

    public void send_createNote(String authenticationToken, com.evernote.edam.type.Note note) throws TException
    {
      oprot_.writeMessageBegin(new TMessage("createNote", TMessageType.CALL, seqid_));
      createNote_args args = new createNote_args();
      args.authenticationToken = authenticationToken;
      args.note = note;
      args.write(oprot_);
      oprot_.writeMessageEnd();
      oprot_.getTransport().flush();
    }

    public com.evernote.edam.type.Note recv_createNote() throws com.evernote.edam.error.EDAMUserException, com.evernote.edam.error.EDAMSystemException, com.evernote.edam.error.EDAMNotFoundException, TException
    {
      TMessage msg = iprot_.readMessageBegin();
      if (msg.type == TMessageType.EXCEPTION) {
        TApplicationException x = TApplicationException.read(iprot_);
        iprot_.readMessageEnd();
        throw x;
      }
      createNote_result result = new createNote_result();
      result.read(iprot_);
      iprot_.readMessageEnd();
      if (result.isSetSuccess()) {
        return result.success;
      }
      if (result.userException != null) {
        throw result.userException;
      }
      if (result.systemException != null) {
        throw result.systemException;
      }
      if (result.notFoundException != null) {
        throw result.notFoundException;
      }
      throw new TApplicationException(TApplicationException.MISSING_RESULT, "createNote failed: unknown result");
    }

    public com.evernote.edam.type.Note updateNote(String authenticationToken, com.evernote.edam.type.Note note) throws com.evernote.edam.error.EDAMUserException, com.evernote.edam.error.EDAMSystemException, com.evernote.edam.error.EDAMNotFoundException, TException
    {
      send_updateNote(authenticationToken, note);
      return recv_updateNote();
    }

    public void send_updateNote(String authenticationToken, com.evernote.edam.type.Note note) throws TException
    {
      oprot_.writeMessageBegin(new TMessage("updateNote", TMessageType.CALL, seqid_));
      updateNote_args args = new updateNote_args();
      args.authenticationToken = authenticationToken;
      args.note = note;
      args.write(oprot_);
      oprot_.writeMessageEnd();
      oprot_.getTransport().flush();
    }

    public com.evernote.edam.type.Note recv_updateNote() throws com.evernote.edam.error.EDAMUserException, com.evernote.edam.error.EDAMSystemException, com.evernote.edam.error.EDAMNotFoundException, TException
    {
      TMessage msg = iprot_.readMessageBegin();
      if (msg.type == TMessageType.EXCEPTION) {
        TApplicationException x = TApplicationException.read(iprot_);
        iprot_.readMessageEnd();
        throw x;
      }
      updateNote_result result = new updateNote_result();
      result.read(iprot_);
      iprot_.readMessageEnd();
      if (result.isSetSuccess()) {
        return result.success;
      }
      if (result.userException != null) {
        throw result.userException;
      }
      if (result.systemException != null) {
        throw result.systemException;
      }
      if (result.notFoundException != null) {
        throw result.notFoundException;
      }
      throw new TApplicationException(TApplicationException.MISSING_RESULT, "updateNote failed: unknown result");
    }

    public int deleteNote(String authenticationToken, String guid) throws com.evernote.edam.error.EDAMUserException, com.evernote.edam.error.EDAMSystemException, com.evernote.edam.error.EDAMNotFoundException, TException
    {
      send_deleteNote(authenticationToken, guid);
      return recv_deleteNote();
    }

    public void send_deleteNote(String authenticationToken, String guid) throws TException
    {
      oprot_.writeMessageBegin(new TMessage("deleteNote", TMessageType.CALL, seqid_));
      deleteNote_args args = new deleteNote_args();
      args.authenticationToken = authenticationToken;
      args.guid = guid;
      args.write(oprot_);
      oprot_.writeMessageEnd();
      oprot_.getTransport().flush();
    }

    public int recv_deleteNote() throws com.evernote.edam.error.EDAMUserException, com.evernote.edam.error.EDAMSystemException, com.evernote.edam.error.EDAMNotFoundException, TException
    {
      TMessage msg = iprot_.readMessageBegin();
      if (msg.type == TMessageType.EXCEPTION) {
        TApplicationException x = TApplicationException.read(iprot_);
        iprot_.readMessageEnd();
        throw x;
      }
      deleteNote_result result = new deleteNote_result();
      result.read(iprot_);
      iprot_.readMessageEnd();
      if (result.isSetSuccess()) {
        return result.success;
      }
      if (result.userException != null) {
        throw result.userException;
      }
      if (result.systemException != null) {
        throw result.systemException;
      }
      if (result.notFoundException != null) {
        throw result.notFoundException;
      }
      throw new TApplicationException(TApplicationException.MISSING_RESULT, "deleteNote failed: unknown result");
    }

    public int expungeNote(String authenticationToken, String guid) throws com.evernote.edam.error.EDAMUserException, com.evernote.edam.error.EDAMSystemException, com.evernote.edam.error.EDAMNotFoundException, TException
    {
      send_expungeNote(authenticationToken, guid);
      return recv_expungeNote();
    }

    public void send_expungeNote(String authenticationToken, String guid) throws TException
    {
      oprot_.writeMessageBegin(new TMessage("expungeNote", TMessageType.CALL, seqid_));
      expungeNote_args args = new expungeNote_args();
      args.authenticationToken = authenticationToken;
      args.guid = guid;
      args.write(oprot_);
      oprot_.writeMessageEnd();
      oprot_.getTransport().flush();
    }

    public int recv_expungeNote() throws com.evernote.edam.error.EDAMUserException, com.evernote.edam.error.EDAMSystemException, com.evernote.edam.error.EDAMNotFoundException, TException
    {
      TMessage msg = iprot_.readMessageBegin();
      if (msg.type == TMessageType.EXCEPTION) {
        TApplicationException x = TApplicationException.read(iprot_);
        iprot_.readMessageEnd();
        throw x;
      }
      expungeNote_result result = new expungeNote_result();
      result.read(iprot_);
      iprot_.readMessageEnd();
      if (result.isSetSuccess()) {
        return result.success;
      }
      if (result.userException != null) {
        throw result.userException;
      }
      if (result.systemException != null) {
        throw result.systemException;
      }
      if (result.notFoundException != null) {
        throw result.notFoundException;
      }
      throw new TApplicationException(TApplicationException.MISSING_RESULT, "expungeNote failed: unknown result");
    }

    public int expungeNotes(String authenticationToken, List<String> noteGuids) throws com.evernote.edam.error.EDAMUserException, com.evernote.edam.error.EDAMSystemException, com.evernote.edam.error.EDAMNotFoundException, TException
    {
      send_expungeNotes(authenticationToken, noteGuids);
      return recv_expungeNotes();
    }

    public void send_expungeNotes(String authenticationToken, List<String> noteGuids) throws TException
    {
      oprot_.writeMessageBegin(new TMessage("expungeNotes", TMessageType.CALL, seqid_));
      expungeNotes_args args = new expungeNotes_args();
      args.authenticationToken = authenticationToken;
      args.noteGuids = noteGuids;
      args.write(oprot_);
      oprot_.writeMessageEnd();
      oprot_.getTransport().flush();
    }

    public int recv_expungeNotes() throws com.evernote.edam.error.EDAMUserException, com.evernote.edam.error.EDAMSystemException, com.evernote.edam.error.EDAMNotFoundException, TException
    {
      TMessage msg = iprot_.readMessageBegin();
      if (msg.type == TMessageType.EXCEPTION) {
        TApplicationException x = TApplicationException.read(iprot_);
        iprot_.readMessageEnd();
        throw x;
      }
      expungeNotes_result result = new expungeNotes_result();
      result.read(iprot_);
      iprot_.readMessageEnd();
      if (result.isSetSuccess()) {
        return result.success;
      }
      if (result.userException != null) {
        throw result.userException;
      }
      if (result.systemException != null) {
        throw result.systemException;
      }
      if (result.notFoundException != null) {
        throw result.notFoundException;
      }
      throw new TApplicationException(TApplicationException.MISSING_RESULT, "expungeNotes failed: unknown result");
    }

    public int expungeInactiveNotes(String authenticationToken) throws com.evernote.edam.error.EDAMUserException, com.evernote.edam.error.EDAMSystemException, TException
    {
      send_expungeInactiveNotes(authenticationToken);
      return recv_expungeInactiveNotes();
    }

    public void send_expungeInactiveNotes(String authenticationToken) throws TException
    {
      oprot_.writeMessageBegin(new TMessage("expungeInactiveNotes", TMessageType.CALL, seqid_));
      expungeInactiveNotes_args args = new expungeInactiveNotes_args();
      args.authenticationToken = authenticationToken;
      args.write(oprot_);
      oprot_.writeMessageEnd();
      oprot_.getTransport().flush();
    }

    public int recv_expungeInactiveNotes() throws com.evernote.edam.error.EDAMUserException, com.evernote.edam.error.EDAMSystemException, TException
    {
      TMessage msg = iprot_.readMessageBegin();
      if (msg.type == TMessageType.EXCEPTION) {
        TApplicationException x = TApplicationException.read(iprot_);
        iprot_.readMessageEnd();
        throw x;
      }
      expungeInactiveNotes_result result = new expungeInactiveNotes_result();
      result.read(iprot_);
      iprot_.readMessageEnd();
      if (result.isSetSuccess()) {
        return result.success;
      }
      if (result.userException != null) {
        throw result.userException;
      }
      if (result.systemException != null) {
        throw result.systemException;
      }
      throw new TApplicationException(TApplicationException.MISSING_RESULT, "expungeInactiveNotes failed: unknown result");
    }

    public com.evernote.edam.type.Note copyNote(String authenticationToken, String noteGuid, String toNotebookGuid) throws com.evernote.edam.error.EDAMUserException, com.evernote.edam.error.EDAMSystemException, com.evernote.edam.error.EDAMNotFoundException, TException
    {
      send_copyNote(authenticationToken, noteGuid, toNotebookGuid);
      return recv_copyNote();
    }

    public void send_copyNote(String authenticationToken, String noteGuid, String toNotebookGuid) throws TException
    {
      oprot_.writeMessageBegin(new TMessage("copyNote", TMessageType.CALL, seqid_));
      copyNote_args args = new copyNote_args();
      args.authenticationToken = authenticationToken;
      args.noteGuid = noteGuid;
      args.toNotebookGuid = toNotebookGuid;
      args.write(oprot_);
      oprot_.writeMessageEnd();
      oprot_.getTransport().flush();
    }

    public com.evernote.edam.type.Note recv_copyNote() throws com.evernote.edam.error.EDAMUserException, com.evernote.edam.error.EDAMSystemException, com.evernote.edam.error.EDAMNotFoundException, TException
    {
      TMessage msg = iprot_.readMessageBegin();
      if (msg.type == TMessageType.EXCEPTION) {
        TApplicationException x = TApplicationException.read(iprot_);
        iprot_.readMessageEnd();
        throw x;
      }
      copyNote_result result = new copyNote_result();
      result.read(iprot_);
      iprot_.readMessageEnd();
      if (result.isSetSuccess()) {
        return result.success;
      }
      if (result.userException != null) {
        throw result.userException;
      }
      if (result.systemException != null) {
        throw result.systemException;
      }
      if (result.notFoundException != null) {
        throw result.notFoundException;
      }
      throw new TApplicationException(TApplicationException.MISSING_RESULT, "copyNote failed: unknown result");
    }

    public List<NoteVersionId> listNoteVersions(String authenticationToken, String noteGuid) throws com.evernote.edam.error.EDAMUserException, com.evernote.edam.error.EDAMSystemException, com.evernote.edam.error.EDAMNotFoundException, TException
    {
      send_listNoteVersions(authenticationToken, noteGuid);
      return recv_listNoteVersions();
    }

    public void send_listNoteVersions(String authenticationToken, String noteGuid) throws TException
    {
      oprot_.writeMessageBegin(new TMessage("listNoteVersions", TMessageType.CALL, seqid_));
      listNoteVersions_args args = new listNoteVersions_args();
      args.authenticationToken = authenticationToken;
      args.noteGuid = noteGuid;
      args.write(oprot_);
      oprot_.writeMessageEnd();
      oprot_.getTransport().flush();
    }

    public List<NoteVersionId> recv_listNoteVersions() throws com.evernote.edam.error.EDAMUserException, com.evernote.edam.error.EDAMSystemException, com.evernote.edam.error.EDAMNotFoundException, TException
    {
      TMessage msg = iprot_.readMessageBegin();
      if (msg.type == TMessageType.EXCEPTION) {
        TApplicationException x = TApplicationException.read(iprot_);
        iprot_.readMessageEnd();
        throw x;
      }
      listNoteVersions_result result = new listNoteVersions_result();
      result.read(iprot_);
      iprot_.readMessageEnd();
      if (result.isSetSuccess()) {
        return result.success;
      }
      if (result.userException != null) {
        throw result.userException;
      }
      if (result.systemException != null) {
        throw result.systemException;
      }
      if (result.notFoundException != null) {
        throw result.notFoundException;
      }
      throw new TApplicationException(TApplicationException.MISSING_RESULT, "listNoteVersions failed: unknown result");
    }

    public com.evernote.edam.type.Note getNoteVersion(String authenticationToken, String noteGuid, int updateSequenceNum, boolean withResourcesData, boolean withResourcesRecognition, boolean withResourcesAlternateData) throws com.evernote.edam.error.EDAMUserException, com.evernote.edam.error.EDAMSystemException, com.evernote.edam.error.EDAMNotFoundException, TException
    {
      send_getNoteVersion(authenticationToken, noteGuid, updateSequenceNum, withResourcesData, withResourcesRecognition, withResourcesAlternateData);
      return recv_getNoteVersion();
    }

    public void send_getNoteVersion(String authenticationToken, String noteGuid, int updateSequenceNum, boolean withResourcesData, boolean withResourcesRecognition, boolean withResourcesAlternateData) throws TException
    {
      oprot_.writeMessageBegin(new TMessage("getNoteVersion", TMessageType.CALL, seqid_));
      getNoteVersion_args args = new getNoteVersion_args();
      args.authenticationToken = authenticationToken;
      args.noteGuid = noteGuid;
      args.updateSequenceNum = updateSequenceNum;
      args.withResourcesData = withResourcesData;
      args.withResourcesRecognition = withResourcesRecognition;
      args.withResourcesAlternateData = withResourcesAlternateData;
      args.write(oprot_);
      oprot_.writeMessageEnd();
      oprot_.getTransport().flush();
    }

    public com.evernote.edam.type.Note recv_getNoteVersion() throws com.evernote.edam.error.EDAMUserException, com.evernote.edam.error.EDAMSystemException, com.evernote.edam.error.EDAMNotFoundException, TException
    {
      TMessage msg = iprot_.readMessageBegin();
      if (msg.type == TMessageType.EXCEPTION) {
        TApplicationException x = TApplicationException.read(iprot_);
        iprot_.readMessageEnd();
        throw x;
      }
      getNoteVersion_result result = new getNoteVersion_result();
      result.read(iprot_);
      iprot_.readMessageEnd();
      if (result.isSetSuccess()) {
        return result.success;
      }
      if (result.userException != null) {
        throw result.userException;
      }
      if (result.systemException != null) {
        throw result.systemException;
      }
      if (result.notFoundException != null) {
        throw result.notFoundException;
      }
      throw new TApplicationException(TApplicationException.MISSING_RESULT, "getNoteVersion failed: unknown result");
    }

    public com.evernote.edam.type.Resource getResource(String authenticationToken, String guid, boolean withData, boolean withRecognition, boolean withAttributes, boolean withAlternateData) throws com.evernote.edam.error.EDAMUserException, com.evernote.edam.error.EDAMSystemException, com.evernote.edam.error.EDAMNotFoundException, TException
    {
      send_getResource(authenticationToken, guid, withData, withRecognition, withAttributes, withAlternateData);
      return recv_getResource();
    }

    public void send_getResource(String authenticationToken, String guid, boolean withData, boolean withRecognition, boolean withAttributes, boolean withAlternateData) throws TException
    {
      oprot_.writeMessageBegin(new TMessage("getResource", TMessageType.CALL, seqid_));
      getResource_args args = new getResource_args();
      args.authenticationToken = authenticationToken;
      args.guid = guid;
      args.withData = withData;
      args.withRecognition = withRecognition;
      args.withAttributes = withAttributes;
      args.withAlternateData = withAlternateData;
      args.write(oprot_);
      oprot_.writeMessageEnd();
      oprot_.getTransport().flush();
    }

    public com.evernote.edam.type.Resource recv_getResource() throws com.evernote.edam.error.EDAMUserException, com.evernote.edam.error.EDAMSystemException, com.evernote.edam.error.EDAMNotFoundException, TException
    {
      TMessage msg = iprot_.readMessageBegin();
      if (msg.type == TMessageType.EXCEPTION) {
        TApplicationException x = TApplicationException.read(iprot_);
        iprot_.readMessageEnd();
        throw x;
      }
      getResource_result result = new getResource_result();
      result.read(iprot_);
      iprot_.readMessageEnd();
      if (result.isSetSuccess()) {
        return result.success;
      }
      if (result.userException != null) {
        throw result.userException;
      }
      if (result.systemException != null) {
        throw result.systemException;
      }
      if (result.notFoundException != null) {
        throw result.notFoundException;
      }
      throw new TApplicationException(TApplicationException.MISSING_RESULT, "getResource failed: unknown result");
    }

    public int updateResource(String authenticationToken, com.evernote.edam.type.Resource resource) throws com.evernote.edam.error.EDAMUserException, com.evernote.edam.error.EDAMSystemException, com.evernote.edam.error.EDAMNotFoundException, TException
    {
      send_updateResource(authenticationToken, resource);
      return recv_updateResource();
    }

    public void send_updateResource(String authenticationToken, com.evernote.edam.type.Resource resource) throws TException
    {
      oprot_.writeMessageBegin(new TMessage("updateResource", TMessageType.CALL, seqid_));
      updateResource_args args = new updateResource_args();
      args.authenticationToken = authenticationToken;
      args.resource = resource;
      args.write(oprot_);
      oprot_.writeMessageEnd();
      oprot_.getTransport().flush();
    }

    public int recv_updateResource() throws com.evernote.edam.error.EDAMUserException, com.evernote.edam.error.EDAMSystemException, com.evernote.edam.error.EDAMNotFoundException, TException
    {
      TMessage msg = iprot_.readMessageBegin();
      if (msg.type == TMessageType.EXCEPTION) {
        TApplicationException x = TApplicationException.read(iprot_);
        iprot_.readMessageEnd();
        throw x;
      }
      updateResource_result result = new updateResource_result();
      result.read(iprot_);
      iprot_.readMessageEnd();
      if (result.isSetSuccess()) {
        return result.success;
      }
      if (result.userException != null) {
        throw result.userException;
      }
      if (result.systemException != null) {
        throw result.systemException;
      }
      if (result.notFoundException != null) {
        throw result.notFoundException;
      }
      throw new TApplicationException(TApplicationException.MISSING_RESULT, "updateResource failed: unknown result");
    }

    public byte[] getResourceData(String authenticationToken, String guid) throws com.evernote.edam.error.EDAMUserException, com.evernote.edam.error.EDAMSystemException, com.evernote.edam.error.EDAMNotFoundException, TException
    {
      send_getResourceData(authenticationToken, guid);
      return recv_getResourceData();
    }

    public void send_getResourceData(String authenticationToken, String guid) throws TException
    {
      oprot_.writeMessageBegin(new TMessage("getResourceData", TMessageType.CALL, seqid_));
      getResourceData_args args = new getResourceData_args();
      args.authenticationToken = authenticationToken;
      args.guid = guid;
      args.write(oprot_);
      oprot_.writeMessageEnd();
      oprot_.getTransport().flush();
    }

    public byte[] recv_getResourceData() throws com.evernote.edam.error.EDAMUserException, com.evernote.edam.error.EDAMSystemException, com.evernote.edam.error.EDAMNotFoundException, TException
    {
      TMessage msg = iprot_.readMessageBegin();
      if (msg.type == TMessageType.EXCEPTION) {
        TApplicationException x = TApplicationException.read(iprot_);
        iprot_.readMessageEnd();
        throw x;
      }
      getResourceData_result result = new getResourceData_result();
      result.read(iprot_);
      iprot_.readMessageEnd();
      if (result.isSetSuccess()) {
        return result.success;
      }
      if (result.userException != null) {
        throw result.userException;
      }
      if (result.systemException != null) {
        throw result.systemException;
      }
      if (result.notFoundException != null) {
        throw result.notFoundException;
      }
      throw new TApplicationException(TApplicationException.MISSING_RESULT, "getResourceData failed: unknown result");
    }

    public com.evernote.edam.type.Resource getResourceByHash(String authenticationToken, String noteGuid, byte[] contentHash, boolean withData, boolean withRecognition, boolean withAlternateData) throws com.evernote.edam.error.EDAMUserException, com.evernote.edam.error.EDAMSystemException, com.evernote.edam.error.EDAMNotFoundException, TException
    {
      send_getResourceByHash(authenticationToken, noteGuid, contentHash, withData, withRecognition, withAlternateData);
      return recv_getResourceByHash();
    }

    public void send_getResourceByHash(String authenticationToken, String noteGuid, byte[] contentHash, boolean withData, boolean withRecognition, boolean withAlternateData) throws TException
    {
      oprot_.writeMessageBegin(new TMessage("getResourceByHash", TMessageType.CALL, seqid_));
      getResourceByHash_args args = new getResourceByHash_args();
      args.authenticationToken = authenticationToken;
      args.noteGuid = noteGuid;
      args.contentHash = contentHash;
      args.withData = withData;
      args.withRecognition = withRecognition;
      args.withAlternateData = withAlternateData;
      args.write(oprot_);
      oprot_.writeMessageEnd();
      oprot_.getTransport().flush();
    }

    public com.evernote.edam.type.Resource recv_getResourceByHash() throws com.evernote.edam.error.EDAMUserException, com.evernote.edam.error.EDAMSystemException, com.evernote.edam.error.EDAMNotFoundException, TException
    {
      TMessage msg = iprot_.readMessageBegin();
      if (msg.type == TMessageType.EXCEPTION) {
        TApplicationException x = TApplicationException.read(iprot_);
        iprot_.readMessageEnd();
        throw x;
      }
      getResourceByHash_result result = new getResourceByHash_result();
      result.read(iprot_);
      iprot_.readMessageEnd();
      if (result.isSetSuccess()) {
        return result.success;
      }
      if (result.userException != null) {
        throw result.userException;
      }
      if (result.systemException != null) {
        throw result.systemException;
      }
      if (result.notFoundException != null) {
        throw result.notFoundException;
      }
      throw new TApplicationException(TApplicationException.MISSING_RESULT, "getResourceByHash failed: unknown result");
    }

    public byte[] getResourceRecognition(String authenticationToken, String guid) throws com.evernote.edam.error.EDAMUserException, com.evernote.edam.error.EDAMSystemException, com.evernote.edam.error.EDAMNotFoundException, TException
    {
      send_getResourceRecognition(authenticationToken, guid);
      return recv_getResourceRecognition();
    }

    public void send_getResourceRecognition(String authenticationToken, String guid) throws TException
    {
      oprot_.writeMessageBegin(new TMessage("getResourceRecognition", TMessageType.CALL, seqid_));
      getResourceRecognition_args args = new getResourceRecognition_args();
      args.authenticationToken = authenticationToken;
      args.guid = guid;
      args.write(oprot_);
      oprot_.writeMessageEnd();
      oprot_.getTransport().flush();
    }

    public byte[] recv_getResourceRecognition() throws com.evernote.edam.error.EDAMUserException, com.evernote.edam.error.EDAMSystemException, com.evernote.edam.error.EDAMNotFoundException, TException
    {
      TMessage msg = iprot_.readMessageBegin();
      if (msg.type == TMessageType.EXCEPTION) {
        TApplicationException x = TApplicationException.read(iprot_);
        iprot_.readMessageEnd();
        throw x;
      }
      getResourceRecognition_result result = new getResourceRecognition_result();
      result.read(iprot_);
      iprot_.readMessageEnd();
      if (result.isSetSuccess()) {
        return result.success;
      }
      if (result.userException != null) {
        throw result.userException;
      }
      if (result.systemException != null) {
        throw result.systemException;
      }
      if (result.notFoundException != null) {
        throw result.notFoundException;
      }
      throw new TApplicationException(TApplicationException.MISSING_RESULT, "getResourceRecognition failed: unknown result");
    }

    public byte[] getResourceAlternateData(String authenticationToken, String guid) throws com.evernote.edam.error.EDAMUserException, com.evernote.edam.error.EDAMSystemException, com.evernote.edam.error.EDAMNotFoundException, TException
    {
      send_getResourceAlternateData(authenticationToken, guid);
      return recv_getResourceAlternateData();
    }

    public void send_getResourceAlternateData(String authenticationToken, String guid) throws TException
    {
      oprot_.writeMessageBegin(new TMessage("getResourceAlternateData", TMessageType.CALL, seqid_));
      getResourceAlternateData_args args = new getResourceAlternateData_args();
      args.authenticationToken = authenticationToken;
      args.guid = guid;
      args.write(oprot_);
      oprot_.writeMessageEnd();
      oprot_.getTransport().flush();
    }

    public byte[] recv_getResourceAlternateData() throws com.evernote.edam.error.EDAMUserException, com.evernote.edam.error.EDAMSystemException, com.evernote.edam.error.EDAMNotFoundException, TException
    {
      TMessage msg = iprot_.readMessageBegin();
      if (msg.type == TMessageType.EXCEPTION) {
        TApplicationException x = TApplicationException.read(iprot_);
        iprot_.readMessageEnd();
        throw x;
      }
      getResourceAlternateData_result result = new getResourceAlternateData_result();
      result.read(iprot_);
      iprot_.readMessageEnd();
      if (result.isSetSuccess()) {
        return result.success;
      }
      if (result.userException != null) {
        throw result.userException;
      }
      if (result.systemException != null) {
        throw result.systemException;
      }
      if (result.notFoundException != null) {
        throw result.notFoundException;
      }
      throw new TApplicationException(TApplicationException.MISSING_RESULT, "getResourceAlternateData failed: unknown result");
    }

    public com.evernote.edam.type.ResourceAttributes getResourceAttributes(String authenticationToken, String guid) throws com.evernote.edam.error.EDAMUserException, com.evernote.edam.error.EDAMSystemException, com.evernote.edam.error.EDAMNotFoundException, TException
    {
      send_getResourceAttributes(authenticationToken, guid);
      return recv_getResourceAttributes();
    }

    public void send_getResourceAttributes(String authenticationToken, String guid) throws TException
    {
      oprot_.writeMessageBegin(new TMessage("getResourceAttributes", TMessageType.CALL, seqid_));
      getResourceAttributes_args args = new getResourceAttributes_args();
      args.authenticationToken = authenticationToken;
      args.guid = guid;
      args.write(oprot_);
      oprot_.writeMessageEnd();
      oprot_.getTransport().flush();
    }

    public com.evernote.edam.type.ResourceAttributes recv_getResourceAttributes() throws com.evernote.edam.error.EDAMUserException, com.evernote.edam.error.EDAMSystemException, com.evernote.edam.error.EDAMNotFoundException, TException
    {
      TMessage msg = iprot_.readMessageBegin();
      if (msg.type == TMessageType.EXCEPTION) {
        TApplicationException x = TApplicationException.read(iprot_);
        iprot_.readMessageEnd();
        throw x;
      }
      getResourceAttributes_result result = new getResourceAttributes_result();
      result.read(iprot_);
      iprot_.readMessageEnd();
      if (result.isSetSuccess()) {
        return result.success;
      }
      if (result.userException != null) {
        throw result.userException;
      }
      if (result.systemException != null) {
        throw result.systemException;
      }
      if (result.notFoundException != null) {
        throw result.notFoundException;
      }
      throw new TApplicationException(TApplicationException.MISSING_RESULT, "getResourceAttributes failed: unknown result");
    }

    public long getAccountSize(String authenticationToken) throws com.evernote.edam.error.EDAMUserException, com.evernote.edam.error.EDAMSystemException, TException
    {
      send_getAccountSize(authenticationToken);
      return recv_getAccountSize();
    }

    public void send_getAccountSize(String authenticationToken) throws TException
    {
      oprot_.writeMessageBegin(new TMessage("getAccountSize", TMessageType.CALL, seqid_));
      getAccountSize_args args = new getAccountSize_args();
      args.authenticationToken = authenticationToken;
      args.write(oprot_);
      oprot_.writeMessageEnd();
      oprot_.getTransport().flush();
    }

    public long recv_getAccountSize() throws com.evernote.edam.error.EDAMUserException, com.evernote.edam.error.EDAMSystemException, TException
    {
      TMessage msg = iprot_.readMessageBegin();
      if (msg.type == TMessageType.EXCEPTION) {
        TApplicationException x = TApplicationException.read(iprot_);
        iprot_.readMessageEnd();
        throw x;
      }
      getAccountSize_result result = new getAccountSize_result();
      result.read(iprot_);
      iprot_.readMessageEnd();
      if (result.isSetSuccess()) {
        return result.success;
      }
      if (result.userException != null) {
        throw result.userException;
      }
      if (result.systemException != null) {
        throw result.systemException;
      }
      throw new TApplicationException(TApplicationException.MISSING_RESULT, "getAccountSize failed: unknown result");
    }

    public List<com.evernote.edam.type.Ad> getAds(String authenticationToken, AdParameters adParameters) throws com.evernote.edam.error.EDAMUserException, com.evernote.edam.error.EDAMSystemException, TException
    {
      send_getAds(authenticationToken, adParameters);
      return recv_getAds();
    }

    public void send_getAds(String authenticationToken, AdParameters adParameters) throws TException
    {
      oprot_.writeMessageBegin(new TMessage("getAds", TMessageType.CALL, seqid_));
      getAds_args args = new getAds_args();
      args.authenticationToken = authenticationToken;
      args.adParameters = adParameters;
      args.write(oprot_);
      oprot_.writeMessageEnd();
      oprot_.getTransport().flush();
    }

    public List<com.evernote.edam.type.Ad> recv_getAds() throws com.evernote.edam.error.EDAMUserException, com.evernote.edam.error.EDAMSystemException, TException
    {
      TMessage msg = iprot_.readMessageBegin();
      if (msg.type == TMessageType.EXCEPTION) {
        TApplicationException x = TApplicationException.read(iprot_);
        iprot_.readMessageEnd();
        throw x;
      }
      getAds_result result = new getAds_result();
      result.read(iprot_);
      iprot_.readMessageEnd();
      if (result.isSetSuccess()) {
        return result.success;
      }
      if (result.userException != null) {
        throw result.userException;
      }
      if (result.systemException != null) {
        throw result.systemException;
      }
      throw new TApplicationException(TApplicationException.MISSING_RESULT, "getAds failed: unknown result");
    }

    public com.evernote.edam.type.Ad getRandomAd(String authenticationToken, AdParameters adParameters) throws com.evernote.edam.error.EDAMUserException, com.evernote.edam.error.EDAMSystemException, TException
    {
      send_getRandomAd(authenticationToken, adParameters);
      return recv_getRandomAd();
    }

    public void send_getRandomAd(String authenticationToken, AdParameters adParameters) throws TException
    {
      oprot_.writeMessageBegin(new TMessage("getRandomAd", TMessageType.CALL, seqid_));
      getRandomAd_args args = new getRandomAd_args();
      args.authenticationToken = authenticationToken;
      args.adParameters = adParameters;
      args.write(oprot_);
      oprot_.writeMessageEnd();
      oprot_.getTransport().flush();
    }

    public com.evernote.edam.type.Ad recv_getRandomAd() throws com.evernote.edam.error.EDAMUserException, com.evernote.edam.error.EDAMSystemException, TException
    {
      TMessage msg = iprot_.readMessageBegin();
      if (msg.type == TMessageType.EXCEPTION) {
        TApplicationException x = TApplicationException.read(iprot_);
        iprot_.readMessageEnd();
        throw x;
      }
      getRandomAd_result result = new getRandomAd_result();
      result.read(iprot_);
      iprot_.readMessageEnd();
      if (result.isSetSuccess()) {
        return result.success;
      }
      if (result.userException != null) {
        throw result.userException;
      }
      if (result.systemException != null) {
        throw result.systemException;
      }
      throw new TApplicationException(TApplicationException.MISSING_RESULT, "getRandomAd failed: unknown result");
    }

    public com.evernote.edam.type.Notebook getPublicNotebook(int userId, String publicUri) throws com.evernote.edam.error.EDAMSystemException, com.evernote.edam.error.EDAMNotFoundException, TException
    {
      send_getPublicNotebook(userId, publicUri);
      return recv_getPublicNotebook();
    }

    public void send_getPublicNotebook(int userId, String publicUri) throws TException
    {
      oprot_.writeMessageBegin(new TMessage("getPublicNotebook", TMessageType.CALL, seqid_));
      getPublicNotebook_args args = new getPublicNotebook_args();
      args.userId = userId;
      args.publicUri = publicUri;
      args.write(oprot_);
      oprot_.writeMessageEnd();
      oprot_.getTransport().flush();
    }

    public com.evernote.edam.type.Notebook recv_getPublicNotebook() throws com.evernote.edam.error.EDAMSystemException, com.evernote.edam.error.EDAMNotFoundException, TException
    {
      TMessage msg = iprot_.readMessageBegin();
      if (msg.type == TMessageType.EXCEPTION) {
        TApplicationException x = TApplicationException.read(iprot_);
        iprot_.readMessageEnd();
        throw x;
      }
      getPublicNotebook_result result = new getPublicNotebook_result();
      result.read(iprot_);
      iprot_.readMessageEnd();
      if (result.isSetSuccess()) {
        return result.success;
      }
      if (result.systemException != null) {
        throw result.systemException;
      }
      if (result.notFoundException != null) {
        throw result.notFoundException;
      }
      throw new TApplicationException(TApplicationException.MISSING_RESULT, "getPublicNotebook failed: unknown result");
    }

    public com.evernote.edam.type.SharedNotebook createSharedNotebook(String authenticationToken, com.evernote.edam.type.SharedNotebook sharedNotebook) throws com.evernote.edam.error.EDAMUserException, com.evernote.edam.error.EDAMNotFoundException, com.evernote.edam.error.EDAMSystemException, TException
    {
      send_createSharedNotebook(authenticationToken, sharedNotebook);
      return recv_createSharedNotebook();
    }

    public void send_createSharedNotebook(String authenticationToken, com.evernote.edam.type.SharedNotebook sharedNotebook) throws TException
    {
      oprot_.writeMessageBegin(new TMessage("createSharedNotebook", TMessageType.CALL, seqid_));
      createSharedNotebook_args args = new createSharedNotebook_args();
      args.authenticationToken = authenticationToken;
      args.sharedNotebook = sharedNotebook;
      args.write(oprot_);
      oprot_.writeMessageEnd();
      oprot_.getTransport().flush();
    }

    public com.evernote.edam.type.SharedNotebook recv_createSharedNotebook() throws com.evernote.edam.error.EDAMUserException, com.evernote.edam.error.EDAMNotFoundException, com.evernote.edam.error.EDAMSystemException, TException
    {
      TMessage msg = iprot_.readMessageBegin();
      if (msg.type == TMessageType.EXCEPTION) {
        TApplicationException x = TApplicationException.read(iprot_);
        iprot_.readMessageEnd();
        throw x;
      }
      createSharedNotebook_result result = new createSharedNotebook_result();
      result.read(iprot_);
      iprot_.readMessageEnd();
      if (result.isSetSuccess()) {
        return result.success;
      }
      if (result.userException != null) {
        throw result.userException;
      }
      if (result.notFoundException != null) {
        throw result.notFoundException;
      }
      if (result.systemException != null) {
        throw result.systemException;
      }
      throw new TApplicationException(TApplicationException.MISSING_RESULT, "createSharedNotebook failed: unknown result");
    }

    public List<com.evernote.edam.type.SharedNotebook> listSharedNotebooks(String authenticationToken) throws com.evernote.edam.error.EDAMUserException, com.evernote.edam.error.EDAMNotFoundException, com.evernote.edam.error.EDAMSystemException, TException
    {
      send_listSharedNotebooks(authenticationToken);
      return recv_listSharedNotebooks();
    }

    public void send_listSharedNotebooks(String authenticationToken) throws TException
    {
      oprot_.writeMessageBegin(new TMessage("listSharedNotebooks", TMessageType.CALL, seqid_));
      listSharedNotebooks_args args = new listSharedNotebooks_args();
      args.authenticationToken = authenticationToken;
      args.write(oprot_);
      oprot_.writeMessageEnd();
      oprot_.getTransport().flush();
    }

    public List<com.evernote.edam.type.SharedNotebook> recv_listSharedNotebooks() throws com.evernote.edam.error.EDAMUserException, com.evernote.edam.error.EDAMNotFoundException, com.evernote.edam.error.EDAMSystemException, TException
    {
      TMessage msg = iprot_.readMessageBegin();
      if (msg.type == TMessageType.EXCEPTION) {
        TApplicationException x = TApplicationException.read(iprot_);
        iprot_.readMessageEnd();
        throw x;
      }
      listSharedNotebooks_result result = new listSharedNotebooks_result();
      result.read(iprot_);
      iprot_.readMessageEnd();
      if (result.isSetSuccess()) {
        return result.success;
      }
      if (result.userException != null) {
        throw result.userException;
      }
      if (result.notFoundException != null) {
        throw result.notFoundException;
      }
      if (result.systemException != null) {
        throw result.systemException;
      }
      throw new TApplicationException(TApplicationException.MISSING_RESULT, "listSharedNotebooks failed: unknown result");
    }

    public int expungeSharedNotebooks(String authenticationToken, List<Long> sharedNotebookIds) throws com.evernote.edam.error.EDAMUserException, com.evernote.edam.error.EDAMNotFoundException, com.evernote.edam.error.EDAMSystemException, TException
    {
      send_expungeSharedNotebooks(authenticationToken, sharedNotebookIds);
      return recv_expungeSharedNotebooks();
    }

    public void send_expungeSharedNotebooks(String authenticationToken, List<Long> sharedNotebookIds) throws TException
    {
      oprot_.writeMessageBegin(new TMessage("expungeSharedNotebooks", TMessageType.CALL, seqid_));
      expungeSharedNotebooks_args args = new expungeSharedNotebooks_args();
      args.authenticationToken = authenticationToken;
      args.sharedNotebookIds = sharedNotebookIds;
      args.write(oprot_);
      oprot_.writeMessageEnd();
      oprot_.getTransport().flush();
    }

    public int recv_expungeSharedNotebooks() throws com.evernote.edam.error.EDAMUserException, com.evernote.edam.error.EDAMNotFoundException, com.evernote.edam.error.EDAMSystemException, TException
    {
      TMessage msg = iprot_.readMessageBegin();
      if (msg.type == TMessageType.EXCEPTION) {
        TApplicationException x = TApplicationException.read(iprot_);
        iprot_.readMessageEnd();
        throw x;
      }
      expungeSharedNotebooks_result result = new expungeSharedNotebooks_result();
      result.read(iprot_);
      iprot_.readMessageEnd();
      if (result.isSetSuccess()) {
        return result.success;
      }
      if (result.userException != null) {
        throw result.userException;
      }
      if (result.notFoundException != null) {
        throw result.notFoundException;
      }
      if (result.systemException != null) {
        throw result.systemException;
      }
      throw new TApplicationException(TApplicationException.MISSING_RESULT, "expungeSharedNotebooks failed: unknown result");
    }

    public com.evernote.edam.type.LinkedNotebook createLinkedNotebook(String authenticationToken, com.evernote.edam.type.LinkedNotebook linkedNotebook) throws com.evernote.edam.error.EDAMUserException, com.evernote.edam.error.EDAMNotFoundException, com.evernote.edam.error.EDAMSystemException, TException
    {
      send_createLinkedNotebook(authenticationToken, linkedNotebook);
      return recv_createLinkedNotebook();
    }

    public void send_createLinkedNotebook(String authenticationToken, com.evernote.edam.type.LinkedNotebook linkedNotebook) throws TException
    {
      oprot_.writeMessageBegin(new TMessage("createLinkedNotebook", TMessageType.CALL, seqid_));
      createLinkedNotebook_args args = new createLinkedNotebook_args();
      args.authenticationToken = authenticationToken;
      args.linkedNotebook = linkedNotebook;
      args.write(oprot_);
      oprot_.writeMessageEnd();
      oprot_.getTransport().flush();
    }

    public com.evernote.edam.type.LinkedNotebook recv_createLinkedNotebook() throws com.evernote.edam.error.EDAMUserException, com.evernote.edam.error.EDAMNotFoundException, com.evernote.edam.error.EDAMSystemException, TException
    {
      TMessage msg = iprot_.readMessageBegin();
      if (msg.type == TMessageType.EXCEPTION) {
        TApplicationException x = TApplicationException.read(iprot_);
        iprot_.readMessageEnd();
        throw x;
      }
      createLinkedNotebook_result result = new createLinkedNotebook_result();
      result.read(iprot_);
      iprot_.readMessageEnd();
      if (result.isSetSuccess()) {
        return result.success;
      }
      if (result.userException != null) {
        throw result.userException;
      }
      if (result.notFoundException != null) {
        throw result.notFoundException;
      }
      if (result.systemException != null) {
        throw result.systemException;
      }
      throw new TApplicationException(TApplicationException.MISSING_RESULT, "createLinkedNotebook failed: unknown result");
    }

    public com.evernote.edam.type.LinkedNotebook updateLinkedNotebook(String authenticationToken, com.evernote.edam.type.LinkedNotebook linkedNotebook) throws com.evernote.edam.error.EDAMUserException, com.evernote.edam.error.EDAMNotFoundException, com.evernote.edam.error.EDAMSystemException, TException
    {
      send_updateLinkedNotebook(authenticationToken, linkedNotebook);
      return recv_updateLinkedNotebook();
    }

    public void send_updateLinkedNotebook(String authenticationToken, com.evernote.edam.type.LinkedNotebook linkedNotebook) throws TException
    {
      oprot_.writeMessageBegin(new TMessage("updateLinkedNotebook", TMessageType.CALL, seqid_));
      updateLinkedNotebook_args args = new updateLinkedNotebook_args();
      args.authenticationToken = authenticationToken;
      args.linkedNotebook = linkedNotebook;
      args.write(oprot_);
      oprot_.writeMessageEnd();
      oprot_.getTransport().flush();
    }

    public com.evernote.edam.type.LinkedNotebook recv_updateLinkedNotebook() throws com.evernote.edam.error.EDAMUserException, com.evernote.edam.error.EDAMNotFoundException, com.evernote.edam.error.EDAMSystemException, TException
    {
      TMessage msg = iprot_.readMessageBegin();
      if (msg.type == TMessageType.EXCEPTION) {
        TApplicationException x = TApplicationException.read(iprot_);
        iprot_.readMessageEnd();
        throw x;
      }
      updateLinkedNotebook_result result = new updateLinkedNotebook_result();
      result.read(iprot_);
      iprot_.readMessageEnd();
      if (result.isSetSuccess()) {
        return result.success;
      }
      if (result.userException != null) {
        throw result.userException;
      }
      if (result.notFoundException != null) {
        throw result.notFoundException;
      }
      if (result.systemException != null) {
        throw result.systemException;
      }
      throw new TApplicationException(TApplicationException.MISSING_RESULT, "updateLinkedNotebook failed: unknown result");
    }

    public List<com.evernote.edam.type.LinkedNotebook> listLinkedNotebooks(String authenticationToken) throws com.evernote.edam.error.EDAMUserException, com.evernote.edam.error.EDAMNotFoundException, com.evernote.edam.error.EDAMSystemException, TException
    {
      send_listLinkedNotebooks(authenticationToken);
      return recv_listLinkedNotebooks();
    }

    public void send_listLinkedNotebooks(String authenticationToken) throws TException
    {
      oprot_.writeMessageBegin(new TMessage("listLinkedNotebooks", TMessageType.CALL, seqid_));
      listLinkedNotebooks_args args = new listLinkedNotebooks_args();
      args.authenticationToken = authenticationToken;
      args.write(oprot_);
      oprot_.writeMessageEnd();
      oprot_.getTransport().flush();
    }

    public List<com.evernote.edam.type.LinkedNotebook> recv_listLinkedNotebooks() throws com.evernote.edam.error.EDAMUserException, com.evernote.edam.error.EDAMNotFoundException, com.evernote.edam.error.EDAMSystemException, TException
    {
      TMessage msg = iprot_.readMessageBegin();
      if (msg.type == TMessageType.EXCEPTION) {
        TApplicationException x = TApplicationException.read(iprot_);
        iprot_.readMessageEnd();
        throw x;
      }
      listLinkedNotebooks_result result = new listLinkedNotebooks_result();
      result.read(iprot_);
      iprot_.readMessageEnd();
      if (result.isSetSuccess()) {
        return result.success;
      }
      if (result.userException != null) {
        throw result.userException;
      }
      if (result.notFoundException != null) {
        throw result.notFoundException;
      }
      if (result.systemException != null) {
        throw result.systemException;
      }
      throw new TApplicationException(TApplicationException.MISSING_RESULT, "listLinkedNotebooks failed: unknown result");
    }

    public int expungeLinkedNotebook(String authenticationToken, long linkedNotebookId) throws com.evernote.edam.error.EDAMUserException, com.evernote.edam.error.EDAMNotFoundException, com.evernote.edam.error.EDAMSystemException, TException
    {
      send_expungeLinkedNotebook(authenticationToken, linkedNotebookId);
      return recv_expungeLinkedNotebook();
    }

    public void send_expungeLinkedNotebook(String authenticationToken, long linkedNotebookId) throws TException
    {
      oprot_.writeMessageBegin(new TMessage("expungeLinkedNotebook", TMessageType.CALL, seqid_));
      expungeLinkedNotebook_args args = new expungeLinkedNotebook_args();
      args.authenticationToken = authenticationToken;
      args.linkedNotebookId = linkedNotebookId;
      args.write(oprot_);
      oprot_.writeMessageEnd();
      oprot_.getTransport().flush();
    }

    public int recv_expungeLinkedNotebook() throws com.evernote.edam.error.EDAMUserException, com.evernote.edam.error.EDAMNotFoundException, com.evernote.edam.error.EDAMSystemException, TException
    {
      TMessage msg = iprot_.readMessageBegin();
      if (msg.type == TMessageType.EXCEPTION) {
        TApplicationException x = TApplicationException.read(iprot_);
        iprot_.readMessageEnd();
        throw x;
      }
      expungeLinkedNotebook_result result = new expungeLinkedNotebook_result();
      result.read(iprot_);
      iprot_.readMessageEnd();
      if (result.isSetSuccess()) {
        return result.success;
      }
      if (result.userException != null) {
        throw result.userException;
      }
      if (result.notFoundException != null) {
        throw result.notFoundException;
      }
      if (result.systemException != null) {
        throw result.systemException;
      }
      throw new TApplicationException(TApplicationException.MISSING_RESULT, "expungeLinkedNotebook failed: unknown result");
    }

    public com.evernote.edam.userstore.AuthenticationResult authenticateToSharedNotebook(String shareKey, String authenticationToken) throws com.evernote.edam.error.EDAMUserException, com.evernote.edam.error.EDAMNotFoundException, com.evernote.edam.error.EDAMSystemException, TException
    {
      send_authenticateToSharedNotebook(shareKey, authenticationToken);
      return recv_authenticateToSharedNotebook();
    }

    public void send_authenticateToSharedNotebook(String shareKey, String authenticationToken) throws TException
    {
      oprot_.writeMessageBegin(new TMessage("authenticateToSharedNotebook", TMessageType.CALL, seqid_));
      authenticateToSharedNotebook_args args = new authenticateToSharedNotebook_args();
      args.shareKey = shareKey;
      args.authenticationToken = authenticationToken;
      args.write(oprot_);
      oprot_.writeMessageEnd();
      oprot_.getTransport().flush();
    }

    public com.evernote.edam.userstore.AuthenticationResult recv_authenticateToSharedNotebook() throws com.evernote.edam.error.EDAMUserException, com.evernote.edam.error.EDAMNotFoundException, com.evernote.edam.error.EDAMSystemException, TException
    {
      TMessage msg = iprot_.readMessageBegin();
      if (msg.type == TMessageType.EXCEPTION) {
        TApplicationException x = TApplicationException.read(iprot_);
        iprot_.readMessageEnd();
        throw x;
      }
      authenticateToSharedNotebook_result result = new authenticateToSharedNotebook_result();
      result.read(iprot_);
      iprot_.readMessageEnd();
      if (result.isSetSuccess()) {
        return result.success;
      }
      if (result.userException != null) {
        throw result.userException;
      }
      if (result.notFoundException != null) {
        throw result.notFoundException;
      }
      if (result.systemException != null) {
        throw result.systemException;
      }
      throw new TApplicationException(TApplicationException.MISSING_RESULT, "authenticateToSharedNotebook failed: unknown result");
    }

    public com.evernote.edam.type.SharedNotebook getSharedNotebookByAuth(String authenticationToken) throws com.evernote.edam.error.EDAMUserException, com.evernote.edam.error.EDAMNotFoundException, com.evernote.edam.error.EDAMSystemException, TException
    {
      send_getSharedNotebookByAuth(authenticationToken);
      return recv_getSharedNotebookByAuth();
    }

    public void send_getSharedNotebookByAuth(String authenticationToken) throws TException
    {
      oprot_.writeMessageBegin(new TMessage("getSharedNotebookByAuth", TMessageType.CALL, seqid_));
      getSharedNotebookByAuth_args args = new getSharedNotebookByAuth_args();
      args.authenticationToken = authenticationToken;
      args.write(oprot_);
      oprot_.writeMessageEnd();
      oprot_.getTransport().flush();
    }

    public com.evernote.edam.type.SharedNotebook recv_getSharedNotebookByAuth() throws com.evernote.edam.error.EDAMUserException, com.evernote.edam.error.EDAMNotFoundException, com.evernote.edam.error.EDAMSystemException, TException
    {
      TMessage msg = iprot_.readMessageBegin();
      if (msg.type == TMessageType.EXCEPTION) {
        TApplicationException x = TApplicationException.read(iprot_);
        iprot_.readMessageEnd();
        throw x;
      }
      getSharedNotebookByAuth_result result = new getSharedNotebookByAuth_result();
      result.read(iprot_);
      iprot_.readMessageEnd();
      if (result.isSetSuccess()) {
        return result.success;
      }
      if (result.userException != null) {
        throw result.userException;
      }
      if (result.notFoundException != null) {
        throw result.notFoundException;
      }
      if (result.systemException != null) {
        throw result.systemException;
      }
      throw new TApplicationException(TApplicationException.MISSING_RESULT, "getSharedNotebookByAuth failed: unknown result");
    }

    public void emailNote(String authenticationToken, NoteEmailParameters parameters) throws com.evernote.edam.error.EDAMUserException, com.evernote.edam.error.EDAMNotFoundException, com.evernote.edam.error.EDAMSystemException, TException
    {
      send_emailNote(authenticationToken, parameters);
      recv_emailNote();
    }

    public void send_emailNote(String authenticationToken, NoteEmailParameters parameters) throws TException
    {
      oprot_.writeMessageBegin(new TMessage("emailNote", TMessageType.CALL, seqid_));
      emailNote_args args = new emailNote_args();
      args.authenticationToken = authenticationToken;
      args.parameters = parameters;
      args.write(oprot_);
      oprot_.writeMessageEnd();
      oprot_.getTransport().flush();
    }

    public void recv_emailNote() throws com.evernote.edam.error.EDAMUserException, com.evernote.edam.error.EDAMNotFoundException, com.evernote.edam.error.EDAMSystemException, TException
    {
      TMessage msg = iprot_.readMessageBegin();
      if (msg.type == TMessageType.EXCEPTION) {
        TApplicationException x = TApplicationException.read(iprot_);
        iprot_.readMessageEnd();
        throw x;
      }
      emailNote_result result = new emailNote_result();
      result.read(iprot_);
      iprot_.readMessageEnd();
      if (result.userException != null) {
        throw result.userException;
      }
      if (result.notFoundException != null) {
        throw result.notFoundException;
      }
      if (result.systemException != null) {
        throw result.systemException;
      }
      return;
    }

  }
  public static class Processor implements TProcessor {
    private static final org.slf4j.Logger LOGGER = org.slf4j.LoggerFactory.getLogger(Processor.class.getName());
    public Processor(Iface iface)
    {
      iface_ = iface;
      processMap_.put("getSyncState", new getSyncState());
      processMap_.put("getSyncChunk", new getSyncChunk());
      processMap_.put("listNotebooks", new listNotebooks());
      processMap_.put("getNotebook", new getNotebook());
      processMap_.put("getDefaultNotebook", new getDefaultNotebook());
      processMap_.put("createNotebook", new createNotebook());
      processMap_.put("updateNotebook", new updateNotebook());
      processMap_.put("expungeNotebook", new expungeNotebook());
      processMap_.put("listTags", new listTags());
      processMap_.put("listTagsByNotebook", new listTagsByNotebook());
      processMap_.put("getTag", new getTag());
      processMap_.put("createTag", new createTag());
      processMap_.put("updateTag", new updateTag());
      processMap_.put("untagAll", new untagAll());
      processMap_.put("expungeTag", new expungeTag());
      processMap_.put("listSearches", new listSearches());
      processMap_.put("getSearch", new getSearch());
      processMap_.put("createSearch", new createSearch());
      processMap_.put("updateSearch", new updateSearch());
      processMap_.put("expungeSearch", new expungeSearch());
      processMap_.put("findNotes", new findNotes());
      processMap_.put("findNoteCounts", new findNoteCounts());
      processMap_.put("getNote", new getNote());
      processMap_.put("getNoteContent", new getNoteContent());
      processMap_.put("getNoteSearchText", new getNoteSearchText());
      processMap_.put("getNoteTagNames", new getNoteTagNames());
      processMap_.put("createNote", new createNote());
      processMap_.put("updateNote", new updateNote());
      processMap_.put("deleteNote", new deleteNote());
      processMap_.put("expungeNote", new expungeNote());
      processMap_.put("expungeNotes", new expungeNotes());
      processMap_.put("expungeInactiveNotes", new expungeInactiveNotes());
      processMap_.put("copyNote", new copyNote());
      processMap_.put("listNoteVersions", new listNoteVersions());
      processMap_.put("getNoteVersion", new getNoteVersion());
      processMap_.put("getResource", new getResource());
      processMap_.put("updateResource", new updateResource());
      processMap_.put("getResourceData", new getResourceData());
      processMap_.put("getResourceByHash", new getResourceByHash());
      processMap_.put("getResourceRecognition", new getResourceRecognition());
      processMap_.put("getResourceAlternateData", new getResourceAlternateData());
      processMap_.put("getResourceAttributes", new getResourceAttributes());
      processMap_.put("getAccountSize", new getAccountSize());
      processMap_.put("getAds", new getAds());
      processMap_.put("getRandomAd", new getRandomAd());
      processMap_.put("getPublicNotebook", new getPublicNotebook());
      processMap_.put("createSharedNotebook", new createSharedNotebook());
      processMap_.put("listSharedNotebooks", new listSharedNotebooks());
      processMap_.put("expungeSharedNotebooks", new expungeSharedNotebooks());
      processMap_.put("createLinkedNotebook", new createLinkedNotebook());
      processMap_.put("updateLinkedNotebook", new updateLinkedNotebook());
      processMap_.put("listLinkedNotebooks", new listLinkedNotebooks());
      processMap_.put("expungeLinkedNotebook", new expungeLinkedNotebook());
      processMap_.put("authenticateToSharedNotebook", new authenticateToSharedNotebook());
      processMap_.put("getSharedNotebookByAuth", new getSharedNotebookByAuth());
      processMap_.put("emailNote", new emailNote());
    }

    protected static interface ProcessFunction {
      public void process(int seqid, TProtocol iprot, TProtocol oprot) throws TException;
    }

    private Iface iface_;
    protected final HashMap<String,ProcessFunction> processMap_ = new HashMap<String,ProcessFunction>();

    public boolean process(TProtocol iprot, TProtocol oprot) throws TException
    {
      TMessage msg = iprot.readMessageBegin();
      ProcessFunction fn = processMap_.get(msg.name);
      if (fn == null) {
        TProtocolUtil.skip(iprot, TType.STRUCT);
        iprot.readMessageEnd();
        TApplicationException x = new TApplicationException(TApplicationException.UNKNOWN_METHOD, "Invalid method name: '"+msg.name+"'");
        oprot.writeMessageBegin(new TMessage(msg.name, TMessageType.EXCEPTION, msg.seqid));
        x.write(oprot);
        oprot.writeMessageEnd();
        oprot.getTransport().flush();
        return true;
      }
      fn.process(msg.seqid, iprot, oprot);
      return true;
    }

    private class getSyncState implements ProcessFunction {
      public void process(int seqid, TProtocol iprot, TProtocol oprot) throws TException
      {
        getSyncState_args args = new getSyncState_args();
        args.read(iprot);
        iprot.readMessageEnd();
        getSyncState_result result = new getSyncState_result();
        try {
          result.success = iface_.getSyncState(args.authenticationToken);
        } catch (com.evernote.edam.error.EDAMUserException userException) {
          result.userException = userException;
        } catch (com.evernote.edam.error.EDAMSystemException systemException) {
          result.systemException = systemException;
        } catch (Throwable th) {
          LOGGER.error("Internal error processing getSyncState", th);
          TApplicationException x = new TApplicationException(TApplicationException.INTERNAL_ERROR, "Internal error processing getSyncState");
          oprot.writeMessageBegin(new TMessage("getSyncState", TMessageType.EXCEPTION, seqid));
          x.write(oprot);
          oprot.writeMessageEnd();
          oprot.getTransport().flush();
          return;
        }
        oprot.writeMessageBegin(new TMessage("getSyncState", TMessageType.REPLY, seqid));
        result.write(oprot);
        oprot.writeMessageEnd();
        oprot.getTransport().flush();
      }

    }

    private class getSyncChunk implements ProcessFunction {
      public void process(int seqid, TProtocol iprot, TProtocol oprot) throws TException
      {
        getSyncChunk_args args = new getSyncChunk_args();
        args.read(iprot);
        iprot.readMessageEnd();
        getSyncChunk_result result = new getSyncChunk_result();
        try {
          result.success = iface_.getSyncChunk(args.authenticationToken, args.afterUSN, args.maxEntries, args.fullSyncOnly);
        } catch (com.evernote.edam.error.EDAMUserException userException) {
          result.userException = userException;
        } catch (com.evernote.edam.error.EDAMSystemException systemException) {
          result.systemException = systemException;
        } catch (Throwable th) {
          LOGGER.error("Internal error processing getSyncChunk", th);
          TApplicationException x = new TApplicationException(TApplicationException.INTERNAL_ERROR, "Internal error processing getSyncChunk");
          oprot.writeMessageBegin(new TMessage("getSyncChunk", TMessageType.EXCEPTION, seqid));
          x.write(oprot);
          oprot.writeMessageEnd();
          oprot.getTransport().flush();
          return;
        }
        oprot.writeMessageBegin(new TMessage("getSyncChunk", TMessageType.REPLY, seqid));
        result.write(oprot);
        oprot.writeMessageEnd();
        oprot.getTransport().flush();
      }

    }

    private class listNotebooks implements ProcessFunction {
      public void process(int seqid, TProtocol iprot, TProtocol oprot) throws TException
      {
        listNotebooks_args args = new listNotebooks_args();
        args.read(iprot);
        iprot.readMessageEnd();
        listNotebooks_result result = new listNotebooks_result();
        try {
          result.success = iface_.listNotebooks(args.authenticationToken);
        } catch (com.evernote.edam.error.EDAMUserException userException) {
          result.userException = userException;
        } catch (com.evernote.edam.error.EDAMSystemException systemException) {
          result.systemException = systemException;
        } catch (Throwable th) {
          LOGGER.error("Internal error processing listNotebooks", th);
          TApplicationException x = new TApplicationException(TApplicationException.INTERNAL_ERROR, "Internal error processing listNotebooks");
          oprot.writeMessageBegin(new TMessage("listNotebooks", TMessageType.EXCEPTION, seqid));
          x.write(oprot);
          oprot.writeMessageEnd();
          oprot.getTransport().flush();
          return;
        }
        oprot.writeMessageBegin(new TMessage("listNotebooks", TMessageType.REPLY, seqid));
        result.write(oprot);
        oprot.writeMessageEnd();
        oprot.getTransport().flush();
      }

    }

    private class getNotebook implements ProcessFunction {
      public void process(int seqid, TProtocol iprot, TProtocol oprot) throws TException
      {
        getNotebook_args args = new getNotebook_args();
        args.read(iprot);
        iprot.readMessageEnd();
        getNotebook_result result = new getNotebook_result();
        try {
          result.success = iface_.getNotebook(args.authenticationToken, args.guid);
        } catch (com.evernote.edam.error.EDAMUserException userException) {
          result.userException = userException;
        } catch (com.evernote.edam.error.EDAMSystemException systemException) {
          result.systemException = systemException;
        } catch (com.evernote.edam.error.EDAMNotFoundException notFoundException) {
          result.notFoundException = notFoundException;
        } catch (Throwable th) {
          LOGGER.error("Internal error processing getNotebook", th);
          TApplicationException x = new TApplicationException(TApplicationException.INTERNAL_ERROR, "Internal error processing getNotebook");
          oprot.writeMessageBegin(new TMessage("getNotebook", TMessageType.EXCEPTION, seqid));
          x.write(oprot);
          oprot.writeMessageEnd();
          oprot.getTransport().flush();
          return;
        }
        oprot.writeMessageBegin(new TMessage("getNotebook", TMessageType.REPLY, seqid));
        result.write(oprot);
        oprot.writeMessageEnd();
        oprot.getTransport().flush();
      }

    }

    private class getDefaultNotebook implements ProcessFunction {
      public void process(int seqid, TProtocol iprot, TProtocol oprot) throws TException
      {
        getDefaultNotebook_args args = new getDefaultNotebook_args();
        args.read(iprot);
        iprot.readMessageEnd();
        getDefaultNotebook_result result = new getDefaultNotebook_result();
        try {
          result.success = iface_.getDefaultNotebook(args.authenticationToken);
        } catch (com.evernote.edam.error.EDAMUserException userException) {
          result.userException = userException;
        } catch (com.evernote.edam.error.EDAMSystemException systemException) {
          result.systemException = systemException;
        } catch (Throwable th) {
          LOGGER.error("Internal error processing getDefaultNotebook", th);
          TApplicationException x = new TApplicationException(TApplicationException.INTERNAL_ERROR, "Internal error processing getDefaultNotebook");
          oprot.writeMessageBegin(new TMessage("getDefaultNotebook", TMessageType.EXCEPTION, seqid));
          x.write(oprot);
          oprot.writeMessageEnd();
          oprot.getTransport().flush();
          return;
        }
        oprot.writeMessageBegin(new TMessage("getDefaultNotebook", TMessageType.REPLY, seqid));
        result.write(oprot);
        oprot.writeMessageEnd();
        oprot.getTransport().flush();
      }

    }

    private class createNotebook implements ProcessFunction {
      public void process(int seqid, TProtocol iprot, TProtocol oprot) throws TException
      {
        createNotebook_args args = new createNotebook_args();
        args.read(iprot);
        iprot.readMessageEnd();
        createNotebook_result result = new createNotebook_result();
        try {
          result.success = iface_.createNotebook(args.authenticationToken, args.notebook);
        } catch (com.evernote.edam.error.EDAMUserException userException) {
          result.userException = userException;
        } catch (com.evernote.edam.error.EDAMSystemException systemException) {
          result.systemException = systemException;
        } catch (Throwable th) {
          LOGGER.error("Internal error processing createNotebook", th);
          TApplicationException x = new TApplicationException(TApplicationException.INTERNAL_ERROR, "Internal error processing createNotebook");
          oprot.writeMessageBegin(new TMessage("createNotebook", TMessageType.EXCEPTION, seqid));
          x.write(oprot);
          oprot.writeMessageEnd();
          oprot.getTransport().flush();
          return;
        }
        oprot.writeMessageBegin(new TMessage("createNotebook", TMessageType.REPLY, seqid));
        result.write(oprot);
        oprot.writeMessageEnd();
        oprot.getTransport().flush();
      }

    }

    private class updateNotebook implements ProcessFunction {
      public void process(int seqid, TProtocol iprot, TProtocol oprot) throws TException
      {
        updateNotebook_args args = new updateNotebook_args();
        args.read(iprot);
        iprot.readMessageEnd();
        updateNotebook_result result = new updateNotebook_result();
        try {
          result.success = iface_.updateNotebook(args.authenticationToken, args.notebook);
          result.setSuccessIsSet(true);
        } catch (com.evernote.edam.error.EDAMUserException userException) {
          result.userException = userException;
        } catch (com.evernote.edam.error.EDAMSystemException systemException) {
          result.systemException = systemException;
        } catch (com.evernote.edam.error.EDAMNotFoundException notFoundException) {
          result.notFoundException = notFoundException;
        } catch (Throwable th) {
          LOGGER.error("Internal error processing updateNotebook", th);
          TApplicationException x = new TApplicationException(TApplicationException.INTERNAL_ERROR, "Internal error processing updateNotebook");
          oprot.writeMessageBegin(new TMessage("updateNotebook", TMessageType.EXCEPTION, seqid));
          x.write(oprot);
          oprot.writeMessageEnd();
          oprot.getTransport().flush();
          return;
        }
        oprot.writeMessageBegin(new TMessage("updateNotebook", TMessageType.REPLY, seqid));
        result.write(oprot);
        oprot.writeMessageEnd();
        oprot.getTransport().flush();
      }

    }

    private class expungeNotebook implements ProcessFunction {
      public void process(int seqid, TProtocol iprot, TProtocol oprot) throws TException
      {
        expungeNotebook_args args = new expungeNotebook_args();
        args.read(iprot);
        iprot.readMessageEnd();
        expungeNotebook_result result = new expungeNotebook_result();
        try {
          result.success = iface_.expungeNotebook(args.authenticationToken, args.guid);
          result.setSuccessIsSet(true);
        } catch (com.evernote.edam.error.EDAMUserException userException) {
          result.userException = userException;
        } catch (com.evernote.edam.error.EDAMSystemException systemException) {
          result.systemException = systemException;
        } catch (com.evernote.edam.error.EDAMNotFoundException notFoundException) {
          result.notFoundException = notFoundException;
        } catch (Throwable th) {
          LOGGER.error("Internal error processing expungeNotebook", th);
          TApplicationException x = new TApplicationException(TApplicationException.INTERNAL_ERROR, "Internal error processing expungeNotebook");
          oprot.writeMessageBegin(new TMessage("expungeNotebook", TMessageType.EXCEPTION, seqid));
          x.write(oprot);
          oprot.writeMessageEnd();
          oprot.getTransport().flush();
          return;
        }
        oprot.writeMessageBegin(new TMessage("expungeNotebook", TMessageType.REPLY, seqid));
        result.write(oprot);
        oprot.writeMessageEnd();
        oprot.getTransport().flush();
      }

    }

    private class listTags implements ProcessFunction {
      public void process(int seqid, TProtocol iprot, TProtocol oprot) throws TException
      {
        listTags_args args = new listTags_args();
        args.read(iprot);
        iprot.readMessageEnd();
        listTags_result result = new listTags_result();
        try {
          result.success = iface_.listTags(args.authenticationToken);
        } catch (com.evernote.edam.error.EDAMUserException userException) {
          result.userException = userException;
        } catch (com.evernote.edam.error.EDAMSystemException systemException) {
          result.systemException = systemException;
        } catch (Throwable th) {
          LOGGER.error("Internal error processing listTags", th);
          TApplicationException x = new TApplicationException(TApplicationException.INTERNAL_ERROR, "Internal error processing listTags");
          oprot.writeMessageBegin(new TMessage("listTags", TMessageType.EXCEPTION, seqid));
          x.write(oprot);
          oprot.writeMessageEnd();
          oprot.getTransport().flush();
          return;
        }
        oprot.writeMessageBegin(new TMessage("listTags", TMessageType.REPLY, seqid));
        result.write(oprot);
        oprot.writeMessageEnd();
        oprot.getTransport().flush();
      }

    }

    private class listTagsByNotebook implements ProcessFunction {
      public void process(int seqid, TProtocol iprot, TProtocol oprot) throws TException
      {
        listTagsByNotebook_args args = new listTagsByNotebook_args();
        args.read(iprot);
        iprot.readMessageEnd();
        listTagsByNotebook_result result = new listTagsByNotebook_result();
        try {
          result.success = iface_.listTagsByNotebook(args.authenticationToken, args.notebookGuid);
        } catch (com.evernote.edam.error.EDAMUserException userException) {
          result.userException = userException;
        } catch (com.evernote.edam.error.EDAMSystemException systemException) {
          result.systemException = systemException;
        } catch (com.evernote.edam.error.EDAMNotFoundException notFoundException) {
          result.notFoundException = notFoundException;
        } catch (Throwable th) {
          LOGGER.error("Internal error processing listTagsByNotebook", th);
          TApplicationException x = new TApplicationException(TApplicationException.INTERNAL_ERROR, "Internal error processing listTagsByNotebook");
          oprot.writeMessageBegin(new TMessage("listTagsByNotebook", TMessageType.EXCEPTION, seqid));
          x.write(oprot);
          oprot.writeMessageEnd();
          oprot.getTransport().flush();
          return;
        }
        oprot.writeMessageBegin(new TMessage("listTagsByNotebook", TMessageType.REPLY, seqid));
        result.write(oprot);
        oprot.writeMessageEnd();
        oprot.getTransport().flush();
      }

    }

    private class getTag implements ProcessFunction {
      public void process(int seqid, TProtocol iprot, TProtocol oprot) throws TException
      {
        getTag_args args = new getTag_args();
        args.read(iprot);
        iprot.readMessageEnd();
        getTag_result result = new getTag_result();
        try {
          result.success = iface_.getTag(args.authenticationToken, args.guid);
        } catch (com.evernote.edam.error.EDAMUserException userException) {
          result.userException = userException;
        } catch (com.evernote.edam.error.EDAMSystemException systemException) {
          result.systemException = systemException;
        } catch (com.evernote.edam.error.EDAMNotFoundException notFoundException) {
          result.notFoundException = notFoundException;
        } catch (Throwable th) {
          LOGGER.error("Internal error processing getTag", th);
          TApplicationException x = new TApplicationException(TApplicationException.INTERNAL_ERROR, "Internal error processing getTag");
          oprot.writeMessageBegin(new TMessage("getTag", TMessageType.EXCEPTION, seqid));
          x.write(oprot);
          oprot.writeMessageEnd();
          oprot.getTransport().flush();
          return;
        }
        oprot.writeMessageBegin(new TMessage("getTag", TMessageType.REPLY, seqid));
        result.write(oprot);
        oprot.writeMessageEnd();
        oprot.getTransport().flush();
      }

    }

    private class createTag implements ProcessFunction {
      public void process(int seqid, TProtocol iprot, TProtocol oprot) throws TException
      {
        createTag_args args = new createTag_args();
        args.read(iprot);
        iprot.readMessageEnd();
        createTag_result result = new createTag_result();
        try {
          result.success = iface_.createTag(args.authenticationToken, args.tag);
        } catch (com.evernote.edam.error.EDAMUserException userException) {
          result.userException = userException;
        } catch (com.evernote.edam.error.EDAMSystemException systemException) {
          result.systemException = systemException;
        } catch (com.evernote.edam.error.EDAMNotFoundException notFoundException) {
          result.notFoundException = notFoundException;
        } catch (Throwable th) {
          LOGGER.error("Internal error processing createTag", th);
          TApplicationException x = new TApplicationException(TApplicationException.INTERNAL_ERROR, "Internal error processing createTag");
          oprot.writeMessageBegin(new TMessage("createTag", TMessageType.EXCEPTION, seqid));
          x.write(oprot);
          oprot.writeMessageEnd();
          oprot.getTransport().flush();
          return;
        }
        oprot.writeMessageBegin(new TMessage("createTag", TMessageType.REPLY, seqid));
        result.write(oprot);
        oprot.writeMessageEnd();
        oprot.getTransport().flush();
      }

    }

    private class updateTag implements ProcessFunction {
      public void process(int seqid, TProtocol iprot, TProtocol oprot) throws TException
      {
        updateTag_args args = new updateTag_args();
        args.read(iprot);
        iprot.readMessageEnd();
        updateTag_result result = new updateTag_result();
        try {
          result.success = iface_.updateTag(args.authenticationToken, args.tag);
          result.setSuccessIsSet(true);
        } catch (com.evernote.edam.error.EDAMUserException userException) {
          result.userException = userException;
        } catch (com.evernote.edam.error.EDAMSystemException systemException) {
          result.systemException = systemException;
        } catch (com.evernote.edam.error.EDAMNotFoundException notFoundException) {
          result.notFoundException = notFoundException;
        } catch (Throwable th) {
          LOGGER.error("Internal error processing updateTag", th);
          TApplicationException x = new TApplicationException(TApplicationException.INTERNAL_ERROR, "Internal error processing updateTag");
          oprot.writeMessageBegin(new TMessage("updateTag", TMessageType.EXCEPTION, seqid));
          x.write(oprot);
          oprot.writeMessageEnd();
          oprot.getTransport().flush();
          return;
        }
        oprot.writeMessageBegin(new TMessage("updateTag", TMessageType.REPLY, seqid));
        result.write(oprot);
        oprot.writeMessageEnd();
        oprot.getTransport().flush();
      }

    }

    private class untagAll implements ProcessFunction {
      public void process(int seqid, TProtocol iprot, TProtocol oprot) throws TException
      {
        untagAll_args args = new untagAll_args();
        args.read(iprot);
        iprot.readMessageEnd();
        untagAll_result result = new untagAll_result();
        try {
          iface_.untagAll(args.authenticationToken, args.guid);
        } catch (com.evernote.edam.error.EDAMUserException userException) {
          result.userException = userException;
        } catch (com.evernote.edam.error.EDAMSystemException systemException) {
          result.systemException = systemException;
        } catch (com.evernote.edam.error.EDAMNotFoundException notFoundException) {
          result.notFoundException = notFoundException;
        } catch (Throwable th) {
          LOGGER.error("Internal error processing untagAll", th);
          TApplicationException x = new TApplicationException(TApplicationException.INTERNAL_ERROR, "Internal error processing untagAll");
          oprot.writeMessageBegin(new TMessage("untagAll", TMessageType.EXCEPTION, seqid));
          x.write(oprot);
          oprot.writeMessageEnd();
          oprot.getTransport().flush();
          return;
        }
        oprot.writeMessageBegin(new TMessage("untagAll", TMessageType.REPLY, seqid));
        result.write(oprot);
        oprot.writeMessageEnd();
        oprot.getTransport().flush();
      }

    }

    private class expungeTag implements ProcessFunction {
      public void process(int seqid, TProtocol iprot, TProtocol oprot) throws TException
      {
        expungeTag_args args = new expungeTag_args();
        args.read(iprot);
        iprot.readMessageEnd();
        expungeTag_result result = new expungeTag_result();
        try {
          result.success = iface_.expungeTag(args.authenticationToken, args.guid);
          result.setSuccessIsSet(true);
        } catch (com.evernote.edam.error.EDAMUserException userException) {
          result.userException = userException;
        } catch (com.evernote.edam.error.EDAMSystemException systemException) {
          result.systemException = systemException;
        } catch (com.evernote.edam.error.EDAMNotFoundException notFoundException) {
          result.notFoundException = notFoundException;
        } catch (Throwable th) {
          LOGGER.error("Internal error processing expungeTag", th);
          TApplicationException x = new TApplicationException(TApplicationException.INTERNAL_ERROR, "Internal error processing expungeTag");
          oprot.writeMessageBegin(new TMessage("expungeTag", TMessageType.EXCEPTION, seqid));
          x.write(oprot);
          oprot.writeMessageEnd();
          oprot.getTransport().flush();
          return;
        }
        oprot.writeMessageBegin(new TMessage("expungeTag", TMessageType.REPLY, seqid));
        result.write(oprot);
        oprot.writeMessageEnd();
        oprot.getTransport().flush();
      }

    }

    private class listSearches implements ProcessFunction {
      public void process(int seqid, TProtocol iprot, TProtocol oprot) throws TException
      {
        listSearches_args args = new listSearches_args();
        args.read(iprot);
        iprot.readMessageEnd();
        listSearches_result result = new listSearches_result();
        try {
          result.success = iface_.listSearches(args.authenticationToken);
        } catch (com.evernote.edam.error.EDAMUserException userException) {
          result.userException = userException;
        } catch (com.evernote.edam.error.EDAMSystemException systemException) {
          result.systemException = systemException;
        } catch (Throwable th) {
          LOGGER.error("Internal error processing listSearches", th);
          TApplicationException x = new TApplicationException(TApplicationException.INTERNAL_ERROR, "Internal error processing listSearches");
          oprot.writeMessageBegin(new TMessage("listSearches", TMessageType.EXCEPTION, seqid));
          x.write(oprot);
          oprot.writeMessageEnd();
          oprot.getTransport().flush();
          return;
        }
        oprot.writeMessageBegin(new TMessage("listSearches", TMessageType.REPLY, seqid));
        result.write(oprot);
        oprot.writeMessageEnd();
        oprot.getTransport().flush();
      }

    }

    private class getSearch implements ProcessFunction {
      public void process(int seqid, TProtocol iprot, TProtocol oprot) throws TException
      {
        getSearch_args args = new getSearch_args();
        args.read(iprot);
        iprot.readMessageEnd();
        getSearch_result result = new getSearch_result();
        try {
          result.success = iface_.getSearch(args.authenticationToken, args.guid);
        } catch (com.evernote.edam.error.EDAMUserException userException) {
          result.userException = userException;
        } catch (com.evernote.edam.error.EDAMSystemException systemException) {
          result.systemException = systemException;
        } catch (com.evernote.edam.error.EDAMNotFoundException notFoundException) {
          result.notFoundException = notFoundException;
        } catch (Throwable th) {
          LOGGER.error("Internal error processing getSearch", th);
          TApplicationException x = new TApplicationException(TApplicationException.INTERNAL_ERROR, "Internal error processing getSearch");
          oprot.writeMessageBegin(new TMessage("getSearch", TMessageType.EXCEPTION, seqid));
          x.write(oprot);
          oprot.writeMessageEnd();
          oprot.getTransport().flush();
          return;
        }
        oprot.writeMessageBegin(new TMessage("getSearch", TMessageType.REPLY, seqid));
        result.write(oprot);
        oprot.writeMessageEnd();
        oprot.getTransport().flush();
      }

    }

    private class createSearch implements ProcessFunction {
      public void process(int seqid, TProtocol iprot, TProtocol oprot) throws TException
      {
        createSearch_args args = new createSearch_args();
        args.read(iprot);
        iprot.readMessageEnd();
        createSearch_result result = new createSearch_result();
        try {
          result.success = iface_.createSearch(args.authenticationToken, args.search);
        } catch (com.evernote.edam.error.EDAMUserException userException) {
          result.userException = userException;
        } catch (com.evernote.edam.error.EDAMSystemException systemException) {
          result.systemException = systemException;
        } catch (Throwable th) {
          LOGGER.error("Internal error processing createSearch", th);
          TApplicationException x = new TApplicationException(TApplicationException.INTERNAL_ERROR, "Internal error processing createSearch");
          oprot.writeMessageBegin(new TMessage("createSearch", TMessageType.EXCEPTION, seqid));
          x.write(oprot);
          oprot.writeMessageEnd();
          oprot.getTransport().flush();
          return;
        }
        oprot.writeMessageBegin(new TMessage("createSearch", TMessageType.REPLY, seqid));
        result.write(oprot);
        oprot.writeMessageEnd();
        oprot.getTransport().flush();
      }

    }

    private class updateSearch implements ProcessFunction {
      public void process(int seqid, TProtocol iprot, TProtocol oprot) throws TException
      {
        updateSearch_args args = new updateSearch_args();
        args.read(iprot);
        iprot.readMessageEnd();
        updateSearch_result result = new updateSearch_result();
        try {
          result.success = iface_.updateSearch(args.authenticationToken, args.search);
          result.setSuccessIsSet(true);
        } catch (com.evernote.edam.error.EDAMUserException userException) {
          result.userException = userException;
        } catch (com.evernote.edam.error.EDAMSystemException systemException) {
          result.systemException = systemException;
        } catch (com.evernote.edam.error.EDAMNotFoundException notFoundException) {
          result.notFoundException = notFoundException;
        } catch (Throwable th) {
          LOGGER.error("Internal error processing updateSearch", th);
          TApplicationException x = new TApplicationException(TApplicationException.INTERNAL_ERROR, "Internal error processing updateSearch");
          oprot.writeMessageBegin(new TMessage("updateSearch", TMessageType.EXCEPTION, seqid));
          x.write(oprot);
          oprot.writeMessageEnd();
          oprot.getTransport().flush();
          return;
        }
        oprot.writeMessageBegin(new TMessage("updateSearch", TMessageType.REPLY, seqid));
        result.write(oprot);
        oprot.writeMessageEnd();
        oprot.getTransport().flush();
      }

    }

    private class expungeSearch implements ProcessFunction {
      public void process(int seqid, TProtocol iprot, TProtocol oprot) throws TException
      {
        expungeSearch_args args = new expungeSearch_args();
        args.read(iprot);
        iprot.readMessageEnd();
        expungeSearch_result result = new expungeSearch_result();
        try {
          result.success = iface_.expungeSearch(args.authenticationToken, args.guid);
          result.setSuccessIsSet(true);
        } catch (com.evernote.edam.error.EDAMUserException userException) {
          result.userException = userException;
        } catch (com.evernote.edam.error.EDAMSystemException systemException) {
          result.systemException = systemException;
        } catch (com.evernote.edam.error.EDAMNotFoundException notFoundException) {
          result.notFoundException = notFoundException;
        } catch (Throwable th) {
          LOGGER.error("Internal error processing expungeSearch", th);
          TApplicationException x = new TApplicationException(TApplicationException.INTERNAL_ERROR, "Internal error processing expungeSearch");
          oprot.writeMessageBegin(new TMessage("expungeSearch", TMessageType.EXCEPTION, seqid));
          x.write(oprot);
          oprot.writeMessageEnd();
          oprot.getTransport().flush();
          return;
        }
        oprot.writeMessageBegin(new TMessage("expungeSearch", TMessageType.REPLY, seqid));
        result.write(oprot);
        oprot.writeMessageEnd();
        oprot.getTransport().flush();
      }

    }

    private class findNotes implements ProcessFunction {
      public void process(int seqid, TProtocol iprot, TProtocol oprot) throws TException
      {
        findNotes_args args = new findNotes_args();
        args.read(iprot);
        iprot.readMessageEnd();
        findNotes_result result = new findNotes_result();
        try {
          result.success = iface_.findNotes(args.authenticationToken, args.filter, args.offset, args.maxNotes);
        } catch (com.evernote.edam.error.EDAMUserException userException) {
          result.userException = userException;
        } catch (com.evernote.edam.error.EDAMSystemException systemException) {
          result.systemException = systemException;
        } catch (com.evernote.edam.error.EDAMNotFoundException notFoundException) {
          result.notFoundException = notFoundException;
        } catch (Throwable th) {
          LOGGER.error("Internal error processing findNotes", th);
          TApplicationException x = new TApplicationException(TApplicationException.INTERNAL_ERROR, "Internal error processing findNotes");
          oprot.writeMessageBegin(new TMessage("findNotes", TMessageType.EXCEPTION, seqid));
          x.write(oprot);
          oprot.writeMessageEnd();
          oprot.getTransport().flush();
          return;
        }
        oprot.writeMessageBegin(new TMessage("findNotes", TMessageType.REPLY, seqid));
        result.write(oprot);
        oprot.writeMessageEnd();
        oprot.getTransport().flush();
      }

    }

    private class findNoteCounts implements ProcessFunction {
      public void process(int seqid, TProtocol iprot, TProtocol oprot) throws TException
      {
        findNoteCounts_args args = new findNoteCounts_args();
        args.read(iprot);
        iprot.readMessageEnd();
        findNoteCounts_result result = new findNoteCounts_result();
        try {
          result.success = iface_.findNoteCounts(args.authenticationToken, args.filter, args.withTrash);
        } catch (com.evernote.edam.error.EDAMUserException userException) {
          result.userException = userException;
        } catch (com.evernote.edam.error.EDAMSystemException systemException) {
          result.systemException = systemException;
        } catch (com.evernote.edam.error.EDAMNotFoundException notFoundException) {
          result.notFoundException = notFoundException;
        } catch (Throwable th) {
          LOGGER.error("Internal error processing findNoteCounts", th);
          TApplicationException x = new TApplicationException(TApplicationException.INTERNAL_ERROR, "Internal error processing findNoteCounts");
          oprot.writeMessageBegin(new TMessage("findNoteCounts", TMessageType.EXCEPTION, seqid));
          x.write(oprot);
          oprot.writeMessageEnd();
          oprot.getTransport().flush();
          return;
        }
        oprot.writeMessageBegin(new TMessage("findNoteCounts", TMessageType.REPLY, seqid));
        result.write(oprot);
        oprot.writeMessageEnd();
        oprot.getTransport().flush();
      }

    }

    private class getNote implements ProcessFunction {
      public void process(int seqid, TProtocol iprot, TProtocol oprot) throws TException
      {
        getNote_args args = new getNote_args();
        args.read(iprot);
        iprot.readMessageEnd();
        getNote_result result = new getNote_result();
        try {
          result.success = iface_.getNote(args.authenticationToken, args.guid, args.withContent, args.withResourcesData, args.withResourcesRecognition, args.withResourcesAlternateData);
        } catch (com.evernote.edam.error.EDAMUserException userException) {
          result.userException = userException;
        } catch (com.evernote.edam.error.EDAMSystemException systemException) {
          result.systemException = systemException;
        } catch (com.evernote.edam.error.EDAMNotFoundException notFoundException) {
          result.notFoundException = notFoundException;
        } catch (Throwable th) {
          LOGGER.error("Internal error processing getNote", th);
          TApplicationException x = new TApplicationException(TApplicationException.INTERNAL_ERROR, "Internal error processing getNote");
          oprot.writeMessageBegin(new TMessage("getNote", TMessageType.EXCEPTION, seqid));
          x.write(oprot);
          oprot.writeMessageEnd();
          oprot.getTransport().flush();
          return;
        }
        oprot.writeMessageBegin(new TMessage("getNote", TMessageType.REPLY, seqid));
        result.write(oprot);
        oprot.writeMessageEnd();
        oprot.getTransport().flush();
      }

    }

    private class getNoteContent implements ProcessFunction {
      public void process(int seqid, TProtocol iprot, TProtocol oprot) throws TException
      {
        getNoteContent_args args = new getNoteContent_args();
        args.read(iprot);
        iprot.readMessageEnd();
        getNoteContent_result result = new getNoteContent_result();
        try {
          result.success = iface_.getNoteContent(args.authenticationToken, args.guid);
        } catch (com.evernote.edam.error.EDAMUserException userException) {
          result.userException = userException;
        } catch (com.evernote.edam.error.EDAMSystemException systemException) {
          result.systemException = systemException;
        } catch (com.evernote.edam.error.EDAMNotFoundException notFoundException) {
          result.notFoundException = notFoundException;
        } catch (Throwable th) {
          LOGGER.error("Internal error processing getNoteContent", th);
          TApplicationException x = new TApplicationException(TApplicationException.INTERNAL_ERROR, "Internal error processing getNoteContent");
          oprot.writeMessageBegin(new TMessage("getNoteContent", TMessageType.EXCEPTION, seqid));
          x.write(oprot);
          oprot.writeMessageEnd();
          oprot.getTransport().flush();
          return;
        }
        oprot.writeMessageBegin(new TMessage("getNoteContent", TMessageType.REPLY, seqid));
        result.write(oprot);
        oprot.writeMessageEnd();
        oprot.getTransport().flush();
      }

    }

    private class getNoteSearchText implements ProcessFunction {
      public void process(int seqid, TProtocol iprot, TProtocol oprot) throws TException
      {
        getNoteSearchText_args args = new getNoteSearchText_args();
        args.read(iprot);
        iprot.readMessageEnd();
        getNoteSearchText_result result = new getNoteSearchText_result();
        try {
          result.success = iface_.getNoteSearchText(args.authenticationToken, args.guid);
        } catch (com.evernote.edam.error.EDAMUserException userException) {
          result.userException = userException;
        } catch (com.evernote.edam.error.EDAMSystemException systemException) {
          result.systemException = systemException;
        } catch (com.evernote.edam.error.EDAMNotFoundException notFoundException) {
          result.notFoundException = notFoundException;
        } catch (Throwable th) {
          LOGGER.error("Internal error processing getNoteSearchText", th);
          TApplicationException x = new TApplicationException(TApplicationException.INTERNAL_ERROR, "Internal error processing getNoteSearchText");
          oprot.writeMessageBegin(new TMessage("getNoteSearchText", TMessageType.EXCEPTION, seqid));
          x.write(oprot);
          oprot.writeMessageEnd();
          oprot.getTransport().flush();
          return;
        }
        oprot.writeMessageBegin(new TMessage("getNoteSearchText", TMessageType.REPLY, seqid));
        result.write(oprot);
        oprot.writeMessageEnd();
        oprot.getTransport().flush();
      }

    }

    private class getNoteTagNames implements ProcessFunction {
      public void process(int seqid, TProtocol iprot, TProtocol oprot) throws TException
      {
        getNoteTagNames_args args = new getNoteTagNames_args();
        args.read(iprot);
        iprot.readMessageEnd();
        getNoteTagNames_result result = new getNoteTagNames_result();
        try {
          result.success = iface_.getNoteTagNames(args.authenticationToken, args.guid);
        } catch (com.evernote.edam.error.EDAMUserException userException) {
          result.userException = userException;
        } catch (com.evernote.edam.error.EDAMSystemException systemException) {
          result.systemException = systemException;
        } catch (com.evernote.edam.error.EDAMNotFoundException notFoundException) {
          result.notFoundException = notFoundException;
        } catch (Throwable th) {
          LOGGER.error("Internal error processing getNoteTagNames", th);
          TApplicationException x = new TApplicationException(TApplicationException.INTERNAL_ERROR, "Internal error processing getNoteTagNames");
          oprot.writeMessageBegin(new TMessage("getNoteTagNames", TMessageType.EXCEPTION, seqid));
          x.write(oprot);
          oprot.writeMessageEnd();
          oprot.getTransport().flush();
          return;
        }
        oprot.writeMessageBegin(new TMessage("getNoteTagNames", TMessageType.REPLY, seqid));
        result.write(oprot);
        oprot.writeMessageEnd();
        oprot.getTransport().flush();
      }

    }

    private class createNote implements ProcessFunction {
      public void process(int seqid, TProtocol iprot, TProtocol oprot) throws TException
      {
        createNote_args args = new createNote_args();
        args.read(iprot);
        iprot.readMessageEnd();
        createNote_result result = new createNote_result();
        try {
          result.success = iface_.createNote(args.authenticationToken, args.note);
        } catch (com.evernote.edam.error.EDAMUserException userException) {
          result.userException = userException;
        } catch (com.evernote.edam.error.EDAMSystemException systemException) {
          result.systemException = systemException;
        } catch (com.evernote.edam.error.EDAMNotFoundException notFoundException) {
          result.notFoundException = notFoundException;
        } catch (Throwable th) {
          LOGGER.error("Internal error processing createNote", th);
          TApplicationException x = new TApplicationException(TApplicationException.INTERNAL_ERROR, "Internal error processing createNote");
          oprot.writeMessageBegin(new TMessage("createNote", TMessageType.EXCEPTION, seqid));
          x.write(oprot);
          oprot.writeMessageEnd();
          oprot.getTransport().flush();
          return;
        }
        oprot.writeMessageBegin(new TMessage("createNote", TMessageType.REPLY, seqid));
        result.write(oprot);
        oprot.writeMessageEnd();
        oprot.getTransport().flush();
      }

    }

    private class updateNote implements ProcessFunction {
      public void process(int seqid, TProtocol iprot, TProtocol oprot) throws TException
      {
        updateNote_args args = new updateNote_args();
        args.read(iprot);
        iprot.readMessageEnd();
        updateNote_result result = new updateNote_result();
        try {
          result.success = iface_.updateNote(args.authenticationToken, args.note);
        } catch (com.evernote.edam.error.EDAMUserException userException) {
          result.userException = userException;
        } catch (com.evernote.edam.error.EDAMSystemException systemException) {
          result.systemException = systemException;
        } catch (com.evernote.edam.error.EDAMNotFoundException notFoundException) {
          result.notFoundException = notFoundException;
        } catch (Throwable th) {
          LOGGER.error("Internal error processing updateNote", th);
          TApplicationException x = new TApplicationException(TApplicationException.INTERNAL_ERROR, "Internal error processing updateNote");
          oprot.writeMessageBegin(new TMessage("updateNote", TMessageType.EXCEPTION, seqid));
          x.write(oprot);
          oprot.writeMessageEnd();
          oprot.getTransport().flush();
          return;
        }
        oprot.writeMessageBegin(new TMessage("updateNote", TMessageType.REPLY, seqid));
        result.write(oprot);
        oprot.writeMessageEnd();
        oprot.getTransport().flush();
      }

    }

    private class deleteNote implements ProcessFunction {
      public void process(int seqid, TProtocol iprot, TProtocol oprot) throws TException
      {
        deleteNote_args args = new deleteNote_args();
        args.read(iprot);
        iprot.readMessageEnd();
        deleteNote_result result = new deleteNote_result();
        try {
          result.success = iface_.deleteNote(args.authenticationToken, args.guid);
          result.setSuccessIsSet(true);
        } catch (com.evernote.edam.error.EDAMUserException userException) {
          result.userException = userException;
        } catch (com.evernote.edam.error.EDAMSystemException systemException) {
          result.systemException = systemException;
        } catch (com.evernote.edam.error.EDAMNotFoundException notFoundException) {
          result.notFoundException = notFoundException;
        } catch (Throwable th) {
          LOGGER.error("Internal error processing deleteNote", th);
          TApplicationException x = new TApplicationException(TApplicationException.INTERNAL_ERROR, "Internal error processing deleteNote");
          oprot.writeMessageBegin(new TMessage("deleteNote", TMessageType.EXCEPTION, seqid));
          x.write(oprot);
          oprot.writeMessageEnd();
          oprot.getTransport().flush();
          return;
        }
        oprot.writeMessageBegin(new TMessage("deleteNote", TMessageType.REPLY, seqid));
        result.write(oprot);
        oprot.writeMessageEnd();
        oprot.getTransport().flush();
      }

    }

    private class expungeNote implements ProcessFunction {
      public void process(int seqid, TProtocol iprot, TProtocol oprot) throws TException
      {
        expungeNote_args args = new expungeNote_args();
        args.read(iprot);
        iprot.readMessageEnd();
        expungeNote_result result = new expungeNote_result();
        try {
          result.success = iface_.expungeNote(args.authenticationToken, args.guid);
          result.setSuccessIsSet(true);
        } catch (com.evernote.edam.error.EDAMUserException userException) {
          result.userException = userException;
        } catch (com.evernote.edam.error.EDAMSystemException systemException) {
          result.systemException = systemException;
        } catch (com.evernote.edam.error.EDAMNotFoundException notFoundException) {
          result.notFoundException = notFoundException;
        } catch (Throwable th) {
          LOGGER.error("Internal error processing expungeNote", th);
          TApplicationException x = new TApplicationException(TApplicationException.INTERNAL_ERROR, "Internal error processing expungeNote");
          oprot.writeMessageBegin(new TMessage("expungeNote", TMessageType.EXCEPTION, seqid));
          x.write(oprot);
          oprot.writeMessageEnd();
          oprot.getTransport().flush();
          return;
        }
        oprot.writeMessageBegin(new TMessage("expungeNote", TMessageType.REPLY, seqid));
        result.write(oprot);
        oprot.writeMessageEnd();
        oprot.getTransport().flush();
      }

    }

    private class expungeNotes implements ProcessFunction {
      public void process(int seqid, TProtocol iprot, TProtocol oprot) throws TException
      {
        expungeNotes_args args = new expungeNotes_args();
        args.read(iprot);
        iprot.readMessageEnd();
        expungeNotes_result result = new expungeNotes_result();
        try {
          result.success = iface_.expungeNotes(args.authenticationToken, args.noteGuids);
          result.setSuccessIsSet(true);
        } catch (com.evernote.edam.error.EDAMUserException userException) {
          result.userException = userException;
        } catch (com.evernote.edam.error.EDAMSystemException systemException) {
          result.systemException = systemException;
        } catch (com.evernote.edam.error.EDAMNotFoundException notFoundException) {
          result.notFoundException = notFoundException;
        } catch (Throwable th) {
          LOGGER.error("Internal error processing expungeNotes", th);
          TApplicationException x = new TApplicationException(TApplicationException.INTERNAL_ERROR, "Internal error processing expungeNotes");
          oprot.writeMessageBegin(new TMessage("expungeNotes", TMessageType.EXCEPTION, seqid));
          x.write(oprot);
          oprot.writeMessageEnd();
          oprot.getTransport().flush();
          return;
        }
        oprot.writeMessageBegin(new TMessage("expungeNotes", TMessageType.REPLY, seqid));
        result.write(oprot);
        oprot.writeMessageEnd();
        oprot.getTransport().flush();
      }

    }

    private class expungeInactiveNotes implements ProcessFunction {
      public void process(int seqid, TProtocol iprot, TProtocol oprot) throws TException
      {
        expungeInactiveNotes_args args = new expungeInactiveNotes_args();
        args.read(iprot);
        iprot.readMessageEnd();
        expungeInactiveNotes_result result = new expungeInactiveNotes_result();
        try {
          result.success = iface_.expungeInactiveNotes(args.authenticationToken);
          result.setSuccessIsSet(true);
        } catch (com.evernote.edam.error.EDAMUserException userException) {
          result.userException = userException;
        } catch (com.evernote.edam.error.EDAMSystemException systemException) {
          result.systemException = systemException;
        } catch (Throwable th) {
          LOGGER.error("Internal error processing expungeInactiveNotes", th);
          TApplicationException x = new TApplicationException(TApplicationException.INTERNAL_ERROR, "Internal error processing expungeInactiveNotes");
          oprot.writeMessageBegin(new TMessage("expungeInactiveNotes", TMessageType.EXCEPTION, seqid));
          x.write(oprot);
          oprot.writeMessageEnd();
          oprot.getTransport().flush();
          return;
        }
        oprot.writeMessageBegin(new TMessage("expungeInactiveNotes", TMessageType.REPLY, seqid));
        result.write(oprot);
        oprot.writeMessageEnd();
        oprot.getTransport().flush();
      }

    }

    private class copyNote implements ProcessFunction {
      public void process(int seqid, TProtocol iprot, TProtocol oprot) throws TException
      {
        copyNote_args args = new copyNote_args();
        args.read(iprot);
        iprot.readMessageEnd();
        copyNote_result result = new copyNote_result();
        try {
          result.success = iface_.copyNote(args.authenticationToken, args.noteGuid, args.toNotebookGuid);
        } catch (com.evernote.edam.error.EDAMUserException userException) {
          result.userException = userException;
        } catch (com.evernote.edam.error.EDAMSystemException systemException) {
          result.systemException = systemException;
        } catch (com.evernote.edam.error.EDAMNotFoundException notFoundException) {
          result.notFoundException = notFoundException;
        } catch (Throwable th) {
          LOGGER.error("Internal error processing copyNote", th);
          TApplicationException x = new TApplicationException(TApplicationException.INTERNAL_ERROR, "Internal error processing copyNote");
          oprot.writeMessageBegin(new TMessage("copyNote", TMessageType.EXCEPTION, seqid));
          x.write(oprot);
          oprot.writeMessageEnd();
          oprot.getTransport().flush();
          return;
        }
        oprot.writeMessageBegin(new TMessage("copyNote", TMessageType.REPLY, seqid));
        result.write(oprot);
        oprot.writeMessageEnd();
        oprot.getTransport().flush();
      }

    }

    private class listNoteVersions implements ProcessFunction {
      public void process(int seqid, TProtocol iprot, TProtocol oprot) throws TException
      {
        listNoteVersions_args args = new listNoteVersions_args();
        args.read(iprot);
        iprot.readMessageEnd();
        listNoteVersions_result result = new listNoteVersions_result();
        try {
          result.success = iface_.listNoteVersions(args.authenticationToken, args.noteGuid);
        } catch (com.evernote.edam.error.EDAMUserException userException) {
          result.userException = userException;
        } catch (com.evernote.edam.error.EDAMSystemException systemException) {
          result.systemException = systemException;
        } catch (com.evernote.edam.error.EDAMNotFoundException notFoundException) {
          result.notFoundException = notFoundException;
        } catch (Throwable th) {
          LOGGER.error("Internal error processing listNoteVersions", th);
          TApplicationException x = new TApplicationException(TApplicationException.INTERNAL_ERROR, "Internal error processing listNoteVersions");
          oprot.writeMessageBegin(new TMessage("listNoteVersions", TMessageType.EXCEPTION, seqid));
          x.write(oprot);
          oprot.writeMessageEnd();
          oprot.getTransport().flush();
          return;
        }
        oprot.writeMessageBegin(new TMessage("listNoteVersions", TMessageType.REPLY, seqid));
        result.write(oprot);
        oprot.writeMessageEnd();
        oprot.getTransport().flush();
      }

    }

    private class getNoteVersion implements ProcessFunction {
      public void process(int seqid, TProtocol iprot, TProtocol oprot) throws TException
      {
        getNoteVersion_args args = new getNoteVersion_args();
        args.read(iprot);
        iprot.readMessageEnd();
        getNoteVersion_result result = new getNoteVersion_result();
        try {
          result.success = iface_.getNoteVersion(args.authenticationToken, args.noteGuid, args.updateSequenceNum, args.withResourcesData, args.withResourcesRecognition, args.withResourcesAlternateData);
        } catch (com.evernote.edam.error.EDAMUserException userException) {
          result.userException = userException;
        } catch (com.evernote.edam.error.EDAMSystemException systemException) {
          result.systemException = systemException;
        } catch (com.evernote.edam.error.EDAMNotFoundException notFoundException) {
          result.notFoundException = notFoundException;
        } catch (Throwable th) {
          LOGGER.error("Internal error processing getNoteVersion", th);
          TApplicationException x = new TApplicationException(TApplicationException.INTERNAL_ERROR, "Internal error processing getNoteVersion");
          oprot.writeMessageBegin(new TMessage("getNoteVersion", TMessageType.EXCEPTION, seqid));
          x.write(oprot);
          oprot.writeMessageEnd();
          oprot.getTransport().flush();
          return;
        }
        oprot.writeMessageBegin(new TMessage("getNoteVersion", TMessageType.REPLY, seqid));
        result.write(oprot);
        oprot.writeMessageEnd();
        oprot.getTransport().flush();
      }

    }

    private class getResource implements ProcessFunction {
      public void process(int seqid, TProtocol iprot, TProtocol oprot) throws TException
      {
        getResource_args args = new getResource_args();
        args.read(iprot);
        iprot.readMessageEnd();
        getResource_result result = new getResource_result();
        try {
          result.success = iface_.getResource(args.authenticationToken, args.guid, args.withData, args.withRecognition, args.withAttributes, args.withAlternateData);
        } catch (com.evernote.edam.error.EDAMUserException userException) {
          result.userException = userException;
        } catch (com.evernote.edam.error.EDAMSystemException systemException) {
          result.systemException = systemException;
        } catch (com.evernote.edam.error.EDAMNotFoundException notFoundException) {
          result.notFoundException = notFoundException;
        } catch (Throwable th) {
          LOGGER.error("Internal error processing getResource", th);
          TApplicationException x = new TApplicationException(TApplicationException.INTERNAL_ERROR, "Internal error processing getResource");
          oprot.writeMessageBegin(new TMessage("getResource", TMessageType.EXCEPTION, seqid));
          x.write(oprot);
          oprot.writeMessageEnd();
          oprot.getTransport().flush();
          return;
        }
        oprot.writeMessageBegin(new TMessage("getResource", TMessageType.REPLY, seqid));
        result.write(oprot);
        oprot.writeMessageEnd();
        oprot.getTransport().flush();
      }

    }

    private class updateResource implements ProcessFunction {
      public void process(int seqid, TProtocol iprot, TProtocol oprot) throws TException
      {
        updateResource_args args = new updateResource_args();
        args.read(iprot);
        iprot.readMessageEnd();
        updateResource_result result = new updateResource_result();
        try {
          result.success = iface_.updateResource(args.authenticationToken, args.resource);
          result.setSuccessIsSet(true);
        } catch (com.evernote.edam.error.EDAMUserException userException) {
          result.userException = userException;
        } catch (com.evernote.edam.error.EDAMSystemException systemException) {
          result.systemException = systemException;
        } catch (com.evernote.edam.error.EDAMNotFoundException notFoundException) {
          result.notFoundException = notFoundException;
        } catch (Throwable th) {
          LOGGER.error("Internal error processing updateResource", th);
          TApplicationException x = new TApplicationException(TApplicationException.INTERNAL_ERROR, "Internal error processing updateResource");
          oprot.writeMessageBegin(new TMessage("updateResource", TMessageType.EXCEPTION, seqid));
          x.write(oprot);
          oprot.writeMessageEnd();
          oprot.getTransport().flush();
          return;
        }
        oprot.writeMessageBegin(new TMessage("updateResource", TMessageType.REPLY, seqid));
        result.write(oprot);
        oprot.writeMessageEnd();
        oprot.getTransport().flush();
      }

    }

    private class getResourceData implements ProcessFunction {
      public void process(int seqid, TProtocol iprot, TProtocol oprot) throws TException
      {
        getResourceData_args args = new getResourceData_args();
        args.read(iprot);
        iprot.readMessageEnd();
        getResourceData_result result = new getResourceData_result();
        try {
          result.success = iface_.getResourceData(args.authenticationToken, args.guid);
        } catch (com.evernote.edam.error.EDAMUserException userException) {
          result.userException = userException;
        } catch (com.evernote.edam.error.EDAMSystemException systemException) {
          result.systemException = systemException;
        } catch (com.evernote.edam.error.EDAMNotFoundException notFoundException) {
          result.notFoundException = notFoundException;
        } catch (Throwable th) {
          LOGGER.error("Internal error processing getResourceData", th);
          TApplicationException x = new TApplicationException(TApplicationException.INTERNAL_ERROR, "Internal error processing getResourceData");
          oprot.writeMessageBegin(new TMessage("getResourceData", TMessageType.EXCEPTION, seqid));
          x.write(oprot);
          oprot.writeMessageEnd();
          oprot.getTransport().flush();
          return;
        }
        oprot.writeMessageBegin(new TMessage("getResourceData", TMessageType.REPLY, seqid));
        result.write(oprot);
        oprot.writeMessageEnd();
        oprot.getTransport().flush();
      }

    }

    private class getResourceByHash implements ProcessFunction {
      public void process(int seqid, TProtocol iprot, TProtocol oprot) throws TException
      {
        getResourceByHash_args args = new getResourceByHash_args();
        args.read(iprot);
        iprot.readMessageEnd();
        getResourceByHash_result result = new getResourceByHash_result();
        try {
          result.success = iface_.getResourceByHash(args.authenticationToken, args.noteGuid, args.contentHash, args.withData, args.withRecognition, args.withAlternateData);
        } catch (com.evernote.edam.error.EDAMUserException userException) {
          result.userException = userException;
        } catch (com.evernote.edam.error.EDAMSystemException systemException) {
          result.systemException = systemException;
        } catch (com.evernote.edam.error.EDAMNotFoundException notFoundException) {
          result.notFoundException = notFoundException;
        } catch (Throwable th) {
          LOGGER.error("Internal error processing getResourceByHash", th);
          TApplicationException x = new TApplicationException(TApplicationException.INTERNAL_ERROR, "Internal error processing getResourceByHash");
          oprot.writeMessageBegin(new TMessage("getResourceByHash", TMessageType.EXCEPTION, seqid));
          x.write(oprot);
          oprot.writeMessageEnd();
          oprot.getTransport().flush();
          return;
        }
        oprot.writeMessageBegin(new TMessage("getResourceByHash", TMessageType.REPLY, seqid));
        result.write(oprot);
        oprot.writeMessageEnd();
        oprot.getTransport().flush();
      }

    }

    private class getResourceRecognition implements ProcessFunction {
      public void process(int seqid, TProtocol iprot, TProtocol oprot) throws TException
      {
        getResourceRecognition_args args = new getResourceRecognition_args();
        args.read(iprot);
        iprot.readMessageEnd();
        getResourceRecognition_result result = new getResourceRecognition_result();
        try {
          result.success = iface_.getResourceRecognition(args.authenticationToken, args.guid);
        } catch (com.evernote.edam.error.EDAMUserException userException) {
          result.userException = userException;
        } catch (com.evernote.edam.error.EDAMSystemException systemException) {
          result.systemException = systemException;
        } catch (com.evernote.edam.error.EDAMNotFoundException notFoundException) {
          result.notFoundException = notFoundException;
        } catch (Throwable th) {
          LOGGER.error("Internal error processing getResourceRecognition", th);
          TApplicationException x = new TApplicationException(TApplicationException.INTERNAL_ERROR, "Internal error processing getResourceRecognition");
          oprot.writeMessageBegin(new TMessage("getResourceRecognition", TMessageType.EXCEPTION, seqid));
          x.write(oprot);
          oprot.writeMessageEnd();
          oprot.getTransport().flush();
          return;
        }
        oprot.writeMessageBegin(new TMessage("getResourceRecognition", TMessageType.REPLY, seqid));
        result.write(oprot);
        oprot.writeMessageEnd();
        oprot.getTransport().flush();
      }

    }

    private class getResourceAlternateData implements ProcessFunction {
      public void process(int seqid, TProtocol iprot, TProtocol oprot) throws TException
      {
        getResourceAlternateData_args args = new getResourceAlternateData_args();
        args.read(iprot);
        iprot.readMessageEnd();
        getResourceAlternateData_result result = new getResourceAlternateData_result();
        try {
          result.success = iface_.getResourceAlternateData(args.authenticationToken, args.guid);
        } catch (com.evernote.edam.error.EDAMUserException userException) {
          result.userException = userException;
        } catch (com.evernote.edam.error.EDAMSystemException systemException) {
          result.systemException = systemException;
        } catch (com.evernote.edam.error.EDAMNotFoundException notFoundException) {
          result.notFoundException = notFoundException;
        } catch (Throwable th) {
          LOGGER.error("Internal error processing getResourceAlternateData", th);
          TApplicationException x = new TApplicationException(TApplicationException.INTERNAL_ERROR, "Internal error processing getResourceAlternateData");
          oprot.writeMessageBegin(new TMessage("getResourceAlternateData", TMessageType.EXCEPTION, seqid));
          x.write(oprot);
          oprot.writeMessageEnd();
          oprot.getTransport().flush();
          return;
        }
        oprot.writeMessageBegin(new TMessage("getResourceAlternateData", TMessageType.REPLY, seqid));
        result.write(oprot);
        oprot.writeMessageEnd();
        oprot.getTransport().flush();
      }

    }

    private class getResourceAttributes implements ProcessFunction {
      public void process(int seqid, TProtocol iprot, TProtocol oprot) throws TException
      {
        getResourceAttributes_args args = new getResourceAttributes_args();
        args.read(iprot);
        iprot.readMessageEnd();
        getResourceAttributes_result result = new getResourceAttributes_result();
        try {
          result.success = iface_.getResourceAttributes(args.authenticationToken, args.guid);
        } catch (com.evernote.edam.error.EDAMUserException userException) {
          result.userException = userException;
        } catch (com.evernote.edam.error.EDAMSystemException systemException) {
          result.systemException = systemException;
        } catch (com.evernote.edam.error.EDAMNotFoundException notFoundException) {
          result.notFoundException = notFoundException;
        } catch (Throwable th) {
          LOGGER.error("Internal error processing getResourceAttributes", th);
          TApplicationException x = new TApplicationException(TApplicationException.INTERNAL_ERROR, "Internal error processing getResourceAttributes");
          oprot.writeMessageBegin(new TMessage("getResourceAttributes", TMessageType.EXCEPTION, seqid));
          x.write(oprot);
          oprot.writeMessageEnd();
          oprot.getTransport().flush();
          return;
        }
        oprot.writeMessageBegin(new TMessage("getResourceAttributes", TMessageType.REPLY, seqid));
        result.write(oprot);
        oprot.writeMessageEnd();
        oprot.getTransport().flush();
      }

    }

    private class getAccountSize implements ProcessFunction {
      public void process(int seqid, TProtocol iprot, TProtocol oprot) throws TException
      {
        getAccountSize_args args = new getAccountSize_args();
        args.read(iprot);
        iprot.readMessageEnd();
        getAccountSize_result result = new getAccountSize_result();
        try {
          result.success = iface_.getAccountSize(args.authenticationToken);
          result.setSuccessIsSet(true);
        } catch (com.evernote.edam.error.EDAMUserException userException) {
          result.userException = userException;
        } catch (com.evernote.edam.error.EDAMSystemException systemException) {
          result.systemException = systemException;
        } catch (Throwable th) {
          LOGGER.error("Internal error processing getAccountSize", th);
          TApplicationException x = new TApplicationException(TApplicationException.INTERNAL_ERROR, "Internal error processing getAccountSize");
          oprot.writeMessageBegin(new TMessage("getAccountSize", TMessageType.EXCEPTION, seqid));
          x.write(oprot);
          oprot.writeMessageEnd();
          oprot.getTransport().flush();
          return;
        }
        oprot.writeMessageBegin(new TMessage("getAccountSize", TMessageType.REPLY, seqid));
        result.write(oprot);
        oprot.writeMessageEnd();
        oprot.getTransport().flush();
      }

    }

    private class getAds implements ProcessFunction {
      public void process(int seqid, TProtocol iprot, TProtocol oprot) throws TException
      {
        getAds_args args = new getAds_args();
        args.read(iprot);
        iprot.readMessageEnd();
        getAds_result result = new getAds_result();
        try {
          result.success = iface_.getAds(args.authenticationToken, args.adParameters);
        } catch (com.evernote.edam.error.EDAMUserException userException) {
          result.userException = userException;
        } catch (com.evernote.edam.error.EDAMSystemException systemException) {
          result.systemException = systemException;
        } catch (Throwable th) {
          LOGGER.error("Internal error processing getAds", th);
          TApplicationException x = new TApplicationException(TApplicationException.INTERNAL_ERROR, "Internal error processing getAds");
          oprot.writeMessageBegin(new TMessage("getAds", TMessageType.EXCEPTION, seqid));
          x.write(oprot);
          oprot.writeMessageEnd();
          oprot.getTransport().flush();
          return;
        }
        oprot.writeMessageBegin(new TMessage("getAds", TMessageType.REPLY, seqid));
        result.write(oprot);
        oprot.writeMessageEnd();
        oprot.getTransport().flush();
      }

    }

    private class getRandomAd implements ProcessFunction {
      public void process(int seqid, TProtocol iprot, TProtocol oprot) throws TException
      {
        getRandomAd_args args = new getRandomAd_args();
        args.read(iprot);
        iprot.readMessageEnd();
        getRandomAd_result result = new getRandomAd_result();
        try {
          result.success = iface_.getRandomAd(args.authenticationToken, args.adParameters);
        } catch (com.evernote.edam.error.EDAMUserException userException) {
          result.userException = userException;
        } catch (com.evernote.edam.error.EDAMSystemException systemException) {
          result.systemException = systemException;
        } catch (Throwable th) {
          LOGGER.error("Internal error processing getRandomAd", th);
          TApplicationException x = new TApplicationException(TApplicationException.INTERNAL_ERROR, "Internal error processing getRandomAd");
          oprot.writeMessageBegin(new TMessage("getRandomAd", TMessageType.EXCEPTION, seqid));
          x.write(oprot);
          oprot.writeMessageEnd();
          oprot.getTransport().flush();
          return;
        }
        oprot.writeMessageBegin(new TMessage("getRandomAd", TMessageType.REPLY, seqid));
        result.write(oprot);
        oprot.writeMessageEnd();
        oprot.getTransport().flush();
      }

    }

    private class getPublicNotebook implements ProcessFunction {
      public void process(int seqid, TProtocol iprot, TProtocol oprot) throws TException
      {
        getPublicNotebook_args args = new getPublicNotebook_args();
        args.read(iprot);
        iprot.readMessageEnd();
        getPublicNotebook_result result = new getPublicNotebook_result();
        try {
          result.success = iface_.getPublicNotebook(args.userId, args.publicUri);
        } catch (com.evernote.edam.error.EDAMSystemException systemException) {
          result.systemException = systemException;
        } catch (com.evernote.edam.error.EDAMNotFoundException notFoundException) {
          result.notFoundException = notFoundException;
        } catch (Throwable th) {
          LOGGER.error("Internal error processing getPublicNotebook", th);
          TApplicationException x = new TApplicationException(TApplicationException.INTERNAL_ERROR, "Internal error processing getPublicNotebook");
          oprot.writeMessageBegin(new TMessage("getPublicNotebook", TMessageType.EXCEPTION, seqid));
          x.write(oprot);
          oprot.writeMessageEnd();
          oprot.getTransport().flush();
          return;
        }
        oprot.writeMessageBegin(new TMessage("getPublicNotebook", TMessageType.REPLY, seqid));
        result.write(oprot);
        oprot.writeMessageEnd();
        oprot.getTransport().flush();
      }

    }

    private class createSharedNotebook implements ProcessFunction {
      public void process(int seqid, TProtocol iprot, TProtocol oprot) throws TException
      {
        createSharedNotebook_args args = new createSharedNotebook_args();
        args.read(iprot);
        iprot.readMessageEnd();
        createSharedNotebook_result result = new createSharedNotebook_result();
        try {
          result.success = iface_.createSharedNotebook(args.authenticationToken, args.sharedNotebook);
        } catch (com.evernote.edam.error.EDAMUserException userException) {
          result.userException = userException;
        } catch (com.evernote.edam.error.EDAMNotFoundException notFoundException) {
          result.notFoundException = notFoundException;
        } catch (com.evernote.edam.error.EDAMSystemException systemException) {
          result.systemException = systemException;
        } catch (Throwable th) {
          LOGGER.error("Internal error processing createSharedNotebook", th);
          TApplicationException x = new TApplicationException(TApplicationException.INTERNAL_ERROR, "Internal error processing createSharedNotebook");
          oprot.writeMessageBegin(new TMessage("createSharedNotebook", TMessageType.EXCEPTION, seqid));
          x.write(oprot);
          oprot.writeMessageEnd();
          oprot.getTransport().flush();
          return;
        }
        oprot.writeMessageBegin(new TMessage("createSharedNotebook", TMessageType.REPLY, seqid));
        result.write(oprot);
        oprot.writeMessageEnd();
        oprot.getTransport().flush();
      }

    }

    private class listSharedNotebooks implements ProcessFunction {
      public void process(int seqid, TProtocol iprot, TProtocol oprot) throws TException
      {
        listSharedNotebooks_args args = new listSharedNotebooks_args();
        args.read(iprot);
        iprot.readMessageEnd();
        listSharedNotebooks_result result = new listSharedNotebooks_result();
        try {
          result.success = iface_.listSharedNotebooks(args.authenticationToken);
        } catch (com.evernote.edam.error.EDAMUserException userException) {
          result.userException = userException;
        } catch (com.evernote.edam.error.EDAMNotFoundException notFoundException) {
          result.notFoundException = notFoundException;
        } catch (com.evernote.edam.error.EDAMSystemException systemException) {
          result.systemException = systemException;
        } catch (Throwable th) {
          LOGGER.error("Internal error processing listSharedNotebooks", th);
          TApplicationException x = new TApplicationException(TApplicationException.INTERNAL_ERROR, "Internal error processing listSharedNotebooks");
          oprot.writeMessageBegin(new TMessage("listSharedNotebooks", TMessageType.EXCEPTION, seqid));
          x.write(oprot);
          oprot.writeMessageEnd();
          oprot.getTransport().flush();
          return;
        }
        oprot.writeMessageBegin(new TMessage("listSharedNotebooks", TMessageType.REPLY, seqid));
        result.write(oprot);
        oprot.writeMessageEnd();
        oprot.getTransport().flush();
      }

    }

    private class expungeSharedNotebooks implements ProcessFunction {
      public void process(int seqid, TProtocol iprot, TProtocol oprot) throws TException
      {
        expungeSharedNotebooks_args args = new expungeSharedNotebooks_args();
        args.read(iprot);
        iprot.readMessageEnd();
        expungeSharedNotebooks_result result = new expungeSharedNotebooks_result();
        try {
          result.success = iface_.expungeSharedNotebooks(args.authenticationToken, args.sharedNotebookIds);
          result.setSuccessIsSet(true);
        } catch (com.evernote.edam.error.EDAMUserException userException) {
          result.userException = userException;
        } catch (com.evernote.edam.error.EDAMNotFoundException notFoundException) {
          result.notFoundException = notFoundException;
        } catch (com.evernote.edam.error.EDAMSystemException systemException) {
          result.systemException = systemException;
        } catch (Throwable th) {
          LOGGER.error("Internal error processing expungeSharedNotebooks", th);
          TApplicationException x = new TApplicationException(TApplicationException.INTERNAL_ERROR, "Internal error processing expungeSharedNotebooks");
          oprot.writeMessageBegin(new TMessage("expungeSharedNotebooks", TMessageType.EXCEPTION, seqid));
          x.write(oprot);
          oprot.writeMessageEnd();
          oprot.getTransport().flush();
          return;
        }
        oprot.writeMessageBegin(new TMessage("expungeSharedNotebooks", TMessageType.REPLY, seqid));
        result.write(oprot);
        oprot.writeMessageEnd();
        oprot.getTransport().flush();
      }

    }

    private class createLinkedNotebook implements ProcessFunction {
      public void process(int seqid, TProtocol iprot, TProtocol oprot) throws TException
      {
        createLinkedNotebook_args args = new createLinkedNotebook_args();
        args.read(iprot);
        iprot.readMessageEnd();
        createLinkedNotebook_result result = new createLinkedNotebook_result();
        try {
          result.success = iface_.createLinkedNotebook(args.authenticationToken, args.linkedNotebook);
        } catch (com.evernote.edam.error.EDAMUserException userException) {
          result.userException = userException;
        } catch (com.evernote.edam.error.EDAMNotFoundException notFoundException) {
          result.notFoundException = notFoundException;
        } catch (com.evernote.edam.error.EDAMSystemException systemException) {
          result.systemException = systemException;
        } catch (Throwable th) {
          LOGGER.error("Internal error processing createLinkedNotebook", th);
          TApplicationException x = new TApplicationException(TApplicationException.INTERNAL_ERROR, "Internal error processing createLinkedNotebook");
          oprot.writeMessageBegin(new TMessage("createLinkedNotebook", TMessageType.EXCEPTION, seqid));
          x.write(oprot);
          oprot.writeMessageEnd();
          oprot.getTransport().flush();
          return;
        }
        oprot.writeMessageBegin(new TMessage("createLinkedNotebook", TMessageType.REPLY, seqid));
        result.write(oprot);
        oprot.writeMessageEnd();
        oprot.getTransport().flush();
      }

    }

    private class updateLinkedNotebook implements ProcessFunction {
      public void process(int seqid, TProtocol iprot, TProtocol oprot) throws TException
      {
        updateLinkedNotebook_args args = new updateLinkedNotebook_args();
        args.read(iprot);
        iprot.readMessageEnd();
        updateLinkedNotebook_result result = new updateLinkedNotebook_result();
        try {
          result.success = iface_.updateLinkedNotebook(args.authenticationToken, args.linkedNotebook);
        } catch (com.evernote.edam.error.EDAMUserException userException) {
          result.userException = userException;
        } catch (com.evernote.edam.error.EDAMNotFoundException notFoundException) {
          result.notFoundException = notFoundException;
        } catch (com.evernote.edam.error.EDAMSystemException systemException) {
          result.systemException = systemException;
        } catch (Throwable th) {
          LOGGER.error("Internal error processing updateLinkedNotebook", th);
          TApplicationException x = new TApplicationException(TApplicationException.INTERNAL_ERROR, "Internal error processing updateLinkedNotebook");
          oprot.writeMessageBegin(new TMessage("updateLinkedNotebook", TMessageType.EXCEPTION, seqid));
          x.write(oprot);
          oprot.writeMessageEnd();
          oprot.getTransport().flush();
          return;
        }
        oprot.writeMessageBegin(new TMessage("updateLinkedNotebook", TMessageType.REPLY, seqid));
        result.write(oprot);
        oprot.writeMessageEnd();
        oprot.getTransport().flush();
      }

    }

    private class listLinkedNotebooks implements ProcessFunction {
      public void process(int seqid, TProtocol iprot, TProtocol oprot) throws TException
      {
        listLinkedNotebooks_args args = new listLinkedNotebooks_args();
        args.read(iprot);
        iprot.readMessageEnd();
        listLinkedNotebooks_result result = new listLinkedNotebooks_result();
        try {
          result.success = iface_.listLinkedNotebooks(args.authenticationToken);
        } catch (com.evernote.edam.error.EDAMUserException userException) {
          result.userException = userException;
        } catch (com.evernote.edam.error.EDAMNotFoundException notFoundException) {
          result.notFoundException = notFoundException;
        } catch (com.evernote.edam.error.EDAMSystemException systemException) {
          result.systemException = systemException;
        } catch (Throwable th) {
          LOGGER.error("Internal error processing listLinkedNotebooks", th);
          TApplicationException x = new TApplicationException(TApplicationException.INTERNAL_ERROR, "Internal error processing listLinkedNotebooks");
          oprot.writeMessageBegin(new TMessage("listLinkedNotebooks", TMessageType.EXCEPTION, seqid));
          x.write(oprot);
          oprot.writeMessageEnd();
          oprot.getTransport().flush();
          return;
        }
        oprot.writeMessageBegin(new TMessage("listLinkedNotebooks", TMessageType.REPLY, seqid));
        result.write(oprot);
        oprot.writeMessageEnd();
        oprot.getTransport().flush();
      }

    }

    private class expungeLinkedNotebook implements ProcessFunction {
      public void process(int seqid, TProtocol iprot, TProtocol oprot) throws TException
      {
        expungeLinkedNotebook_args args = new expungeLinkedNotebook_args();
        args.read(iprot);
        iprot.readMessageEnd();
        expungeLinkedNotebook_result result = new expungeLinkedNotebook_result();
        try {
          result.success = iface_.expungeLinkedNotebook(args.authenticationToken, args.linkedNotebookId);
          result.setSuccessIsSet(true);
        } catch (com.evernote.edam.error.EDAMUserException userException) {
          result.userException = userException;
        } catch (com.evernote.edam.error.EDAMNotFoundException notFoundException) {
          result.notFoundException = notFoundException;
        } catch (com.evernote.edam.error.EDAMSystemException systemException) {
          result.systemException = systemException;
        } catch (Throwable th) {
          LOGGER.error("Internal error processing expungeLinkedNotebook", th);
          TApplicationException x = new TApplicationException(TApplicationException.INTERNAL_ERROR, "Internal error processing expungeLinkedNotebook");
          oprot.writeMessageBegin(new TMessage("expungeLinkedNotebook", TMessageType.EXCEPTION, seqid));
          x.write(oprot);
          oprot.writeMessageEnd();
          oprot.getTransport().flush();
          return;
        }
        oprot.writeMessageBegin(new TMessage("expungeLinkedNotebook", TMessageType.REPLY, seqid));
        result.write(oprot);
        oprot.writeMessageEnd();
        oprot.getTransport().flush();
      }

    }

    private class authenticateToSharedNotebook implements ProcessFunction {
      public void process(int seqid, TProtocol iprot, TProtocol oprot) throws TException
      {
        authenticateToSharedNotebook_args args = new authenticateToSharedNotebook_args();
        args.read(iprot);
        iprot.readMessageEnd();
        authenticateToSharedNotebook_result result = new authenticateToSharedNotebook_result();
        try {
          result.success = iface_.authenticateToSharedNotebook(args.shareKey, args.authenticationToken);
        } catch (com.evernote.edam.error.EDAMUserException userException) {
          result.userException = userException;
        } catch (com.evernote.edam.error.EDAMNotFoundException notFoundException) {
          result.notFoundException = notFoundException;
        } catch (com.evernote.edam.error.EDAMSystemException systemException) {
          result.systemException = systemException;
        } catch (Throwable th) {
          LOGGER.error("Internal error processing authenticateToSharedNotebook", th);
          TApplicationException x = new TApplicationException(TApplicationException.INTERNAL_ERROR, "Internal error processing authenticateToSharedNotebook");
          oprot.writeMessageBegin(new TMessage("authenticateToSharedNotebook", TMessageType.EXCEPTION, seqid));
          x.write(oprot);
          oprot.writeMessageEnd();
          oprot.getTransport().flush();
          return;
        }
        oprot.writeMessageBegin(new TMessage("authenticateToSharedNotebook", TMessageType.REPLY, seqid));
        result.write(oprot);
        oprot.writeMessageEnd();
        oprot.getTransport().flush();
      }

    }

    private class getSharedNotebookByAuth implements ProcessFunction {
      public void process(int seqid, TProtocol iprot, TProtocol oprot) throws TException
      {
        getSharedNotebookByAuth_args args = new getSharedNotebookByAuth_args();
        args.read(iprot);
        iprot.readMessageEnd();
        getSharedNotebookByAuth_result result = new getSharedNotebookByAuth_result();
        try {
          result.success = iface_.getSharedNotebookByAuth(args.authenticationToken);
        } catch (com.evernote.edam.error.EDAMUserException userException) {
          result.userException = userException;
        } catch (com.evernote.edam.error.EDAMNotFoundException notFoundException) {
          result.notFoundException = notFoundException;
        } catch (com.evernote.edam.error.EDAMSystemException systemException) {
          result.systemException = systemException;
        } catch (Throwable th) {
          LOGGER.error("Internal error processing getSharedNotebookByAuth", th);
          TApplicationException x = new TApplicationException(TApplicationException.INTERNAL_ERROR, "Internal error processing getSharedNotebookByAuth");
          oprot.writeMessageBegin(new TMessage("getSharedNotebookByAuth", TMessageType.EXCEPTION, seqid));
          x.write(oprot);
          oprot.writeMessageEnd();
          oprot.getTransport().flush();
          return;
        }
        oprot.writeMessageBegin(new TMessage("getSharedNotebookByAuth", TMessageType.REPLY, seqid));
        result.write(oprot);
        oprot.writeMessageEnd();
        oprot.getTransport().flush();
      }

    }

    private class emailNote implements ProcessFunction {
      public void process(int seqid, TProtocol iprot, TProtocol oprot) throws TException
      {
        emailNote_args args = new emailNote_args();
        args.read(iprot);
        iprot.readMessageEnd();
        emailNote_result result = new emailNote_result();
        try {
          iface_.emailNote(args.authenticationToken, args.parameters);
        } catch (com.evernote.edam.error.EDAMUserException userException) {
          result.userException = userException;
        } catch (com.evernote.edam.error.EDAMNotFoundException notFoundException) {
          result.notFoundException = notFoundException;
        } catch (com.evernote.edam.error.EDAMSystemException systemException) {
          result.systemException = systemException;
        } catch (Throwable th) {
          LOGGER.error("Internal error processing emailNote", th);
          TApplicationException x = new TApplicationException(TApplicationException.INTERNAL_ERROR, "Internal error processing emailNote");
          oprot.writeMessageBegin(new TMessage("emailNote", TMessageType.EXCEPTION, seqid));
          x.write(oprot);
          oprot.writeMessageEnd();
          oprot.getTransport().flush();
          return;
        }
        oprot.writeMessageBegin(new TMessage("emailNote", TMessageType.REPLY, seqid));
        result.write(oprot);
        oprot.writeMessageEnd();
        oprot.getTransport().flush();
      }

    }

  }

  public static class getSyncState_args implements TBase<getSyncState_args._Fields>, java.io.Serializable, Cloneable, Comparable<getSyncState_args>   {
    private static final TStruct STRUCT_DESC = new TStruct("getSyncState_args");

    private static final TField AUTHENTICATION_TOKEN_FIELD_DESC = new TField("authenticationToken", TType.STRING, (short)1);

    private String authenticationToken;

    /** The set of fields this struct contains, along with convenience methods for finding and manipulating them. */
    public enum _Fields implements TFieldIdEnum {
      AUTHENTICATION_TOKEN((short)1, "authenticationToken");

      private static final Map<Integer, _Fields> byId = new HashMap<Integer, _Fields>();
      private static final Map<String, _Fields> byName = new HashMap<String, _Fields>();

      static {
        for (_Fields field : EnumSet.allOf(_Fields.class)) {
          byId.put((int)field._thriftId, field);
          byName.put(field.getFieldName(), field);
        }
      }

      /**
       * Find the _Fields constant that matches fieldId, or null if its not found.
       */
      public static _Fields findByThriftId(int fieldId) {
        return byId.get(fieldId);
      }

      /**
       * Find the _Fields constant that matches fieldId, throwing an exception
       * if it is not found.
       */
      public static _Fields findByThriftIdOrThrow(int fieldId) {
        _Fields fields = findByThriftId(fieldId);
        if (fields == null) throw new IllegalArgumentException("Field " + fieldId + " doesn't exist!");
        return fields;
      }

      /**
       * Find the _Fields constant that matches name, or null if its not found.
       */
      public static _Fields findByName(String name) {
        return byName.get(name);
      }

      private final short _thriftId;
      private final String _fieldName;

      _Fields(short thriftId, String fieldName) {
        _thriftId = thriftId;
        _fieldName = fieldName;
      }

      public short getThriftFieldId() {
        return _thriftId;
      }

      public String getFieldName() {
        return _fieldName;
      }
    }

    // isset id assignments

    public static final Map<_Fields, FieldMetaData> metaDataMap = Collections.unmodifiableMap(new EnumMap<_Fields, FieldMetaData>(_Fields.class) {{
      put(_Fields.AUTHENTICATION_TOKEN, new FieldMetaData("authenticationToken", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.STRING)));
    }});

    static {
      FieldMetaData.addStructMetaDataMap(getSyncState_args.class, metaDataMap);
    }

    public getSyncState_args() {
    }

    public getSyncState_args(
      String authenticationToken)
    {
      this();
      this.authenticationToken = authenticationToken;
    }

    /**
     * Performs a deep copy on <i>other</i>.
     */
    public getSyncState_args(getSyncState_args other) {
      if (other.isSetAuthenticationToken()) {
        this.authenticationToken = other.authenticationToken;
      }
    }

    public getSyncState_args deepCopy() {
      return new getSyncState_args(this);
    }

    @Deprecated
    public getSyncState_args clone() {
      return new getSyncState_args(this);
    }

    public String getAuthenticationToken() {
      return this.authenticationToken;
    }

    public void setAuthenticationToken(String authenticationToken) {
      this.authenticationToken = authenticationToken;
    }

    public void unsetAuthenticationToken() {
      this.authenticationToken = null;
    }

    /** Returns true if field authenticationToken is set (has been asigned a value) and false otherwise */
    public boolean isSetAuthenticationToken() {
      return this.authenticationToken != null;
    }

    public void setAuthenticationTokenIsSet(boolean value) {
      if (!value) {
        this.authenticationToken = null;
      }
    }

    public void setFieldValue(_Fields field, Object value) {
      switch (field) {
      case AUTHENTICATION_TOKEN:
        if (value == null) {
          unsetAuthenticationToken();
        } else {
          setAuthenticationToken((String)value);
        }
        break;

      }
    }

    public void setFieldValue(int fieldID, Object value) {
      setFieldValue(_Fields.findByThriftIdOrThrow(fieldID), value);
    }

    public Object getFieldValue(_Fields field) {
      switch (field) {
      case AUTHENTICATION_TOKEN:
        return getAuthenticationToken();

      }
      throw new IllegalStateException();
    }

    public Object getFieldValue(int fieldId) {
      return getFieldValue(_Fields.findByThriftIdOrThrow(fieldId));
    }

    /** Returns true if field corresponding to fieldID is set (has been asigned a value) and false otherwise */
    public boolean isSet(_Fields field) {
      switch (field) {
      case AUTHENTICATION_TOKEN:
        return isSetAuthenticationToken();
      }
      throw new IllegalStateException();
    }

    public boolean isSet(int fieldID) {
      return isSet(_Fields.findByThriftIdOrThrow(fieldID));
    }

    public boolean equals(Object that) {
      if (that == null)
        return false;
      if (that instanceof getSyncState_args)
        return this.equals((getSyncState_args)that);
      return false;
    }

    public boolean equals(getSyncState_args that) {
      if (that == null)
        return false;

      boolean this_present_authenticationToken = true && this.isSetAuthenticationToken();
      boolean that_present_authenticationToken = true && that.isSetAuthenticationToken();
      if (this_present_authenticationToken || that_present_authenticationToken) {
        if (!(this_present_authenticationToken && that_present_authenticationToken))
          return false;
        if (!this.authenticationToken.equals(that.authenticationToken))
          return false;
      }

      return true;
    }

    public int hashCode() {
      return 0;
    }

    public int compareTo(getSyncState_args other) {
      if (!getClass().equals(other.getClass())) {
        return getClass().getName().compareTo(other.getClass().getName());
      }

      int lastComparison = 0;
      getSyncState_args typedOther = (getSyncState_args)other;

      lastComparison = Boolean.valueOf(isSetAuthenticationToken()).compareTo(isSetAuthenticationToken());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(authenticationToken, typedOther.authenticationToken);
      if (lastComparison != 0) {
        return lastComparison;
      }
      return 0;
    }

    public void read(TProtocol iprot) throws TException {
      TField field;
      iprot.readStructBegin();
      while (true)
      {
        field = iprot.readFieldBegin();
        if (field.type == TType.STOP) { 
          break;
        }
        _Fields fieldId = _Fields.findByThriftId(field.id);
        if (fieldId == null) {
          TProtocolUtil.skip(iprot, field.type);
        } else {
          switch (fieldId) {
            case AUTHENTICATION_TOKEN:
              if (field.type == TType.STRING) {
                this.authenticationToken = iprot.readString();
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
          }
          iprot.readFieldEnd();
        }
      }
      iprot.readStructEnd();
      validate();
    }

    public void write(TProtocol oprot) throws TException {
      validate();

      oprot.writeStructBegin(STRUCT_DESC);
      if (this.authenticationToken != null) {
        oprot.writeFieldBegin(AUTHENTICATION_TOKEN_FIELD_DESC);
        oprot.writeString(this.authenticationToken);
        oprot.writeFieldEnd();
      }
      oprot.writeFieldStop();
      oprot.writeStructEnd();
    }

    public String toString() {
      StringBuilder sb = new StringBuilder("getSyncState_args(");
      boolean first = true;

      sb.append("authenticationToken:");
      if (this.authenticationToken == null) {
        sb.append("null");
      } else {
        sb.append(this.authenticationToken);
      }
      first = false;
      sb.append(")");
      return sb.toString();
    }

    public void validate() throws TException {
      // check for required fields
    }

  }

  public static class getSyncState_result implements TBase<getSyncState_result._Fields>, java.io.Serializable, Cloneable, Comparable<getSyncState_result>   {
    private static final TStruct STRUCT_DESC = new TStruct("getSyncState_result");

    private static final TField SUCCESS_FIELD_DESC = new TField("success", TType.STRUCT, (short)0);
    private static final TField USER_EXCEPTION_FIELD_DESC = new TField("userException", TType.STRUCT, (short)1);
    private static final TField SYSTEM_EXCEPTION_FIELD_DESC = new TField("systemException", TType.STRUCT, (short)2);

    private SyncState success;
    private com.evernote.edam.error.EDAMUserException userException;
    private com.evernote.edam.error.EDAMSystemException systemException;

    /** The set of fields this struct contains, along with convenience methods for finding and manipulating them. */
    public enum _Fields implements TFieldIdEnum {
      SUCCESS((short)0, "success"),
      USER_EXCEPTION((short)1, "userException"),
      SYSTEM_EXCEPTION((short)2, "systemException");

      private static final Map<Integer, _Fields> byId = new HashMap<Integer, _Fields>();
      private static final Map<String, _Fields> byName = new HashMap<String, _Fields>();

      static {
        for (_Fields field : EnumSet.allOf(_Fields.class)) {
          byId.put((int)field._thriftId, field);
          byName.put(field.getFieldName(), field);
        }
      }

      /**
       * Find the _Fields constant that matches fieldId, or null if its not found.
       */
      public static _Fields findByThriftId(int fieldId) {
        return byId.get(fieldId);
      }

      /**
       * Find the _Fields constant that matches fieldId, throwing an exception
       * if it is not found.
       */
      public static _Fields findByThriftIdOrThrow(int fieldId) {
        _Fields fields = findByThriftId(fieldId);
        if (fields == null) throw new IllegalArgumentException("Field " + fieldId + " doesn't exist!");
        return fields;
      }

      /**
       * Find the _Fields constant that matches name, or null if its not found.
       */
      public static _Fields findByName(String name) {
        return byName.get(name);
      }

      private final short _thriftId;
      private final String _fieldName;

      _Fields(short thriftId, String fieldName) {
        _thriftId = thriftId;
        _fieldName = fieldName;
      }

      public short getThriftFieldId() {
        return _thriftId;
      }

      public String getFieldName() {
        return _fieldName;
      }
    }

    // isset id assignments

    public static final Map<_Fields, FieldMetaData> metaDataMap = Collections.unmodifiableMap(new EnumMap<_Fields, FieldMetaData>(_Fields.class) {{
      put(_Fields.SUCCESS, new FieldMetaData("success", TFieldRequirementType.DEFAULT, 
          new StructMetaData(TType.STRUCT, SyncState.class)));
      put(_Fields.USER_EXCEPTION, new FieldMetaData("userException", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.STRUCT)));
      put(_Fields.SYSTEM_EXCEPTION, new FieldMetaData("systemException", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.STRUCT)));
    }});

    static {
      FieldMetaData.addStructMetaDataMap(getSyncState_result.class, metaDataMap);
    }

    public getSyncState_result() {
    }

    public getSyncState_result(
      SyncState success,
      com.evernote.edam.error.EDAMUserException userException,
      com.evernote.edam.error.EDAMSystemException systemException)
    {
      this();
      this.success = success;
      this.userException = userException;
      this.systemException = systemException;
    }

    /**
     * Performs a deep copy on <i>other</i>.
     */
    public getSyncState_result(getSyncState_result other) {
      if (other.isSetSuccess()) {
        this.success = new SyncState(other.success);
      }
      if (other.isSetUserException()) {
        this.userException = new com.evernote.edam.error.EDAMUserException(other.userException);
      }
      if (other.isSetSystemException()) {
        this.systemException = new com.evernote.edam.error.EDAMSystemException(other.systemException);
      }
    }

    public getSyncState_result deepCopy() {
      return new getSyncState_result(this);
    }

    @Deprecated
    public getSyncState_result clone() {
      return new getSyncState_result(this);
    }

    public SyncState getSuccess() {
      return this.success;
    }

    public void setSuccess(SyncState success) {
      this.success = success;
    }

    public void unsetSuccess() {
      this.success = null;
    }

    /** Returns true if field success is set (has been asigned a value) and false otherwise */
    public boolean isSetSuccess() {
      return this.success != null;
    }

    public void setSuccessIsSet(boolean value) {
      if (!value) {
        this.success = null;
      }
    }

    public com.evernote.edam.error.EDAMUserException getUserException() {
      return this.userException;
    }

    public void setUserException(com.evernote.edam.error.EDAMUserException userException) {
      this.userException = userException;
    }

    public void unsetUserException() {
      this.userException = null;
    }

    /** Returns true if field userException is set (has been asigned a value) and false otherwise */
    public boolean isSetUserException() {
      return this.userException != null;
    }

    public void setUserExceptionIsSet(boolean value) {
      if (!value) {
        this.userException = null;
      }
    }

    public com.evernote.edam.error.EDAMSystemException getSystemException() {
      return this.systemException;
    }

    public void setSystemException(com.evernote.edam.error.EDAMSystemException systemException) {
      this.systemException = systemException;
    }

    public void unsetSystemException() {
      this.systemException = null;
    }

    /** Returns true if field systemException is set (has been asigned a value) and false otherwise */
    public boolean isSetSystemException() {
      return this.systemException != null;
    }

    public void setSystemExceptionIsSet(boolean value) {
      if (!value) {
        this.systemException = null;
      }
    }

    public void setFieldValue(_Fields field, Object value) {
      switch (field) {
      case SUCCESS:
        if (value == null) {
          unsetSuccess();
        } else {
          setSuccess((SyncState)value);
        }
        break;

      case USER_EXCEPTION:
        if (value == null) {
          unsetUserException();
        } else {
          setUserException((com.evernote.edam.error.EDAMUserException)value);
        }
        break;

      case SYSTEM_EXCEPTION:
        if (value == null) {
          unsetSystemException();
        } else {
          setSystemException((com.evernote.edam.error.EDAMSystemException)value);
        }
        break;

      }
    }

    public void setFieldValue(int fieldID, Object value) {
      setFieldValue(_Fields.findByThriftIdOrThrow(fieldID), value);
    }

    public Object getFieldValue(_Fields field) {
      switch (field) {
      case SUCCESS:
        return getSuccess();

      case USER_EXCEPTION:
        return getUserException();

      case SYSTEM_EXCEPTION:
        return getSystemException();

      }
      throw new IllegalStateException();
    }

    public Object getFieldValue(int fieldId) {
      return getFieldValue(_Fields.findByThriftIdOrThrow(fieldId));
    }

    /** Returns true if field corresponding to fieldID is set (has been asigned a value) and false otherwise */
    public boolean isSet(_Fields field) {
      switch (field) {
      case SUCCESS:
        return isSetSuccess();
      case USER_EXCEPTION:
        return isSetUserException();
      case SYSTEM_EXCEPTION:
        return isSetSystemException();
      }
      throw new IllegalStateException();
    }

    public boolean isSet(int fieldID) {
      return isSet(_Fields.findByThriftIdOrThrow(fieldID));
    }

    public boolean equals(Object that) {
      if (that == null)
        return false;
      if (that instanceof getSyncState_result)
        return this.equals((getSyncState_result)that);
      return false;
    }

    public boolean equals(getSyncState_result that) {
      if (that == null)
        return false;

      boolean this_present_success = true && this.isSetSuccess();
      boolean that_present_success = true && that.isSetSuccess();
      if (this_present_success || that_present_success) {
        if (!(this_present_success && that_present_success))
          return false;
        if (!this.success.equals(that.success))
          return false;
      }

      boolean this_present_userException = true && this.isSetUserException();
      boolean that_present_userException = true && that.isSetUserException();
      if (this_present_userException || that_present_userException) {
        if (!(this_present_userException && that_present_userException))
          return false;
        if (!this.userException.equals(that.userException))
          return false;
      }

      boolean this_present_systemException = true && this.isSetSystemException();
      boolean that_present_systemException = true && that.isSetSystemException();
      if (this_present_systemException || that_present_systemException) {
        if (!(this_present_systemException && that_present_systemException))
          return false;
        if (!this.systemException.equals(that.systemException))
          return false;
      }

      return true;
    }

    public int hashCode() {
      return 0;
    }

    public int compareTo(getSyncState_result other) {
      if (!getClass().equals(other.getClass())) {
        return getClass().getName().compareTo(other.getClass().getName());
      }

      int lastComparison = 0;
      getSyncState_result typedOther = (getSyncState_result)other;

      lastComparison = Boolean.valueOf(isSetSuccess()).compareTo(isSetSuccess());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(success, typedOther.success);
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = Boolean.valueOf(isSetUserException()).compareTo(isSetUserException());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(userException, typedOther.userException);
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = Boolean.valueOf(isSetSystemException()).compareTo(isSetSystemException());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(systemException, typedOther.systemException);
      if (lastComparison != 0) {
        return lastComparison;
      }
      return 0;
    }

    public void read(TProtocol iprot) throws TException {
      TField field;
      iprot.readStructBegin();
      while (true)
      {
        field = iprot.readFieldBegin();
        if (field.type == TType.STOP) { 
          break;
        }
        _Fields fieldId = _Fields.findByThriftId(field.id);
        if (fieldId == null) {
          TProtocolUtil.skip(iprot, field.type);
        } else {
          switch (fieldId) {
            case SUCCESS:
              if (field.type == TType.STRUCT) {
                this.success = new SyncState();
                this.success.read(iprot);
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
            case USER_EXCEPTION:
              if (field.type == TType.STRUCT) {
                this.userException = new com.evernote.edam.error.EDAMUserException();
                this.userException.read(iprot);
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
            case SYSTEM_EXCEPTION:
              if (field.type == TType.STRUCT) {
                this.systemException = new com.evernote.edam.error.EDAMSystemException();
                this.systemException.read(iprot);
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
          }
          iprot.readFieldEnd();
        }
      }
      iprot.readStructEnd();
      validate();
    }

    public void write(TProtocol oprot) throws TException {
      oprot.writeStructBegin(STRUCT_DESC);

      if (this.isSetSuccess()) {
        oprot.writeFieldBegin(SUCCESS_FIELD_DESC);
        this.success.write(oprot);
        oprot.writeFieldEnd();
      } else if (this.isSetUserException()) {
        oprot.writeFieldBegin(USER_EXCEPTION_FIELD_DESC);
        this.userException.write(oprot);
        oprot.writeFieldEnd();
      } else if (this.isSetSystemException()) {
        oprot.writeFieldBegin(SYSTEM_EXCEPTION_FIELD_DESC);
        this.systemException.write(oprot);
        oprot.writeFieldEnd();
      }
      oprot.writeFieldStop();
      oprot.writeStructEnd();
    }

    public String toString() {
      StringBuilder sb = new StringBuilder("getSyncState_result(");
      boolean first = true;

      sb.append("success:");
      if (this.success == null) {
        sb.append("null");
      } else {
        sb.append(this.success);
      }
      first = false;
      if (!first) sb.append(", ");
      sb.append("userException:");
      if (this.userException == null) {
        sb.append("null");
      } else {
        sb.append(this.userException);
      }
      first = false;
      if (!first) sb.append(", ");
      sb.append("systemException:");
      if (this.systemException == null) {
        sb.append("null");
      } else {
        sb.append(this.systemException);
      }
      first = false;
      sb.append(")");
      return sb.toString();
    }

    public void validate() throws TException {
      // check for required fields
    }

  }

  public static class getSyncChunk_args implements TBase<getSyncChunk_args._Fields>, java.io.Serializable, Cloneable, Comparable<getSyncChunk_args>   {
    private static final TStruct STRUCT_DESC = new TStruct("getSyncChunk_args");

    private static final TField AUTHENTICATION_TOKEN_FIELD_DESC = new TField("authenticationToken", TType.STRING, (short)1);
    private static final TField AFTER_USN_FIELD_DESC = new TField("afterUSN", TType.I32, (short)2);
    private static final TField MAX_ENTRIES_FIELD_DESC = new TField("maxEntries", TType.I32, (short)3);
    private static final TField FULL_SYNC_ONLY_FIELD_DESC = new TField("fullSyncOnly", TType.BOOL, (short)4);

    private String authenticationToken;
    private int afterUSN;
    private int maxEntries;
    private boolean fullSyncOnly;

    /** The set of fields this struct contains, along with convenience methods for finding and manipulating them. */
    public enum _Fields implements TFieldIdEnum {
      AUTHENTICATION_TOKEN((short)1, "authenticationToken"),
      AFTER_USN((short)2, "afterUSN"),
      MAX_ENTRIES((short)3, "maxEntries"),
      FULL_SYNC_ONLY((short)4, "fullSyncOnly");

      private static final Map<Integer, _Fields> byId = new HashMap<Integer, _Fields>();
      private static final Map<String, _Fields> byName = new HashMap<String, _Fields>();

      static {
        for (_Fields field : EnumSet.allOf(_Fields.class)) {
          byId.put((int)field._thriftId, field);
          byName.put(field.getFieldName(), field);
        }
      }

      /**
       * Find the _Fields constant that matches fieldId, or null if its not found.
       */
      public static _Fields findByThriftId(int fieldId) {
        return byId.get(fieldId);
      }

      /**
       * Find the _Fields constant that matches fieldId, throwing an exception
       * if it is not found.
       */
      public static _Fields findByThriftIdOrThrow(int fieldId) {
        _Fields fields = findByThriftId(fieldId);
        if (fields == null) throw new IllegalArgumentException("Field " + fieldId + " doesn't exist!");
        return fields;
      }

      /**
       * Find the _Fields constant that matches name, or null if its not found.
       */
      public static _Fields findByName(String name) {
        return byName.get(name);
      }

      private final short _thriftId;
      private final String _fieldName;

      _Fields(short thriftId, String fieldName) {
        _thriftId = thriftId;
        _fieldName = fieldName;
      }

      public short getThriftFieldId() {
        return _thriftId;
      }

      public String getFieldName() {
        return _fieldName;
      }
    }

    // isset id assignments
    private static final int __AFTERUSN_ISSET_ID = 0;
    private static final int __MAXENTRIES_ISSET_ID = 1;
    private static final int __FULLSYNCONLY_ISSET_ID = 2;
    private BitSet __isset_bit_vector = new BitSet(3);

    public static final Map<_Fields, FieldMetaData> metaDataMap = Collections.unmodifiableMap(new EnumMap<_Fields, FieldMetaData>(_Fields.class) {{
      put(_Fields.AUTHENTICATION_TOKEN, new FieldMetaData("authenticationToken", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.STRING)));
      put(_Fields.AFTER_USN, new FieldMetaData("afterUSN", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.I32)));
      put(_Fields.MAX_ENTRIES, new FieldMetaData("maxEntries", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.I32)));
      put(_Fields.FULL_SYNC_ONLY, new FieldMetaData("fullSyncOnly", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.BOOL)));
    }});

    static {
      FieldMetaData.addStructMetaDataMap(getSyncChunk_args.class, metaDataMap);
    }

    public getSyncChunk_args() {
    }

    public getSyncChunk_args(
      String authenticationToken,
      int afterUSN,
      int maxEntries,
      boolean fullSyncOnly)
    {
      this();
      this.authenticationToken = authenticationToken;
      this.afterUSN = afterUSN;
      setAfterUSNIsSet(true);
      this.maxEntries = maxEntries;
      setMaxEntriesIsSet(true);
      this.fullSyncOnly = fullSyncOnly;
      setFullSyncOnlyIsSet(true);
    }

    /**
     * Performs a deep copy on <i>other</i>.
     */
    public getSyncChunk_args(getSyncChunk_args other) {
      __isset_bit_vector.clear();
      __isset_bit_vector.or(other.__isset_bit_vector);
      if (other.isSetAuthenticationToken()) {
        this.authenticationToken = other.authenticationToken;
      }
      this.afterUSN = other.afterUSN;
      this.maxEntries = other.maxEntries;
      this.fullSyncOnly = other.fullSyncOnly;
    }

    public getSyncChunk_args deepCopy() {
      return new getSyncChunk_args(this);
    }

    @Deprecated
    public getSyncChunk_args clone() {
      return new getSyncChunk_args(this);
    }

    public String getAuthenticationToken() {
      return this.authenticationToken;
    }

    public void setAuthenticationToken(String authenticationToken) {
      this.authenticationToken = authenticationToken;
    }

    public void unsetAuthenticationToken() {
      this.authenticationToken = null;
    }

    /** Returns true if field authenticationToken is set (has been asigned a value) and false otherwise */
    public boolean isSetAuthenticationToken() {
      return this.authenticationToken != null;
    }

    public void setAuthenticationTokenIsSet(boolean value) {
      if (!value) {
        this.authenticationToken = null;
      }
    }

    public int getAfterUSN() {
      return this.afterUSN;
    }

    public void setAfterUSN(int afterUSN) {
      this.afterUSN = afterUSN;
      setAfterUSNIsSet(true);
    }

    public void unsetAfterUSN() {
      __isset_bit_vector.clear(__AFTERUSN_ISSET_ID);
    }

    /** Returns true if field afterUSN is set (has been asigned a value) and false otherwise */
    public boolean isSetAfterUSN() {
      return __isset_bit_vector.get(__AFTERUSN_ISSET_ID);
    }

    public void setAfterUSNIsSet(boolean value) {
      __isset_bit_vector.set(__AFTERUSN_ISSET_ID, value);
    }

    public int getMaxEntries() {
      return this.maxEntries;
    }

    public void setMaxEntries(int maxEntries) {
      this.maxEntries = maxEntries;
      setMaxEntriesIsSet(true);
    }

    public void unsetMaxEntries() {
      __isset_bit_vector.clear(__MAXENTRIES_ISSET_ID);
    }

    /** Returns true if field maxEntries is set (has been asigned a value) and false otherwise */
    public boolean isSetMaxEntries() {
      return __isset_bit_vector.get(__MAXENTRIES_ISSET_ID);
    }

    public void setMaxEntriesIsSet(boolean value) {
      __isset_bit_vector.set(__MAXENTRIES_ISSET_ID, value);
    }

    public boolean isFullSyncOnly() {
      return this.fullSyncOnly;
    }

    public void setFullSyncOnly(boolean fullSyncOnly) {
      this.fullSyncOnly = fullSyncOnly;
      setFullSyncOnlyIsSet(true);
    }

    public void unsetFullSyncOnly() {
      __isset_bit_vector.clear(__FULLSYNCONLY_ISSET_ID);
    }

    /** Returns true if field fullSyncOnly is set (has been asigned a value) and false otherwise */
    public boolean isSetFullSyncOnly() {
      return __isset_bit_vector.get(__FULLSYNCONLY_ISSET_ID);
    }

    public void setFullSyncOnlyIsSet(boolean value) {
      __isset_bit_vector.set(__FULLSYNCONLY_ISSET_ID, value);
    }

    public void setFieldValue(_Fields field, Object value) {
      switch (field) {
      case AUTHENTICATION_TOKEN:
        if (value == null) {
          unsetAuthenticationToken();
        } else {
          setAuthenticationToken((String)value);
        }
        break;

      case AFTER_USN:
        if (value == null) {
          unsetAfterUSN();
        } else {
          setAfterUSN((Integer)value);
        }
        break;

      case MAX_ENTRIES:
        if (value == null) {
          unsetMaxEntries();
        } else {
          setMaxEntries((Integer)value);
        }
        break;

      case FULL_SYNC_ONLY:
        if (value == null) {
          unsetFullSyncOnly();
        } else {
          setFullSyncOnly((Boolean)value);
        }
        break;

      }
    }

    public void setFieldValue(int fieldID, Object value) {
      setFieldValue(_Fields.findByThriftIdOrThrow(fieldID), value);
    }

    public Object getFieldValue(_Fields field) {
      switch (field) {
      case AUTHENTICATION_TOKEN:
        return getAuthenticationToken();

      case AFTER_USN:
        return new Integer(getAfterUSN());

      case MAX_ENTRIES:
        return new Integer(getMaxEntries());

      case FULL_SYNC_ONLY:
        return new Boolean(isFullSyncOnly());

      }
      throw new IllegalStateException();
    }

    public Object getFieldValue(int fieldId) {
      return getFieldValue(_Fields.findByThriftIdOrThrow(fieldId));
    }

    /** Returns true if field corresponding to fieldID is set (has been asigned a value) and false otherwise */
    public boolean isSet(_Fields field) {
      switch (field) {
      case AUTHENTICATION_TOKEN:
        return isSetAuthenticationToken();
      case AFTER_USN:
        return isSetAfterUSN();
      case MAX_ENTRIES:
        return isSetMaxEntries();
      case FULL_SYNC_ONLY:
        return isSetFullSyncOnly();
      }
      throw new IllegalStateException();
    }

    public boolean isSet(int fieldID) {
      return isSet(_Fields.findByThriftIdOrThrow(fieldID));
    }

    public boolean equals(Object that) {
      if (that == null)
        return false;
      if (that instanceof getSyncChunk_args)
        return this.equals((getSyncChunk_args)that);
      return false;
    }

    public boolean equals(getSyncChunk_args that) {
      if (that == null)
        return false;

      boolean this_present_authenticationToken = true && this.isSetAuthenticationToken();
      boolean that_present_authenticationToken = true && that.isSetAuthenticationToken();
      if (this_present_authenticationToken || that_present_authenticationToken) {
        if (!(this_present_authenticationToken && that_present_authenticationToken))
          return false;
        if (!this.authenticationToken.equals(that.authenticationToken))
          return false;
      }

      boolean this_present_afterUSN = true;
      boolean that_present_afterUSN = true;
      if (this_present_afterUSN || that_present_afterUSN) {
        if (!(this_present_afterUSN && that_present_afterUSN))
          return false;
        if (this.afterUSN != that.afterUSN)
          return false;
      }

      boolean this_present_maxEntries = true;
      boolean that_present_maxEntries = true;
      if (this_present_maxEntries || that_present_maxEntries) {
        if (!(this_present_maxEntries && that_present_maxEntries))
          return false;
        if (this.maxEntries != that.maxEntries)
          return false;
      }

      boolean this_present_fullSyncOnly = true;
      boolean that_present_fullSyncOnly = true;
      if (this_present_fullSyncOnly || that_present_fullSyncOnly) {
        if (!(this_present_fullSyncOnly && that_present_fullSyncOnly))
          return false;
        if (this.fullSyncOnly != that.fullSyncOnly)
          return false;
      }

      return true;
    }

    public int hashCode() {
      return 0;
    }

    public int compareTo(getSyncChunk_args other) {
      if (!getClass().equals(other.getClass())) {
        return getClass().getName().compareTo(other.getClass().getName());
      }

      int lastComparison = 0;
      getSyncChunk_args typedOther = (getSyncChunk_args)other;

      lastComparison = Boolean.valueOf(isSetAuthenticationToken()).compareTo(isSetAuthenticationToken());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(authenticationToken, typedOther.authenticationToken);
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = Boolean.valueOf(isSetAfterUSN()).compareTo(isSetAfterUSN());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(afterUSN, typedOther.afterUSN);
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = Boolean.valueOf(isSetMaxEntries()).compareTo(isSetMaxEntries());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(maxEntries, typedOther.maxEntries);
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = Boolean.valueOf(isSetFullSyncOnly()).compareTo(isSetFullSyncOnly());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(fullSyncOnly, typedOther.fullSyncOnly);
      if (lastComparison != 0) {
        return lastComparison;
      }
      return 0;
    }

    public void read(TProtocol iprot) throws TException {
      TField field;
      iprot.readStructBegin();
      while (true)
      {
        field = iprot.readFieldBegin();
        if (field.type == TType.STOP) { 
          break;
        }
        _Fields fieldId = _Fields.findByThriftId(field.id);
        if (fieldId == null) {
          TProtocolUtil.skip(iprot, field.type);
        } else {
          switch (fieldId) {
            case AUTHENTICATION_TOKEN:
              if (field.type == TType.STRING) {
                this.authenticationToken = iprot.readString();
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
            case AFTER_USN:
              if (field.type == TType.I32) {
                this.afterUSN = iprot.readI32();
                setAfterUSNIsSet(true);
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
            case MAX_ENTRIES:
              if (field.type == TType.I32) {
                this.maxEntries = iprot.readI32();
                setMaxEntriesIsSet(true);
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
            case FULL_SYNC_ONLY:
              if (field.type == TType.BOOL) {
                this.fullSyncOnly = iprot.readBool();
                setFullSyncOnlyIsSet(true);
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
          }
          iprot.readFieldEnd();
        }
      }
      iprot.readStructEnd();
      validate();
    }

    public void write(TProtocol oprot) throws TException {
      validate();

      oprot.writeStructBegin(STRUCT_DESC);
      if (this.authenticationToken != null) {
        oprot.writeFieldBegin(AUTHENTICATION_TOKEN_FIELD_DESC);
        oprot.writeString(this.authenticationToken);
        oprot.writeFieldEnd();
      }
      oprot.writeFieldBegin(AFTER_USN_FIELD_DESC);
      oprot.writeI32(this.afterUSN);
      oprot.writeFieldEnd();
      oprot.writeFieldBegin(MAX_ENTRIES_FIELD_DESC);
      oprot.writeI32(this.maxEntries);
      oprot.writeFieldEnd();
      oprot.writeFieldBegin(FULL_SYNC_ONLY_FIELD_DESC);
      oprot.writeBool(this.fullSyncOnly);
      oprot.writeFieldEnd();
      oprot.writeFieldStop();
      oprot.writeStructEnd();
    }

    public String toString() {
      StringBuilder sb = new StringBuilder("getSyncChunk_args(");
      boolean first = true;

      sb.append("authenticationToken:");
      if (this.authenticationToken == null) {
        sb.append("null");
      } else {
        sb.append(this.authenticationToken);
      }
      first = false;
      if (!first) sb.append(", ");
      sb.append("afterUSN:");
      sb.append(this.afterUSN);
      first = false;
      if (!first) sb.append(", ");
      sb.append("maxEntries:");
      sb.append(this.maxEntries);
      first = false;
      if (!first) sb.append(", ");
      sb.append("fullSyncOnly:");
      sb.append(this.fullSyncOnly);
      first = false;
      sb.append(")");
      return sb.toString();
    }

    public void validate() throws TException {
      // check for required fields
    }

  }

  public static class getSyncChunk_result implements TBase<getSyncChunk_result._Fields>, java.io.Serializable, Cloneable, Comparable<getSyncChunk_result>   {
    private static final TStruct STRUCT_DESC = new TStruct("getSyncChunk_result");

    private static final TField SUCCESS_FIELD_DESC = new TField("success", TType.STRUCT, (short)0);
    private static final TField USER_EXCEPTION_FIELD_DESC = new TField("userException", TType.STRUCT, (short)1);
    private static final TField SYSTEM_EXCEPTION_FIELD_DESC = new TField("systemException", TType.STRUCT, (short)2);

    private SyncChunk success;
    private com.evernote.edam.error.EDAMUserException userException;
    private com.evernote.edam.error.EDAMSystemException systemException;

    /** The set of fields this struct contains, along with convenience methods for finding and manipulating them. */
    public enum _Fields implements TFieldIdEnum {
      SUCCESS((short)0, "success"),
      USER_EXCEPTION((short)1, "userException"),
      SYSTEM_EXCEPTION((short)2, "systemException");

      private static final Map<Integer, _Fields> byId = new HashMap<Integer, _Fields>();
      private static final Map<String, _Fields> byName = new HashMap<String, _Fields>();

      static {
        for (_Fields field : EnumSet.allOf(_Fields.class)) {
          byId.put((int)field._thriftId, field);
          byName.put(field.getFieldName(), field);
        }
      }

      /**
       * Find the _Fields constant that matches fieldId, or null if its not found.
       */
      public static _Fields findByThriftId(int fieldId) {
        return byId.get(fieldId);
      }

      /**
       * Find the _Fields constant that matches fieldId, throwing an exception
       * if it is not found.
       */
      public static _Fields findByThriftIdOrThrow(int fieldId) {
        _Fields fields = findByThriftId(fieldId);
        if (fields == null) throw new IllegalArgumentException("Field " + fieldId + " doesn't exist!");
        return fields;
      }

      /**
       * Find the _Fields constant that matches name, or null if its not found.
       */
      public static _Fields findByName(String name) {
        return byName.get(name);
      }

      private final short _thriftId;
      private final String _fieldName;

      _Fields(short thriftId, String fieldName) {
        _thriftId = thriftId;
        _fieldName = fieldName;
      }

      public short getThriftFieldId() {
        return _thriftId;
      }

      public String getFieldName() {
        return _fieldName;
      }
    }

    // isset id assignments

    public static final Map<_Fields, FieldMetaData> metaDataMap = Collections.unmodifiableMap(new EnumMap<_Fields, FieldMetaData>(_Fields.class) {{
      put(_Fields.SUCCESS, new FieldMetaData("success", TFieldRequirementType.DEFAULT, 
          new StructMetaData(TType.STRUCT, SyncChunk.class)));
      put(_Fields.USER_EXCEPTION, new FieldMetaData("userException", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.STRUCT)));
      put(_Fields.SYSTEM_EXCEPTION, new FieldMetaData("systemException", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.STRUCT)));
    }});

    static {
      FieldMetaData.addStructMetaDataMap(getSyncChunk_result.class, metaDataMap);
    }

    public getSyncChunk_result() {
    }

    public getSyncChunk_result(
      SyncChunk success,
      com.evernote.edam.error.EDAMUserException userException,
      com.evernote.edam.error.EDAMSystemException systemException)
    {
      this();
      this.success = success;
      this.userException = userException;
      this.systemException = systemException;
    }

    /**
     * Performs a deep copy on <i>other</i>.
     */
    public getSyncChunk_result(getSyncChunk_result other) {
      if (other.isSetSuccess()) {
        this.success = new SyncChunk(other.success);
      }
      if (other.isSetUserException()) {
        this.userException = new com.evernote.edam.error.EDAMUserException(other.userException);
      }
      if (other.isSetSystemException()) {
        this.systemException = new com.evernote.edam.error.EDAMSystemException(other.systemException);
      }
    }

    public getSyncChunk_result deepCopy() {
      return new getSyncChunk_result(this);
    }

    @Deprecated
    public getSyncChunk_result clone() {
      return new getSyncChunk_result(this);
    }

    public SyncChunk getSuccess() {
      return this.success;
    }

    public void setSuccess(SyncChunk success) {
      this.success = success;
    }

    public void unsetSuccess() {
      this.success = null;
    }

    /** Returns true if field success is set (has been asigned a value) and false otherwise */
    public boolean isSetSuccess() {
      return this.success != null;
    }

    public void setSuccessIsSet(boolean value) {
      if (!value) {
        this.success = null;
      }
    }

    public com.evernote.edam.error.EDAMUserException getUserException() {
      return this.userException;
    }

    public void setUserException(com.evernote.edam.error.EDAMUserException userException) {
      this.userException = userException;
    }

    public void unsetUserException() {
      this.userException = null;
    }

    /** Returns true if field userException is set (has been asigned a value) and false otherwise */
    public boolean isSetUserException() {
      return this.userException != null;
    }

    public void setUserExceptionIsSet(boolean value) {
      if (!value) {
        this.userException = null;
      }
    }

    public com.evernote.edam.error.EDAMSystemException getSystemException() {
      return this.systemException;
    }

    public void setSystemException(com.evernote.edam.error.EDAMSystemException systemException) {
      this.systemException = systemException;
    }

    public void unsetSystemException() {
      this.systemException = null;
    }

    /** Returns true if field systemException is set (has been asigned a value) and false otherwise */
    public boolean isSetSystemException() {
      return this.systemException != null;
    }

    public void setSystemExceptionIsSet(boolean value) {
      if (!value) {
        this.systemException = null;
      }
    }

    public void setFieldValue(_Fields field, Object value) {
      switch (field) {
      case SUCCESS:
        if (value == null) {
          unsetSuccess();
        } else {
          setSuccess((SyncChunk)value);
        }
        break;

      case USER_EXCEPTION:
        if (value == null) {
          unsetUserException();
        } else {
          setUserException((com.evernote.edam.error.EDAMUserException)value);
        }
        break;

      case SYSTEM_EXCEPTION:
        if (value == null) {
          unsetSystemException();
        } else {
          setSystemException((com.evernote.edam.error.EDAMSystemException)value);
        }
        break;

      }
    }

    public void setFieldValue(int fieldID, Object value) {
      setFieldValue(_Fields.findByThriftIdOrThrow(fieldID), value);
    }

    public Object getFieldValue(_Fields field) {
      switch (field) {
      case SUCCESS:
        return getSuccess();

      case USER_EXCEPTION:
        return getUserException();

      case SYSTEM_EXCEPTION:
        return getSystemException();

      }
      throw new IllegalStateException();
    }

    public Object getFieldValue(int fieldId) {
      return getFieldValue(_Fields.findByThriftIdOrThrow(fieldId));
    }

    /** Returns true if field corresponding to fieldID is set (has been asigned a value) and false otherwise */
    public boolean isSet(_Fields field) {
      switch (field) {
      case SUCCESS:
        return isSetSuccess();
      case USER_EXCEPTION:
        return isSetUserException();
      case SYSTEM_EXCEPTION:
        return isSetSystemException();
      }
      throw new IllegalStateException();
    }

    public boolean isSet(int fieldID) {
      return isSet(_Fields.findByThriftIdOrThrow(fieldID));
    }

    public boolean equals(Object that) {
      if (that == null)
        return false;
      if (that instanceof getSyncChunk_result)
        return this.equals((getSyncChunk_result)that);
      return false;
    }

    public boolean equals(getSyncChunk_result that) {
      if (that == null)
        return false;

      boolean this_present_success = true && this.isSetSuccess();
      boolean that_present_success = true && that.isSetSuccess();
      if (this_present_success || that_present_success) {
        if (!(this_present_success && that_present_success))
          return false;
        if (!this.success.equals(that.success))
          return false;
      }

      boolean this_present_userException = true && this.isSetUserException();
      boolean that_present_userException = true && that.isSetUserException();
      if (this_present_userException || that_present_userException) {
        if (!(this_present_userException && that_present_userException))
          return false;
        if (!this.userException.equals(that.userException))
          return false;
      }

      boolean this_present_systemException = true && this.isSetSystemException();
      boolean that_present_systemException = true && that.isSetSystemException();
      if (this_present_systemException || that_present_systemException) {
        if (!(this_present_systemException && that_present_systemException))
          return false;
        if (!this.systemException.equals(that.systemException))
          return false;
      }

      return true;
    }

    public int hashCode() {
      return 0;
    }

    public int compareTo(getSyncChunk_result other) {
      if (!getClass().equals(other.getClass())) {
        return getClass().getName().compareTo(other.getClass().getName());
      }

      int lastComparison = 0;
      getSyncChunk_result typedOther = (getSyncChunk_result)other;

      lastComparison = Boolean.valueOf(isSetSuccess()).compareTo(isSetSuccess());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(success, typedOther.success);
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = Boolean.valueOf(isSetUserException()).compareTo(isSetUserException());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(userException, typedOther.userException);
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = Boolean.valueOf(isSetSystemException()).compareTo(isSetSystemException());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(systemException, typedOther.systemException);
      if (lastComparison != 0) {
        return lastComparison;
      }
      return 0;
    }

    public void read(TProtocol iprot) throws TException {
      TField field;
      iprot.readStructBegin();
      while (true)
      {
        field = iprot.readFieldBegin();
        if (field.type == TType.STOP) { 
          break;
        }
        _Fields fieldId = _Fields.findByThriftId(field.id);
        if (fieldId == null) {
          TProtocolUtil.skip(iprot, field.type);
        } else {
          switch (fieldId) {
            case SUCCESS:
              if (field.type == TType.STRUCT) {
                this.success = new SyncChunk();
                this.success.read(iprot);
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
            case USER_EXCEPTION:
              if (field.type == TType.STRUCT) {
                this.userException = new com.evernote.edam.error.EDAMUserException();
                this.userException.read(iprot);
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
            case SYSTEM_EXCEPTION:
              if (field.type == TType.STRUCT) {
                this.systemException = new com.evernote.edam.error.EDAMSystemException();
                this.systemException.read(iprot);
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
          }
          iprot.readFieldEnd();
        }
      }
      iprot.readStructEnd();
      validate();
    }

    public void write(TProtocol oprot) throws TException {
      oprot.writeStructBegin(STRUCT_DESC);

      if (this.isSetSuccess()) {
        oprot.writeFieldBegin(SUCCESS_FIELD_DESC);
        this.success.write(oprot);
        oprot.writeFieldEnd();
      } else if (this.isSetUserException()) {
        oprot.writeFieldBegin(USER_EXCEPTION_FIELD_DESC);
        this.userException.write(oprot);
        oprot.writeFieldEnd();
      } else if (this.isSetSystemException()) {
        oprot.writeFieldBegin(SYSTEM_EXCEPTION_FIELD_DESC);
        this.systemException.write(oprot);
        oprot.writeFieldEnd();
      }
      oprot.writeFieldStop();
      oprot.writeStructEnd();
    }

    public String toString() {
      StringBuilder sb = new StringBuilder("getSyncChunk_result(");
      boolean first = true;

      sb.append("success:");
      if (this.success == null) {
        sb.append("null");
      } else {
        sb.append(this.success);
      }
      first = false;
      if (!first) sb.append(", ");
      sb.append("userException:");
      if (this.userException == null) {
        sb.append("null");
      } else {
        sb.append(this.userException);
      }
      first = false;
      if (!first) sb.append(", ");
      sb.append("systemException:");
      if (this.systemException == null) {
        sb.append("null");
      } else {
        sb.append(this.systemException);
      }
      first = false;
      sb.append(")");
      return sb.toString();
    }

    public void validate() throws TException {
      // check for required fields
    }

  }

  public static class listNotebooks_args implements TBase<listNotebooks_args._Fields>, java.io.Serializable, Cloneable, Comparable<listNotebooks_args>   {
    private static final TStruct STRUCT_DESC = new TStruct("listNotebooks_args");

    private static final TField AUTHENTICATION_TOKEN_FIELD_DESC = new TField("authenticationToken", TType.STRING, (short)1);

    private String authenticationToken;

    /** The set of fields this struct contains, along with convenience methods for finding and manipulating them. */
    public enum _Fields implements TFieldIdEnum {
      AUTHENTICATION_TOKEN((short)1, "authenticationToken");

      private static final Map<Integer, _Fields> byId = new HashMap<Integer, _Fields>();
      private static final Map<String, _Fields> byName = new HashMap<String, _Fields>();

      static {
        for (_Fields field : EnumSet.allOf(_Fields.class)) {
          byId.put((int)field._thriftId, field);
          byName.put(field.getFieldName(), field);
        }
      }

      /**
       * Find the _Fields constant that matches fieldId, or null if its not found.
       */
      public static _Fields findByThriftId(int fieldId) {
        return byId.get(fieldId);
      }

      /**
       * Find the _Fields constant that matches fieldId, throwing an exception
       * if it is not found.
       */
      public static _Fields findByThriftIdOrThrow(int fieldId) {
        _Fields fields = findByThriftId(fieldId);
        if (fields == null) throw new IllegalArgumentException("Field " + fieldId + " doesn't exist!");
        return fields;
      }

      /**
       * Find the _Fields constant that matches name, or null if its not found.
       */
      public static _Fields findByName(String name) {
        return byName.get(name);
      }

      private final short _thriftId;
      private final String _fieldName;

      _Fields(short thriftId, String fieldName) {
        _thriftId = thriftId;
        _fieldName = fieldName;
      }

      public short getThriftFieldId() {
        return _thriftId;
      }

      public String getFieldName() {
        return _fieldName;
      }
    }

    // isset id assignments

    public static final Map<_Fields, FieldMetaData> metaDataMap = Collections.unmodifiableMap(new EnumMap<_Fields, FieldMetaData>(_Fields.class) {{
      put(_Fields.AUTHENTICATION_TOKEN, new FieldMetaData("authenticationToken", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.STRING)));
    }});

    static {
      FieldMetaData.addStructMetaDataMap(listNotebooks_args.class, metaDataMap);
    }

    public listNotebooks_args() {
    }

    public listNotebooks_args(
      String authenticationToken)
    {
      this();
      this.authenticationToken = authenticationToken;
    }

    /**
     * Performs a deep copy on <i>other</i>.
     */
    public listNotebooks_args(listNotebooks_args other) {
      if (other.isSetAuthenticationToken()) {
        this.authenticationToken = other.authenticationToken;
      }
    }

    public listNotebooks_args deepCopy() {
      return new listNotebooks_args(this);
    }

    @Deprecated
    public listNotebooks_args clone() {
      return new listNotebooks_args(this);
    }

    public String getAuthenticationToken() {
      return this.authenticationToken;
    }

    public void setAuthenticationToken(String authenticationToken) {
      this.authenticationToken = authenticationToken;
    }

    public void unsetAuthenticationToken() {
      this.authenticationToken = null;
    }

    /** Returns true if field authenticationToken is set (has been asigned a value) and false otherwise */
    public boolean isSetAuthenticationToken() {
      return this.authenticationToken != null;
    }

    public void setAuthenticationTokenIsSet(boolean value) {
      if (!value) {
        this.authenticationToken = null;
      }
    }

    public void setFieldValue(_Fields field, Object value) {
      switch (field) {
      case AUTHENTICATION_TOKEN:
        if (value == null) {
          unsetAuthenticationToken();
        } else {
          setAuthenticationToken((String)value);
        }
        break;

      }
    }

    public void setFieldValue(int fieldID, Object value) {
      setFieldValue(_Fields.findByThriftIdOrThrow(fieldID), value);
    }

    public Object getFieldValue(_Fields field) {
      switch (field) {
      case AUTHENTICATION_TOKEN:
        return getAuthenticationToken();

      }
      throw new IllegalStateException();
    }

    public Object getFieldValue(int fieldId) {
      return getFieldValue(_Fields.findByThriftIdOrThrow(fieldId));
    }

    /** Returns true if field corresponding to fieldID is set (has been asigned a value) and false otherwise */
    public boolean isSet(_Fields field) {
      switch (field) {
      case AUTHENTICATION_TOKEN:
        return isSetAuthenticationToken();
      }
      throw new IllegalStateException();
    }

    public boolean isSet(int fieldID) {
      return isSet(_Fields.findByThriftIdOrThrow(fieldID));
    }

    public boolean equals(Object that) {
      if (that == null)
        return false;
      if (that instanceof listNotebooks_args)
        return this.equals((listNotebooks_args)that);
      return false;
    }

    public boolean equals(listNotebooks_args that) {
      if (that == null)
        return false;

      boolean this_present_authenticationToken = true && this.isSetAuthenticationToken();
      boolean that_present_authenticationToken = true && that.isSetAuthenticationToken();
      if (this_present_authenticationToken || that_present_authenticationToken) {
        if (!(this_present_authenticationToken && that_present_authenticationToken))
          return false;
        if (!this.authenticationToken.equals(that.authenticationToken))
          return false;
      }

      return true;
    }

    public int hashCode() {
      return 0;
    }

    public int compareTo(listNotebooks_args other) {
      if (!getClass().equals(other.getClass())) {
        return getClass().getName().compareTo(other.getClass().getName());
      }

      int lastComparison = 0;
      listNotebooks_args typedOther = (listNotebooks_args)other;

      lastComparison = Boolean.valueOf(isSetAuthenticationToken()).compareTo(isSetAuthenticationToken());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(authenticationToken, typedOther.authenticationToken);
      if (lastComparison != 0) {
        return lastComparison;
      }
      return 0;
    }

    public void read(TProtocol iprot) throws TException {
      TField field;
      iprot.readStructBegin();
      while (true)
      {
        field = iprot.readFieldBegin();
        if (field.type == TType.STOP) { 
          break;
        }
        _Fields fieldId = _Fields.findByThriftId(field.id);
        if (fieldId == null) {
          TProtocolUtil.skip(iprot, field.type);
        } else {
          switch (fieldId) {
            case AUTHENTICATION_TOKEN:
              if (field.type == TType.STRING) {
                this.authenticationToken = iprot.readString();
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
          }
          iprot.readFieldEnd();
        }
      }
      iprot.readStructEnd();
      validate();
    }

    public void write(TProtocol oprot) throws TException {
      validate();

      oprot.writeStructBegin(STRUCT_DESC);
      if (this.authenticationToken != null) {
        oprot.writeFieldBegin(AUTHENTICATION_TOKEN_FIELD_DESC);
        oprot.writeString(this.authenticationToken);
        oprot.writeFieldEnd();
      }
      oprot.writeFieldStop();
      oprot.writeStructEnd();
    }

    public String toString() {
      StringBuilder sb = new StringBuilder("listNotebooks_args(");
      boolean first = true;

      sb.append("authenticationToken:");
      if (this.authenticationToken == null) {
        sb.append("null");
      } else {
        sb.append(this.authenticationToken);
      }
      first = false;
      sb.append(")");
      return sb.toString();
    }

    public void validate() throws TException {
      // check for required fields
    }

  }

  public static class listNotebooks_result implements TBase<listNotebooks_result._Fields>, java.io.Serializable, Cloneable, Comparable<listNotebooks_result>   {
    private static final TStruct STRUCT_DESC = new TStruct("listNotebooks_result");

    private static final TField SUCCESS_FIELD_DESC = new TField("success", TType.LIST, (short)0);
    private static final TField USER_EXCEPTION_FIELD_DESC = new TField("userException", TType.STRUCT, (short)1);
    private static final TField SYSTEM_EXCEPTION_FIELD_DESC = new TField("systemException", TType.STRUCT, (short)2);

    private List<com.evernote.edam.type.Notebook> success;
    private com.evernote.edam.error.EDAMUserException userException;
    private com.evernote.edam.error.EDAMSystemException systemException;

    /** The set of fields this struct contains, along with convenience methods for finding and manipulating them. */
    public enum _Fields implements TFieldIdEnum {
      SUCCESS((short)0, "success"),
      USER_EXCEPTION((short)1, "userException"),
      SYSTEM_EXCEPTION((short)2, "systemException");

      private static final Map<Integer, _Fields> byId = new HashMap<Integer, _Fields>();
      private static final Map<String, _Fields> byName = new HashMap<String, _Fields>();

      static {
        for (_Fields field : EnumSet.allOf(_Fields.class)) {
          byId.put((int)field._thriftId, field);
          byName.put(field.getFieldName(), field);
        }
      }

      /**
       * Find the _Fields constant that matches fieldId, or null if its not found.
       */
      public static _Fields findByThriftId(int fieldId) {
        return byId.get(fieldId);
      }

      /**
       * Find the _Fields constant that matches fieldId, throwing an exception
       * if it is not found.
       */
      public static _Fields findByThriftIdOrThrow(int fieldId) {
        _Fields fields = findByThriftId(fieldId);
        if (fields == null) throw new IllegalArgumentException("Field " + fieldId + " doesn't exist!");
        return fields;
      }

      /**
       * Find the _Fields constant that matches name, or null if its not found.
       */
      public static _Fields findByName(String name) {
        return byName.get(name);
      }

      private final short _thriftId;
      private final String _fieldName;

      _Fields(short thriftId, String fieldName) {
        _thriftId = thriftId;
        _fieldName = fieldName;
      }

      public short getThriftFieldId() {
        return _thriftId;
      }

      public String getFieldName() {
        return _fieldName;
      }
    }

    // isset id assignments

    public static final Map<_Fields, FieldMetaData> metaDataMap = Collections.unmodifiableMap(new EnumMap<_Fields, FieldMetaData>(_Fields.class) {{
      put(_Fields.SUCCESS, new FieldMetaData("success", TFieldRequirementType.DEFAULT, 
          new ListMetaData(TType.LIST, 
              new StructMetaData(TType.STRUCT, com.evernote.edam.type.Notebook.class))));
      put(_Fields.USER_EXCEPTION, new FieldMetaData("userException", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.STRUCT)));
      put(_Fields.SYSTEM_EXCEPTION, new FieldMetaData("systemException", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.STRUCT)));
    }});

    static {
      FieldMetaData.addStructMetaDataMap(listNotebooks_result.class, metaDataMap);
    }

    public listNotebooks_result() {
    }

    public listNotebooks_result(
      List<com.evernote.edam.type.Notebook> success,
      com.evernote.edam.error.EDAMUserException userException,
      com.evernote.edam.error.EDAMSystemException systemException)
    {
      this();
      this.success = success;
      this.userException = userException;
      this.systemException = systemException;
    }

    /**
     * Performs a deep copy on <i>other</i>.
     */
    public listNotebooks_result(listNotebooks_result other) {
      if (other.isSetSuccess()) {
        List<com.evernote.edam.type.Notebook> __this__success = new ArrayList<com.evernote.edam.type.Notebook>();
        for (com.evernote.edam.type.Notebook other_element : other.success) {
          __this__success.add(new com.evernote.edam.type.Notebook(other_element));
        }
        this.success = __this__success;
      }
      if (other.isSetUserException()) {
        this.userException = new com.evernote.edam.error.EDAMUserException(other.userException);
      }
      if (other.isSetSystemException()) {
        this.systemException = new com.evernote.edam.error.EDAMSystemException(other.systemException);
      }
    }

    public listNotebooks_result deepCopy() {
      return new listNotebooks_result(this);
    }

    @Deprecated
    public listNotebooks_result clone() {
      return new listNotebooks_result(this);
    }

    public int getSuccessSize() {
      return (this.success == null) ? 0 : this.success.size();
    }

    public java.util.Iterator<com.evernote.edam.type.Notebook> getSuccessIterator() {
      return (this.success == null) ? null : this.success.iterator();
    }

    public void addToSuccess(com.evernote.edam.type.Notebook elem) {
      if (this.success == null) {
        this.success = new ArrayList<com.evernote.edam.type.Notebook>();
      }
      this.success.add(elem);
    }

    public List<com.evernote.edam.type.Notebook> getSuccess() {
      return this.success;
    }

    public void setSuccess(List<com.evernote.edam.type.Notebook> success) {
      this.success = success;
    }

    public void unsetSuccess() {
      this.success = null;
    }

    /** Returns true if field success is set (has been asigned a value) and false otherwise */
    public boolean isSetSuccess() {
      return this.success != null;
    }

    public void setSuccessIsSet(boolean value) {
      if (!value) {
        this.success = null;
      }
    }

    public com.evernote.edam.error.EDAMUserException getUserException() {
      return this.userException;
    }

    public void setUserException(com.evernote.edam.error.EDAMUserException userException) {
      this.userException = userException;
    }

    public void unsetUserException() {
      this.userException = null;
    }

    /** Returns true if field userException is set (has been asigned a value) and false otherwise */
    public boolean isSetUserException() {
      return this.userException != null;
    }

    public void setUserExceptionIsSet(boolean value) {
      if (!value) {
        this.userException = null;
      }
    }

    public com.evernote.edam.error.EDAMSystemException getSystemException() {
      return this.systemException;
    }

    public void setSystemException(com.evernote.edam.error.EDAMSystemException systemException) {
      this.systemException = systemException;
    }

    public void unsetSystemException() {
      this.systemException = null;
    }

    /** Returns true if field systemException is set (has been asigned a value) and false otherwise */
    public boolean isSetSystemException() {
      return this.systemException != null;
    }

    public void setSystemExceptionIsSet(boolean value) {
      if (!value) {
        this.systemException = null;
      }
    }

    public void setFieldValue(_Fields field, Object value) {
      switch (field) {
      case SUCCESS:
        if (value == null) {
          unsetSuccess();
        } else {
          setSuccess((List<com.evernote.edam.type.Notebook>)value);
        }
        break;

      case USER_EXCEPTION:
        if (value == null) {
          unsetUserException();
        } else {
          setUserException((com.evernote.edam.error.EDAMUserException)value);
        }
        break;

      case SYSTEM_EXCEPTION:
        if (value == null) {
          unsetSystemException();
        } else {
          setSystemException((com.evernote.edam.error.EDAMSystemException)value);
        }
        break;

      }
    }

    public void setFieldValue(int fieldID, Object value) {
      setFieldValue(_Fields.findByThriftIdOrThrow(fieldID), value);
    }

    public Object getFieldValue(_Fields field) {
      switch (field) {
      case SUCCESS:
        return getSuccess();

      case USER_EXCEPTION:
        return getUserException();

      case SYSTEM_EXCEPTION:
        return getSystemException();

      }
      throw new IllegalStateException();
    }

    public Object getFieldValue(int fieldId) {
      return getFieldValue(_Fields.findByThriftIdOrThrow(fieldId));
    }

    /** Returns true if field corresponding to fieldID is set (has been asigned a value) and false otherwise */
    public boolean isSet(_Fields field) {
      switch (field) {
      case SUCCESS:
        return isSetSuccess();
      case USER_EXCEPTION:
        return isSetUserException();
      case SYSTEM_EXCEPTION:
        return isSetSystemException();
      }
      throw new IllegalStateException();
    }

    public boolean isSet(int fieldID) {
      return isSet(_Fields.findByThriftIdOrThrow(fieldID));
    }

    public boolean equals(Object that) {
      if (that == null)
        return false;
      if (that instanceof listNotebooks_result)
        return this.equals((listNotebooks_result)that);
      return false;
    }

    public boolean equals(listNotebooks_result that) {
      if (that == null)
        return false;

      boolean this_present_success = true && this.isSetSuccess();
      boolean that_present_success = true && that.isSetSuccess();
      if (this_present_success || that_present_success) {
        if (!(this_present_success && that_present_success))
          return false;
        if (!this.success.equals(that.success))
          return false;
      }

      boolean this_present_userException = true && this.isSetUserException();
      boolean that_present_userException = true && that.isSetUserException();
      if (this_present_userException || that_present_userException) {
        if (!(this_present_userException && that_present_userException))
          return false;
        if (!this.userException.equals(that.userException))
          return false;
      }

      boolean this_present_systemException = true && this.isSetSystemException();
      boolean that_present_systemException = true && that.isSetSystemException();
      if (this_present_systemException || that_present_systemException) {
        if (!(this_present_systemException && that_present_systemException))
          return false;
        if (!this.systemException.equals(that.systemException))
          return false;
      }

      return true;
    }

    public int hashCode() {
      return 0;
    }

    public int compareTo(listNotebooks_result other) {
      if (!getClass().equals(other.getClass())) {
        return getClass().getName().compareTo(other.getClass().getName());
      }

      int lastComparison = 0;
      listNotebooks_result typedOther = (listNotebooks_result)other;

      lastComparison = Boolean.valueOf(isSetSuccess()).compareTo(isSetSuccess());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(success, typedOther.success);
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = Boolean.valueOf(isSetUserException()).compareTo(isSetUserException());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(userException, typedOther.userException);
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = Boolean.valueOf(isSetSystemException()).compareTo(isSetSystemException());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(systemException, typedOther.systemException);
      if (lastComparison != 0) {
        return lastComparison;
      }
      return 0;
    }

    public void read(TProtocol iprot) throws TException {
      TField field;
      iprot.readStructBegin();
      while (true)
      {
        field = iprot.readFieldBegin();
        if (field.type == TType.STOP) { 
          break;
        }
        _Fields fieldId = _Fields.findByThriftId(field.id);
        if (fieldId == null) {
          TProtocolUtil.skip(iprot, field.type);
        } else {
          switch (fieldId) {
            case SUCCESS:
              if (field.type == TType.LIST) {
                {
                  TList _list79 = iprot.readListBegin();
                  this.success = new ArrayList<com.evernote.edam.type.Notebook>(_list79.size);
                  for (int _i80 = 0; _i80 < _list79.size; ++_i80)
                  {
                    com.evernote.edam.type.Notebook _elem81;
                    _elem81 = new com.evernote.edam.type.Notebook();
                    _elem81.read(iprot);
                    this.success.add(_elem81);
                  }
                  iprot.readListEnd();
                }
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
            case USER_EXCEPTION:
              if (field.type == TType.STRUCT) {
                this.userException = new com.evernote.edam.error.EDAMUserException();
                this.userException.read(iprot);
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
            case SYSTEM_EXCEPTION:
              if (field.type == TType.STRUCT) {
                this.systemException = new com.evernote.edam.error.EDAMSystemException();
                this.systemException.read(iprot);
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
          }
          iprot.readFieldEnd();
        }
      }
      iprot.readStructEnd();
      validate();
    }

    public void write(TProtocol oprot) throws TException {
      oprot.writeStructBegin(STRUCT_DESC);

      if (this.isSetSuccess()) {
        oprot.writeFieldBegin(SUCCESS_FIELD_DESC);
        {
          oprot.writeListBegin(new TList(TType.STRUCT, this.success.size()));
          for (com.evernote.edam.type.Notebook _iter82 : this.success)
          {
            _iter82.write(oprot);
          }
          oprot.writeListEnd();
        }
        oprot.writeFieldEnd();
      } else if (this.isSetUserException()) {
        oprot.writeFieldBegin(USER_EXCEPTION_FIELD_DESC);
        this.userException.write(oprot);
        oprot.writeFieldEnd();
      } else if (this.isSetSystemException()) {
        oprot.writeFieldBegin(SYSTEM_EXCEPTION_FIELD_DESC);
        this.systemException.write(oprot);
        oprot.writeFieldEnd();
      }
      oprot.writeFieldStop();
      oprot.writeStructEnd();
    }

    public String toString() {
      StringBuilder sb = new StringBuilder("listNotebooks_result(");
      boolean first = true;

      sb.append("success:");
      if (this.success == null) {
        sb.append("null");
      } else {
        sb.append(this.success);
      }
      first = false;
      if (!first) sb.append(", ");
      sb.append("userException:");
      if (this.userException == null) {
        sb.append("null");
      } else {
        sb.append(this.userException);
      }
      first = false;
      if (!first) sb.append(", ");
      sb.append("systemException:");
      if (this.systemException == null) {
        sb.append("null");
      } else {
        sb.append(this.systemException);
      }
      first = false;
      sb.append(")");
      return sb.toString();
    }

    public void validate() throws TException {
      // check for required fields
    }

  }

  public static class getNotebook_args implements TBase<getNotebook_args._Fields>, java.io.Serializable, Cloneable, Comparable<getNotebook_args>   {
    private static final TStruct STRUCT_DESC = new TStruct("getNotebook_args");

    private static final TField AUTHENTICATION_TOKEN_FIELD_DESC = new TField("authenticationToken", TType.STRING, (short)1);
    private static final TField GUID_FIELD_DESC = new TField("guid", TType.STRING, (short)2);

    private String authenticationToken;
    private String guid;

    /** The set of fields this struct contains, along with convenience methods for finding and manipulating them. */
    public enum _Fields implements TFieldIdEnum {
      AUTHENTICATION_TOKEN((short)1, "authenticationToken"),
      GUID((short)2, "guid");

      private static final Map<Integer, _Fields> byId = new HashMap<Integer, _Fields>();
      private static final Map<String, _Fields> byName = new HashMap<String, _Fields>();

      static {
        for (_Fields field : EnumSet.allOf(_Fields.class)) {
          byId.put((int)field._thriftId, field);
          byName.put(field.getFieldName(), field);
        }
      }

      /**
       * Find the _Fields constant that matches fieldId, or null if its not found.
       */
      public static _Fields findByThriftId(int fieldId) {
        return byId.get(fieldId);
      }

      /**
       * Find the _Fields constant that matches fieldId, throwing an exception
       * if it is not found.
       */
      public static _Fields findByThriftIdOrThrow(int fieldId) {
        _Fields fields = findByThriftId(fieldId);
        if (fields == null) throw new IllegalArgumentException("Field " + fieldId + " doesn't exist!");
        return fields;
      }

      /**
       * Find the _Fields constant that matches name, or null if its not found.
       */
      public static _Fields findByName(String name) {
        return byName.get(name);
      }

      private final short _thriftId;
      private final String _fieldName;

      _Fields(short thriftId, String fieldName) {
        _thriftId = thriftId;
        _fieldName = fieldName;
      }

      public short getThriftFieldId() {
        return _thriftId;
      }

      public String getFieldName() {
        return _fieldName;
      }
    }

    // isset id assignments

    public static final Map<_Fields, FieldMetaData> metaDataMap = Collections.unmodifiableMap(new EnumMap<_Fields, FieldMetaData>(_Fields.class) {{
      put(_Fields.AUTHENTICATION_TOKEN, new FieldMetaData("authenticationToken", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.STRING)));
      put(_Fields.GUID, new FieldMetaData("guid", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.STRING)));
    }});

    static {
      FieldMetaData.addStructMetaDataMap(getNotebook_args.class, metaDataMap);
    }

    public getNotebook_args() {
    }

    public getNotebook_args(
      String authenticationToken,
      String guid)
    {
      this();
      this.authenticationToken = authenticationToken;
      this.guid = guid;
    }

    /**
     * Performs a deep copy on <i>other</i>.
     */
    public getNotebook_args(getNotebook_args other) {
      if (other.isSetAuthenticationToken()) {
        this.authenticationToken = other.authenticationToken;
      }
      if (other.isSetGuid()) {
        this.guid = other.guid;
      }
    }

    public getNotebook_args deepCopy() {
      return new getNotebook_args(this);
    }

    @Deprecated
    public getNotebook_args clone() {
      return new getNotebook_args(this);
    }

    public String getAuthenticationToken() {
      return this.authenticationToken;
    }

    public void setAuthenticationToken(String authenticationToken) {
      this.authenticationToken = authenticationToken;
    }

    public void unsetAuthenticationToken() {
      this.authenticationToken = null;
    }

    /** Returns true if field authenticationToken is set (has been asigned a value) and false otherwise */
    public boolean isSetAuthenticationToken() {
      return this.authenticationToken != null;
    }

    public void setAuthenticationTokenIsSet(boolean value) {
      if (!value) {
        this.authenticationToken = null;
      }
    }

    public String getGuid() {
      return this.guid;
    }

    public void setGuid(String guid) {
      this.guid = guid;
    }

    public void unsetGuid() {
      this.guid = null;
    }

    /** Returns true if field guid is set (has been asigned a value) and false otherwise */
    public boolean isSetGuid() {
      return this.guid != null;
    }

    public void setGuidIsSet(boolean value) {
      if (!value) {
        this.guid = null;
      }
    }

    public void setFieldValue(_Fields field, Object value) {
      switch (field) {
      case AUTHENTICATION_TOKEN:
        if (value == null) {
          unsetAuthenticationToken();
        } else {
          setAuthenticationToken((String)value);
        }
        break;

      case GUID:
        if (value == null) {
          unsetGuid();
        } else {
          setGuid((String)value);
        }
        break;

      }
    }

    public void setFieldValue(int fieldID, Object value) {
      setFieldValue(_Fields.findByThriftIdOrThrow(fieldID), value);
    }

    public Object getFieldValue(_Fields field) {
      switch (field) {
      case AUTHENTICATION_TOKEN:
        return getAuthenticationToken();

      case GUID:
        return getGuid();

      }
      throw new IllegalStateException();
    }

    public Object getFieldValue(int fieldId) {
      return getFieldValue(_Fields.findByThriftIdOrThrow(fieldId));
    }

    /** Returns true if field corresponding to fieldID is set (has been asigned a value) and false otherwise */
    public boolean isSet(_Fields field) {
      switch (field) {
      case AUTHENTICATION_TOKEN:
        return isSetAuthenticationToken();
      case GUID:
        return isSetGuid();
      }
      throw new IllegalStateException();
    }

    public boolean isSet(int fieldID) {
      return isSet(_Fields.findByThriftIdOrThrow(fieldID));
    }

    public boolean equals(Object that) {
      if (that == null)
        return false;
      if (that instanceof getNotebook_args)
        return this.equals((getNotebook_args)that);
      return false;
    }

    public boolean equals(getNotebook_args that) {
      if (that == null)
        return false;

      boolean this_present_authenticationToken = true && this.isSetAuthenticationToken();
      boolean that_present_authenticationToken = true && that.isSetAuthenticationToken();
      if (this_present_authenticationToken || that_present_authenticationToken) {
        if (!(this_present_authenticationToken && that_present_authenticationToken))
          return false;
        if (!this.authenticationToken.equals(that.authenticationToken))
          return false;
      }

      boolean this_present_guid = true && this.isSetGuid();
      boolean that_present_guid = true && that.isSetGuid();
      if (this_present_guid || that_present_guid) {
        if (!(this_present_guid && that_present_guid))
          return false;
        if (!this.guid.equals(that.guid))
          return false;
      }

      return true;
    }

    public int hashCode() {
      return 0;
    }

    public int compareTo(getNotebook_args other) {
      if (!getClass().equals(other.getClass())) {
        return getClass().getName().compareTo(other.getClass().getName());
      }

      int lastComparison = 0;
      getNotebook_args typedOther = (getNotebook_args)other;

      lastComparison = Boolean.valueOf(isSetAuthenticationToken()).compareTo(isSetAuthenticationToken());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(authenticationToken, typedOther.authenticationToken);
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = Boolean.valueOf(isSetGuid()).compareTo(isSetGuid());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(guid, typedOther.guid);
      if (lastComparison != 0) {
        return lastComparison;
      }
      return 0;
    }

    public void read(TProtocol iprot) throws TException {
      TField field;
      iprot.readStructBegin();
      while (true)
      {
        field = iprot.readFieldBegin();
        if (field.type == TType.STOP) { 
          break;
        }
        _Fields fieldId = _Fields.findByThriftId(field.id);
        if (fieldId == null) {
          TProtocolUtil.skip(iprot, field.type);
        } else {
          switch (fieldId) {
            case AUTHENTICATION_TOKEN:
              if (field.type == TType.STRING) {
                this.authenticationToken = iprot.readString();
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
            case GUID:
              if (field.type == TType.STRING) {
                this.guid = iprot.readString();
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
          }
          iprot.readFieldEnd();
        }
      }
      iprot.readStructEnd();
      validate();
    }

    public void write(TProtocol oprot) throws TException {
      validate();

      oprot.writeStructBegin(STRUCT_DESC);
      if (this.authenticationToken != null) {
        oprot.writeFieldBegin(AUTHENTICATION_TOKEN_FIELD_DESC);
        oprot.writeString(this.authenticationToken);
        oprot.writeFieldEnd();
      }
      if (this.guid != null) {
        oprot.writeFieldBegin(GUID_FIELD_DESC);
        oprot.writeString(this.guid);
        oprot.writeFieldEnd();
      }
      oprot.writeFieldStop();
      oprot.writeStructEnd();
    }

    public String toString() {
      StringBuilder sb = new StringBuilder("getNotebook_args(");
      boolean first = true;

      sb.append("authenticationToken:");
      if (this.authenticationToken == null) {
        sb.append("null");
      } else {
        sb.append(this.authenticationToken);
      }
      first = false;
      if (!first) sb.append(", ");
      sb.append("guid:");
      if (this.guid == null) {
        sb.append("null");
      } else {
        sb.append(this.guid);
      }
      first = false;
      sb.append(")");
      return sb.toString();
    }

    public void validate() throws TException {
      // check for required fields
    }

  }

  public static class getNotebook_result implements TBase<getNotebook_result._Fields>, java.io.Serializable, Cloneable, Comparable<getNotebook_result>   {
    private static final TStruct STRUCT_DESC = new TStruct("getNotebook_result");

    private static final TField SUCCESS_FIELD_DESC = new TField("success", TType.STRUCT, (short)0);
    private static final TField USER_EXCEPTION_FIELD_DESC = new TField("userException", TType.STRUCT, (short)1);
    private static final TField SYSTEM_EXCEPTION_FIELD_DESC = new TField("systemException", TType.STRUCT, (short)2);
    private static final TField NOT_FOUND_EXCEPTION_FIELD_DESC = new TField("notFoundException", TType.STRUCT, (short)3);

    private com.evernote.edam.type.Notebook success;
    private com.evernote.edam.error.EDAMUserException userException;
    private com.evernote.edam.error.EDAMSystemException systemException;
    private com.evernote.edam.error.EDAMNotFoundException notFoundException;

    /** The set of fields this struct contains, along with convenience methods for finding and manipulating them. */
    public enum _Fields implements TFieldIdEnum {
      SUCCESS((short)0, "success"),
      USER_EXCEPTION((short)1, "userException"),
      SYSTEM_EXCEPTION((short)2, "systemException"),
      NOT_FOUND_EXCEPTION((short)3, "notFoundException");

      private static final Map<Integer, _Fields> byId = new HashMap<Integer, _Fields>();
      private static final Map<String, _Fields> byName = new HashMap<String, _Fields>();

      static {
        for (_Fields field : EnumSet.allOf(_Fields.class)) {
          byId.put((int)field._thriftId, field);
          byName.put(field.getFieldName(), field);
        }
      }

      /**
       * Find the _Fields constant that matches fieldId, or null if its not found.
       */
      public static _Fields findByThriftId(int fieldId) {
        return byId.get(fieldId);
      }

      /**
       * Find the _Fields constant that matches fieldId, throwing an exception
       * if it is not found.
       */
      public static _Fields findByThriftIdOrThrow(int fieldId) {
        _Fields fields = findByThriftId(fieldId);
        if (fields == null) throw new IllegalArgumentException("Field " + fieldId + " doesn't exist!");
        return fields;
      }

      /**
       * Find the _Fields constant that matches name, or null if its not found.
       */
      public static _Fields findByName(String name) {
        return byName.get(name);
      }

      private final short _thriftId;
      private final String _fieldName;

      _Fields(short thriftId, String fieldName) {
        _thriftId = thriftId;
        _fieldName = fieldName;
      }

      public short getThriftFieldId() {
        return _thriftId;
      }

      public String getFieldName() {
        return _fieldName;
      }
    }

    // isset id assignments

    public static final Map<_Fields, FieldMetaData> metaDataMap = Collections.unmodifiableMap(new EnumMap<_Fields, FieldMetaData>(_Fields.class) {{
      put(_Fields.SUCCESS, new FieldMetaData("success", TFieldRequirementType.DEFAULT, 
          new StructMetaData(TType.STRUCT, com.evernote.edam.type.Notebook.class)));
      put(_Fields.USER_EXCEPTION, new FieldMetaData("userException", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.STRUCT)));
      put(_Fields.SYSTEM_EXCEPTION, new FieldMetaData("systemException", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.STRUCT)));
      put(_Fields.NOT_FOUND_EXCEPTION, new FieldMetaData("notFoundException", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.STRUCT)));
    }});

    static {
      FieldMetaData.addStructMetaDataMap(getNotebook_result.class, metaDataMap);
    }

    public getNotebook_result() {
    }

    public getNotebook_result(
      com.evernote.edam.type.Notebook success,
      com.evernote.edam.error.EDAMUserException userException,
      com.evernote.edam.error.EDAMSystemException systemException,
      com.evernote.edam.error.EDAMNotFoundException notFoundException)
    {
      this();
      this.success = success;
      this.userException = userException;
      this.systemException = systemException;
      this.notFoundException = notFoundException;
    }

    /**
     * Performs a deep copy on <i>other</i>.
     */
    public getNotebook_result(getNotebook_result other) {
      if (other.isSetSuccess()) {
        this.success = new com.evernote.edam.type.Notebook(other.success);
      }
      if (other.isSetUserException()) {
        this.userException = new com.evernote.edam.error.EDAMUserException(other.userException);
      }
      if (other.isSetSystemException()) {
        this.systemException = new com.evernote.edam.error.EDAMSystemException(other.systemException);
      }
      if (other.isSetNotFoundException()) {
        this.notFoundException = new com.evernote.edam.error.EDAMNotFoundException(other.notFoundException);
      }
    }

    public getNotebook_result deepCopy() {
      return new getNotebook_result(this);
    }

    @Deprecated
    public getNotebook_result clone() {
      return new getNotebook_result(this);
    }

    public com.evernote.edam.type.Notebook getSuccess() {
      return this.success;
    }

    public void setSuccess(com.evernote.edam.type.Notebook success) {
      this.success = success;
    }

    public void unsetSuccess() {
      this.success = null;
    }

    /** Returns true if field success is set (has been asigned a value) and false otherwise */
    public boolean isSetSuccess() {
      return this.success != null;
    }

    public void setSuccessIsSet(boolean value) {
      if (!value) {
        this.success = null;
      }
    }

    public com.evernote.edam.error.EDAMUserException getUserException() {
      return this.userException;
    }

    public void setUserException(com.evernote.edam.error.EDAMUserException userException) {
      this.userException = userException;
    }

    public void unsetUserException() {
      this.userException = null;
    }

    /** Returns true if field userException is set (has been asigned a value) and false otherwise */
    public boolean isSetUserException() {
      return this.userException != null;
    }

    public void setUserExceptionIsSet(boolean value) {
      if (!value) {
        this.userException = null;
      }
    }

    public com.evernote.edam.error.EDAMSystemException getSystemException() {
      return this.systemException;
    }

    public void setSystemException(com.evernote.edam.error.EDAMSystemException systemException) {
      this.systemException = systemException;
    }

    public void unsetSystemException() {
      this.systemException = null;
    }

    /** Returns true if field systemException is set (has been asigned a value) and false otherwise */
    public boolean isSetSystemException() {
      return this.systemException != null;
    }

    public void setSystemExceptionIsSet(boolean value) {
      if (!value) {
        this.systemException = null;
      }
    }

    public com.evernote.edam.error.EDAMNotFoundException getNotFoundException() {
      return this.notFoundException;
    }

    public void setNotFoundException(com.evernote.edam.error.EDAMNotFoundException notFoundException) {
      this.notFoundException = notFoundException;
    }

    public void unsetNotFoundException() {
      this.notFoundException = null;
    }

    /** Returns true if field notFoundException is set (has been asigned a value) and false otherwise */
    public boolean isSetNotFoundException() {
      return this.notFoundException != null;
    }

    public void setNotFoundExceptionIsSet(boolean value) {
      if (!value) {
        this.notFoundException = null;
      }
    }

    public void setFieldValue(_Fields field, Object value) {
      switch (field) {
      case SUCCESS:
        if (value == null) {
          unsetSuccess();
        } else {
          setSuccess((com.evernote.edam.type.Notebook)value);
        }
        break;

      case USER_EXCEPTION:
        if (value == null) {
          unsetUserException();
        } else {
          setUserException((com.evernote.edam.error.EDAMUserException)value);
        }
        break;

      case SYSTEM_EXCEPTION:
        if (value == null) {
          unsetSystemException();
        } else {
          setSystemException((com.evernote.edam.error.EDAMSystemException)value);
        }
        break;

      case NOT_FOUND_EXCEPTION:
        if (value == null) {
          unsetNotFoundException();
        } else {
          setNotFoundException((com.evernote.edam.error.EDAMNotFoundException)value);
        }
        break;

      }
    }

    public void setFieldValue(int fieldID, Object value) {
      setFieldValue(_Fields.findByThriftIdOrThrow(fieldID), value);
    }

    public Object getFieldValue(_Fields field) {
      switch (field) {
      case SUCCESS:
        return getSuccess();

      case USER_EXCEPTION:
        return getUserException();

      case SYSTEM_EXCEPTION:
        return getSystemException();

      case NOT_FOUND_EXCEPTION:
        return getNotFoundException();

      }
      throw new IllegalStateException();
    }

    public Object getFieldValue(int fieldId) {
      return getFieldValue(_Fields.findByThriftIdOrThrow(fieldId));
    }

    /** Returns true if field corresponding to fieldID is set (has been asigned a value) and false otherwise */
    public boolean isSet(_Fields field) {
      switch (field) {
      case SUCCESS:
        return isSetSuccess();
      case USER_EXCEPTION:
        return isSetUserException();
      case SYSTEM_EXCEPTION:
        return isSetSystemException();
      case NOT_FOUND_EXCEPTION:
        return isSetNotFoundException();
      }
      throw new IllegalStateException();
    }

    public boolean isSet(int fieldID) {
      return isSet(_Fields.findByThriftIdOrThrow(fieldID));
    }

    public boolean equals(Object that) {
      if (that == null)
        return false;
      if (that instanceof getNotebook_result)
        return this.equals((getNotebook_result)that);
      return false;
    }

    public boolean equals(getNotebook_result that) {
      if (that == null)
        return false;

      boolean this_present_success = true && this.isSetSuccess();
      boolean that_present_success = true && that.isSetSuccess();
      if (this_present_success || that_present_success) {
        if (!(this_present_success && that_present_success))
          return false;
        if (!this.success.equals(that.success))
          return false;
      }

      boolean this_present_userException = true && this.isSetUserException();
      boolean that_present_userException = true && that.isSetUserException();
      if (this_present_userException || that_present_userException) {
        if (!(this_present_userException && that_present_userException))
          return false;
        if (!this.userException.equals(that.userException))
          return false;
      }

      boolean this_present_systemException = true && this.isSetSystemException();
      boolean that_present_systemException = true && that.isSetSystemException();
      if (this_present_systemException || that_present_systemException) {
        if (!(this_present_systemException && that_present_systemException))
          return false;
        if (!this.systemException.equals(that.systemException))
          return false;
      }

      boolean this_present_notFoundException = true && this.isSetNotFoundException();
      boolean that_present_notFoundException = true && that.isSetNotFoundException();
      if (this_present_notFoundException || that_present_notFoundException) {
        if (!(this_present_notFoundException && that_present_notFoundException))
          return false;
        if (!this.notFoundException.equals(that.notFoundException))
          return false;
      }

      return true;
    }

    public int hashCode() {
      return 0;
    }

    public int compareTo(getNotebook_result other) {
      if (!getClass().equals(other.getClass())) {
        return getClass().getName().compareTo(other.getClass().getName());
      }

      int lastComparison = 0;
      getNotebook_result typedOther = (getNotebook_result)other;

      lastComparison = Boolean.valueOf(isSetSuccess()).compareTo(isSetSuccess());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(success, typedOther.success);
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = Boolean.valueOf(isSetUserException()).compareTo(isSetUserException());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(userException, typedOther.userException);
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = Boolean.valueOf(isSetSystemException()).compareTo(isSetSystemException());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(systemException, typedOther.systemException);
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = Boolean.valueOf(isSetNotFoundException()).compareTo(isSetNotFoundException());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(notFoundException, typedOther.notFoundException);
      if (lastComparison != 0) {
        return lastComparison;
      }
      return 0;
    }

    public void read(TProtocol iprot) throws TException {
      TField field;
      iprot.readStructBegin();
      while (true)
      {
        field = iprot.readFieldBegin();
        if (field.type == TType.STOP) { 
          break;
        }
        _Fields fieldId = _Fields.findByThriftId(field.id);
        if (fieldId == null) {
          TProtocolUtil.skip(iprot, field.type);
        } else {
          switch (fieldId) {
            case SUCCESS:
              if (field.type == TType.STRUCT) {
                this.success = new com.evernote.edam.type.Notebook();
                this.success.read(iprot);
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
            case USER_EXCEPTION:
              if (field.type == TType.STRUCT) {
                this.userException = new com.evernote.edam.error.EDAMUserException();
                this.userException.read(iprot);
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
            case SYSTEM_EXCEPTION:
              if (field.type == TType.STRUCT) {
                this.systemException = new com.evernote.edam.error.EDAMSystemException();
                this.systemException.read(iprot);
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
            case NOT_FOUND_EXCEPTION:
              if (field.type == TType.STRUCT) {
                this.notFoundException = new com.evernote.edam.error.EDAMNotFoundException();
                this.notFoundException.read(iprot);
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
          }
          iprot.readFieldEnd();
        }
      }
      iprot.readStructEnd();
      validate();
    }

    public void write(TProtocol oprot) throws TException {
      oprot.writeStructBegin(STRUCT_DESC);

      if (this.isSetSuccess()) {
        oprot.writeFieldBegin(SUCCESS_FIELD_DESC);
        this.success.write(oprot);
        oprot.writeFieldEnd();
      } else if (this.isSetUserException()) {
        oprot.writeFieldBegin(USER_EXCEPTION_FIELD_DESC);
        this.userException.write(oprot);
        oprot.writeFieldEnd();
      } else if (this.isSetSystemException()) {
        oprot.writeFieldBegin(SYSTEM_EXCEPTION_FIELD_DESC);
        this.systemException.write(oprot);
        oprot.writeFieldEnd();
      } else if (this.isSetNotFoundException()) {
        oprot.writeFieldBegin(NOT_FOUND_EXCEPTION_FIELD_DESC);
        this.notFoundException.write(oprot);
        oprot.writeFieldEnd();
      }
      oprot.writeFieldStop();
      oprot.writeStructEnd();
    }

    public String toString() {
      StringBuilder sb = new StringBuilder("getNotebook_result(");
      boolean first = true;

      sb.append("success:");
      if (this.success == null) {
        sb.append("null");
      } else {
        sb.append(this.success);
      }
      first = false;
      if (!first) sb.append(", ");
      sb.append("userException:");
      if (this.userException == null) {
        sb.append("null");
      } else {
        sb.append(this.userException);
      }
      first = false;
      if (!first) sb.append(", ");
      sb.append("systemException:");
      if (this.systemException == null) {
        sb.append("null");
      } else {
        sb.append(this.systemException);
      }
      first = false;
      if (!first) sb.append(", ");
      sb.append("notFoundException:");
      if (this.notFoundException == null) {
        sb.append("null");
      } else {
        sb.append(this.notFoundException);
      }
      first = false;
      sb.append(")");
      return sb.toString();
    }

    public void validate() throws TException {
      // check for required fields
    }

  }

  public static class getDefaultNotebook_args implements TBase<getDefaultNotebook_args._Fields>, java.io.Serializable, Cloneable, Comparable<getDefaultNotebook_args>   {
    private static final TStruct STRUCT_DESC = new TStruct("getDefaultNotebook_args");

    private static final TField AUTHENTICATION_TOKEN_FIELD_DESC = new TField("authenticationToken", TType.STRING, (short)1);

    private String authenticationToken;

    /** The set of fields this struct contains, along with convenience methods for finding and manipulating them. */
    public enum _Fields implements TFieldIdEnum {
      AUTHENTICATION_TOKEN((short)1, "authenticationToken");

      private static final Map<Integer, _Fields> byId = new HashMap<Integer, _Fields>();
      private static final Map<String, _Fields> byName = new HashMap<String, _Fields>();

      static {
        for (_Fields field : EnumSet.allOf(_Fields.class)) {
          byId.put((int)field._thriftId, field);
          byName.put(field.getFieldName(), field);
        }
      }

      /**
       * Find the _Fields constant that matches fieldId, or null if its not found.
       */
      public static _Fields findByThriftId(int fieldId) {
        return byId.get(fieldId);
      }

      /**
       * Find the _Fields constant that matches fieldId, throwing an exception
       * if it is not found.
       */
      public static _Fields findByThriftIdOrThrow(int fieldId) {
        _Fields fields = findByThriftId(fieldId);
        if (fields == null) throw new IllegalArgumentException("Field " + fieldId + " doesn't exist!");
        return fields;
      }

      /**
       * Find the _Fields constant that matches name, or null if its not found.
       */
      public static _Fields findByName(String name) {
        return byName.get(name);
      }

      private final short _thriftId;
      private final String _fieldName;

      _Fields(short thriftId, String fieldName) {
        _thriftId = thriftId;
        _fieldName = fieldName;
      }

      public short getThriftFieldId() {
        return _thriftId;
      }

      public String getFieldName() {
        return _fieldName;
      }
    }

    // isset id assignments

    public static final Map<_Fields, FieldMetaData> metaDataMap = Collections.unmodifiableMap(new EnumMap<_Fields, FieldMetaData>(_Fields.class) {{
      put(_Fields.AUTHENTICATION_TOKEN, new FieldMetaData("authenticationToken", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.STRING)));
    }});

    static {
      FieldMetaData.addStructMetaDataMap(getDefaultNotebook_args.class, metaDataMap);
    }

    public getDefaultNotebook_args() {
    }

    public getDefaultNotebook_args(
      String authenticationToken)
    {
      this();
      this.authenticationToken = authenticationToken;
    }

    /**
     * Performs a deep copy on <i>other</i>.
     */
    public getDefaultNotebook_args(getDefaultNotebook_args other) {
      if (other.isSetAuthenticationToken()) {
        this.authenticationToken = other.authenticationToken;
      }
    }

    public getDefaultNotebook_args deepCopy() {
      return new getDefaultNotebook_args(this);
    }

    @Deprecated
    public getDefaultNotebook_args clone() {
      return new getDefaultNotebook_args(this);
    }

    public String getAuthenticationToken() {
      return this.authenticationToken;
    }

    public void setAuthenticationToken(String authenticationToken) {
      this.authenticationToken = authenticationToken;
    }

    public void unsetAuthenticationToken() {
      this.authenticationToken = null;
    }

    /** Returns true if field authenticationToken is set (has been asigned a value) and false otherwise */
    public boolean isSetAuthenticationToken() {
      return this.authenticationToken != null;
    }

    public void setAuthenticationTokenIsSet(boolean value) {
      if (!value) {
        this.authenticationToken = null;
      }
    }

    public void setFieldValue(_Fields field, Object value) {
      switch (field) {
      case AUTHENTICATION_TOKEN:
        if (value == null) {
          unsetAuthenticationToken();
        } else {
          setAuthenticationToken((String)value);
        }
        break;

      }
    }

    public void setFieldValue(int fieldID, Object value) {
      setFieldValue(_Fields.findByThriftIdOrThrow(fieldID), value);
    }

    public Object getFieldValue(_Fields field) {
      switch (field) {
      case AUTHENTICATION_TOKEN:
        return getAuthenticationToken();

      }
      throw new IllegalStateException();
    }

    public Object getFieldValue(int fieldId) {
      return getFieldValue(_Fields.findByThriftIdOrThrow(fieldId));
    }

    /** Returns true if field corresponding to fieldID is set (has been asigned a value) and false otherwise */
    public boolean isSet(_Fields field) {
      switch (field) {
      case AUTHENTICATION_TOKEN:
        return isSetAuthenticationToken();
      }
      throw new IllegalStateException();
    }

    public boolean isSet(int fieldID) {
      return isSet(_Fields.findByThriftIdOrThrow(fieldID));
    }

    public boolean equals(Object that) {
      if (that == null)
        return false;
      if (that instanceof getDefaultNotebook_args)
        return this.equals((getDefaultNotebook_args)that);
      return false;
    }

    public boolean equals(getDefaultNotebook_args that) {
      if (that == null)
        return false;

      boolean this_present_authenticationToken = true && this.isSetAuthenticationToken();
      boolean that_present_authenticationToken = true && that.isSetAuthenticationToken();
      if (this_present_authenticationToken || that_present_authenticationToken) {
        if (!(this_present_authenticationToken && that_present_authenticationToken))
          return false;
        if (!this.authenticationToken.equals(that.authenticationToken))
          return false;
      }

      return true;
    }

    public int hashCode() {
      return 0;
    }

    public int compareTo(getDefaultNotebook_args other) {
      if (!getClass().equals(other.getClass())) {
        return getClass().getName().compareTo(other.getClass().getName());
      }

      int lastComparison = 0;
      getDefaultNotebook_args typedOther = (getDefaultNotebook_args)other;

      lastComparison = Boolean.valueOf(isSetAuthenticationToken()).compareTo(isSetAuthenticationToken());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(authenticationToken, typedOther.authenticationToken);
      if (lastComparison != 0) {
        return lastComparison;
      }
      return 0;
    }

    public void read(TProtocol iprot) throws TException {
      TField field;
      iprot.readStructBegin();
      while (true)
      {
        field = iprot.readFieldBegin();
        if (field.type == TType.STOP) { 
          break;
        }
        _Fields fieldId = _Fields.findByThriftId(field.id);
        if (fieldId == null) {
          TProtocolUtil.skip(iprot, field.type);
        } else {
          switch (fieldId) {
            case AUTHENTICATION_TOKEN:
              if (field.type == TType.STRING) {
                this.authenticationToken = iprot.readString();
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
          }
          iprot.readFieldEnd();
        }
      }
      iprot.readStructEnd();
      validate();
    }

    public void write(TProtocol oprot) throws TException {
      validate();

      oprot.writeStructBegin(STRUCT_DESC);
      if (this.authenticationToken != null) {
        oprot.writeFieldBegin(AUTHENTICATION_TOKEN_FIELD_DESC);
        oprot.writeString(this.authenticationToken);
        oprot.writeFieldEnd();
      }
      oprot.writeFieldStop();
      oprot.writeStructEnd();
    }

    public String toString() {
      StringBuilder sb = new StringBuilder("getDefaultNotebook_args(");
      boolean first = true;

      sb.append("authenticationToken:");
      if (this.authenticationToken == null) {
        sb.append("null");
      } else {
        sb.append(this.authenticationToken);
      }
      first = false;
      sb.append(")");
      return sb.toString();
    }

    public void validate() throws TException {
      // check for required fields
    }

  }

  public static class getDefaultNotebook_result implements TBase<getDefaultNotebook_result._Fields>, java.io.Serializable, Cloneable, Comparable<getDefaultNotebook_result>   {
    private static final TStruct STRUCT_DESC = new TStruct("getDefaultNotebook_result");

    private static final TField SUCCESS_FIELD_DESC = new TField("success", TType.STRUCT, (short)0);
    private static final TField USER_EXCEPTION_FIELD_DESC = new TField("userException", TType.STRUCT, (short)1);
    private static final TField SYSTEM_EXCEPTION_FIELD_DESC = new TField("systemException", TType.STRUCT, (short)2);

    private com.evernote.edam.type.Notebook success;
    private com.evernote.edam.error.EDAMUserException userException;
    private com.evernote.edam.error.EDAMSystemException systemException;

    /** The set of fields this struct contains, along with convenience methods for finding and manipulating them. */
    public enum _Fields implements TFieldIdEnum {
      SUCCESS((short)0, "success"),
      USER_EXCEPTION((short)1, "userException"),
      SYSTEM_EXCEPTION((short)2, "systemException");

      private static final Map<Integer, _Fields> byId = new HashMap<Integer, _Fields>();
      private static final Map<String, _Fields> byName = new HashMap<String, _Fields>();

      static {
        for (_Fields field : EnumSet.allOf(_Fields.class)) {
          byId.put((int)field._thriftId, field);
          byName.put(field.getFieldName(), field);
        }
      }

      /**
       * Find the _Fields constant that matches fieldId, or null if its not found.
       */
      public static _Fields findByThriftId(int fieldId) {
        return byId.get(fieldId);
      }

      /**
       * Find the _Fields constant that matches fieldId, throwing an exception
       * if it is not found.
       */
      public static _Fields findByThriftIdOrThrow(int fieldId) {
        _Fields fields = findByThriftId(fieldId);
        if (fields == null) throw new IllegalArgumentException("Field " + fieldId + " doesn't exist!");
        return fields;
      }

      /**
       * Find the _Fields constant that matches name, or null if its not found.
       */
      public static _Fields findByName(String name) {
        return byName.get(name);
      }

      private final short _thriftId;
      private final String _fieldName;

      _Fields(short thriftId, String fieldName) {
        _thriftId = thriftId;
        _fieldName = fieldName;
      }

      public short getThriftFieldId() {
        return _thriftId;
      }

      public String getFieldName() {
        return _fieldName;
      }
    }

    // isset id assignments

    public static final Map<_Fields, FieldMetaData> metaDataMap = Collections.unmodifiableMap(new EnumMap<_Fields, FieldMetaData>(_Fields.class) {{
      put(_Fields.SUCCESS, new FieldMetaData("success", TFieldRequirementType.DEFAULT, 
          new StructMetaData(TType.STRUCT, com.evernote.edam.type.Notebook.class)));
      put(_Fields.USER_EXCEPTION, new FieldMetaData("userException", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.STRUCT)));
      put(_Fields.SYSTEM_EXCEPTION, new FieldMetaData("systemException", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.STRUCT)));
    }});

    static {
      FieldMetaData.addStructMetaDataMap(getDefaultNotebook_result.class, metaDataMap);
    }

    public getDefaultNotebook_result() {
    }

    public getDefaultNotebook_result(
      com.evernote.edam.type.Notebook success,
      com.evernote.edam.error.EDAMUserException userException,
      com.evernote.edam.error.EDAMSystemException systemException)
    {
      this();
      this.success = success;
      this.userException = userException;
      this.systemException = systemException;
    }

    /**
     * Performs a deep copy on <i>other</i>.
     */
    public getDefaultNotebook_result(getDefaultNotebook_result other) {
      if (other.isSetSuccess()) {
        this.success = new com.evernote.edam.type.Notebook(other.success);
      }
      if (other.isSetUserException()) {
        this.userException = new com.evernote.edam.error.EDAMUserException(other.userException);
      }
      if (other.isSetSystemException()) {
        this.systemException = new com.evernote.edam.error.EDAMSystemException(other.systemException);
      }
    }

    public getDefaultNotebook_result deepCopy() {
      return new getDefaultNotebook_result(this);
    }

    @Deprecated
    public getDefaultNotebook_result clone() {
      return new getDefaultNotebook_result(this);
    }

    public com.evernote.edam.type.Notebook getSuccess() {
      return this.success;
    }

    public void setSuccess(com.evernote.edam.type.Notebook success) {
      this.success = success;
    }

    public void unsetSuccess() {
      this.success = null;
    }

    /** Returns true if field success is set (has been asigned a value) and false otherwise */
    public boolean isSetSuccess() {
      return this.success != null;
    }

    public void setSuccessIsSet(boolean value) {
      if (!value) {
        this.success = null;
      }
    }

    public com.evernote.edam.error.EDAMUserException getUserException() {
      return this.userException;
    }

    public void setUserException(com.evernote.edam.error.EDAMUserException userException) {
      this.userException = userException;
    }

    public void unsetUserException() {
      this.userException = null;
    }

    /** Returns true if field userException is set (has been asigned a value) and false otherwise */
    public boolean isSetUserException() {
      return this.userException != null;
    }

    public void setUserExceptionIsSet(boolean value) {
      if (!value) {
        this.userException = null;
      }
    }

    public com.evernote.edam.error.EDAMSystemException getSystemException() {
      return this.systemException;
    }

    public void setSystemException(com.evernote.edam.error.EDAMSystemException systemException) {
      this.systemException = systemException;
    }

    public void unsetSystemException() {
      this.systemException = null;
    }

    /** Returns true if field systemException is set (has been asigned a value) and false otherwise */
    public boolean isSetSystemException() {
      return this.systemException != null;
    }

    public void setSystemExceptionIsSet(boolean value) {
      if (!value) {
        this.systemException = null;
      }
    }

    public void setFieldValue(_Fields field, Object value) {
      switch (field) {
      case SUCCESS:
        if (value == null) {
          unsetSuccess();
        } else {
          setSuccess((com.evernote.edam.type.Notebook)value);
        }
        break;

      case USER_EXCEPTION:
        if (value == null) {
          unsetUserException();
        } else {
          setUserException((com.evernote.edam.error.EDAMUserException)value);
        }
        break;

      case SYSTEM_EXCEPTION:
        if (value == null) {
          unsetSystemException();
        } else {
          setSystemException((com.evernote.edam.error.EDAMSystemException)value);
        }
        break;

      }
    }

    public void setFieldValue(int fieldID, Object value) {
      setFieldValue(_Fields.findByThriftIdOrThrow(fieldID), value);
    }

    public Object getFieldValue(_Fields field) {
      switch (field) {
      case SUCCESS:
        return getSuccess();

      case USER_EXCEPTION:
        return getUserException();

      case SYSTEM_EXCEPTION:
        return getSystemException();

      }
      throw new IllegalStateException();
    }

    public Object getFieldValue(int fieldId) {
      return getFieldValue(_Fields.findByThriftIdOrThrow(fieldId));
    }

    /** Returns true if field corresponding to fieldID is set (has been asigned a value) and false otherwise */
    public boolean isSet(_Fields field) {
      switch (field) {
      case SUCCESS:
        return isSetSuccess();
      case USER_EXCEPTION:
        return isSetUserException();
      case SYSTEM_EXCEPTION:
        return isSetSystemException();
      }
      throw new IllegalStateException();
    }

    public boolean isSet(int fieldID) {
      return isSet(_Fields.findByThriftIdOrThrow(fieldID));
    }

    public boolean equals(Object that) {
      if (that == null)
        return false;
      if (that instanceof getDefaultNotebook_result)
        return this.equals((getDefaultNotebook_result)that);
      return false;
    }

    public boolean equals(getDefaultNotebook_result that) {
      if (that == null)
        return false;

      boolean this_present_success = true && this.isSetSuccess();
      boolean that_present_success = true && that.isSetSuccess();
      if (this_present_success || that_present_success) {
        if (!(this_present_success && that_present_success))
          return false;
        if (!this.success.equals(that.success))
          return false;
      }

      boolean this_present_userException = true && this.isSetUserException();
      boolean that_present_userException = true && that.isSetUserException();
      if (this_present_userException || that_present_userException) {
        if (!(this_present_userException && that_present_userException))
          return false;
        if (!this.userException.equals(that.userException))
          return false;
      }

      boolean this_present_systemException = true && this.isSetSystemException();
      boolean that_present_systemException = true && that.isSetSystemException();
      if (this_present_systemException || that_present_systemException) {
        if (!(this_present_systemException && that_present_systemException))
          return false;
        if (!this.systemException.equals(that.systemException))
          return false;
      }

      return true;
    }

    public int hashCode() {
      return 0;
    }

    public int compareTo(getDefaultNotebook_result other) {
      if (!getClass().equals(other.getClass())) {
        return getClass().getName().compareTo(other.getClass().getName());
      }

      int lastComparison = 0;
      getDefaultNotebook_result typedOther = (getDefaultNotebook_result)other;

      lastComparison = Boolean.valueOf(isSetSuccess()).compareTo(isSetSuccess());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(success, typedOther.success);
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = Boolean.valueOf(isSetUserException()).compareTo(isSetUserException());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(userException, typedOther.userException);
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = Boolean.valueOf(isSetSystemException()).compareTo(isSetSystemException());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(systemException, typedOther.systemException);
      if (lastComparison != 0) {
        return lastComparison;
      }
      return 0;
    }

    public void read(TProtocol iprot) throws TException {
      TField field;
      iprot.readStructBegin();
      while (true)
      {
        field = iprot.readFieldBegin();
        if (field.type == TType.STOP) { 
          break;
        }
        _Fields fieldId = _Fields.findByThriftId(field.id);
        if (fieldId == null) {
          TProtocolUtil.skip(iprot, field.type);
        } else {
          switch (fieldId) {
            case SUCCESS:
              if (field.type == TType.STRUCT) {
                this.success = new com.evernote.edam.type.Notebook();
                this.success.read(iprot);
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
            case USER_EXCEPTION:
              if (field.type == TType.STRUCT) {
                this.userException = new com.evernote.edam.error.EDAMUserException();
                this.userException.read(iprot);
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
            case SYSTEM_EXCEPTION:
              if (field.type == TType.STRUCT) {
                this.systemException = new com.evernote.edam.error.EDAMSystemException();
                this.systemException.read(iprot);
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
          }
          iprot.readFieldEnd();
        }
      }
      iprot.readStructEnd();
      validate();
    }

    public void write(TProtocol oprot) throws TException {
      oprot.writeStructBegin(STRUCT_DESC);

      if (this.isSetSuccess()) {
        oprot.writeFieldBegin(SUCCESS_FIELD_DESC);
        this.success.write(oprot);
        oprot.writeFieldEnd();
      } else if (this.isSetUserException()) {
        oprot.writeFieldBegin(USER_EXCEPTION_FIELD_DESC);
        this.userException.write(oprot);
        oprot.writeFieldEnd();
      } else if (this.isSetSystemException()) {
        oprot.writeFieldBegin(SYSTEM_EXCEPTION_FIELD_DESC);
        this.systemException.write(oprot);
        oprot.writeFieldEnd();
      }
      oprot.writeFieldStop();
      oprot.writeStructEnd();
    }

    public String toString() {
      StringBuilder sb = new StringBuilder("getDefaultNotebook_result(");
      boolean first = true;

      sb.append("success:");
      if (this.success == null) {
        sb.append("null");
      } else {
        sb.append(this.success);
      }
      first = false;
      if (!first) sb.append(", ");
      sb.append("userException:");
      if (this.userException == null) {
        sb.append("null");
      } else {
        sb.append(this.userException);
      }
      first = false;
      if (!first) sb.append(", ");
      sb.append("systemException:");
      if (this.systemException == null) {
        sb.append("null");
      } else {
        sb.append(this.systemException);
      }
      first = false;
      sb.append(")");
      return sb.toString();
    }

    public void validate() throws TException {
      // check for required fields
    }

  }

  public static class createNotebook_args implements TBase<createNotebook_args._Fields>, java.io.Serializable, Cloneable, Comparable<createNotebook_args>   {
    private static final TStruct STRUCT_DESC = new TStruct("createNotebook_args");

    private static final TField AUTHENTICATION_TOKEN_FIELD_DESC = new TField("authenticationToken", TType.STRING, (short)1);
    private static final TField NOTEBOOK_FIELD_DESC = new TField("notebook", TType.STRUCT, (short)2);

    private String authenticationToken;
    private com.evernote.edam.type.Notebook notebook;

    /** The set of fields this struct contains, along with convenience methods for finding and manipulating them. */
    public enum _Fields implements TFieldIdEnum {
      AUTHENTICATION_TOKEN((short)1, "authenticationToken"),
      NOTEBOOK((short)2, "notebook");

      private static final Map<Integer, _Fields> byId = new HashMap<Integer, _Fields>();
      private static final Map<String, _Fields> byName = new HashMap<String, _Fields>();

      static {
        for (_Fields field : EnumSet.allOf(_Fields.class)) {
          byId.put((int)field._thriftId, field);
          byName.put(field.getFieldName(), field);
        }
      }

      /**
       * Find the _Fields constant that matches fieldId, or null if its not found.
       */
      public static _Fields findByThriftId(int fieldId) {
        return byId.get(fieldId);
      }

      /**
       * Find the _Fields constant that matches fieldId, throwing an exception
       * if it is not found.
       */
      public static _Fields findByThriftIdOrThrow(int fieldId) {
        _Fields fields = findByThriftId(fieldId);
        if (fields == null) throw new IllegalArgumentException("Field " + fieldId + " doesn't exist!");
        return fields;
      }

      /**
       * Find the _Fields constant that matches name, or null if its not found.
       */
      public static _Fields findByName(String name) {
        return byName.get(name);
      }

      private final short _thriftId;
      private final String _fieldName;

      _Fields(short thriftId, String fieldName) {
        _thriftId = thriftId;
        _fieldName = fieldName;
      }

      public short getThriftFieldId() {
        return _thriftId;
      }

      public String getFieldName() {
        return _fieldName;
      }
    }

    // isset id assignments

    public static final Map<_Fields, FieldMetaData> metaDataMap = Collections.unmodifiableMap(new EnumMap<_Fields, FieldMetaData>(_Fields.class) {{
      put(_Fields.AUTHENTICATION_TOKEN, new FieldMetaData("authenticationToken", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.STRING)));
      put(_Fields.NOTEBOOK, new FieldMetaData("notebook", TFieldRequirementType.DEFAULT, 
          new StructMetaData(TType.STRUCT, com.evernote.edam.type.Notebook.class)));
    }});

    static {
      FieldMetaData.addStructMetaDataMap(createNotebook_args.class, metaDataMap);
    }

    public createNotebook_args() {
    }

    public createNotebook_args(
      String authenticationToken,
      com.evernote.edam.type.Notebook notebook)
    {
      this();
      this.authenticationToken = authenticationToken;
      this.notebook = notebook;
    }

    /**
     * Performs a deep copy on <i>other</i>.
     */
    public createNotebook_args(createNotebook_args other) {
      if (other.isSetAuthenticationToken()) {
        this.authenticationToken = other.authenticationToken;
      }
      if (other.isSetNotebook()) {
        this.notebook = new com.evernote.edam.type.Notebook(other.notebook);
      }
    }

    public createNotebook_args deepCopy() {
      return new createNotebook_args(this);
    }

    @Deprecated
    public createNotebook_args clone() {
      return new createNotebook_args(this);
    }

    public String getAuthenticationToken() {
      return this.authenticationToken;
    }

    public void setAuthenticationToken(String authenticationToken) {
      this.authenticationToken = authenticationToken;
    }

    public void unsetAuthenticationToken() {
      this.authenticationToken = null;
    }

    /** Returns true if field authenticationToken is set (has been asigned a value) and false otherwise */
    public boolean isSetAuthenticationToken() {
      return this.authenticationToken != null;
    }

    public void setAuthenticationTokenIsSet(boolean value) {
      if (!value) {
        this.authenticationToken = null;
      }
    }

    public com.evernote.edam.type.Notebook getNotebook() {
      return this.notebook;
    }

    public void setNotebook(com.evernote.edam.type.Notebook notebook) {
      this.notebook = notebook;
    }

    public void unsetNotebook() {
      this.notebook = null;
    }

    /** Returns true if field notebook is set (has been asigned a value) and false otherwise */
    public boolean isSetNotebook() {
      return this.notebook != null;
    }

    public void setNotebookIsSet(boolean value) {
      if (!value) {
        this.notebook = null;
      }
    }

    public void setFieldValue(_Fields field, Object value) {
      switch (field) {
      case AUTHENTICATION_TOKEN:
        if (value == null) {
          unsetAuthenticationToken();
        } else {
          setAuthenticationToken((String)value);
        }
        break;

      case NOTEBOOK:
        if (value == null) {
          unsetNotebook();
        } else {
          setNotebook((com.evernote.edam.type.Notebook)value);
        }
        break;

      }
    }

    public void setFieldValue(int fieldID, Object value) {
      setFieldValue(_Fields.findByThriftIdOrThrow(fieldID), value);
    }

    public Object getFieldValue(_Fields field) {
      switch (field) {
      case AUTHENTICATION_TOKEN:
        return getAuthenticationToken();

      case NOTEBOOK:
        return getNotebook();

      }
      throw new IllegalStateException();
    }

    public Object getFieldValue(int fieldId) {
      return getFieldValue(_Fields.findByThriftIdOrThrow(fieldId));
    }

    /** Returns true if field corresponding to fieldID is set (has been asigned a value) and false otherwise */
    public boolean isSet(_Fields field) {
      switch (field) {
      case AUTHENTICATION_TOKEN:
        return isSetAuthenticationToken();
      case NOTEBOOK:
        return isSetNotebook();
      }
      throw new IllegalStateException();
    }

    public boolean isSet(int fieldID) {
      return isSet(_Fields.findByThriftIdOrThrow(fieldID));
    }

    public boolean equals(Object that) {
      if (that == null)
        return false;
      if (that instanceof createNotebook_args)
        return this.equals((createNotebook_args)that);
      return false;
    }

    public boolean equals(createNotebook_args that) {
      if (that == null)
        return false;

      boolean this_present_authenticationToken = true && this.isSetAuthenticationToken();
      boolean that_present_authenticationToken = true && that.isSetAuthenticationToken();
      if (this_present_authenticationToken || that_present_authenticationToken) {
        if (!(this_present_authenticationToken && that_present_authenticationToken))
          return false;
        if (!this.authenticationToken.equals(that.authenticationToken))
          return false;
      }

      boolean this_present_notebook = true && this.isSetNotebook();
      boolean that_present_notebook = true && that.isSetNotebook();
      if (this_present_notebook || that_present_notebook) {
        if (!(this_present_notebook && that_present_notebook))
          return false;
        if (!this.notebook.equals(that.notebook))
          return false;
      }

      return true;
    }

    public int hashCode() {
      return 0;
    }

    public int compareTo(createNotebook_args other) {
      if (!getClass().equals(other.getClass())) {
        return getClass().getName().compareTo(other.getClass().getName());
      }

      int lastComparison = 0;
      createNotebook_args typedOther = (createNotebook_args)other;

      lastComparison = Boolean.valueOf(isSetAuthenticationToken()).compareTo(isSetAuthenticationToken());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(authenticationToken, typedOther.authenticationToken);
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = Boolean.valueOf(isSetNotebook()).compareTo(isSetNotebook());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(notebook, typedOther.notebook);
      if (lastComparison != 0) {
        return lastComparison;
      }
      return 0;
    }

    public void read(TProtocol iprot) throws TException {
      TField field;
      iprot.readStructBegin();
      while (true)
      {
        field = iprot.readFieldBegin();
        if (field.type == TType.STOP) { 
          break;
        }
        _Fields fieldId = _Fields.findByThriftId(field.id);
        if (fieldId == null) {
          TProtocolUtil.skip(iprot, field.type);
        } else {
          switch (fieldId) {
            case AUTHENTICATION_TOKEN:
              if (field.type == TType.STRING) {
                this.authenticationToken = iprot.readString();
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
            case NOTEBOOK:
              if (field.type == TType.STRUCT) {
                this.notebook = new com.evernote.edam.type.Notebook();
                this.notebook.read(iprot);
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
          }
          iprot.readFieldEnd();
        }
      }
      iprot.readStructEnd();
      validate();
    }

    public void write(TProtocol oprot) throws TException {
      validate();

      oprot.writeStructBegin(STRUCT_DESC);
      if (this.authenticationToken != null) {
        oprot.writeFieldBegin(AUTHENTICATION_TOKEN_FIELD_DESC);
        oprot.writeString(this.authenticationToken);
        oprot.writeFieldEnd();
      }
      if (this.notebook != null) {
        oprot.writeFieldBegin(NOTEBOOK_FIELD_DESC);
        this.notebook.write(oprot);
        oprot.writeFieldEnd();
      }
      oprot.writeFieldStop();
      oprot.writeStructEnd();
    }

    public String toString() {
      StringBuilder sb = new StringBuilder("createNotebook_args(");
      boolean first = true;

      sb.append("authenticationToken:");
      if (this.authenticationToken == null) {
        sb.append("null");
      } else {
        sb.append(this.authenticationToken);
      }
      first = false;
      if (!first) sb.append(", ");
      sb.append("notebook:");
      if (this.notebook == null) {
        sb.append("null");
      } else {
        sb.append(this.notebook);
      }
      first = false;
      sb.append(")");
      return sb.toString();
    }

    public void validate() throws TException {
      // check for required fields
    }

  }

  public static class createNotebook_result implements TBase<createNotebook_result._Fields>, java.io.Serializable, Cloneable, Comparable<createNotebook_result>   {
    private static final TStruct STRUCT_DESC = new TStruct("createNotebook_result");

    private static final TField SUCCESS_FIELD_DESC = new TField("success", TType.STRUCT, (short)0);
    private static final TField USER_EXCEPTION_FIELD_DESC = new TField("userException", TType.STRUCT, (short)1);
    private static final TField SYSTEM_EXCEPTION_FIELD_DESC = new TField("systemException", TType.STRUCT, (short)2);

    private com.evernote.edam.type.Notebook success;
    private com.evernote.edam.error.EDAMUserException userException;
    private com.evernote.edam.error.EDAMSystemException systemException;

    /** The set of fields this struct contains, along with convenience methods for finding and manipulating them. */
    public enum _Fields implements TFieldIdEnum {
      SUCCESS((short)0, "success"),
      USER_EXCEPTION((short)1, "userException"),
      SYSTEM_EXCEPTION((short)2, "systemException");

      private static final Map<Integer, _Fields> byId = new HashMap<Integer, _Fields>();
      private static final Map<String, _Fields> byName = new HashMap<String, _Fields>();

      static {
        for (_Fields field : EnumSet.allOf(_Fields.class)) {
          byId.put((int)field._thriftId, field);
          byName.put(field.getFieldName(), field);
        }
      }

      /**
       * Find the _Fields constant that matches fieldId, or null if its not found.
       */
      public static _Fields findByThriftId(int fieldId) {
        return byId.get(fieldId);
      }

      /**
       * Find the _Fields constant that matches fieldId, throwing an exception
       * if it is not found.
       */
      public static _Fields findByThriftIdOrThrow(int fieldId) {
        _Fields fields = findByThriftId(fieldId);
        if (fields == null) throw new IllegalArgumentException("Field " + fieldId + " doesn't exist!");
        return fields;
      }

      /**
       * Find the _Fields constant that matches name, or null if its not found.
       */
      public static _Fields findByName(String name) {
        return byName.get(name);
      }

      private final short _thriftId;
      private final String _fieldName;

      _Fields(short thriftId, String fieldName) {
        _thriftId = thriftId;
        _fieldName = fieldName;
      }

      public short getThriftFieldId() {
        return _thriftId;
      }

      public String getFieldName() {
        return _fieldName;
      }
    }

    // isset id assignments

    public static final Map<_Fields, FieldMetaData> metaDataMap = Collections.unmodifiableMap(new EnumMap<_Fields, FieldMetaData>(_Fields.class) {{
      put(_Fields.SUCCESS, new FieldMetaData("success", TFieldRequirementType.DEFAULT, 
          new StructMetaData(TType.STRUCT, com.evernote.edam.type.Notebook.class)));
      put(_Fields.USER_EXCEPTION, new FieldMetaData("userException", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.STRUCT)));
      put(_Fields.SYSTEM_EXCEPTION, new FieldMetaData("systemException", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.STRUCT)));
    }});

    static {
      FieldMetaData.addStructMetaDataMap(createNotebook_result.class, metaDataMap);
    }

    public createNotebook_result() {
    }

    public createNotebook_result(
      com.evernote.edam.type.Notebook success,
      com.evernote.edam.error.EDAMUserException userException,
      com.evernote.edam.error.EDAMSystemException systemException)
    {
      this();
      this.success = success;
      this.userException = userException;
      this.systemException = systemException;
    }

    /**
     * Performs a deep copy on <i>other</i>.
     */
    public createNotebook_result(createNotebook_result other) {
      if (other.isSetSuccess()) {
        this.success = new com.evernote.edam.type.Notebook(other.success);
      }
      if (other.isSetUserException()) {
        this.userException = new com.evernote.edam.error.EDAMUserException(other.userException);
      }
      if (other.isSetSystemException()) {
        this.systemException = new com.evernote.edam.error.EDAMSystemException(other.systemException);
      }
    }

    public createNotebook_result deepCopy() {
      return new createNotebook_result(this);
    }

    @Deprecated
    public createNotebook_result clone() {
      return new createNotebook_result(this);
    }

    public com.evernote.edam.type.Notebook getSuccess() {
      return this.success;
    }

    public void setSuccess(com.evernote.edam.type.Notebook success) {
      this.success = success;
    }

    public void unsetSuccess() {
      this.success = null;
    }

    /** Returns true if field success is set (has been asigned a value) and false otherwise */
    public boolean isSetSuccess() {
      return this.success != null;
    }

    public void setSuccessIsSet(boolean value) {
      if (!value) {
        this.success = null;
      }
    }

    public com.evernote.edam.error.EDAMUserException getUserException() {
      return this.userException;
    }

    public void setUserException(com.evernote.edam.error.EDAMUserException userException) {
      this.userException = userException;
    }

    public void unsetUserException() {
      this.userException = null;
    }

    /** Returns true if field userException is set (has been asigned a value) and false otherwise */
    public boolean isSetUserException() {
      return this.userException != null;
    }

    public void setUserExceptionIsSet(boolean value) {
      if (!value) {
        this.userException = null;
      }
    }

    public com.evernote.edam.error.EDAMSystemException getSystemException() {
      return this.systemException;
    }

    public void setSystemException(com.evernote.edam.error.EDAMSystemException systemException) {
      this.systemException = systemException;
    }

    public void unsetSystemException() {
      this.systemException = null;
    }

    /** Returns true if field systemException is set (has been asigned a value) and false otherwise */
    public boolean isSetSystemException() {
      return this.systemException != null;
    }

    public void setSystemExceptionIsSet(boolean value) {
      if (!value) {
        this.systemException = null;
      }
    }

    public void setFieldValue(_Fields field, Object value) {
      switch (field) {
      case SUCCESS:
        if (value == null) {
          unsetSuccess();
        } else {
          setSuccess((com.evernote.edam.type.Notebook)value);
        }
        break;

      case USER_EXCEPTION:
        if (value == null) {
          unsetUserException();
        } else {
          setUserException((com.evernote.edam.error.EDAMUserException)value);
        }
        break;

      case SYSTEM_EXCEPTION:
        if (value == null) {
          unsetSystemException();
        } else {
          setSystemException((com.evernote.edam.error.EDAMSystemException)value);
        }
        break;

      }
    }

    public void setFieldValue(int fieldID, Object value) {
      setFieldValue(_Fields.findByThriftIdOrThrow(fieldID), value);
    }

    public Object getFieldValue(_Fields field) {
      switch (field) {
      case SUCCESS:
        return getSuccess();

      case USER_EXCEPTION:
        return getUserException();

      case SYSTEM_EXCEPTION:
        return getSystemException();

      }
      throw new IllegalStateException();
    }

    public Object getFieldValue(int fieldId) {
      return getFieldValue(_Fields.findByThriftIdOrThrow(fieldId));
    }

    /** Returns true if field corresponding to fieldID is set (has been asigned a value) and false otherwise */
    public boolean isSet(_Fields field) {
      switch (field) {
      case SUCCESS:
        return isSetSuccess();
      case USER_EXCEPTION:
        return isSetUserException();
      case SYSTEM_EXCEPTION:
        return isSetSystemException();
      }
      throw new IllegalStateException();
    }

    public boolean isSet(int fieldID) {
      return isSet(_Fields.findByThriftIdOrThrow(fieldID));
    }

    public boolean equals(Object that) {
      if (that == null)
        return false;
      if (that instanceof createNotebook_result)
        return this.equals((createNotebook_result)that);
      return false;
    }

    public boolean equals(createNotebook_result that) {
      if (that == null)
        return false;

      boolean this_present_success = true && this.isSetSuccess();
      boolean that_present_success = true && that.isSetSuccess();
      if (this_present_success || that_present_success) {
        if (!(this_present_success && that_present_success))
          return false;
        if (!this.success.equals(that.success))
          return false;
      }

      boolean this_present_userException = true && this.isSetUserException();
      boolean that_present_userException = true && that.isSetUserException();
      if (this_present_userException || that_present_userException) {
        if (!(this_present_userException && that_present_userException))
          return false;
        if (!this.userException.equals(that.userException))
          return false;
      }

      boolean this_present_systemException = true && this.isSetSystemException();
      boolean that_present_systemException = true && that.isSetSystemException();
      if (this_present_systemException || that_present_systemException) {
        if (!(this_present_systemException && that_present_systemException))
          return false;
        if (!this.systemException.equals(that.systemException))
          return false;
      }

      return true;
    }

    public int hashCode() {
      return 0;
    }

    public int compareTo(createNotebook_result other) {
      if (!getClass().equals(other.getClass())) {
        return getClass().getName().compareTo(other.getClass().getName());
      }

      int lastComparison = 0;
      createNotebook_result typedOther = (createNotebook_result)other;

      lastComparison = Boolean.valueOf(isSetSuccess()).compareTo(isSetSuccess());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(success, typedOther.success);
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = Boolean.valueOf(isSetUserException()).compareTo(isSetUserException());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(userException, typedOther.userException);
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = Boolean.valueOf(isSetSystemException()).compareTo(isSetSystemException());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(systemException, typedOther.systemException);
      if (lastComparison != 0) {
        return lastComparison;
      }
      return 0;
    }

    public void read(TProtocol iprot) throws TException {
      TField field;
      iprot.readStructBegin();
      while (true)
      {
        field = iprot.readFieldBegin();
        if (field.type == TType.STOP) { 
          break;
        }
        _Fields fieldId = _Fields.findByThriftId(field.id);
        if (fieldId == null) {
          TProtocolUtil.skip(iprot, field.type);
        } else {
          switch (fieldId) {
            case SUCCESS:
              if (field.type == TType.STRUCT) {
                this.success = new com.evernote.edam.type.Notebook();
                this.success.read(iprot);
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
            case USER_EXCEPTION:
              if (field.type == TType.STRUCT) {
                this.userException = new com.evernote.edam.error.EDAMUserException();
                this.userException.read(iprot);
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
            case SYSTEM_EXCEPTION:
              if (field.type == TType.STRUCT) {
                this.systemException = new com.evernote.edam.error.EDAMSystemException();
                this.systemException.read(iprot);
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
          }
          iprot.readFieldEnd();
        }
      }
      iprot.readStructEnd();
      validate();
    }

    public void write(TProtocol oprot) throws TException {
      oprot.writeStructBegin(STRUCT_DESC);

      if (this.isSetSuccess()) {
        oprot.writeFieldBegin(SUCCESS_FIELD_DESC);
        this.success.write(oprot);
        oprot.writeFieldEnd();
      } else if (this.isSetUserException()) {
        oprot.writeFieldBegin(USER_EXCEPTION_FIELD_DESC);
        this.userException.write(oprot);
        oprot.writeFieldEnd();
      } else if (this.isSetSystemException()) {
        oprot.writeFieldBegin(SYSTEM_EXCEPTION_FIELD_DESC);
        this.systemException.write(oprot);
        oprot.writeFieldEnd();
      }
      oprot.writeFieldStop();
      oprot.writeStructEnd();
    }

    public String toString() {
      StringBuilder sb = new StringBuilder("createNotebook_result(");
      boolean first = true;

      sb.append("success:");
      if (this.success == null) {
        sb.append("null");
      } else {
        sb.append(this.success);
      }
      first = false;
      if (!first) sb.append(", ");
      sb.append("userException:");
      if (this.userException == null) {
        sb.append("null");
      } else {
        sb.append(this.userException);
      }
      first = false;
      if (!first) sb.append(", ");
      sb.append("systemException:");
      if (this.systemException == null) {
        sb.append("null");
      } else {
        sb.append(this.systemException);
      }
      first = false;
      sb.append(")");
      return sb.toString();
    }

    public void validate() throws TException {
      // check for required fields
    }

  }

  public static class updateNotebook_args implements TBase<updateNotebook_args._Fields>, java.io.Serializable, Cloneable, Comparable<updateNotebook_args>   {
    private static final TStruct STRUCT_DESC = new TStruct("updateNotebook_args");

    private static final TField AUTHENTICATION_TOKEN_FIELD_DESC = new TField("authenticationToken", TType.STRING, (short)1);
    private static final TField NOTEBOOK_FIELD_DESC = new TField("notebook", TType.STRUCT, (short)2);

    private String authenticationToken;
    private com.evernote.edam.type.Notebook notebook;

    /** The set of fields this struct contains, along with convenience methods for finding and manipulating them. */
    public enum _Fields implements TFieldIdEnum {
      AUTHENTICATION_TOKEN((short)1, "authenticationToken"),
      NOTEBOOK((short)2, "notebook");

      private static final Map<Integer, _Fields> byId = new HashMap<Integer, _Fields>();
      private static final Map<String, _Fields> byName = new HashMap<String, _Fields>();

      static {
        for (_Fields field : EnumSet.allOf(_Fields.class)) {
          byId.put((int)field._thriftId, field);
          byName.put(field.getFieldName(), field);
        }
      }

      /**
       * Find the _Fields constant that matches fieldId, or null if its not found.
       */
      public static _Fields findByThriftId(int fieldId) {
        return byId.get(fieldId);
      }

      /**
       * Find the _Fields constant that matches fieldId, throwing an exception
       * if it is not found.
       */
      public static _Fields findByThriftIdOrThrow(int fieldId) {
        _Fields fields = findByThriftId(fieldId);
        if (fields == null) throw new IllegalArgumentException("Field " + fieldId + " doesn't exist!");
        return fields;
      }

      /**
       * Find the _Fields constant that matches name, or null if its not found.
       */
      public static _Fields findByName(String name) {
        return byName.get(name);
      }

      private final short _thriftId;
      private final String _fieldName;

      _Fields(short thriftId, String fieldName) {
        _thriftId = thriftId;
        _fieldName = fieldName;
      }

      public short getThriftFieldId() {
        return _thriftId;
      }

      public String getFieldName() {
        return _fieldName;
      }
    }

    // isset id assignments

    public static final Map<_Fields, FieldMetaData> metaDataMap = Collections.unmodifiableMap(new EnumMap<_Fields, FieldMetaData>(_Fields.class) {{
      put(_Fields.AUTHENTICATION_TOKEN, new FieldMetaData("authenticationToken", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.STRING)));
      put(_Fields.NOTEBOOK, new FieldMetaData("notebook", TFieldRequirementType.DEFAULT, 
          new StructMetaData(TType.STRUCT, com.evernote.edam.type.Notebook.class)));
    }});

    static {
      FieldMetaData.addStructMetaDataMap(updateNotebook_args.class, metaDataMap);
    }

    public updateNotebook_args() {
    }

    public updateNotebook_args(
      String authenticationToken,
      com.evernote.edam.type.Notebook notebook)
    {
      this();
      this.authenticationToken = authenticationToken;
      this.notebook = notebook;
    }

    /**
     * Performs a deep copy on <i>other</i>.
     */
    public updateNotebook_args(updateNotebook_args other) {
      if (other.isSetAuthenticationToken()) {
        this.authenticationToken = other.authenticationToken;
      }
      if (other.isSetNotebook()) {
        this.notebook = new com.evernote.edam.type.Notebook(other.notebook);
      }
    }

    public updateNotebook_args deepCopy() {
      return new updateNotebook_args(this);
    }

    @Deprecated
    public updateNotebook_args clone() {
      return new updateNotebook_args(this);
    }

    public String getAuthenticationToken() {
      return this.authenticationToken;
    }

    public void setAuthenticationToken(String authenticationToken) {
      this.authenticationToken = authenticationToken;
    }

    public void unsetAuthenticationToken() {
      this.authenticationToken = null;
    }

    /** Returns true if field authenticationToken is set (has been asigned a value) and false otherwise */
    public boolean isSetAuthenticationToken() {
      return this.authenticationToken != null;
    }

    public void setAuthenticationTokenIsSet(boolean value) {
      if (!value) {
        this.authenticationToken = null;
      }
    }

    public com.evernote.edam.type.Notebook getNotebook() {
      return this.notebook;
    }

    public void setNotebook(com.evernote.edam.type.Notebook notebook) {
      this.notebook = notebook;
    }

    public void unsetNotebook() {
      this.notebook = null;
    }

    /** Returns true if field notebook is set (has been asigned a value) and false otherwise */
    public boolean isSetNotebook() {
      return this.notebook != null;
    }

    public void setNotebookIsSet(boolean value) {
      if (!value) {
        this.notebook = null;
      }
    }

    public void setFieldValue(_Fields field, Object value) {
      switch (field) {
      case AUTHENTICATION_TOKEN:
        if (value == null) {
          unsetAuthenticationToken();
        } else {
          setAuthenticationToken((String)value);
        }
        break;

      case NOTEBOOK:
        if (value == null) {
          unsetNotebook();
        } else {
          setNotebook((com.evernote.edam.type.Notebook)value);
        }
        break;

      }
    }

    public void setFieldValue(int fieldID, Object value) {
      setFieldValue(_Fields.findByThriftIdOrThrow(fieldID), value);
    }

    public Object getFieldValue(_Fields field) {
      switch (field) {
      case AUTHENTICATION_TOKEN:
        return getAuthenticationToken();

      case NOTEBOOK:
        return getNotebook();

      }
      throw new IllegalStateException();
    }

    public Object getFieldValue(int fieldId) {
      return getFieldValue(_Fields.findByThriftIdOrThrow(fieldId));
    }

    /** Returns true if field corresponding to fieldID is set (has been asigned a value) and false otherwise */
    public boolean isSet(_Fields field) {
      switch (field) {
      case AUTHENTICATION_TOKEN:
        return isSetAuthenticationToken();
      case NOTEBOOK:
        return isSetNotebook();
      }
      throw new IllegalStateException();
    }

    public boolean isSet(int fieldID) {
      return isSet(_Fields.findByThriftIdOrThrow(fieldID));
    }

    public boolean equals(Object that) {
      if (that == null)
        return false;
      if (that instanceof updateNotebook_args)
        return this.equals((updateNotebook_args)that);
      return false;
    }

    public boolean equals(updateNotebook_args that) {
      if (that == null)
        return false;

      boolean this_present_authenticationToken = true && this.isSetAuthenticationToken();
      boolean that_present_authenticationToken = true && that.isSetAuthenticationToken();
      if (this_present_authenticationToken || that_present_authenticationToken) {
        if (!(this_present_authenticationToken && that_present_authenticationToken))
          return false;
        if (!this.authenticationToken.equals(that.authenticationToken))
          return false;
      }

      boolean this_present_notebook = true && this.isSetNotebook();
      boolean that_present_notebook = true && that.isSetNotebook();
      if (this_present_notebook || that_present_notebook) {
        if (!(this_present_notebook && that_present_notebook))
          return false;
        if (!this.notebook.equals(that.notebook))
          return false;
      }

      return true;
    }

    public int hashCode() {
      return 0;
    }

    public int compareTo(updateNotebook_args other) {
      if (!getClass().equals(other.getClass())) {
        return getClass().getName().compareTo(other.getClass().getName());
      }

      int lastComparison = 0;
      updateNotebook_args typedOther = (updateNotebook_args)other;

      lastComparison = Boolean.valueOf(isSetAuthenticationToken()).compareTo(isSetAuthenticationToken());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(authenticationToken, typedOther.authenticationToken);
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = Boolean.valueOf(isSetNotebook()).compareTo(isSetNotebook());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(notebook, typedOther.notebook);
      if (lastComparison != 0) {
        return lastComparison;
      }
      return 0;
    }

    public void read(TProtocol iprot) throws TException {
      TField field;
      iprot.readStructBegin();
      while (true)
      {
        field = iprot.readFieldBegin();
        if (field.type == TType.STOP) { 
          break;
        }
        _Fields fieldId = _Fields.findByThriftId(field.id);
        if (fieldId == null) {
          TProtocolUtil.skip(iprot, field.type);
        } else {
          switch (fieldId) {
            case AUTHENTICATION_TOKEN:
              if (field.type == TType.STRING) {
                this.authenticationToken = iprot.readString();
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
            case NOTEBOOK:
              if (field.type == TType.STRUCT) {
                this.notebook = new com.evernote.edam.type.Notebook();
                this.notebook.read(iprot);
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
          }
          iprot.readFieldEnd();
        }
      }
      iprot.readStructEnd();
      validate();
    }

    public void write(TProtocol oprot) throws TException {
      validate();

      oprot.writeStructBegin(STRUCT_DESC);
      if (this.authenticationToken != null) {
        oprot.writeFieldBegin(AUTHENTICATION_TOKEN_FIELD_DESC);
        oprot.writeString(this.authenticationToken);
        oprot.writeFieldEnd();
      }
      if (this.notebook != null) {
        oprot.writeFieldBegin(NOTEBOOK_FIELD_DESC);
        this.notebook.write(oprot);
        oprot.writeFieldEnd();
      }
      oprot.writeFieldStop();
      oprot.writeStructEnd();
    }

    public String toString() {
      StringBuilder sb = new StringBuilder("updateNotebook_args(");
      boolean first = true;

      sb.append("authenticationToken:");
      if (this.authenticationToken == null) {
        sb.append("null");
      } else {
        sb.append(this.authenticationToken);
      }
      first = false;
      if (!first) sb.append(", ");
      sb.append("notebook:");
      if (this.notebook == null) {
        sb.append("null");
      } else {
        sb.append(this.notebook);
      }
      first = false;
      sb.append(")");
      return sb.toString();
    }

    public void validate() throws TException {
      // check for required fields
    }

  }

  public static class updateNotebook_result implements TBase<updateNotebook_result._Fields>, java.io.Serializable, Cloneable, Comparable<updateNotebook_result>   {
    private static final TStruct STRUCT_DESC = new TStruct("updateNotebook_result");

    private static final TField SUCCESS_FIELD_DESC = new TField("success", TType.I32, (short)0);
    private static final TField USER_EXCEPTION_FIELD_DESC = new TField("userException", TType.STRUCT, (short)1);
    private static final TField SYSTEM_EXCEPTION_FIELD_DESC = new TField("systemException", TType.STRUCT, (short)2);
    private static final TField NOT_FOUND_EXCEPTION_FIELD_DESC = new TField("notFoundException", TType.STRUCT, (short)3);

    private int success;
    private com.evernote.edam.error.EDAMUserException userException;
    private com.evernote.edam.error.EDAMSystemException systemException;
    private com.evernote.edam.error.EDAMNotFoundException notFoundException;

    /** The set of fields this struct contains, along with convenience methods for finding and manipulating them. */
    public enum _Fields implements TFieldIdEnum {
      SUCCESS((short)0, "success"),
      USER_EXCEPTION((short)1, "userException"),
      SYSTEM_EXCEPTION((short)2, "systemException"),
      NOT_FOUND_EXCEPTION((short)3, "notFoundException");

      private static final Map<Integer, _Fields> byId = new HashMap<Integer, _Fields>();
      private static final Map<String, _Fields> byName = new HashMap<String, _Fields>();

      static {
        for (_Fields field : EnumSet.allOf(_Fields.class)) {
          byId.put((int)field._thriftId, field);
          byName.put(field.getFieldName(), field);
        }
      }

      /**
       * Find the _Fields constant that matches fieldId, or null if its not found.
       */
      public static _Fields findByThriftId(int fieldId) {
        return byId.get(fieldId);
      }

      /**
       * Find the _Fields constant that matches fieldId, throwing an exception
       * if it is not found.
       */
      public static _Fields findByThriftIdOrThrow(int fieldId) {
        _Fields fields = findByThriftId(fieldId);
        if (fields == null) throw new IllegalArgumentException("Field " + fieldId + " doesn't exist!");
        return fields;
      }

      /**
       * Find the _Fields constant that matches name, or null if its not found.
       */
      public static _Fields findByName(String name) {
        return byName.get(name);
      }

      private final short _thriftId;
      private final String _fieldName;

      _Fields(short thriftId, String fieldName) {
        _thriftId = thriftId;
        _fieldName = fieldName;
      }

      public short getThriftFieldId() {
        return _thriftId;
      }

      public String getFieldName() {
        return _fieldName;
      }
    }

    // isset id assignments
    private static final int __SUCCESS_ISSET_ID = 0;
    private BitSet __isset_bit_vector = new BitSet(1);

    public static final Map<_Fields, FieldMetaData> metaDataMap = Collections.unmodifiableMap(new EnumMap<_Fields, FieldMetaData>(_Fields.class) {{
      put(_Fields.SUCCESS, new FieldMetaData("success", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.I32)));
      put(_Fields.USER_EXCEPTION, new FieldMetaData("userException", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.STRUCT)));
      put(_Fields.SYSTEM_EXCEPTION, new FieldMetaData("systemException", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.STRUCT)));
      put(_Fields.NOT_FOUND_EXCEPTION, new FieldMetaData("notFoundException", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.STRUCT)));
    }});

    static {
      FieldMetaData.addStructMetaDataMap(updateNotebook_result.class, metaDataMap);
    }

    public updateNotebook_result() {
    }

    public updateNotebook_result(
      int success,
      com.evernote.edam.error.EDAMUserException userException,
      com.evernote.edam.error.EDAMSystemException systemException,
      com.evernote.edam.error.EDAMNotFoundException notFoundException)
    {
      this();
      this.success = success;
      setSuccessIsSet(true);
      this.userException = userException;
      this.systemException = systemException;
      this.notFoundException = notFoundException;
    }

    /**
     * Performs a deep copy on <i>other</i>.
     */
    public updateNotebook_result(updateNotebook_result other) {
      __isset_bit_vector.clear();
      __isset_bit_vector.or(other.__isset_bit_vector);
      this.success = other.success;
      if (other.isSetUserException()) {
        this.userException = new com.evernote.edam.error.EDAMUserException(other.userException);
      }
      if (other.isSetSystemException()) {
        this.systemException = new com.evernote.edam.error.EDAMSystemException(other.systemException);
      }
      if (other.isSetNotFoundException()) {
        this.notFoundException = new com.evernote.edam.error.EDAMNotFoundException(other.notFoundException);
      }
    }

    public updateNotebook_result deepCopy() {
      return new updateNotebook_result(this);
    }

    @Deprecated
    public updateNotebook_result clone() {
      return new updateNotebook_result(this);
    }

    public int getSuccess() {
      return this.success;
    }

    public void setSuccess(int success) {
      this.success = success;
      setSuccessIsSet(true);
    }

    public void unsetSuccess() {
      __isset_bit_vector.clear(__SUCCESS_ISSET_ID);
    }

    /** Returns true if field success is set (has been asigned a value) and false otherwise */
    public boolean isSetSuccess() {
      return __isset_bit_vector.get(__SUCCESS_ISSET_ID);
    }

    public void setSuccessIsSet(boolean value) {
      __isset_bit_vector.set(__SUCCESS_ISSET_ID, value);
    }

    public com.evernote.edam.error.EDAMUserException getUserException() {
      return this.userException;
    }

    public void setUserException(com.evernote.edam.error.EDAMUserException userException) {
      this.userException = userException;
    }

    public void unsetUserException() {
      this.userException = null;
    }

    /** Returns true if field userException is set (has been asigned a value) and false otherwise */
    public boolean isSetUserException() {
      return this.userException != null;
    }

    public void setUserExceptionIsSet(boolean value) {
      if (!value) {
        this.userException = null;
      }
    }

    public com.evernote.edam.error.EDAMSystemException getSystemException() {
      return this.systemException;
    }

    public void setSystemException(com.evernote.edam.error.EDAMSystemException systemException) {
      this.systemException = systemException;
    }

    public void unsetSystemException() {
      this.systemException = null;
    }

    /** Returns true if field systemException is set (has been asigned a value) and false otherwise */
    public boolean isSetSystemException() {
      return this.systemException != null;
    }

    public void setSystemExceptionIsSet(boolean value) {
      if (!value) {
        this.systemException = null;
      }
    }

    public com.evernote.edam.error.EDAMNotFoundException getNotFoundException() {
      return this.notFoundException;
    }

    public void setNotFoundException(com.evernote.edam.error.EDAMNotFoundException notFoundException) {
      this.notFoundException = notFoundException;
    }

    public void unsetNotFoundException() {
      this.notFoundException = null;
    }

    /** Returns true if field notFoundException is set (has been asigned a value) and false otherwise */
    public boolean isSetNotFoundException() {
      return this.notFoundException != null;
    }

    public void setNotFoundExceptionIsSet(boolean value) {
      if (!value) {
        this.notFoundException = null;
      }
    }

    public void setFieldValue(_Fields field, Object value) {
      switch (field) {
      case SUCCESS:
        if (value == null) {
          unsetSuccess();
        } else {
          setSuccess((Integer)value);
        }
        break;

      case USER_EXCEPTION:
        if (value == null) {
          unsetUserException();
        } else {
          setUserException((com.evernote.edam.error.EDAMUserException)value);
        }
        break;

      case SYSTEM_EXCEPTION:
        if (value == null) {
          unsetSystemException();
        } else {
          setSystemException((com.evernote.edam.error.EDAMSystemException)value);
        }
        break;

      case NOT_FOUND_EXCEPTION:
        if (value == null) {
          unsetNotFoundException();
        } else {
          setNotFoundException((com.evernote.edam.error.EDAMNotFoundException)value);
        }
        break;

      }
    }

    public void setFieldValue(int fieldID, Object value) {
      setFieldValue(_Fields.findByThriftIdOrThrow(fieldID), value);
    }

    public Object getFieldValue(_Fields field) {
      switch (field) {
      case SUCCESS:
        return new Integer(getSuccess());

      case USER_EXCEPTION:
        return getUserException();

      case SYSTEM_EXCEPTION:
        return getSystemException();

      case NOT_FOUND_EXCEPTION:
        return getNotFoundException();

      }
      throw new IllegalStateException();
    }

    public Object getFieldValue(int fieldId) {
      return getFieldValue(_Fields.findByThriftIdOrThrow(fieldId));
    }

    /** Returns true if field corresponding to fieldID is set (has been asigned a value) and false otherwise */
    public boolean isSet(_Fields field) {
      switch (field) {
      case SUCCESS:
        return isSetSuccess();
      case USER_EXCEPTION:
        return isSetUserException();
      case SYSTEM_EXCEPTION:
        return isSetSystemException();
      case NOT_FOUND_EXCEPTION:
        return isSetNotFoundException();
      }
      throw new IllegalStateException();
    }

    public boolean isSet(int fieldID) {
      return isSet(_Fields.findByThriftIdOrThrow(fieldID));
    }

    public boolean equals(Object that) {
      if (that == null)
        return false;
      if (that instanceof updateNotebook_result)
        return this.equals((updateNotebook_result)that);
      return false;
    }

    public boolean equals(updateNotebook_result that) {
      if (that == null)
        return false;

      boolean this_present_success = true;
      boolean that_present_success = true;
      if (this_present_success || that_present_success) {
        if (!(this_present_success && that_present_success))
          return false;
        if (this.success != that.success)
          return false;
      }

      boolean this_present_userException = true && this.isSetUserException();
      boolean that_present_userException = true && that.isSetUserException();
      if (this_present_userException || that_present_userException) {
        if (!(this_present_userException && that_present_userException))
          return false;
        if (!this.userException.equals(that.userException))
          return false;
      }

      boolean this_present_systemException = true && this.isSetSystemException();
      boolean that_present_systemException = true && that.isSetSystemException();
      if (this_present_systemException || that_present_systemException) {
        if (!(this_present_systemException && that_present_systemException))
          return false;
        if (!this.systemException.equals(that.systemException))
          return false;
      }

      boolean this_present_notFoundException = true && this.isSetNotFoundException();
      boolean that_present_notFoundException = true && that.isSetNotFoundException();
      if (this_present_notFoundException || that_present_notFoundException) {
        if (!(this_present_notFoundException && that_present_notFoundException))
          return false;
        if (!this.notFoundException.equals(that.notFoundException))
          return false;
      }

      return true;
    }

    public int hashCode() {
      return 0;
    }

    public int compareTo(updateNotebook_result other) {
      if (!getClass().equals(other.getClass())) {
        return getClass().getName().compareTo(other.getClass().getName());
      }

      int lastComparison = 0;
      updateNotebook_result typedOther = (updateNotebook_result)other;

      lastComparison = Boolean.valueOf(isSetSuccess()).compareTo(isSetSuccess());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(success, typedOther.success);
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = Boolean.valueOf(isSetUserException()).compareTo(isSetUserException());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(userException, typedOther.userException);
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = Boolean.valueOf(isSetSystemException()).compareTo(isSetSystemException());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(systemException, typedOther.systemException);
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = Boolean.valueOf(isSetNotFoundException()).compareTo(isSetNotFoundException());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(notFoundException, typedOther.notFoundException);
      if (lastComparison != 0) {
        return lastComparison;
      }
      return 0;
    }

    public void read(TProtocol iprot) throws TException {
      TField field;
      iprot.readStructBegin();
      while (true)
      {
        field = iprot.readFieldBegin();
        if (field.type == TType.STOP) { 
          break;
        }
        _Fields fieldId = _Fields.findByThriftId(field.id);
        if (fieldId == null) {
          TProtocolUtil.skip(iprot, field.type);
        } else {
          switch (fieldId) {
            case SUCCESS:
              if (field.type == TType.I32) {
                this.success = iprot.readI32();
                setSuccessIsSet(true);
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
            case USER_EXCEPTION:
              if (field.type == TType.STRUCT) {
                this.userException = new com.evernote.edam.error.EDAMUserException();
                this.userException.read(iprot);
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
            case SYSTEM_EXCEPTION:
              if (field.type == TType.STRUCT) {
                this.systemException = new com.evernote.edam.error.EDAMSystemException();
                this.systemException.read(iprot);
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
            case NOT_FOUND_EXCEPTION:
              if (field.type == TType.STRUCT) {
                this.notFoundException = new com.evernote.edam.error.EDAMNotFoundException();
                this.notFoundException.read(iprot);
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
          }
          iprot.readFieldEnd();
        }
      }
      iprot.readStructEnd();
      validate();
    }

    public void write(TProtocol oprot) throws TException {
      oprot.writeStructBegin(STRUCT_DESC);

      if (this.isSetSuccess()) {
        oprot.writeFieldBegin(SUCCESS_FIELD_DESC);
        oprot.writeI32(this.success);
        oprot.writeFieldEnd();
      } else if (this.isSetUserException()) {
        oprot.writeFieldBegin(USER_EXCEPTION_FIELD_DESC);
        this.userException.write(oprot);
        oprot.writeFieldEnd();
      } else if (this.isSetSystemException()) {
        oprot.writeFieldBegin(SYSTEM_EXCEPTION_FIELD_DESC);
        this.systemException.write(oprot);
        oprot.writeFieldEnd();
      } else if (this.isSetNotFoundException()) {
        oprot.writeFieldBegin(NOT_FOUND_EXCEPTION_FIELD_DESC);
        this.notFoundException.write(oprot);
        oprot.writeFieldEnd();
      }
      oprot.writeFieldStop();
      oprot.writeStructEnd();
    }

    public String toString() {
      StringBuilder sb = new StringBuilder("updateNotebook_result(");
      boolean first = true;

      sb.append("success:");
      sb.append(this.success);
      first = false;
      if (!first) sb.append(", ");
      sb.append("userException:");
      if (this.userException == null) {
        sb.append("null");
      } else {
        sb.append(this.userException);
      }
      first = false;
      if (!first) sb.append(", ");
      sb.append("systemException:");
      if (this.systemException == null) {
        sb.append("null");
      } else {
        sb.append(this.systemException);
      }
      first = false;
      if (!first) sb.append(", ");
      sb.append("notFoundException:");
      if (this.notFoundException == null) {
        sb.append("null");
      } else {
        sb.append(this.notFoundException);
      }
      first = false;
      sb.append(")");
      return sb.toString();
    }

    public void validate() throws TException {
      // check for required fields
    }

  }

  public static class expungeNotebook_args implements TBase<expungeNotebook_args._Fields>, java.io.Serializable, Cloneable, Comparable<expungeNotebook_args>   {
    private static final TStruct STRUCT_DESC = new TStruct("expungeNotebook_args");

    private static final TField AUTHENTICATION_TOKEN_FIELD_DESC = new TField("authenticationToken", TType.STRING, (short)1);
    private static final TField GUID_FIELD_DESC = new TField("guid", TType.STRING, (short)2);

    private String authenticationToken;
    private String guid;

    /** The set of fields this struct contains, along with convenience methods for finding and manipulating them. */
    public enum _Fields implements TFieldIdEnum {
      AUTHENTICATION_TOKEN((short)1, "authenticationToken"),
      GUID((short)2, "guid");

      private static final Map<Integer, _Fields> byId = new HashMap<Integer, _Fields>();
      private static final Map<String, _Fields> byName = new HashMap<String, _Fields>();

      static {
        for (_Fields field : EnumSet.allOf(_Fields.class)) {
          byId.put((int)field._thriftId, field);
          byName.put(field.getFieldName(), field);
        }
      }

      /**
       * Find the _Fields constant that matches fieldId, or null if its not found.
       */
      public static _Fields findByThriftId(int fieldId) {
        return byId.get(fieldId);
      }

      /**
       * Find the _Fields constant that matches fieldId, throwing an exception
       * if it is not found.
       */
      public static _Fields findByThriftIdOrThrow(int fieldId) {
        _Fields fields = findByThriftId(fieldId);
        if (fields == null) throw new IllegalArgumentException("Field " + fieldId + " doesn't exist!");
        return fields;
      }

      /**
       * Find the _Fields constant that matches name, or null if its not found.
       */
      public static _Fields findByName(String name) {
        return byName.get(name);
      }

      private final short _thriftId;
      private final String _fieldName;

      _Fields(short thriftId, String fieldName) {
        _thriftId = thriftId;
        _fieldName = fieldName;
      }

      public short getThriftFieldId() {
        return _thriftId;
      }

      public String getFieldName() {
        return _fieldName;
      }
    }

    // isset id assignments

    public static final Map<_Fields, FieldMetaData> metaDataMap = Collections.unmodifiableMap(new EnumMap<_Fields, FieldMetaData>(_Fields.class) {{
      put(_Fields.AUTHENTICATION_TOKEN, new FieldMetaData("authenticationToken", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.STRING)));
      put(_Fields.GUID, new FieldMetaData("guid", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.STRING)));
    }});

    static {
      FieldMetaData.addStructMetaDataMap(expungeNotebook_args.class, metaDataMap);
    }

    public expungeNotebook_args() {
    }

    public expungeNotebook_args(
      String authenticationToken,
      String guid)
    {
      this();
      this.authenticationToken = authenticationToken;
      this.guid = guid;
    }

    /**
     * Performs a deep copy on <i>other</i>.
     */
    public expungeNotebook_args(expungeNotebook_args other) {
      if (other.isSetAuthenticationToken()) {
        this.authenticationToken = other.authenticationToken;
      }
      if (other.isSetGuid()) {
        this.guid = other.guid;
      }
    }

    public expungeNotebook_args deepCopy() {
      return new expungeNotebook_args(this);
    }

    @Deprecated
    public expungeNotebook_args clone() {
      return new expungeNotebook_args(this);
    }

    public String getAuthenticationToken() {
      return this.authenticationToken;
    }

    public void setAuthenticationToken(String authenticationToken) {
      this.authenticationToken = authenticationToken;
    }

    public void unsetAuthenticationToken() {
      this.authenticationToken = null;
    }

    /** Returns true if field authenticationToken is set (has been asigned a value) and false otherwise */
    public boolean isSetAuthenticationToken() {
      return this.authenticationToken != null;
    }

    public void setAuthenticationTokenIsSet(boolean value) {
      if (!value) {
        this.authenticationToken = null;
      }
    }

    public String getGuid() {
      return this.guid;
    }

    public void setGuid(String guid) {
      this.guid = guid;
    }

    public void unsetGuid() {
      this.guid = null;
    }

    /** Returns true if field guid is set (has been asigned a value) and false otherwise */
    public boolean isSetGuid() {
      return this.guid != null;
    }

    public void setGuidIsSet(boolean value) {
      if (!value) {
        this.guid = null;
      }
    }

    public void setFieldValue(_Fields field, Object value) {
      switch (field) {
      case AUTHENTICATION_TOKEN:
        if (value == null) {
          unsetAuthenticationToken();
        } else {
          setAuthenticationToken((String)value);
        }
        break;

      case GUID:
        if (value == null) {
          unsetGuid();
        } else {
          setGuid((String)value);
        }
        break;

      }
    }

    public void setFieldValue(int fieldID, Object value) {
      setFieldValue(_Fields.findByThriftIdOrThrow(fieldID), value);
    }

    public Object getFieldValue(_Fields field) {
      switch (field) {
      case AUTHENTICATION_TOKEN:
        return getAuthenticationToken();

      case GUID:
        return getGuid();

      }
      throw new IllegalStateException();
    }

    public Object getFieldValue(int fieldId) {
      return getFieldValue(_Fields.findByThriftIdOrThrow(fieldId));
    }

    /** Returns true if field corresponding to fieldID is set (has been asigned a value) and false otherwise */
    public boolean isSet(_Fields field) {
      switch (field) {
      case AUTHENTICATION_TOKEN:
        return isSetAuthenticationToken();
      case GUID:
        return isSetGuid();
      }
      throw new IllegalStateException();
    }

    public boolean isSet(int fieldID) {
      return isSet(_Fields.findByThriftIdOrThrow(fieldID));
    }

    public boolean equals(Object that) {
      if (that == null)
        return false;
      if (that instanceof expungeNotebook_args)
        return this.equals((expungeNotebook_args)that);
      return false;
    }

    public boolean equals(expungeNotebook_args that) {
      if (that == null)
        return false;

      boolean this_present_authenticationToken = true && this.isSetAuthenticationToken();
      boolean that_present_authenticationToken = true && that.isSetAuthenticationToken();
      if (this_present_authenticationToken || that_present_authenticationToken) {
        if (!(this_present_authenticationToken && that_present_authenticationToken))
          return false;
        if (!this.authenticationToken.equals(that.authenticationToken))
          return false;
      }

      boolean this_present_guid = true && this.isSetGuid();
      boolean that_present_guid = true && that.isSetGuid();
      if (this_present_guid || that_present_guid) {
        if (!(this_present_guid && that_present_guid))
          return false;
        if (!this.guid.equals(that.guid))
          return false;
      }

      return true;
    }

    public int hashCode() {
      return 0;
    }

    public int compareTo(expungeNotebook_args other) {
      if (!getClass().equals(other.getClass())) {
        return getClass().getName().compareTo(other.getClass().getName());
      }

      int lastComparison = 0;
      expungeNotebook_args typedOther = (expungeNotebook_args)other;

      lastComparison = Boolean.valueOf(isSetAuthenticationToken()).compareTo(isSetAuthenticationToken());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(authenticationToken, typedOther.authenticationToken);
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = Boolean.valueOf(isSetGuid()).compareTo(isSetGuid());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(guid, typedOther.guid);
      if (lastComparison != 0) {
        return lastComparison;
      }
      return 0;
    }

    public void read(TProtocol iprot) throws TException {
      TField field;
      iprot.readStructBegin();
      while (true)
      {
        field = iprot.readFieldBegin();
        if (field.type == TType.STOP) { 
          break;
        }
        _Fields fieldId = _Fields.findByThriftId(field.id);
        if (fieldId == null) {
          TProtocolUtil.skip(iprot, field.type);
        } else {
          switch (fieldId) {
            case AUTHENTICATION_TOKEN:
              if (field.type == TType.STRING) {
                this.authenticationToken = iprot.readString();
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
            case GUID:
              if (field.type == TType.STRING) {
                this.guid = iprot.readString();
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
          }
          iprot.readFieldEnd();
        }
      }
      iprot.readStructEnd();
      validate();
    }

    public void write(TProtocol oprot) throws TException {
      validate();

      oprot.writeStructBegin(STRUCT_DESC);
      if (this.authenticationToken != null) {
        oprot.writeFieldBegin(AUTHENTICATION_TOKEN_FIELD_DESC);
        oprot.writeString(this.authenticationToken);
        oprot.writeFieldEnd();
      }
      if (this.guid != null) {
        oprot.writeFieldBegin(GUID_FIELD_DESC);
        oprot.writeString(this.guid);
        oprot.writeFieldEnd();
      }
      oprot.writeFieldStop();
      oprot.writeStructEnd();
    }

    public String toString() {
      StringBuilder sb = new StringBuilder("expungeNotebook_args(");
      boolean first = true;

      sb.append("authenticationToken:");
      if (this.authenticationToken == null) {
        sb.append("null");
      } else {
        sb.append(this.authenticationToken);
      }
      first = false;
      if (!first) sb.append(", ");
      sb.append("guid:");
      if (this.guid == null) {
        sb.append("null");
      } else {
        sb.append(this.guid);
      }
      first = false;
      sb.append(")");
      return sb.toString();
    }

    public void validate() throws TException {
      // check for required fields
    }

  }

  public static class expungeNotebook_result implements TBase<expungeNotebook_result._Fields>, java.io.Serializable, Cloneable, Comparable<expungeNotebook_result>   {
    private static final TStruct STRUCT_DESC = new TStruct("expungeNotebook_result");

    private static final TField SUCCESS_FIELD_DESC = new TField("success", TType.I32, (short)0);
    private static final TField USER_EXCEPTION_FIELD_DESC = new TField("userException", TType.STRUCT, (short)1);
    private static final TField SYSTEM_EXCEPTION_FIELD_DESC = new TField("systemException", TType.STRUCT, (short)2);
    private static final TField NOT_FOUND_EXCEPTION_FIELD_DESC = new TField("notFoundException", TType.STRUCT, (short)3);

    private int success;
    private com.evernote.edam.error.EDAMUserException userException;
    private com.evernote.edam.error.EDAMSystemException systemException;
    private com.evernote.edam.error.EDAMNotFoundException notFoundException;

    /** The set of fields this struct contains, along with convenience methods for finding and manipulating them. */
    public enum _Fields implements TFieldIdEnum {
      SUCCESS((short)0, "success"),
      USER_EXCEPTION((short)1, "userException"),
      SYSTEM_EXCEPTION((short)2, "systemException"),
      NOT_FOUND_EXCEPTION((short)3, "notFoundException");

      private static final Map<Integer, _Fields> byId = new HashMap<Integer, _Fields>();
      private static final Map<String, _Fields> byName = new HashMap<String, _Fields>();

      static {
        for (_Fields field : EnumSet.allOf(_Fields.class)) {
          byId.put((int)field._thriftId, field);
          byName.put(field.getFieldName(), field);
        }
      }

      /**
       * Find the _Fields constant that matches fieldId, or null if its not found.
       */
      public static _Fields findByThriftId(int fieldId) {
        return byId.get(fieldId);
      }

      /**
       * Find the _Fields constant that matches fieldId, throwing an exception
       * if it is not found.
       */
      public static _Fields findByThriftIdOrThrow(int fieldId) {
        _Fields fields = findByThriftId(fieldId);
        if (fields == null) throw new IllegalArgumentException("Field " + fieldId + " doesn't exist!");
        return fields;
      }

      /**
       * Find the _Fields constant that matches name, or null if its not found.
       */
      public static _Fields findByName(String name) {
        return byName.get(name);
      }

      private final short _thriftId;
      private final String _fieldName;

      _Fields(short thriftId, String fieldName) {
        _thriftId = thriftId;
        _fieldName = fieldName;
      }

      public short getThriftFieldId() {
        return _thriftId;
      }

      public String getFieldName() {
        return _fieldName;
      }
    }

    // isset id assignments
    private static final int __SUCCESS_ISSET_ID = 0;
    private BitSet __isset_bit_vector = new BitSet(1);

    public static final Map<_Fields, FieldMetaData> metaDataMap = Collections.unmodifiableMap(new EnumMap<_Fields, FieldMetaData>(_Fields.class) {{
      put(_Fields.SUCCESS, new FieldMetaData("success", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.I32)));
      put(_Fields.USER_EXCEPTION, new FieldMetaData("userException", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.STRUCT)));
      put(_Fields.SYSTEM_EXCEPTION, new FieldMetaData("systemException", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.STRUCT)));
      put(_Fields.NOT_FOUND_EXCEPTION, new FieldMetaData("notFoundException", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.STRUCT)));
    }});

    static {
      FieldMetaData.addStructMetaDataMap(expungeNotebook_result.class, metaDataMap);
    }

    public expungeNotebook_result() {
    }

    public expungeNotebook_result(
      int success,
      com.evernote.edam.error.EDAMUserException userException,
      com.evernote.edam.error.EDAMSystemException systemException,
      com.evernote.edam.error.EDAMNotFoundException notFoundException)
    {
      this();
      this.success = success;
      setSuccessIsSet(true);
      this.userException = userException;
      this.systemException = systemException;
      this.notFoundException = notFoundException;
    }

    /**
     * Performs a deep copy on <i>other</i>.
     */
    public expungeNotebook_result(expungeNotebook_result other) {
      __isset_bit_vector.clear();
      __isset_bit_vector.or(other.__isset_bit_vector);
      this.success = other.success;
      if (other.isSetUserException()) {
        this.userException = new com.evernote.edam.error.EDAMUserException(other.userException);
      }
      if (other.isSetSystemException()) {
        this.systemException = new com.evernote.edam.error.EDAMSystemException(other.systemException);
      }
      if (other.isSetNotFoundException()) {
        this.notFoundException = new com.evernote.edam.error.EDAMNotFoundException(other.notFoundException);
      }
    }

    public expungeNotebook_result deepCopy() {
      return new expungeNotebook_result(this);
    }

    @Deprecated
    public expungeNotebook_result clone() {
      return new expungeNotebook_result(this);
    }

    public int getSuccess() {
      return this.success;
    }

    public void setSuccess(int success) {
      this.success = success;
      setSuccessIsSet(true);
    }

    public void unsetSuccess() {
      __isset_bit_vector.clear(__SUCCESS_ISSET_ID);
    }

    /** Returns true if field success is set (has been asigned a value) and false otherwise */
    public boolean isSetSuccess() {
      return __isset_bit_vector.get(__SUCCESS_ISSET_ID);
    }

    public void setSuccessIsSet(boolean value) {
      __isset_bit_vector.set(__SUCCESS_ISSET_ID, value);
    }

    public com.evernote.edam.error.EDAMUserException getUserException() {
      return this.userException;
    }

    public void setUserException(com.evernote.edam.error.EDAMUserException userException) {
      this.userException = userException;
    }

    public void unsetUserException() {
      this.userException = null;
    }

    /** Returns true if field userException is set (has been asigned a value) and false otherwise */
    public boolean isSetUserException() {
      return this.userException != null;
    }

    public void setUserExceptionIsSet(boolean value) {
      if (!value) {
        this.userException = null;
      }
    }

    public com.evernote.edam.error.EDAMSystemException getSystemException() {
      return this.systemException;
    }

    public void setSystemException(com.evernote.edam.error.EDAMSystemException systemException) {
      this.systemException = systemException;
    }

    public void unsetSystemException() {
      this.systemException = null;
    }

    /** Returns true if field systemException is set (has been asigned a value) and false otherwise */
    public boolean isSetSystemException() {
      return this.systemException != null;
    }

    public void setSystemExceptionIsSet(boolean value) {
      if (!value) {
        this.systemException = null;
      }
    }

    public com.evernote.edam.error.EDAMNotFoundException getNotFoundException() {
      return this.notFoundException;
    }

    public void setNotFoundException(com.evernote.edam.error.EDAMNotFoundException notFoundException) {
      this.notFoundException = notFoundException;
    }

    public void unsetNotFoundException() {
      this.notFoundException = null;
    }

    /** Returns true if field notFoundException is set (has been asigned a value) and false otherwise */
    public boolean isSetNotFoundException() {
      return this.notFoundException != null;
    }

    public void setNotFoundExceptionIsSet(boolean value) {
      if (!value) {
        this.notFoundException = null;
      }
    }

    public void setFieldValue(_Fields field, Object value) {
      switch (field) {
      case SUCCESS:
        if (value == null) {
          unsetSuccess();
        } else {
          setSuccess((Integer)value);
        }
        break;

      case USER_EXCEPTION:
        if (value == null) {
          unsetUserException();
        } else {
          setUserException((com.evernote.edam.error.EDAMUserException)value);
        }
        break;

      case SYSTEM_EXCEPTION:
        if (value == null) {
          unsetSystemException();
        } else {
          setSystemException((com.evernote.edam.error.EDAMSystemException)value);
        }
        break;

      case NOT_FOUND_EXCEPTION:
        if (value == null) {
          unsetNotFoundException();
        } else {
          setNotFoundException((com.evernote.edam.error.EDAMNotFoundException)value);
        }
        break;

      }
    }

    public void setFieldValue(int fieldID, Object value) {
      setFieldValue(_Fields.findByThriftIdOrThrow(fieldID), value);
    }

    public Object getFieldValue(_Fields field) {
      switch (field) {
      case SUCCESS:
        return new Integer(getSuccess());

      case USER_EXCEPTION:
        return getUserException();

      case SYSTEM_EXCEPTION:
        return getSystemException();

      case NOT_FOUND_EXCEPTION:
        return getNotFoundException();

      }
      throw new IllegalStateException();
    }

    public Object getFieldValue(int fieldId) {
      return getFieldValue(_Fields.findByThriftIdOrThrow(fieldId));
    }

    /** Returns true if field corresponding to fieldID is set (has been asigned a value) and false otherwise */
    public boolean isSet(_Fields field) {
      switch (field) {
      case SUCCESS:
        return isSetSuccess();
      case USER_EXCEPTION:
        return isSetUserException();
      case SYSTEM_EXCEPTION:
        return isSetSystemException();
      case NOT_FOUND_EXCEPTION:
        return isSetNotFoundException();
      }
      throw new IllegalStateException();
    }

    public boolean isSet(int fieldID) {
      return isSet(_Fields.findByThriftIdOrThrow(fieldID));
    }

    public boolean equals(Object that) {
      if (that == null)
        return false;
      if (that instanceof expungeNotebook_result)
        return this.equals((expungeNotebook_result)that);
      return false;
    }

    public boolean equals(expungeNotebook_result that) {
      if (that == null)
        return false;

      boolean this_present_success = true;
      boolean that_present_success = true;
      if (this_present_success || that_present_success) {
        if (!(this_present_success && that_present_success))
          return false;
        if (this.success != that.success)
          return false;
      }

      boolean this_present_userException = true && this.isSetUserException();
      boolean that_present_userException = true && that.isSetUserException();
      if (this_present_userException || that_present_userException) {
        if (!(this_present_userException && that_present_userException))
          return false;
        if (!this.userException.equals(that.userException))
          return false;
      }

      boolean this_present_systemException = true && this.isSetSystemException();
      boolean that_present_systemException = true && that.isSetSystemException();
      if (this_present_systemException || that_present_systemException) {
        if (!(this_present_systemException && that_present_systemException))
          return false;
        if (!this.systemException.equals(that.systemException))
          return false;
      }

      boolean this_present_notFoundException = true && this.isSetNotFoundException();
      boolean that_present_notFoundException = true && that.isSetNotFoundException();
      if (this_present_notFoundException || that_present_notFoundException) {
        if (!(this_present_notFoundException && that_present_notFoundException))
          return false;
        if (!this.notFoundException.equals(that.notFoundException))
          return false;
      }

      return true;
    }

    public int hashCode() {
      return 0;
    }

    public int compareTo(expungeNotebook_result other) {
      if (!getClass().equals(other.getClass())) {
        return getClass().getName().compareTo(other.getClass().getName());
      }

      int lastComparison = 0;
      expungeNotebook_result typedOther = (expungeNotebook_result)other;

      lastComparison = Boolean.valueOf(isSetSuccess()).compareTo(isSetSuccess());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(success, typedOther.success);
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = Boolean.valueOf(isSetUserException()).compareTo(isSetUserException());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(userException, typedOther.userException);
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = Boolean.valueOf(isSetSystemException()).compareTo(isSetSystemException());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(systemException, typedOther.systemException);
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = Boolean.valueOf(isSetNotFoundException()).compareTo(isSetNotFoundException());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(notFoundException, typedOther.notFoundException);
      if (lastComparison != 0) {
        return lastComparison;
      }
      return 0;
    }

    public void read(TProtocol iprot) throws TException {
      TField field;
      iprot.readStructBegin();
      while (true)
      {
        field = iprot.readFieldBegin();
        if (field.type == TType.STOP) { 
          break;
        }
        _Fields fieldId = _Fields.findByThriftId(field.id);
        if (fieldId == null) {
          TProtocolUtil.skip(iprot, field.type);
        } else {
          switch (fieldId) {
            case SUCCESS:
              if (field.type == TType.I32) {
                this.success = iprot.readI32();
                setSuccessIsSet(true);
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
            case USER_EXCEPTION:
              if (field.type == TType.STRUCT) {
                this.userException = new com.evernote.edam.error.EDAMUserException();
                this.userException.read(iprot);
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
            case SYSTEM_EXCEPTION:
              if (field.type == TType.STRUCT) {
                this.systemException = new com.evernote.edam.error.EDAMSystemException();
                this.systemException.read(iprot);
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
            case NOT_FOUND_EXCEPTION:
              if (field.type == TType.STRUCT) {
                this.notFoundException = new com.evernote.edam.error.EDAMNotFoundException();
                this.notFoundException.read(iprot);
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
          }
          iprot.readFieldEnd();
        }
      }
      iprot.readStructEnd();
      validate();
    }

    public void write(TProtocol oprot) throws TException {
      oprot.writeStructBegin(STRUCT_DESC);

      if (this.isSetSuccess()) {
        oprot.writeFieldBegin(SUCCESS_FIELD_DESC);
        oprot.writeI32(this.success);
        oprot.writeFieldEnd();
      } else if (this.isSetUserException()) {
        oprot.writeFieldBegin(USER_EXCEPTION_FIELD_DESC);
        this.userException.write(oprot);
        oprot.writeFieldEnd();
      } else if (this.isSetSystemException()) {
        oprot.writeFieldBegin(SYSTEM_EXCEPTION_FIELD_DESC);
        this.systemException.write(oprot);
        oprot.writeFieldEnd();
      } else if (this.isSetNotFoundException()) {
        oprot.writeFieldBegin(NOT_FOUND_EXCEPTION_FIELD_DESC);
        this.notFoundException.write(oprot);
        oprot.writeFieldEnd();
      }
      oprot.writeFieldStop();
      oprot.writeStructEnd();
    }

    public String toString() {
      StringBuilder sb = new StringBuilder("expungeNotebook_result(");
      boolean first = true;

      sb.append("success:");
      sb.append(this.success);
      first = false;
      if (!first) sb.append(", ");
      sb.append("userException:");
      if (this.userException == null) {
        sb.append("null");
      } else {
        sb.append(this.userException);
      }
      first = false;
      if (!first) sb.append(", ");
      sb.append("systemException:");
      if (this.systemException == null) {
        sb.append("null");
      } else {
        sb.append(this.systemException);
      }
      first = false;
      if (!first) sb.append(", ");
      sb.append("notFoundException:");
      if (this.notFoundException == null) {
        sb.append("null");
      } else {
        sb.append(this.notFoundException);
      }
      first = false;
      sb.append(")");
      return sb.toString();
    }

    public void validate() throws TException {
      // check for required fields
    }

  }

  public static class listTags_args implements TBase<listTags_args._Fields>, java.io.Serializable, Cloneable, Comparable<listTags_args>   {
    private static final TStruct STRUCT_DESC = new TStruct("listTags_args");

    private static final TField AUTHENTICATION_TOKEN_FIELD_DESC = new TField("authenticationToken", TType.STRING, (short)1);

    private String authenticationToken;

    /** The set of fields this struct contains, along with convenience methods for finding and manipulating them. */
    public enum _Fields implements TFieldIdEnum {
      AUTHENTICATION_TOKEN((short)1, "authenticationToken");

      private static final Map<Integer, _Fields> byId = new HashMap<Integer, _Fields>();
      private static final Map<String, _Fields> byName = new HashMap<String, _Fields>();

      static {
        for (_Fields field : EnumSet.allOf(_Fields.class)) {
          byId.put((int)field._thriftId, field);
          byName.put(field.getFieldName(), field);
        }
      }

      /**
       * Find the _Fields constant that matches fieldId, or null if its not found.
       */
      public static _Fields findByThriftId(int fieldId) {
        return byId.get(fieldId);
      }

      /**
       * Find the _Fields constant that matches fieldId, throwing an exception
       * if it is not found.
       */
      public static _Fields findByThriftIdOrThrow(int fieldId) {
        _Fields fields = findByThriftId(fieldId);
        if (fields == null) throw new IllegalArgumentException("Field " + fieldId + " doesn't exist!");
        return fields;
      }

      /**
       * Find the _Fields constant that matches name, or null if its not found.
       */
      public static _Fields findByName(String name) {
        return byName.get(name);
      }

      private final short _thriftId;
      private final String _fieldName;

      _Fields(short thriftId, String fieldName) {
        _thriftId = thriftId;
        _fieldName = fieldName;
      }

      public short getThriftFieldId() {
        return _thriftId;
      }

      public String getFieldName() {
        return _fieldName;
      }
    }

    // isset id assignments

    public static final Map<_Fields, FieldMetaData> metaDataMap = Collections.unmodifiableMap(new EnumMap<_Fields, FieldMetaData>(_Fields.class) {{
      put(_Fields.AUTHENTICATION_TOKEN, new FieldMetaData("authenticationToken", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.STRING)));
    }});

    static {
      FieldMetaData.addStructMetaDataMap(listTags_args.class, metaDataMap);
    }

    public listTags_args() {
    }

    public listTags_args(
      String authenticationToken)
    {
      this();
      this.authenticationToken = authenticationToken;
    }

    /**
     * Performs a deep copy on <i>other</i>.
     */
    public listTags_args(listTags_args other) {
      if (other.isSetAuthenticationToken()) {
        this.authenticationToken = other.authenticationToken;
      }
    }

    public listTags_args deepCopy() {
      return new listTags_args(this);
    }

    @Deprecated
    public listTags_args clone() {
      return new listTags_args(this);
    }

    public String getAuthenticationToken() {
      return this.authenticationToken;
    }

    public void setAuthenticationToken(String authenticationToken) {
      this.authenticationToken = authenticationToken;
    }

    public void unsetAuthenticationToken() {
      this.authenticationToken = null;
    }

    /** Returns true if field authenticationToken is set (has been asigned a value) and false otherwise */
    public boolean isSetAuthenticationToken() {
      return this.authenticationToken != null;
    }

    public void setAuthenticationTokenIsSet(boolean value) {
      if (!value) {
        this.authenticationToken = null;
      }
    }

    public void setFieldValue(_Fields field, Object value) {
      switch (field) {
      case AUTHENTICATION_TOKEN:
        if (value == null) {
          unsetAuthenticationToken();
        } else {
          setAuthenticationToken((String)value);
        }
        break;

      }
    }

    public void setFieldValue(int fieldID, Object value) {
      setFieldValue(_Fields.findByThriftIdOrThrow(fieldID), value);
    }

    public Object getFieldValue(_Fields field) {
      switch (field) {
      case AUTHENTICATION_TOKEN:
        return getAuthenticationToken();

      }
      throw new IllegalStateException();
    }

    public Object getFieldValue(int fieldId) {
      return getFieldValue(_Fields.findByThriftIdOrThrow(fieldId));
    }

    /** Returns true if field corresponding to fieldID is set (has been asigned a value) and false otherwise */
    public boolean isSet(_Fields field) {
      switch (field) {
      case AUTHENTICATION_TOKEN:
        return isSetAuthenticationToken();
      }
      throw new IllegalStateException();
    }

    public boolean isSet(int fieldID) {
      return isSet(_Fields.findByThriftIdOrThrow(fieldID));
    }

    public boolean equals(Object that) {
      if (that == null)
        return false;
      if (that instanceof listTags_args)
        return this.equals((listTags_args)that);
      return false;
    }

    public boolean equals(listTags_args that) {
      if (that == null)
        return false;

      boolean this_present_authenticationToken = true && this.isSetAuthenticationToken();
      boolean that_present_authenticationToken = true && that.isSetAuthenticationToken();
      if (this_present_authenticationToken || that_present_authenticationToken) {
        if (!(this_present_authenticationToken && that_present_authenticationToken))
          return false;
        if (!this.authenticationToken.equals(that.authenticationToken))
          return false;
      }

      return true;
    }

    public int hashCode() {
      return 0;
    }

    public int compareTo(listTags_args other) {
      if (!getClass().equals(other.getClass())) {
        return getClass().getName().compareTo(other.getClass().getName());
      }

      int lastComparison = 0;
      listTags_args typedOther = (listTags_args)other;

      lastComparison = Boolean.valueOf(isSetAuthenticationToken()).compareTo(isSetAuthenticationToken());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(authenticationToken, typedOther.authenticationToken);
      if (lastComparison != 0) {
        return lastComparison;
      }
      return 0;
    }

    public void read(TProtocol iprot) throws TException {
      TField field;
      iprot.readStructBegin();
      while (true)
      {
        field = iprot.readFieldBegin();
        if (field.type == TType.STOP) { 
          break;
        }
        _Fields fieldId = _Fields.findByThriftId(field.id);
        if (fieldId == null) {
          TProtocolUtil.skip(iprot, field.type);
        } else {
          switch (fieldId) {
            case AUTHENTICATION_TOKEN:
              if (field.type == TType.STRING) {
                this.authenticationToken = iprot.readString();
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
          }
          iprot.readFieldEnd();
        }
      }
      iprot.readStructEnd();
      validate();
    }

    public void write(TProtocol oprot) throws TException {
      validate();

      oprot.writeStructBegin(STRUCT_DESC);
      if (this.authenticationToken != null) {
        oprot.writeFieldBegin(AUTHENTICATION_TOKEN_FIELD_DESC);
        oprot.writeString(this.authenticationToken);
        oprot.writeFieldEnd();
      }
      oprot.writeFieldStop();
      oprot.writeStructEnd();
    }

    public String toString() {
      StringBuilder sb = new StringBuilder("listTags_args(");
      boolean first = true;

      sb.append("authenticationToken:");
      if (this.authenticationToken == null) {
        sb.append("null");
      } else {
        sb.append(this.authenticationToken);
      }
      first = false;
      sb.append(")");
      return sb.toString();
    }

    public void validate() throws TException {
      // check for required fields
    }

  }

  public static class listTags_result implements TBase<listTags_result._Fields>, java.io.Serializable, Cloneable, Comparable<listTags_result>   {
    private static final TStruct STRUCT_DESC = new TStruct("listTags_result");

    private static final TField SUCCESS_FIELD_DESC = new TField("success", TType.LIST, (short)0);
    private static final TField USER_EXCEPTION_FIELD_DESC = new TField("userException", TType.STRUCT, (short)1);
    private static final TField SYSTEM_EXCEPTION_FIELD_DESC = new TField("systemException", TType.STRUCT, (short)2);

    private List<com.evernote.edam.type.Tag> success;
    private com.evernote.edam.error.EDAMUserException userException;
    private com.evernote.edam.error.EDAMSystemException systemException;

    /** The set of fields this struct contains, along with convenience methods for finding and manipulating them. */
    public enum _Fields implements TFieldIdEnum {
      SUCCESS((short)0, "success"),
      USER_EXCEPTION((short)1, "userException"),
      SYSTEM_EXCEPTION((short)2, "systemException");

      private static final Map<Integer, _Fields> byId = new HashMap<Integer, _Fields>();
      private static final Map<String, _Fields> byName = new HashMap<String, _Fields>();

      static {
        for (_Fields field : EnumSet.allOf(_Fields.class)) {
          byId.put((int)field._thriftId, field);
          byName.put(field.getFieldName(), field);
        }
      }

      /**
       * Find the _Fields constant that matches fieldId, or null if its not found.
       */
      public static _Fields findByThriftId(int fieldId) {
        return byId.get(fieldId);
      }

      /**
       * Find the _Fields constant that matches fieldId, throwing an exception
       * if it is not found.
       */
      public static _Fields findByThriftIdOrThrow(int fieldId) {
        _Fields fields = findByThriftId(fieldId);
        if (fields == null) throw new IllegalArgumentException("Field " + fieldId + " doesn't exist!");
        return fields;
      }

      /**
       * Find the _Fields constant that matches name, or null if its not found.
       */
      public static _Fields findByName(String name) {
        return byName.get(name);
      }

      private final short _thriftId;
      private final String _fieldName;

      _Fields(short thriftId, String fieldName) {
        _thriftId = thriftId;
        _fieldName = fieldName;
      }

      public short getThriftFieldId() {
        return _thriftId;
      }

      public String getFieldName() {
        return _fieldName;
      }
    }

    // isset id assignments

    public static final Map<_Fields, FieldMetaData> metaDataMap = Collections.unmodifiableMap(new EnumMap<_Fields, FieldMetaData>(_Fields.class) {{
      put(_Fields.SUCCESS, new FieldMetaData("success", TFieldRequirementType.DEFAULT, 
          new ListMetaData(TType.LIST, 
              new StructMetaData(TType.STRUCT, com.evernote.edam.type.Tag.class))));
      put(_Fields.USER_EXCEPTION, new FieldMetaData("userException", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.STRUCT)));
      put(_Fields.SYSTEM_EXCEPTION, new FieldMetaData("systemException", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.STRUCT)));
    }});

    static {
      FieldMetaData.addStructMetaDataMap(listTags_result.class, metaDataMap);
    }

    public listTags_result() {
    }

    public listTags_result(
      List<com.evernote.edam.type.Tag> success,
      com.evernote.edam.error.EDAMUserException userException,
      com.evernote.edam.error.EDAMSystemException systemException)
    {
      this();
      this.success = success;
      this.userException = userException;
      this.systemException = systemException;
    }

    /**
     * Performs a deep copy on <i>other</i>.
     */
    public listTags_result(listTags_result other) {
      if (other.isSetSuccess()) {
        List<com.evernote.edam.type.Tag> __this__success = new ArrayList<com.evernote.edam.type.Tag>();
        for (com.evernote.edam.type.Tag other_element : other.success) {
          __this__success.add(new com.evernote.edam.type.Tag(other_element));
        }
        this.success = __this__success;
      }
      if (other.isSetUserException()) {
        this.userException = new com.evernote.edam.error.EDAMUserException(other.userException);
      }
      if (other.isSetSystemException()) {
        this.systemException = new com.evernote.edam.error.EDAMSystemException(other.systemException);
      }
    }

    public listTags_result deepCopy() {
      return new listTags_result(this);
    }

    @Deprecated
    public listTags_result clone() {
      return new listTags_result(this);
    }

    public int getSuccessSize() {
      return (this.success == null) ? 0 : this.success.size();
    }

    public java.util.Iterator<com.evernote.edam.type.Tag> getSuccessIterator() {
      return (this.success == null) ? null : this.success.iterator();
    }

    public void addToSuccess(com.evernote.edam.type.Tag elem) {
      if (this.success == null) {
        this.success = new ArrayList<com.evernote.edam.type.Tag>();
      }
      this.success.add(elem);
    }

    public List<com.evernote.edam.type.Tag> getSuccess() {
      return this.success;
    }

    public void setSuccess(List<com.evernote.edam.type.Tag> success) {
      this.success = success;
    }

    public void unsetSuccess() {
      this.success = null;
    }

    /** Returns true if field success is set (has been asigned a value) and false otherwise */
    public boolean isSetSuccess() {
      return this.success != null;
    }

    public void setSuccessIsSet(boolean value) {
      if (!value) {
        this.success = null;
      }
    }

    public com.evernote.edam.error.EDAMUserException getUserException() {
      return this.userException;
    }

    public void setUserException(com.evernote.edam.error.EDAMUserException userException) {
      this.userException = userException;
    }

    public void unsetUserException() {
      this.userException = null;
    }

    /** Returns true if field userException is set (has been asigned a value) and false otherwise */
    public boolean isSetUserException() {
      return this.userException != null;
    }

    public void setUserExceptionIsSet(boolean value) {
      if (!value) {
        this.userException = null;
      }
    }

    public com.evernote.edam.error.EDAMSystemException getSystemException() {
      return this.systemException;
    }

    public void setSystemException(com.evernote.edam.error.EDAMSystemException systemException) {
      this.systemException = systemException;
    }

    public void unsetSystemException() {
      this.systemException = null;
    }

    /** Returns true if field systemException is set (has been asigned a value) and false otherwise */
    public boolean isSetSystemException() {
      return this.systemException != null;
    }

    public void setSystemExceptionIsSet(boolean value) {
      if (!value) {
        this.systemException = null;
      }
    }

    public void setFieldValue(_Fields field, Object value) {
      switch (field) {
      case SUCCESS:
        if (value == null) {
          unsetSuccess();
        } else {
          setSuccess((List<com.evernote.edam.type.Tag>)value);
        }
        break;

      case USER_EXCEPTION:
        if (value == null) {
          unsetUserException();
        } else {
          setUserException((com.evernote.edam.error.EDAMUserException)value);
        }
        break;

      case SYSTEM_EXCEPTION:
        if (value == null) {
          unsetSystemException();
        } else {
          setSystemException((com.evernote.edam.error.EDAMSystemException)value);
        }
        break;

      }
    }

    public void setFieldValue(int fieldID, Object value) {
      setFieldValue(_Fields.findByThriftIdOrThrow(fieldID), value);
    }

    public Object getFieldValue(_Fields field) {
      switch (field) {
      case SUCCESS:
        return getSuccess();

      case USER_EXCEPTION:
        return getUserException();

      case SYSTEM_EXCEPTION:
        return getSystemException();

      }
      throw new IllegalStateException();
    }

    public Object getFieldValue(int fieldId) {
      return getFieldValue(_Fields.findByThriftIdOrThrow(fieldId));
    }

    /** Returns true if field corresponding to fieldID is set (has been asigned a value) and false otherwise */
    public boolean isSet(_Fields field) {
      switch (field) {
      case SUCCESS:
        return isSetSuccess();
      case USER_EXCEPTION:
        return isSetUserException();
      case SYSTEM_EXCEPTION:
        return isSetSystemException();
      }
      throw new IllegalStateException();
    }

    public boolean isSet(int fieldID) {
      return isSet(_Fields.findByThriftIdOrThrow(fieldID));
    }

    public boolean equals(Object that) {
      if (that == null)
        return false;
      if (that instanceof listTags_result)
        return this.equals((listTags_result)that);
      return false;
    }

    public boolean equals(listTags_result that) {
      if (that == null)
        return false;

      boolean this_present_success = true && this.isSetSuccess();
      boolean that_present_success = true && that.isSetSuccess();
      if (this_present_success || that_present_success) {
        if (!(this_present_success && that_present_success))
          return false;
        if (!this.success.equals(that.success))
          return false;
      }

      boolean this_present_userException = true && this.isSetUserException();
      boolean that_present_userException = true && that.isSetUserException();
      if (this_present_userException || that_present_userException) {
        if (!(this_present_userException && that_present_userException))
          return false;
        if (!this.userException.equals(that.userException))
          return false;
      }

      boolean this_present_systemException = true && this.isSetSystemException();
      boolean that_present_systemException = true && that.isSetSystemException();
      if (this_present_systemException || that_present_systemException) {
        if (!(this_present_systemException && that_present_systemException))
          return false;
        if (!this.systemException.equals(that.systemException))
          return false;
      }

      return true;
    }

    public int hashCode() {
      return 0;
    }

    public int compareTo(listTags_result other) {
      if (!getClass().equals(other.getClass())) {
        return getClass().getName().compareTo(other.getClass().getName());
      }

      int lastComparison = 0;
      listTags_result typedOther = (listTags_result)other;

      lastComparison = Boolean.valueOf(isSetSuccess()).compareTo(isSetSuccess());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(success, typedOther.success);
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = Boolean.valueOf(isSetUserException()).compareTo(isSetUserException());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(userException, typedOther.userException);
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = Boolean.valueOf(isSetSystemException()).compareTo(isSetSystemException());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(systemException, typedOther.systemException);
      if (lastComparison != 0) {
        return lastComparison;
      }
      return 0;
    }

    public void read(TProtocol iprot) throws TException {
      TField field;
      iprot.readStructBegin();
      while (true)
      {
        field = iprot.readFieldBegin();
        if (field.type == TType.STOP) { 
          break;
        }
        _Fields fieldId = _Fields.findByThriftId(field.id);
        if (fieldId == null) {
          TProtocolUtil.skip(iprot, field.type);
        } else {
          switch (fieldId) {
            case SUCCESS:
              if (field.type == TType.LIST) {
                {
                  TList _list83 = iprot.readListBegin();
                  this.success = new ArrayList<com.evernote.edam.type.Tag>(_list83.size);
                  for (int _i84 = 0; _i84 < _list83.size; ++_i84)
                  {
                    com.evernote.edam.type.Tag _elem85;
                    _elem85 = new com.evernote.edam.type.Tag();
                    _elem85.read(iprot);
                    this.success.add(_elem85);
                  }
                  iprot.readListEnd();
                }
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
            case USER_EXCEPTION:
              if (field.type == TType.STRUCT) {
                this.userException = new com.evernote.edam.error.EDAMUserException();
                this.userException.read(iprot);
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
            case SYSTEM_EXCEPTION:
              if (field.type == TType.STRUCT) {
                this.systemException = new com.evernote.edam.error.EDAMSystemException();
                this.systemException.read(iprot);
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
          }
          iprot.readFieldEnd();
        }
      }
      iprot.readStructEnd();
      validate();
    }

    public void write(TProtocol oprot) throws TException {
      oprot.writeStructBegin(STRUCT_DESC);

      if (this.isSetSuccess()) {
        oprot.writeFieldBegin(SUCCESS_FIELD_DESC);
        {
          oprot.writeListBegin(new TList(TType.STRUCT, this.success.size()));
          for (com.evernote.edam.type.Tag _iter86 : this.success)
          {
            _iter86.write(oprot);
          }
          oprot.writeListEnd();
        }
        oprot.writeFieldEnd();
      } else if (this.isSetUserException()) {
        oprot.writeFieldBegin(USER_EXCEPTION_FIELD_DESC);
        this.userException.write(oprot);
        oprot.writeFieldEnd();
      } else if (this.isSetSystemException()) {
        oprot.writeFieldBegin(SYSTEM_EXCEPTION_FIELD_DESC);
        this.systemException.write(oprot);
        oprot.writeFieldEnd();
      }
      oprot.writeFieldStop();
      oprot.writeStructEnd();
    }

    public String toString() {
      StringBuilder sb = new StringBuilder("listTags_result(");
      boolean first = true;

      sb.append("success:");
      if (this.success == null) {
        sb.append("null");
      } else {
        sb.append(this.success);
      }
      first = false;
      if (!first) sb.append(", ");
      sb.append("userException:");
      if (this.userException == null) {
        sb.append("null");
      } else {
        sb.append(this.userException);
      }
      first = false;
      if (!first) sb.append(", ");
      sb.append("systemException:");
      if (this.systemException == null) {
        sb.append("null");
      } else {
        sb.append(this.systemException);
      }
      first = false;
      sb.append(")");
      return sb.toString();
    }

    public void validate() throws TException {
      // check for required fields
    }

  }

  public static class listTagsByNotebook_args implements TBase<listTagsByNotebook_args._Fields>, java.io.Serializable, Cloneable, Comparable<listTagsByNotebook_args>   {
    private static final TStruct STRUCT_DESC = new TStruct("listTagsByNotebook_args");

    private static final TField AUTHENTICATION_TOKEN_FIELD_DESC = new TField("authenticationToken", TType.STRING, (short)1);
    private static final TField NOTEBOOK_GUID_FIELD_DESC = new TField("notebookGuid", TType.STRING, (short)2);

    private String authenticationToken;
    private String notebookGuid;

    /** The set of fields this struct contains, along with convenience methods for finding and manipulating them. */
    public enum _Fields implements TFieldIdEnum {
      AUTHENTICATION_TOKEN((short)1, "authenticationToken"),
      NOTEBOOK_GUID((short)2, "notebookGuid");

      private static final Map<Integer, _Fields> byId = new HashMap<Integer, _Fields>();
      private static final Map<String, _Fields> byName = new HashMap<String, _Fields>();

      static {
        for (_Fields field : EnumSet.allOf(_Fields.class)) {
          byId.put((int)field._thriftId, field);
          byName.put(field.getFieldName(), field);
        }
      }

      /**
       * Find the _Fields constant that matches fieldId, or null if its not found.
       */
      public static _Fields findByThriftId(int fieldId) {
        return byId.get(fieldId);
      }

      /**
       * Find the _Fields constant that matches fieldId, throwing an exception
       * if it is not found.
       */
      public static _Fields findByThriftIdOrThrow(int fieldId) {
        _Fields fields = findByThriftId(fieldId);
        if (fields == null) throw new IllegalArgumentException("Field " + fieldId + " doesn't exist!");
        return fields;
      }

      /**
       * Find the _Fields constant that matches name, or null if its not found.
       */
      public static _Fields findByName(String name) {
        return byName.get(name);
      }

      private final short _thriftId;
      private final String _fieldName;

      _Fields(short thriftId, String fieldName) {
        _thriftId = thriftId;
        _fieldName = fieldName;
      }

      public short getThriftFieldId() {
        return _thriftId;
      }

      public String getFieldName() {
        return _fieldName;
      }
    }

    // isset id assignments

    public static final Map<_Fields, FieldMetaData> metaDataMap = Collections.unmodifiableMap(new EnumMap<_Fields, FieldMetaData>(_Fields.class) {{
      put(_Fields.AUTHENTICATION_TOKEN, new FieldMetaData("authenticationToken", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.STRING)));
      put(_Fields.NOTEBOOK_GUID, new FieldMetaData("notebookGuid", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.STRING)));
    }});

    static {
      FieldMetaData.addStructMetaDataMap(listTagsByNotebook_args.class, metaDataMap);
    }

    public listTagsByNotebook_args() {
    }

    public listTagsByNotebook_args(
      String authenticationToken,
      String notebookGuid)
    {
      this();
      this.authenticationToken = authenticationToken;
      this.notebookGuid = notebookGuid;
    }

    /**
     * Performs a deep copy on <i>other</i>.
     */
    public listTagsByNotebook_args(listTagsByNotebook_args other) {
      if (other.isSetAuthenticationToken()) {
        this.authenticationToken = other.authenticationToken;
      }
      if (other.isSetNotebookGuid()) {
        this.notebookGuid = other.notebookGuid;
      }
    }

    public listTagsByNotebook_args deepCopy() {
      return new listTagsByNotebook_args(this);
    }

    @Deprecated
    public listTagsByNotebook_args clone() {
      return new listTagsByNotebook_args(this);
    }

    public String getAuthenticationToken() {
      return this.authenticationToken;
    }

    public void setAuthenticationToken(String authenticationToken) {
      this.authenticationToken = authenticationToken;
    }

    public void unsetAuthenticationToken() {
      this.authenticationToken = null;
    }

    /** Returns true if field authenticationToken is set (has been asigned a value) and false otherwise */
    public boolean isSetAuthenticationToken() {
      return this.authenticationToken != null;
    }

    public void setAuthenticationTokenIsSet(boolean value) {
      if (!value) {
        this.authenticationToken = null;
      }
    }

    public String getNotebookGuid() {
      return this.notebookGuid;
    }

    public void setNotebookGuid(String notebookGuid) {
      this.notebookGuid = notebookGuid;
    }

    public void unsetNotebookGuid() {
      this.notebookGuid = null;
    }

    /** Returns true if field notebookGuid is set (has been asigned a value) and false otherwise */
    public boolean isSetNotebookGuid() {
      return this.notebookGuid != null;
    }

    public void setNotebookGuidIsSet(boolean value) {
      if (!value) {
        this.notebookGuid = null;
      }
    }

    public void setFieldValue(_Fields field, Object value) {
      switch (field) {
      case AUTHENTICATION_TOKEN:
        if (value == null) {
          unsetAuthenticationToken();
        } else {
          setAuthenticationToken((String)value);
        }
        break;

      case NOTEBOOK_GUID:
        if (value == null) {
          unsetNotebookGuid();
        } else {
          setNotebookGuid((String)value);
        }
        break;

      }
    }

    public void setFieldValue(int fieldID, Object value) {
      setFieldValue(_Fields.findByThriftIdOrThrow(fieldID), value);
    }

    public Object getFieldValue(_Fields field) {
      switch (field) {
      case AUTHENTICATION_TOKEN:
        return getAuthenticationToken();

      case NOTEBOOK_GUID:
        return getNotebookGuid();

      }
      throw new IllegalStateException();
    }

    public Object getFieldValue(int fieldId) {
      return getFieldValue(_Fields.findByThriftIdOrThrow(fieldId));
    }

    /** Returns true if field corresponding to fieldID is set (has been asigned a value) and false otherwise */
    public boolean isSet(_Fields field) {
      switch (field) {
      case AUTHENTICATION_TOKEN:
        return isSetAuthenticationToken();
      case NOTEBOOK_GUID:
        return isSetNotebookGuid();
      }
      throw new IllegalStateException();
    }

    public boolean isSet(int fieldID) {
      return isSet(_Fields.findByThriftIdOrThrow(fieldID));
    }

    public boolean equals(Object that) {
      if (that == null)
        return false;
      if (that instanceof listTagsByNotebook_args)
        return this.equals((listTagsByNotebook_args)that);
      return false;
    }

    public boolean equals(listTagsByNotebook_args that) {
      if (that == null)
        return false;

      boolean this_present_authenticationToken = true && this.isSetAuthenticationToken();
      boolean that_present_authenticationToken = true && that.isSetAuthenticationToken();
      if (this_present_authenticationToken || that_present_authenticationToken) {
        if (!(this_present_authenticationToken && that_present_authenticationToken))
          return false;
        if (!this.authenticationToken.equals(that.authenticationToken))
          return false;
      }

      boolean this_present_notebookGuid = true && this.isSetNotebookGuid();
      boolean that_present_notebookGuid = true && that.isSetNotebookGuid();
      if (this_present_notebookGuid || that_present_notebookGuid) {
        if (!(this_present_notebookGuid && that_present_notebookGuid))
          return false;
        if (!this.notebookGuid.equals(that.notebookGuid))
          return false;
      }

      return true;
    }

    public int hashCode() {
      return 0;
    }

    public int compareTo(listTagsByNotebook_args other) {
      if (!getClass().equals(other.getClass())) {
        return getClass().getName().compareTo(other.getClass().getName());
      }

      int lastComparison = 0;
      listTagsByNotebook_args typedOther = (listTagsByNotebook_args)other;

      lastComparison = Boolean.valueOf(isSetAuthenticationToken()).compareTo(isSetAuthenticationToken());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(authenticationToken, typedOther.authenticationToken);
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = Boolean.valueOf(isSetNotebookGuid()).compareTo(isSetNotebookGuid());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(notebookGuid, typedOther.notebookGuid);
      if (lastComparison != 0) {
        return lastComparison;
      }
      return 0;
    }

    public void read(TProtocol iprot) throws TException {
      TField field;
      iprot.readStructBegin();
      while (true)
      {
        field = iprot.readFieldBegin();
        if (field.type == TType.STOP) { 
          break;
        }
        _Fields fieldId = _Fields.findByThriftId(field.id);
        if (fieldId == null) {
          TProtocolUtil.skip(iprot, field.type);
        } else {
          switch (fieldId) {
            case AUTHENTICATION_TOKEN:
              if (field.type == TType.STRING) {
                this.authenticationToken = iprot.readString();
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
            case NOTEBOOK_GUID:
              if (field.type == TType.STRING) {
                this.notebookGuid = iprot.readString();
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
          }
          iprot.readFieldEnd();
        }
      }
      iprot.readStructEnd();
      validate();
    }

    public void write(TProtocol oprot) throws TException {
      validate();

      oprot.writeStructBegin(STRUCT_DESC);
      if (this.authenticationToken != null) {
        oprot.writeFieldBegin(AUTHENTICATION_TOKEN_FIELD_DESC);
        oprot.writeString(this.authenticationToken);
        oprot.writeFieldEnd();
      }
      if (this.notebookGuid != null) {
        oprot.writeFieldBegin(NOTEBOOK_GUID_FIELD_DESC);
        oprot.writeString(this.notebookGuid);
        oprot.writeFieldEnd();
      }
      oprot.writeFieldStop();
      oprot.writeStructEnd();
    }

    public String toString() {
      StringBuilder sb = new StringBuilder("listTagsByNotebook_args(");
      boolean first = true;

      sb.append("authenticationToken:");
      if (this.authenticationToken == null) {
        sb.append("null");
      } else {
        sb.append(this.authenticationToken);
      }
      first = false;
      if (!first) sb.append(", ");
      sb.append("notebookGuid:");
      if (this.notebookGuid == null) {
        sb.append("null");
      } else {
        sb.append(this.notebookGuid);
      }
      first = false;
      sb.append(")");
      return sb.toString();
    }

    public void validate() throws TException {
      // check for required fields
    }

  }

  public static class listTagsByNotebook_result implements TBase<listTagsByNotebook_result._Fields>, java.io.Serializable, Cloneable, Comparable<listTagsByNotebook_result>   {
    private static final TStruct STRUCT_DESC = new TStruct("listTagsByNotebook_result");

    private static final TField SUCCESS_FIELD_DESC = new TField("success", TType.LIST, (short)0);
    private static final TField USER_EXCEPTION_FIELD_DESC = new TField("userException", TType.STRUCT, (short)1);
    private static final TField SYSTEM_EXCEPTION_FIELD_DESC = new TField("systemException", TType.STRUCT, (short)2);
    private static final TField NOT_FOUND_EXCEPTION_FIELD_DESC = new TField("notFoundException", TType.STRUCT, (short)3);

    private List<com.evernote.edam.type.Tag> success;
    private com.evernote.edam.error.EDAMUserException userException;
    private com.evernote.edam.error.EDAMSystemException systemException;
    private com.evernote.edam.error.EDAMNotFoundException notFoundException;

    /** The set of fields this struct contains, along with convenience methods for finding and manipulating them. */
    public enum _Fields implements TFieldIdEnum {
      SUCCESS((short)0, "success"),
      USER_EXCEPTION((short)1, "userException"),
      SYSTEM_EXCEPTION((short)2, "systemException"),
      NOT_FOUND_EXCEPTION((short)3, "notFoundException");

      private static final Map<Integer, _Fields> byId = new HashMap<Integer, _Fields>();
      private static final Map<String, _Fields> byName = new HashMap<String, _Fields>();

      static {
        for (_Fields field : EnumSet.allOf(_Fields.class)) {
          byId.put((int)field._thriftId, field);
          byName.put(field.getFieldName(), field);
        }
      }

      /**
       * Find the _Fields constant that matches fieldId, or null if its not found.
       */
      public static _Fields findByThriftId(int fieldId) {
        return byId.get(fieldId);
      }

      /**
       * Find the _Fields constant that matches fieldId, throwing an exception
       * if it is not found.
       */
      public static _Fields findByThriftIdOrThrow(int fieldId) {
        _Fields fields = findByThriftId(fieldId);
        if (fields == null) throw new IllegalArgumentException("Field " + fieldId + " doesn't exist!");
        return fields;
      }

      /**
       * Find the _Fields constant that matches name, or null if its not found.
       */
      public static _Fields findByName(String name) {
        return byName.get(name);
      }

      private final short _thriftId;
      private final String _fieldName;

      _Fields(short thriftId, String fieldName) {
        _thriftId = thriftId;
        _fieldName = fieldName;
      }

      public short getThriftFieldId() {
        return _thriftId;
      }

      public String getFieldName() {
        return _fieldName;
      }
    }

    // isset id assignments

    public static final Map<_Fields, FieldMetaData> metaDataMap = Collections.unmodifiableMap(new EnumMap<_Fields, FieldMetaData>(_Fields.class) {{
      put(_Fields.SUCCESS, new FieldMetaData("success", TFieldRequirementType.DEFAULT, 
          new ListMetaData(TType.LIST, 
              new StructMetaData(TType.STRUCT, com.evernote.edam.type.Tag.class))));
      put(_Fields.USER_EXCEPTION, new FieldMetaData("userException", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.STRUCT)));
      put(_Fields.SYSTEM_EXCEPTION, new FieldMetaData("systemException", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.STRUCT)));
      put(_Fields.NOT_FOUND_EXCEPTION, new FieldMetaData("notFoundException", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.STRUCT)));
    }});

    static {
      FieldMetaData.addStructMetaDataMap(listTagsByNotebook_result.class, metaDataMap);
    }

    public listTagsByNotebook_result() {
    }

    public listTagsByNotebook_result(
      List<com.evernote.edam.type.Tag> success,
      com.evernote.edam.error.EDAMUserException userException,
      com.evernote.edam.error.EDAMSystemException systemException,
      com.evernote.edam.error.EDAMNotFoundException notFoundException)
    {
      this();
      this.success = success;
      this.userException = userException;
      this.systemException = systemException;
      this.notFoundException = notFoundException;
    }

    /**
     * Performs a deep copy on <i>other</i>.
     */
    public listTagsByNotebook_result(listTagsByNotebook_result other) {
      if (other.isSetSuccess()) {
        List<com.evernote.edam.type.Tag> __this__success = new ArrayList<com.evernote.edam.type.Tag>();
        for (com.evernote.edam.type.Tag other_element : other.success) {
          __this__success.add(new com.evernote.edam.type.Tag(other_element));
        }
        this.success = __this__success;
      }
      if (other.isSetUserException()) {
        this.userException = new com.evernote.edam.error.EDAMUserException(other.userException);
      }
      if (other.isSetSystemException()) {
        this.systemException = new com.evernote.edam.error.EDAMSystemException(other.systemException);
      }
      if (other.isSetNotFoundException()) {
        this.notFoundException = new com.evernote.edam.error.EDAMNotFoundException(other.notFoundException);
      }
    }

    public listTagsByNotebook_result deepCopy() {
      return new listTagsByNotebook_result(this);
    }

    @Deprecated
    public listTagsByNotebook_result clone() {
      return new listTagsByNotebook_result(this);
    }

    public int getSuccessSize() {
      return (this.success == null) ? 0 : this.success.size();
    }

    public java.util.Iterator<com.evernote.edam.type.Tag> getSuccessIterator() {
      return (this.success == null) ? null : this.success.iterator();
    }

    public void addToSuccess(com.evernote.edam.type.Tag elem) {
      if (this.success == null) {
        this.success = new ArrayList<com.evernote.edam.type.Tag>();
      }
      this.success.add(elem);
    }

    public List<com.evernote.edam.type.Tag> getSuccess() {
      return this.success;
    }

    public void setSuccess(List<com.evernote.edam.type.Tag> success) {
      this.success = success;
    }

    public void unsetSuccess() {
      this.success = null;
    }

    /** Returns true if field success is set (has been asigned a value) and false otherwise */
    public boolean isSetSuccess() {
      return this.success != null;
    }

    public void setSuccessIsSet(boolean value) {
      if (!value) {
        this.success = null;
      }
    }

    public com.evernote.edam.error.EDAMUserException getUserException() {
      return this.userException;
    }

    public void setUserException(com.evernote.edam.error.EDAMUserException userException) {
      this.userException = userException;
    }

    public void unsetUserException() {
      this.userException = null;
    }

    /** Returns true if field userException is set (has been asigned a value) and false otherwise */
    public boolean isSetUserException() {
      return this.userException != null;
    }

    public void setUserExceptionIsSet(boolean value) {
      if (!value) {
        this.userException = null;
      }
    }

    public com.evernote.edam.error.EDAMSystemException getSystemException() {
      return this.systemException;
    }

    public void setSystemException(com.evernote.edam.error.EDAMSystemException systemException) {
      this.systemException = systemException;
    }

    public void unsetSystemException() {
      this.systemException = null;
    }

    /** Returns true if field systemException is set (has been asigned a value) and false otherwise */
    public boolean isSetSystemException() {
      return this.systemException != null;
    }

    public void setSystemExceptionIsSet(boolean value) {
      if (!value) {
        this.systemException = null;
      }
    }

    public com.evernote.edam.error.EDAMNotFoundException getNotFoundException() {
      return this.notFoundException;
    }

    public void setNotFoundException(com.evernote.edam.error.EDAMNotFoundException notFoundException) {
      this.notFoundException = notFoundException;
    }

    public void unsetNotFoundException() {
      this.notFoundException = null;
    }

    /** Returns true if field notFoundException is set (has been asigned a value) and false otherwise */
    public boolean isSetNotFoundException() {
      return this.notFoundException != null;
    }

    public void setNotFoundExceptionIsSet(boolean value) {
      if (!value) {
        this.notFoundException = null;
      }
    }

    public void setFieldValue(_Fields field, Object value) {
      switch (field) {
      case SUCCESS:
        if (value == null) {
          unsetSuccess();
        } else {
          setSuccess((List<com.evernote.edam.type.Tag>)value);
        }
        break;

      case USER_EXCEPTION:
        if (value == null) {
          unsetUserException();
        } else {
          setUserException((com.evernote.edam.error.EDAMUserException)value);
        }
        break;

      case SYSTEM_EXCEPTION:
        if (value == null) {
          unsetSystemException();
        } else {
          setSystemException((com.evernote.edam.error.EDAMSystemException)value);
        }
        break;

      case NOT_FOUND_EXCEPTION:
        if (value == null) {
          unsetNotFoundException();
        } else {
          setNotFoundException((com.evernote.edam.error.EDAMNotFoundException)value);
        }
        break;

      }
    }

    public void setFieldValue(int fieldID, Object value) {
      setFieldValue(_Fields.findByThriftIdOrThrow(fieldID), value);
    }

    public Object getFieldValue(_Fields field) {
      switch (field) {
      case SUCCESS:
        return getSuccess();

      case USER_EXCEPTION:
        return getUserException();

      case SYSTEM_EXCEPTION:
        return getSystemException();

      case NOT_FOUND_EXCEPTION:
        return getNotFoundException();

      }
      throw new IllegalStateException();
    }

    public Object getFieldValue(int fieldId) {
      return getFieldValue(_Fields.findByThriftIdOrThrow(fieldId));
    }

    /** Returns true if field corresponding to fieldID is set (has been asigned a value) and false otherwise */
    public boolean isSet(_Fields field) {
      switch (field) {
      case SUCCESS:
        return isSetSuccess();
      case USER_EXCEPTION:
        return isSetUserException();
      case SYSTEM_EXCEPTION:
        return isSetSystemException();
      case NOT_FOUND_EXCEPTION:
        return isSetNotFoundException();
      }
      throw new IllegalStateException();
    }

    public boolean isSet(int fieldID) {
      return isSet(_Fields.findByThriftIdOrThrow(fieldID));
    }

    public boolean equals(Object that) {
      if (that == null)
        return false;
      if (that instanceof listTagsByNotebook_result)
        return this.equals((listTagsByNotebook_result)that);
      return false;
    }

    public boolean equals(listTagsByNotebook_result that) {
      if (that == null)
        return false;

      boolean this_present_success = true && this.isSetSuccess();
      boolean that_present_success = true && that.isSetSuccess();
      if (this_present_success || that_present_success) {
        if (!(this_present_success && that_present_success))
          return false;
        if (!this.success.equals(that.success))
          return false;
      }

      boolean this_present_userException = true && this.isSetUserException();
      boolean that_present_userException = true && that.isSetUserException();
      if (this_present_userException || that_present_userException) {
        if (!(this_present_userException && that_present_userException))
          return false;
        if (!this.userException.equals(that.userException))
          return false;
      }

      boolean this_present_systemException = true && this.isSetSystemException();
      boolean that_present_systemException = true && that.isSetSystemException();
      if (this_present_systemException || that_present_systemException) {
        if (!(this_present_systemException && that_present_systemException))
          return false;
        if (!this.systemException.equals(that.systemException))
          return false;
      }

      boolean this_present_notFoundException = true && this.isSetNotFoundException();
      boolean that_present_notFoundException = true && that.isSetNotFoundException();
      if (this_present_notFoundException || that_present_notFoundException) {
        if (!(this_present_notFoundException && that_present_notFoundException))
          return false;
        if (!this.notFoundException.equals(that.notFoundException))
          return false;
      }

      return true;
    }

    public int hashCode() {
      return 0;
    }

    public int compareTo(listTagsByNotebook_result other) {
      if (!getClass().equals(other.getClass())) {
        return getClass().getName().compareTo(other.getClass().getName());
      }

      int lastComparison = 0;
      listTagsByNotebook_result typedOther = (listTagsByNotebook_result)other;

      lastComparison = Boolean.valueOf(isSetSuccess()).compareTo(isSetSuccess());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(success, typedOther.success);
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = Boolean.valueOf(isSetUserException()).compareTo(isSetUserException());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(userException, typedOther.userException);
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = Boolean.valueOf(isSetSystemException()).compareTo(isSetSystemException());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(systemException, typedOther.systemException);
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = Boolean.valueOf(isSetNotFoundException()).compareTo(isSetNotFoundException());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(notFoundException, typedOther.notFoundException);
      if (lastComparison != 0) {
        return lastComparison;
      }
      return 0;
    }

    public void read(TProtocol iprot) throws TException {
      TField field;
      iprot.readStructBegin();
      while (true)
      {
        field = iprot.readFieldBegin();
        if (field.type == TType.STOP) { 
          break;
        }
        _Fields fieldId = _Fields.findByThriftId(field.id);
        if (fieldId == null) {
          TProtocolUtil.skip(iprot, field.type);
        } else {
          switch (fieldId) {
            case SUCCESS:
              if (field.type == TType.LIST) {
                {
                  TList _list87 = iprot.readListBegin();
                  this.success = new ArrayList<com.evernote.edam.type.Tag>(_list87.size);
                  for (int _i88 = 0; _i88 < _list87.size; ++_i88)
                  {
                    com.evernote.edam.type.Tag _elem89;
                    _elem89 = new com.evernote.edam.type.Tag();
                    _elem89.read(iprot);
                    this.success.add(_elem89);
                  }
                  iprot.readListEnd();
                }
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
            case USER_EXCEPTION:
              if (field.type == TType.STRUCT) {
                this.userException = new com.evernote.edam.error.EDAMUserException();
                this.userException.read(iprot);
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
            case SYSTEM_EXCEPTION:
              if (field.type == TType.STRUCT) {
                this.systemException = new com.evernote.edam.error.EDAMSystemException();
                this.systemException.read(iprot);
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
            case NOT_FOUND_EXCEPTION:
              if (field.type == TType.STRUCT) {
                this.notFoundException = new com.evernote.edam.error.EDAMNotFoundException();
                this.notFoundException.read(iprot);
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
          }
          iprot.readFieldEnd();
        }
      }
      iprot.readStructEnd();
      validate();
    }

    public void write(TProtocol oprot) throws TException {
      oprot.writeStructBegin(STRUCT_DESC);

      if (this.isSetSuccess()) {
        oprot.writeFieldBegin(SUCCESS_FIELD_DESC);
        {
          oprot.writeListBegin(new TList(TType.STRUCT, this.success.size()));
          for (com.evernote.edam.type.Tag _iter90 : this.success)
          {
            _iter90.write(oprot);
          }
          oprot.writeListEnd();
        }
        oprot.writeFieldEnd();
      } else if (this.isSetUserException()) {
        oprot.writeFieldBegin(USER_EXCEPTION_FIELD_DESC);
        this.userException.write(oprot);
        oprot.writeFieldEnd();
      } else if (this.isSetSystemException()) {
        oprot.writeFieldBegin(SYSTEM_EXCEPTION_FIELD_DESC);
        this.systemException.write(oprot);
        oprot.writeFieldEnd();
      } else if (this.isSetNotFoundException()) {
        oprot.writeFieldBegin(NOT_FOUND_EXCEPTION_FIELD_DESC);
        this.notFoundException.write(oprot);
        oprot.writeFieldEnd();
      }
      oprot.writeFieldStop();
      oprot.writeStructEnd();
    }

    public String toString() {
      StringBuilder sb = new StringBuilder("listTagsByNotebook_result(");
      boolean first = true;

      sb.append("success:");
      if (this.success == null) {
        sb.append("null");
      } else {
        sb.append(this.success);
      }
      first = false;
      if (!first) sb.append(", ");
      sb.append("userException:");
      if (this.userException == null) {
        sb.append("null");
      } else {
        sb.append(this.userException);
      }
      first = false;
      if (!first) sb.append(", ");
      sb.append("systemException:");
      if (this.systemException == null) {
        sb.append("null");
      } else {
        sb.append(this.systemException);
      }
      first = false;
      if (!first) sb.append(", ");
      sb.append("notFoundException:");
      if (this.notFoundException == null) {
        sb.append("null");
      } else {
        sb.append(this.notFoundException);
      }
      first = false;
      sb.append(")");
      return sb.toString();
    }

    public void validate() throws TException {
      // check for required fields
    }

  }

  public static class getTag_args implements TBase<getTag_args._Fields>, java.io.Serializable, Cloneable, Comparable<getTag_args>   {
    private static final TStruct STRUCT_DESC = new TStruct("getTag_args");

    private static final TField AUTHENTICATION_TOKEN_FIELD_DESC = new TField("authenticationToken", TType.STRING, (short)1);
    private static final TField GUID_FIELD_DESC = new TField("guid", TType.STRING, (short)2);

    private String authenticationToken;
    private String guid;

    /** The set of fields this struct contains, along with convenience methods for finding and manipulating them. */
    public enum _Fields implements TFieldIdEnum {
      AUTHENTICATION_TOKEN((short)1, "authenticationToken"),
      GUID((short)2, "guid");

      private static final Map<Integer, _Fields> byId = new HashMap<Integer, _Fields>();
      private static final Map<String, _Fields> byName = new HashMap<String, _Fields>();

      static {
        for (_Fields field : EnumSet.allOf(_Fields.class)) {
          byId.put((int)field._thriftId, field);
          byName.put(field.getFieldName(), field);
        }
      }

      /**
       * Find the _Fields constant that matches fieldId, or null if its not found.
       */
      public static _Fields findByThriftId(int fieldId) {
        return byId.get(fieldId);
      }

      /**
       * Find the _Fields constant that matches fieldId, throwing an exception
       * if it is not found.
       */
      public static _Fields findByThriftIdOrThrow(int fieldId) {
        _Fields fields = findByThriftId(fieldId);
        if (fields == null) throw new IllegalArgumentException("Field " + fieldId + " doesn't exist!");
        return fields;
      }

      /**
       * Find the _Fields constant that matches name, or null if its not found.
       */
      public static _Fields findByName(String name) {
        return byName.get(name);
      }

      private final short _thriftId;
      private final String _fieldName;

      _Fields(short thriftId, String fieldName) {
        _thriftId = thriftId;
        _fieldName = fieldName;
      }

      public short getThriftFieldId() {
        return _thriftId;
      }

      public String getFieldName() {
        return _fieldName;
      }
    }

    // isset id assignments

    public static final Map<_Fields, FieldMetaData> metaDataMap = Collections.unmodifiableMap(new EnumMap<_Fields, FieldMetaData>(_Fields.class) {{
      put(_Fields.AUTHENTICATION_TOKEN, new FieldMetaData("authenticationToken", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.STRING)));
      put(_Fields.GUID, new FieldMetaData("guid", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.STRING)));
    }});

    static {
      FieldMetaData.addStructMetaDataMap(getTag_args.class, metaDataMap);
    }

    public getTag_args() {
    }

    public getTag_args(
      String authenticationToken,
      String guid)
    {
      this();
      this.authenticationToken = authenticationToken;
      this.guid = guid;
    }

    /**
     * Performs a deep copy on <i>other</i>.
     */
    public getTag_args(getTag_args other) {
      if (other.isSetAuthenticationToken()) {
        this.authenticationToken = other.authenticationToken;
      }
      if (other.isSetGuid()) {
        this.guid = other.guid;
      }
    }

    public getTag_args deepCopy() {
      return new getTag_args(this);
    }

    @Deprecated
    public getTag_args clone() {
      return new getTag_args(this);
    }

    public String getAuthenticationToken() {
      return this.authenticationToken;
    }

    public void setAuthenticationToken(String authenticationToken) {
      this.authenticationToken = authenticationToken;
    }

    public void unsetAuthenticationToken() {
      this.authenticationToken = null;
    }

    /** Returns true if field authenticationToken is set (has been asigned a value) and false otherwise */
    public boolean isSetAuthenticationToken() {
      return this.authenticationToken != null;
    }

    public void setAuthenticationTokenIsSet(boolean value) {
      if (!value) {
        this.authenticationToken = null;
      }
    }

    public String getGuid() {
      return this.guid;
    }

    public void setGuid(String guid) {
      this.guid = guid;
    }

    public void unsetGuid() {
      this.guid = null;
    }

    /** Returns true if field guid is set (has been asigned a value) and false otherwise */
    public boolean isSetGuid() {
      return this.guid != null;
    }

    public void setGuidIsSet(boolean value) {
      if (!value) {
        this.guid = null;
      }
    }

    public void setFieldValue(_Fields field, Object value) {
      switch (field) {
      case AUTHENTICATION_TOKEN:
        if (value == null) {
          unsetAuthenticationToken();
        } else {
          setAuthenticationToken((String)value);
        }
        break;

      case GUID:
        if (value == null) {
          unsetGuid();
        } else {
          setGuid((String)value);
        }
        break;

      }
    }

    public void setFieldValue(int fieldID, Object value) {
      setFieldValue(_Fields.findByThriftIdOrThrow(fieldID), value);
    }

    public Object getFieldValue(_Fields field) {
      switch (field) {
      case AUTHENTICATION_TOKEN:
        return getAuthenticationToken();

      case GUID:
        return getGuid();

      }
      throw new IllegalStateException();
    }

    public Object getFieldValue(int fieldId) {
      return getFieldValue(_Fields.findByThriftIdOrThrow(fieldId));
    }

    /** Returns true if field corresponding to fieldID is set (has been asigned a value) and false otherwise */
    public boolean isSet(_Fields field) {
      switch (field) {
      case AUTHENTICATION_TOKEN:
        return isSetAuthenticationToken();
      case GUID:
        return isSetGuid();
      }
      throw new IllegalStateException();
    }

    public boolean isSet(int fieldID) {
      return isSet(_Fields.findByThriftIdOrThrow(fieldID));
    }

    public boolean equals(Object that) {
      if (that == null)
        return false;
      if (that instanceof getTag_args)
        return this.equals((getTag_args)that);
      return false;
    }

    public boolean equals(getTag_args that) {
      if (that == null)
        return false;

      boolean this_present_authenticationToken = true && this.isSetAuthenticationToken();
      boolean that_present_authenticationToken = true && that.isSetAuthenticationToken();
      if (this_present_authenticationToken || that_present_authenticationToken) {
        if (!(this_present_authenticationToken && that_present_authenticationToken))
          return false;
        if (!this.authenticationToken.equals(that.authenticationToken))
          return false;
      }

      boolean this_present_guid = true && this.isSetGuid();
      boolean that_present_guid = true && that.isSetGuid();
      if (this_present_guid || that_present_guid) {
        if (!(this_present_guid && that_present_guid))
          return false;
        if (!this.guid.equals(that.guid))
          return false;
      }

      return true;
    }

    public int hashCode() {
      return 0;
    }

    public int compareTo(getTag_args other) {
      if (!getClass().equals(other.getClass())) {
        return getClass().getName().compareTo(other.getClass().getName());
      }

      int lastComparison = 0;
      getTag_args typedOther = (getTag_args)other;

      lastComparison = Boolean.valueOf(isSetAuthenticationToken()).compareTo(isSetAuthenticationToken());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(authenticationToken, typedOther.authenticationToken);
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = Boolean.valueOf(isSetGuid()).compareTo(isSetGuid());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(guid, typedOther.guid);
      if (lastComparison != 0) {
        return lastComparison;
      }
      return 0;
    }

    public void read(TProtocol iprot) throws TException {
      TField field;
      iprot.readStructBegin();
      while (true)
      {
        field = iprot.readFieldBegin();
        if (field.type == TType.STOP) { 
          break;
        }
        _Fields fieldId = _Fields.findByThriftId(field.id);
        if (fieldId == null) {
          TProtocolUtil.skip(iprot, field.type);
        } else {
          switch (fieldId) {
            case AUTHENTICATION_TOKEN:
              if (field.type == TType.STRING) {
                this.authenticationToken = iprot.readString();
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
            case GUID:
              if (field.type == TType.STRING) {
                this.guid = iprot.readString();
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
          }
          iprot.readFieldEnd();
        }
      }
      iprot.readStructEnd();
      validate();
    }

    public void write(TProtocol oprot) throws TException {
      validate();

      oprot.writeStructBegin(STRUCT_DESC);
      if (this.authenticationToken != null) {
        oprot.writeFieldBegin(AUTHENTICATION_TOKEN_FIELD_DESC);
        oprot.writeString(this.authenticationToken);
        oprot.writeFieldEnd();
      }
      if (this.guid != null) {
        oprot.writeFieldBegin(GUID_FIELD_DESC);
        oprot.writeString(this.guid);
        oprot.writeFieldEnd();
      }
      oprot.writeFieldStop();
      oprot.writeStructEnd();
    }

    public String toString() {
      StringBuilder sb = new StringBuilder("getTag_args(");
      boolean first = true;

      sb.append("authenticationToken:");
      if (this.authenticationToken == null) {
        sb.append("null");
      } else {
        sb.append(this.authenticationToken);
      }
      first = false;
      if (!first) sb.append(", ");
      sb.append("guid:");
      if (this.guid == null) {
        sb.append("null");
      } else {
        sb.append(this.guid);
      }
      first = false;
      sb.append(")");
      return sb.toString();
    }

    public void validate() throws TException {
      // check for required fields
    }

  }

  public static class getTag_result implements TBase<getTag_result._Fields>, java.io.Serializable, Cloneable, Comparable<getTag_result>   {
    private static final TStruct STRUCT_DESC = new TStruct("getTag_result");

    private static final TField SUCCESS_FIELD_DESC = new TField("success", TType.STRUCT, (short)0);
    private static final TField USER_EXCEPTION_FIELD_DESC = new TField("userException", TType.STRUCT, (short)1);
    private static final TField SYSTEM_EXCEPTION_FIELD_DESC = new TField("systemException", TType.STRUCT, (short)2);
    private static final TField NOT_FOUND_EXCEPTION_FIELD_DESC = new TField("notFoundException", TType.STRUCT, (short)3);

    private com.evernote.edam.type.Tag success;
    private com.evernote.edam.error.EDAMUserException userException;
    private com.evernote.edam.error.EDAMSystemException systemException;
    private com.evernote.edam.error.EDAMNotFoundException notFoundException;

    /** The set of fields this struct contains, along with convenience methods for finding and manipulating them. */
    public enum _Fields implements TFieldIdEnum {
      SUCCESS((short)0, "success"),
      USER_EXCEPTION((short)1, "userException"),
      SYSTEM_EXCEPTION((short)2, "systemException"),
      NOT_FOUND_EXCEPTION((short)3, "notFoundException");

      private static final Map<Integer, _Fields> byId = new HashMap<Integer, _Fields>();
      private static final Map<String, _Fields> byName = new HashMap<String, _Fields>();

      static {
        for (_Fields field : EnumSet.allOf(_Fields.class)) {
          byId.put((int)field._thriftId, field);
          byName.put(field.getFieldName(), field);
        }
      }

      /**
       * Find the _Fields constant that matches fieldId, or null if its not found.
       */
      public static _Fields findByThriftId(int fieldId) {
        return byId.get(fieldId);
      }

      /**
       * Find the _Fields constant that matches fieldId, throwing an exception
       * if it is not found.
       */
      public static _Fields findByThriftIdOrThrow(int fieldId) {
        _Fields fields = findByThriftId(fieldId);
        if (fields == null) throw new IllegalArgumentException("Field " + fieldId + " doesn't exist!");
        return fields;
      }

      /**
       * Find the _Fields constant that matches name, or null if its not found.
       */
      public static _Fields findByName(String name) {
        return byName.get(name);
      }

      private final short _thriftId;
      private final String _fieldName;

      _Fields(short thriftId, String fieldName) {
        _thriftId = thriftId;
        _fieldName = fieldName;
      }

      public short getThriftFieldId() {
        return _thriftId;
      }

      public String getFieldName() {
        return _fieldName;
      }
    }

    // isset id assignments

    public static final Map<_Fields, FieldMetaData> metaDataMap = Collections.unmodifiableMap(new EnumMap<_Fields, FieldMetaData>(_Fields.class) {{
      put(_Fields.SUCCESS, new FieldMetaData("success", TFieldRequirementType.DEFAULT, 
          new StructMetaData(TType.STRUCT, com.evernote.edam.type.Tag.class)));
      put(_Fields.USER_EXCEPTION, new FieldMetaData("userException", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.STRUCT)));
      put(_Fields.SYSTEM_EXCEPTION, new FieldMetaData("systemException", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.STRUCT)));
      put(_Fields.NOT_FOUND_EXCEPTION, new FieldMetaData("notFoundException", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.STRUCT)));
    }});

    static {
      FieldMetaData.addStructMetaDataMap(getTag_result.class, metaDataMap);
    }

    public getTag_result() {
    }

    public getTag_result(
      com.evernote.edam.type.Tag success,
      com.evernote.edam.error.EDAMUserException userException,
      com.evernote.edam.error.EDAMSystemException systemException,
      com.evernote.edam.error.EDAMNotFoundException notFoundException)
    {
      this();
      this.success = success;
      this.userException = userException;
      this.systemException = systemException;
      this.notFoundException = notFoundException;
    }

    /**
     * Performs a deep copy on <i>other</i>.
     */
    public getTag_result(getTag_result other) {
      if (other.isSetSuccess()) {
        this.success = new com.evernote.edam.type.Tag(other.success);
      }
      if (other.isSetUserException()) {
        this.userException = new com.evernote.edam.error.EDAMUserException(other.userException);
      }
      if (other.isSetSystemException()) {
        this.systemException = new com.evernote.edam.error.EDAMSystemException(other.systemException);
      }
      if (other.isSetNotFoundException()) {
        this.notFoundException = new com.evernote.edam.error.EDAMNotFoundException(other.notFoundException);
      }
    }

    public getTag_result deepCopy() {
      return new getTag_result(this);
    }

    @Deprecated
    public getTag_result clone() {
      return new getTag_result(this);
    }

    public com.evernote.edam.type.Tag getSuccess() {
      return this.success;
    }

    public void setSuccess(com.evernote.edam.type.Tag success) {
      this.success = success;
    }

    public void unsetSuccess() {
      this.success = null;
    }

    /** Returns true if field success is set (has been asigned a value) and false otherwise */
    public boolean isSetSuccess() {
      return this.success != null;
    }

    public void setSuccessIsSet(boolean value) {
      if (!value) {
        this.success = null;
      }
    }

    public com.evernote.edam.error.EDAMUserException getUserException() {
      return this.userException;
    }

    public void setUserException(com.evernote.edam.error.EDAMUserException userException) {
      this.userException = userException;
    }

    public void unsetUserException() {
      this.userException = null;
    }

    /** Returns true if field userException is set (has been asigned a value) and false otherwise */
    public boolean isSetUserException() {
      return this.userException != null;
    }

    public void setUserExceptionIsSet(boolean value) {
      if (!value) {
        this.userException = null;
      }
    }

    public com.evernote.edam.error.EDAMSystemException getSystemException() {
      return this.systemException;
    }

    public void setSystemException(com.evernote.edam.error.EDAMSystemException systemException) {
      this.systemException = systemException;
    }

    public void unsetSystemException() {
      this.systemException = null;
    }

    /** Returns true if field systemException is set (has been asigned a value) and false otherwise */
    public boolean isSetSystemException() {
      return this.systemException != null;
    }

    public void setSystemExceptionIsSet(boolean value) {
      if (!value) {
        this.systemException = null;
      }
    }

    public com.evernote.edam.error.EDAMNotFoundException getNotFoundException() {
      return this.notFoundException;
    }

    public void setNotFoundException(com.evernote.edam.error.EDAMNotFoundException notFoundException) {
      this.notFoundException = notFoundException;
    }

    public void unsetNotFoundException() {
      this.notFoundException = null;
    }

    /** Returns true if field notFoundException is set (has been asigned a value) and false otherwise */
    public boolean isSetNotFoundException() {
      return this.notFoundException != null;
    }

    public void setNotFoundExceptionIsSet(boolean value) {
      if (!value) {
        this.notFoundException = null;
      }
    }

    public void setFieldValue(_Fields field, Object value) {
      switch (field) {
      case SUCCESS:
        if (value == null) {
          unsetSuccess();
        } else {
          setSuccess((com.evernote.edam.type.Tag)value);
        }
        break;

      case USER_EXCEPTION:
        if (value == null) {
          unsetUserException();
        } else {
          setUserException((com.evernote.edam.error.EDAMUserException)value);
        }
        break;

      case SYSTEM_EXCEPTION:
        if (value == null) {
          unsetSystemException();
        } else {
          setSystemException((com.evernote.edam.error.EDAMSystemException)value);
        }
        break;

      case NOT_FOUND_EXCEPTION:
        if (value == null) {
          unsetNotFoundException();
        } else {
          setNotFoundException((com.evernote.edam.error.EDAMNotFoundException)value);
        }
        break;

      }
    }

    public void setFieldValue(int fieldID, Object value) {
      setFieldValue(_Fields.findByThriftIdOrThrow(fieldID), value);
    }

    public Object getFieldValue(_Fields field) {
      switch (field) {
      case SUCCESS:
        return getSuccess();

      case USER_EXCEPTION:
        return getUserException();

      case SYSTEM_EXCEPTION:
        return getSystemException();

      case NOT_FOUND_EXCEPTION:
        return getNotFoundException();

      }
      throw new IllegalStateException();
    }

    public Object getFieldValue(int fieldId) {
      return getFieldValue(_Fields.findByThriftIdOrThrow(fieldId));
    }

    /** Returns true if field corresponding to fieldID is set (has been asigned a value) and false otherwise */
    public boolean isSet(_Fields field) {
      switch (field) {
      case SUCCESS:
        return isSetSuccess();
      case USER_EXCEPTION:
        return isSetUserException();
      case SYSTEM_EXCEPTION:
        return isSetSystemException();
      case NOT_FOUND_EXCEPTION:
        return isSetNotFoundException();
      }
      throw new IllegalStateException();
    }

    public boolean isSet(int fieldID) {
      return isSet(_Fields.findByThriftIdOrThrow(fieldID));
    }

    public boolean equals(Object that) {
      if (that == null)
        return false;
      if (that instanceof getTag_result)
        return this.equals((getTag_result)that);
      return false;
    }

    public boolean equals(getTag_result that) {
      if (that == null)
        return false;

      boolean this_present_success = true && this.isSetSuccess();
      boolean that_present_success = true && that.isSetSuccess();
      if (this_present_success || that_present_success) {
        if (!(this_present_success && that_present_success))
          return false;
        if (!this.success.equals(that.success))
          return false;
      }

      boolean this_present_userException = true && this.isSetUserException();
      boolean that_present_userException = true && that.isSetUserException();
      if (this_present_userException || that_present_userException) {
        if (!(this_present_userException && that_present_userException))
          return false;
        if (!this.userException.equals(that.userException))
          return false;
      }

      boolean this_present_systemException = true && this.isSetSystemException();
      boolean that_present_systemException = true && that.isSetSystemException();
      if (this_present_systemException || that_present_systemException) {
        if (!(this_present_systemException && that_present_systemException))
          return false;
        if (!this.systemException.equals(that.systemException))
          return false;
      }

      boolean this_present_notFoundException = true && this.isSetNotFoundException();
      boolean that_present_notFoundException = true && that.isSetNotFoundException();
      if (this_present_notFoundException || that_present_notFoundException) {
        if (!(this_present_notFoundException && that_present_notFoundException))
          return false;
        if (!this.notFoundException.equals(that.notFoundException))
          return false;
      }

      return true;
    }

    public int hashCode() {
      return 0;
    }

    public int compareTo(getTag_result other) {
      if (!getClass().equals(other.getClass())) {
        return getClass().getName().compareTo(other.getClass().getName());
      }

      int lastComparison = 0;
      getTag_result typedOther = (getTag_result)other;

      lastComparison = Boolean.valueOf(isSetSuccess()).compareTo(isSetSuccess());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(success, typedOther.success);
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = Boolean.valueOf(isSetUserException()).compareTo(isSetUserException());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(userException, typedOther.userException);
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = Boolean.valueOf(isSetSystemException()).compareTo(isSetSystemException());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(systemException, typedOther.systemException);
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = Boolean.valueOf(isSetNotFoundException()).compareTo(isSetNotFoundException());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(notFoundException, typedOther.notFoundException);
      if (lastComparison != 0) {
        return lastComparison;
      }
      return 0;
    }

    public void read(TProtocol iprot) throws TException {
      TField field;
      iprot.readStructBegin();
      while (true)
      {
        field = iprot.readFieldBegin();
        if (field.type == TType.STOP) { 
          break;
        }
        _Fields fieldId = _Fields.findByThriftId(field.id);
        if (fieldId == null) {
          TProtocolUtil.skip(iprot, field.type);
        } else {
          switch (fieldId) {
            case SUCCESS:
              if (field.type == TType.STRUCT) {
                this.success = new com.evernote.edam.type.Tag();
                this.success.read(iprot);
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
            case USER_EXCEPTION:
              if (field.type == TType.STRUCT) {
                this.userException = new com.evernote.edam.error.EDAMUserException();
                this.userException.read(iprot);
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
            case SYSTEM_EXCEPTION:
              if (field.type == TType.STRUCT) {
                this.systemException = new com.evernote.edam.error.EDAMSystemException();
                this.systemException.read(iprot);
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
            case NOT_FOUND_EXCEPTION:
              if (field.type == TType.STRUCT) {
                this.notFoundException = new com.evernote.edam.error.EDAMNotFoundException();
                this.notFoundException.read(iprot);
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
          }
          iprot.readFieldEnd();
        }
      }
      iprot.readStructEnd();
      validate();
    }

    public void write(TProtocol oprot) throws TException {
      oprot.writeStructBegin(STRUCT_DESC);

      if (this.isSetSuccess()) {
        oprot.writeFieldBegin(SUCCESS_FIELD_DESC);
        this.success.write(oprot);
        oprot.writeFieldEnd();
      } else if (this.isSetUserException()) {
        oprot.writeFieldBegin(USER_EXCEPTION_FIELD_DESC);
        this.userException.write(oprot);
        oprot.writeFieldEnd();
      } else if (this.isSetSystemException()) {
        oprot.writeFieldBegin(SYSTEM_EXCEPTION_FIELD_DESC);
        this.systemException.write(oprot);
        oprot.writeFieldEnd();
      } else if (this.isSetNotFoundException()) {
        oprot.writeFieldBegin(NOT_FOUND_EXCEPTION_FIELD_DESC);
        this.notFoundException.write(oprot);
        oprot.writeFieldEnd();
      }
      oprot.writeFieldStop();
      oprot.writeStructEnd();
    }

    public String toString() {
      StringBuilder sb = new StringBuilder("getTag_result(");
      boolean first = true;

      sb.append("success:");
      if (this.success == null) {
        sb.append("null");
      } else {
        sb.append(this.success);
      }
      first = false;
      if (!first) sb.append(", ");
      sb.append("userException:");
      if (this.userException == null) {
        sb.append("null");
      } else {
        sb.append(this.userException);
      }
      first = false;
      if (!first) sb.append(", ");
      sb.append("systemException:");
      if (this.systemException == null) {
        sb.append("null");
      } else {
        sb.append(this.systemException);
      }
      first = false;
      if (!first) sb.append(", ");
      sb.append("notFoundException:");
      if (this.notFoundException == null) {
        sb.append("null");
      } else {
        sb.append(this.notFoundException);
      }
      first = false;
      sb.append(")");
      return sb.toString();
    }

    public void validate() throws TException {
      // check for required fields
    }

  }

  public static class createTag_args implements TBase<createTag_args._Fields>, java.io.Serializable, Cloneable, Comparable<createTag_args>   {
    private static final TStruct STRUCT_DESC = new TStruct("createTag_args");

    private static final TField AUTHENTICATION_TOKEN_FIELD_DESC = new TField("authenticationToken", TType.STRING, (short)1);
    private static final TField TAG_FIELD_DESC = new TField("tag", TType.STRUCT, (short)2);

    private String authenticationToken;
    private com.evernote.edam.type.Tag tag;

    /** The set of fields this struct contains, along with convenience methods for finding and manipulating them. */
    public enum _Fields implements TFieldIdEnum {
      AUTHENTICATION_TOKEN((short)1, "authenticationToken"),
      TAG((short)2, "tag");

      private static final Map<Integer, _Fields> byId = new HashMap<Integer, _Fields>();
      private static final Map<String, _Fields> byName = new HashMap<String, _Fields>();

      static {
        for (_Fields field : EnumSet.allOf(_Fields.class)) {
          byId.put((int)field._thriftId, field);
          byName.put(field.getFieldName(), field);
        }
      }

      /**
       * Find the _Fields constant that matches fieldId, or null if its not found.
       */
      public static _Fields findByThriftId(int fieldId) {
        return byId.get(fieldId);
      }

      /**
       * Find the _Fields constant that matches fieldId, throwing an exception
       * if it is not found.
       */
      public static _Fields findByThriftIdOrThrow(int fieldId) {
        _Fields fields = findByThriftId(fieldId);
        if (fields == null) throw new IllegalArgumentException("Field " + fieldId + " doesn't exist!");
        return fields;
      }

      /**
       * Find the _Fields constant that matches name, or null if its not found.
       */
      public static _Fields findByName(String name) {
        return byName.get(name);
      }

      private final short _thriftId;
      private final String _fieldName;

      _Fields(short thriftId, String fieldName) {
        _thriftId = thriftId;
        _fieldName = fieldName;
      }

      public short getThriftFieldId() {
        return _thriftId;
      }

      public String getFieldName() {
        return _fieldName;
      }
    }

    // isset id assignments

    public static final Map<_Fields, FieldMetaData> metaDataMap = Collections.unmodifiableMap(new EnumMap<_Fields, FieldMetaData>(_Fields.class) {{
      put(_Fields.AUTHENTICATION_TOKEN, new FieldMetaData("authenticationToken", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.STRING)));
      put(_Fields.TAG, new FieldMetaData("tag", TFieldRequirementType.DEFAULT, 
          new StructMetaData(TType.STRUCT, com.evernote.edam.type.Tag.class)));
    }});

    static {
      FieldMetaData.addStructMetaDataMap(createTag_args.class, metaDataMap);
    }

    public createTag_args() {
    }

    public createTag_args(
      String authenticationToken,
      com.evernote.edam.type.Tag tag)
    {
      this();
      this.authenticationToken = authenticationToken;
      this.tag = tag;
    }

    /**
     * Performs a deep copy on <i>other</i>.
     */
    public createTag_args(createTag_args other) {
      if (other.isSetAuthenticationToken()) {
        this.authenticationToken = other.authenticationToken;
      }
      if (other.isSetTag()) {
        this.tag = new com.evernote.edam.type.Tag(other.tag);
      }
    }

    public createTag_args deepCopy() {
      return new createTag_args(this);
    }

    @Deprecated
    public createTag_args clone() {
      return new createTag_args(this);
    }

    public String getAuthenticationToken() {
      return this.authenticationToken;
    }

    public void setAuthenticationToken(String authenticationToken) {
      this.authenticationToken = authenticationToken;
    }

    public void unsetAuthenticationToken() {
      this.authenticationToken = null;
    }

    /** Returns true if field authenticationToken is set (has been asigned a value) and false otherwise */
    public boolean isSetAuthenticationToken() {
      return this.authenticationToken != null;
    }

    public void setAuthenticationTokenIsSet(boolean value) {
      if (!value) {
        this.authenticationToken = null;
      }
    }

    public com.evernote.edam.type.Tag getTag() {
      return this.tag;
    }

    public void setTag(com.evernote.edam.type.Tag tag) {
      this.tag = tag;
    }

    public void unsetTag() {
      this.tag = null;
    }

    /** Returns true if field tag is set (has been asigned a value) and false otherwise */
    public boolean isSetTag() {
      return this.tag != null;
    }

    public void setTagIsSet(boolean value) {
      if (!value) {
        this.tag = null;
      }
    }

    public void setFieldValue(_Fields field, Object value) {
      switch (field) {
      case AUTHENTICATION_TOKEN:
        if (value == null) {
          unsetAuthenticationToken();
        } else {
          setAuthenticationToken((String)value);
        }
        break;

      case TAG:
        if (value == null) {
          unsetTag();
        } else {
          setTag((com.evernote.edam.type.Tag)value);
        }
        break;

      }
    }

    public void setFieldValue(int fieldID, Object value) {
      setFieldValue(_Fields.findByThriftIdOrThrow(fieldID), value);
    }

    public Object getFieldValue(_Fields field) {
      switch (field) {
      case AUTHENTICATION_TOKEN:
        return getAuthenticationToken();

      case TAG:
        return getTag();

      }
      throw new IllegalStateException();
    }

    public Object getFieldValue(int fieldId) {
      return getFieldValue(_Fields.findByThriftIdOrThrow(fieldId));
    }

    /** Returns true if field corresponding to fieldID is set (has been asigned a value) and false otherwise */
    public boolean isSet(_Fields field) {
      switch (field) {
      case AUTHENTICATION_TOKEN:
        return isSetAuthenticationToken();
      case TAG:
        return isSetTag();
      }
      throw new IllegalStateException();
    }

    public boolean isSet(int fieldID) {
      return isSet(_Fields.findByThriftIdOrThrow(fieldID));
    }

    public boolean equals(Object that) {
      if (that == null)
        return false;
      if (that instanceof createTag_args)
        return this.equals((createTag_args)that);
      return false;
    }

    public boolean equals(createTag_args that) {
      if (that == null)
        return false;

      boolean this_present_authenticationToken = true && this.isSetAuthenticationToken();
      boolean that_present_authenticationToken = true && that.isSetAuthenticationToken();
      if (this_present_authenticationToken || that_present_authenticationToken) {
        if (!(this_present_authenticationToken && that_present_authenticationToken))
          return false;
        if (!this.authenticationToken.equals(that.authenticationToken))
          return false;
      }

      boolean this_present_tag = true && this.isSetTag();
      boolean that_present_tag = true && that.isSetTag();
      if (this_present_tag || that_present_tag) {
        if (!(this_present_tag && that_present_tag))
          return false;
        if (!this.tag.equals(that.tag))
          return false;
      }

      return true;
    }

    public int hashCode() {
      return 0;
    }

    public int compareTo(createTag_args other) {
      if (!getClass().equals(other.getClass())) {
        return getClass().getName().compareTo(other.getClass().getName());
      }

      int lastComparison = 0;
      createTag_args typedOther = (createTag_args)other;

      lastComparison = Boolean.valueOf(isSetAuthenticationToken()).compareTo(isSetAuthenticationToken());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(authenticationToken, typedOther.authenticationToken);
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = Boolean.valueOf(isSetTag()).compareTo(isSetTag());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(tag, typedOther.tag);
      if (lastComparison != 0) {
        return lastComparison;
      }
      return 0;
    }

    public void read(TProtocol iprot) throws TException {
      TField field;
      iprot.readStructBegin();
      while (true)
      {
        field = iprot.readFieldBegin();
        if (field.type == TType.STOP) { 
          break;
        }
        _Fields fieldId = _Fields.findByThriftId(field.id);
        if (fieldId == null) {
          TProtocolUtil.skip(iprot, field.type);
        } else {
          switch (fieldId) {
            case AUTHENTICATION_TOKEN:
              if (field.type == TType.STRING) {
                this.authenticationToken = iprot.readString();
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
            case TAG:
              if (field.type == TType.STRUCT) {
                this.tag = new com.evernote.edam.type.Tag();
                this.tag.read(iprot);
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
          }
          iprot.readFieldEnd();
        }
      }
      iprot.readStructEnd();
      validate();
    }

    public void write(TProtocol oprot) throws TException {
      validate();

      oprot.writeStructBegin(STRUCT_DESC);
      if (this.authenticationToken != null) {
        oprot.writeFieldBegin(AUTHENTICATION_TOKEN_FIELD_DESC);
        oprot.writeString(this.authenticationToken);
        oprot.writeFieldEnd();
      }
      if (this.tag != null) {
        oprot.writeFieldBegin(TAG_FIELD_DESC);
        this.tag.write(oprot);
        oprot.writeFieldEnd();
      }
      oprot.writeFieldStop();
      oprot.writeStructEnd();
    }

    public String toString() {
      StringBuilder sb = new StringBuilder("createTag_args(");
      boolean first = true;

      sb.append("authenticationToken:");
      if (this.authenticationToken == null) {
        sb.append("null");
      } else {
        sb.append(this.authenticationToken);
      }
      first = false;
      if (!first) sb.append(", ");
      sb.append("tag:");
      if (this.tag == null) {
        sb.append("null");
      } else {
        sb.append(this.tag);
      }
      first = false;
      sb.append(")");
      return sb.toString();
    }

    public void validate() throws TException {
      // check for required fields
    }

  }

  public static class createTag_result implements TBase<createTag_result._Fields>, java.io.Serializable, Cloneable, Comparable<createTag_result>   {
    private static final TStruct STRUCT_DESC = new TStruct("createTag_result");

    private static final TField SUCCESS_FIELD_DESC = new TField("success", TType.STRUCT, (short)0);
    private static final TField USER_EXCEPTION_FIELD_DESC = new TField("userException", TType.STRUCT, (short)1);
    private static final TField SYSTEM_EXCEPTION_FIELD_DESC = new TField("systemException", TType.STRUCT, (short)2);
    private static final TField NOT_FOUND_EXCEPTION_FIELD_DESC = new TField("notFoundException", TType.STRUCT, (short)3);

    private com.evernote.edam.type.Tag success;
    private com.evernote.edam.error.EDAMUserException userException;
    private com.evernote.edam.error.EDAMSystemException systemException;
    private com.evernote.edam.error.EDAMNotFoundException notFoundException;

    /** The set of fields this struct contains, along with convenience methods for finding and manipulating them. */
    public enum _Fields implements TFieldIdEnum {
      SUCCESS((short)0, "success"),
      USER_EXCEPTION((short)1, "userException"),
      SYSTEM_EXCEPTION((short)2, "systemException"),
      NOT_FOUND_EXCEPTION((short)3, "notFoundException");

      private static final Map<Integer, _Fields> byId = new HashMap<Integer, _Fields>();
      private static final Map<String, _Fields> byName = new HashMap<String, _Fields>();

      static {
        for (_Fields field : EnumSet.allOf(_Fields.class)) {
          byId.put((int)field._thriftId, field);
          byName.put(field.getFieldName(), field);
        }
      }

      /**
       * Find the _Fields constant that matches fieldId, or null if its not found.
       */
      public static _Fields findByThriftId(int fieldId) {
        return byId.get(fieldId);
      }

      /**
       * Find the _Fields constant that matches fieldId, throwing an exception
       * if it is not found.
       */
      public static _Fields findByThriftIdOrThrow(int fieldId) {
        _Fields fields = findByThriftId(fieldId);
        if (fields == null) throw new IllegalArgumentException("Field " + fieldId + " doesn't exist!");
        return fields;
      }

      /**
       * Find the _Fields constant that matches name, or null if its not found.
       */
      public static _Fields findByName(String name) {
        return byName.get(name);
      }

      private final short _thriftId;
      private final String _fieldName;

      _Fields(short thriftId, String fieldName) {
        _thriftId = thriftId;
        _fieldName = fieldName;
      }

      public short getThriftFieldId() {
        return _thriftId;
      }

      public String getFieldName() {
        return _fieldName;
      }
    }

    // isset id assignments

    public static final Map<_Fields, FieldMetaData> metaDataMap = Collections.unmodifiableMap(new EnumMap<_Fields, FieldMetaData>(_Fields.class) {{
      put(_Fields.SUCCESS, new FieldMetaData("success", TFieldRequirementType.DEFAULT, 
          new StructMetaData(TType.STRUCT, com.evernote.edam.type.Tag.class)));
      put(_Fields.USER_EXCEPTION, new FieldMetaData("userException", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.STRUCT)));
      put(_Fields.SYSTEM_EXCEPTION, new FieldMetaData("systemException", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.STRUCT)));
      put(_Fields.NOT_FOUND_EXCEPTION, new FieldMetaData("notFoundException", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.STRUCT)));
    }});

    static {
      FieldMetaData.addStructMetaDataMap(createTag_result.class, metaDataMap);
    }

    public createTag_result() {
    }

    public createTag_result(
      com.evernote.edam.type.Tag success,
      com.evernote.edam.error.EDAMUserException userException,
      com.evernote.edam.error.EDAMSystemException systemException,
      com.evernote.edam.error.EDAMNotFoundException notFoundException)
    {
      this();
      this.success = success;
      this.userException = userException;
      this.systemException = systemException;
      this.notFoundException = notFoundException;
    }

    /**
     * Performs a deep copy on <i>other</i>.
     */
    public createTag_result(createTag_result other) {
      if (other.isSetSuccess()) {
        this.success = new com.evernote.edam.type.Tag(other.success);
      }
      if (other.isSetUserException()) {
        this.userException = new com.evernote.edam.error.EDAMUserException(other.userException);
      }
      if (other.isSetSystemException()) {
        this.systemException = new com.evernote.edam.error.EDAMSystemException(other.systemException);
      }
      if (other.isSetNotFoundException()) {
        this.notFoundException = new com.evernote.edam.error.EDAMNotFoundException(other.notFoundException);
      }
    }

    public createTag_result deepCopy() {
      return new createTag_result(this);
    }

    @Deprecated
    public createTag_result clone() {
      return new createTag_result(this);
    }

    public com.evernote.edam.type.Tag getSuccess() {
      return this.success;
    }

    public void setSuccess(com.evernote.edam.type.Tag success) {
      this.success = success;
    }

    public void unsetSuccess() {
      this.success = null;
    }

    /** Returns true if field success is set (has been asigned a value) and false otherwise */
    public boolean isSetSuccess() {
      return this.success != null;
    }

    public void setSuccessIsSet(boolean value) {
      if (!value) {
        this.success = null;
      }
    }

    public com.evernote.edam.error.EDAMUserException getUserException() {
      return this.userException;
    }

    public void setUserException(com.evernote.edam.error.EDAMUserException userException) {
      this.userException = userException;
    }

    public void unsetUserException() {
      this.userException = null;
    }

    /** Returns true if field userException is set (has been asigned a value) and false otherwise */
    public boolean isSetUserException() {
      return this.userException != null;
    }

    public void setUserExceptionIsSet(boolean value) {
      if (!value) {
        this.userException = null;
      }
    }

    public com.evernote.edam.error.EDAMSystemException getSystemException() {
      return this.systemException;
    }

    public void setSystemException(com.evernote.edam.error.EDAMSystemException systemException) {
      this.systemException = systemException;
    }

    public void unsetSystemException() {
      this.systemException = null;
    }

    /** Returns true if field systemException is set (has been asigned a value) and false otherwise */
    public boolean isSetSystemException() {
      return this.systemException != null;
    }

    public void setSystemExceptionIsSet(boolean value) {
      if (!value) {
        this.systemException = null;
      }
    }

    public com.evernote.edam.error.EDAMNotFoundException getNotFoundException() {
      return this.notFoundException;
    }

    public void setNotFoundException(com.evernote.edam.error.EDAMNotFoundException notFoundException) {
      this.notFoundException = notFoundException;
    }

    public void unsetNotFoundException() {
      this.notFoundException = null;
    }

    /** Returns true if field notFoundException is set (has been asigned a value) and false otherwise */
    public boolean isSetNotFoundException() {
      return this.notFoundException != null;
    }

    public void setNotFoundExceptionIsSet(boolean value) {
      if (!value) {
        this.notFoundException = null;
      }
    }

    public void setFieldValue(_Fields field, Object value) {
      switch (field) {
      case SUCCESS:
        if (value == null) {
          unsetSuccess();
        } else {
          setSuccess((com.evernote.edam.type.Tag)value);
        }
        break;

      case USER_EXCEPTION:
        if (value == null) {
          unsetUserException();
        } else {
          setUserException((com.evernote.edam.error.EDAMUserException)value);
        }
        break;

      case SYSTEM_EXCEPTION:
        if (value == null) {
          unsetSystemException();
        } else {
          setSystemException((com.evernote.edam.error.EDAMSystemException)value);
        }
        break;

      case NOT_FOUND_EXCEPTION:
        if (value == null) {
          unsetNotFoundException();
        } else {
          setNotFoundException((com.evernote.edam.error.EDAMNotFoundException)value);
        }
        break;

      }
    }

    public void setFieldValue(int fieldID, Object value) {
      setFieldValue(_Fields.findByThriftIdOrThrow(fieldID), value);
    }

    public Object getFieldValue(_Fields field) {
      switch (field) {
      case SUCCESS:
        return getSuccess();

      case USER_EXCEPTION:
        return getUserException();

      case SYSTEM_EXCEPTION:
        return getSystemException();

      case NOT_FOUND_EXCEPTION:
        return getNotFoundException();

      }
      throw new IllegalStateException();
    }

    public Object getFieldValue(int fieldId) {
      return getFieldValue(_Fields.findByThriftIdOrThrow(fieldId));
    }

    /** Returns true if field corresponding to fieldID is set (has been asigned a value) and false otherwise */
    public boolean isSet(_Fields field) {
      switch (field) {
      case SUCCESS:
        return isSetSuccess();
      case USER_EXCEPTION:
        return isSetUserException();
      case SYSTEM_EXCEPTION:
        return isSetSystemException();
      case NOT_FOUND_EXCEPTION:
        return isSetNotFoundException();
      }
      throw new IllegalStateException();
    }

    public boolean isSet(int fieldID) {
      return isSet(_Fields.findByThriftIdOrThrow(fieldID));
    }

    public boolean equals(Object that) {
      if (that == null)
        return false;
      if (that instanceof createTag_result)
        return this.equals((createTag_result)that);
      return false;
    }

    public boolean equals(createTag_result that) {
      if (that == null)
        return false;

      boolean this_present_success = true && this.isSetSuccess();
      boolean that_present_success = true && that.isSetSuccess();
      if (this_present_success || that_present_success) {
        if (!(this_present_success && that_present_success))
          return false;
        if (!this.success.equals(that.success))
          return false;
      }

      boolean this_present_userException = true && this.isSetUserException();
      boolean that_present_userException = true && that.isSetUserException();
      if (this_present_userException || that_present_userException) {
        if (!(this_present_userException && that_present_userException))
          return false;
        if (!this.userException.equals(that.userException))
          return false;
      }

      boolean this_present_systemException = true && this.isSetSystemException();
      boolean that_present_systemException = true && that.isSetSystemException();
      if (this_present_systemException || that_present_systemException) {
        if (!(this_present_systemException && that_present_systemException))
          return false;
        if (!this.systemException.equals(that.systemException))
          return false;
      }

      boolean this_present_notFoundException = true && this.isSetNotFoundException();
      boolean that_present_notFoundException = true && that.isSetNotFoundException();
      if (this_present_notFoundException || that_present_notFoundException) {
        if (!(this_present_notFoundException && that_present_notFoundException))
          return false;
        if (!this.notFoundException.equals(that.notFoundException))
          return false;
      }

      return true;
    }

    public int hashCode() {
      return 0;
    }

    public int compareTo(createTag_result other) {
      if (!getClass().equals(other.getClass())) {
        return getClass().getName().compareTo(other.getClass().getName());
      }

      int lastComparison = 0;
      createTag_result typedOther = (createTag_result)other;

      lastComparison = Boolean.valueOf(isSetSuccess()).compareTo(isSetSuccess());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(success, typedOther.success);
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = Boolean.valueOf(isSetUserException()).compareTo(isSetUserException());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(userException, typedOther.userException);
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = Boolean.valueOf(isSetSystemException()).compareTo(isSetSystemException());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(systemException, typedOther.systemException);
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = Boolean.valueOf(isSetNotFoundException()).compareTo(isSetNotFoundException());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(notFoundException, typedOther.notFoundException);
      if (lastComparison != 0) {
        return lastComparison;
      }
      return 0;
    }

    public void read(TProtocol iprot) throws TException {
      TField field;
      iprot.readStructBegin();
      while (true)
      {
        field = iprot.readFieldBegin();
        if (field.type == TType.STOP) { 
          break;
        }
        _Fields fieldId = _Fields.findByThriftId(field.id);
        if (fieldId == null) {
          TProtocolUtil.skip(iprot, field.type);
        } else {
          switch (fieldId) {
            case SUCCESS:
              if (field.type == TType.STRUCT) {
                this.success = new com.evernote.edam.type.Tag();
                this.success.read(iprot);
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
            case USER_EXCEPTION:
              if (field.type == TType.STRUCT) {
                this.userException = new com.evernote.edam.error.EDAMUserException();
                this.userException.read(iprot);
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
            case SYSTEM_EXCEPTION:
              if (field.type == TType.STRUCT) {
                this.systemException = new com.evernote.edam.error.EDAMSystemException();
                this.systemException.read(iprot);
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
            case NOT_FOUND_EXCEPTION:
              if (field.type == TType.STRUCT) {
                this.notFoundException = new com.evernote.edam.error.EDAMNotFoundException();
                this.notFoundException.read(iprot);
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
          }
          iprot.readFieldEnd();
        }
      }
      iprot.readStructEnd();
      validate();
    }

    public void write(TProtocol oprot) throws TException {
      oprot.writeStructBegin(STRUCT_DESC);

      if (this.isSetSuccess()) {
        oprot.writeFieldBegin(SUCCESS_FIELD_DESC);
        this.success.write(oprot);
        oprot.writeFieldEnd();
      } else if (this.isSetUserException()) {
        oprot.writeFieldBegin(USER_EXCEPTION_FIELD_DESC);
        this.userException.write(oprot);
        oprot.writeFieldEnd();
      } else if (this.isSetSystemException()) {
        oprot.writeFieldBegin(SYSTEM_EXCEPTION_FIELD_DESC);
        this.systemException.write(oprot);
        oprot.writeFieldEnd();
      } else if (this.isSetNotFoundException()) {
        oprot.writeFieldBegin(NOT_FOUND_EXCEPTION_FIELD_DESC);
        this.notFoundException.write(oprot);
        oprot.writeFieldEnd();
      }
      oprot.writeFieldStop();
      oprot.writeStructEnd();
    }

    public String toString() {
      StringBuilder sb = new StringBuilder("createTag_result(");
      boolean first = true;

      sb.append("success:");
      if (this.success == null) {
        sb.append("null");
      } else {
        sb.append(this.success);
      }
      first = false;
      if (!first) sb.append(", ");
      sb.append("userException:");
      if (this.userException == null) {
        sb.append("null");
      } else {
        sb.append(this.userException);
      }
      first = false;
      if (!first) sb.append(", ");
      sb.append("systemException:");
      if (this.systemException == null) {
        sb.append("null");
      } else {
        sb.append(this.systemException);
      }
      first = false;
      if (!first) sb.append(", ");
      sb.append("notFoundException:");
      if (this.notFoundException == null) {
        sb.append("null");
      } else {
        sb.append(this.notFoundException);
      }
      first = false;
      sb.append(")");
      return sb.toString();
    }

    public void validate() throws TException {
      // check for required fields
    }

  }

  public static class updateTag_args implements TBase<updateTag_args._Fields>, java.io.Serializable, Cloneable, Comparable<updateTag_args>   {
    private static final TStruct STRUCT_DESC = new TStruct("updateTag_args");

    private static final TField AUTHENTICATION_TOKEN_FIELD_DESC = new TField("authenticationToken", TType.STRING, (short)1);
    private static final TField TAG_FIELD_DESC = new TField("tag", TType.STRUCT, (short)2);

    private String authenticationToken;
    private com.evernote.edam.type.Tag tag;

    /** The set of fields this struct contains, along with convenience methods for finding and manipulating them. */
    public enum _Fields implements TFieldIdEnum {
      AUTHENTICATION_TOKEN((short)1, "authenticationToken"),
      TAG((short)2, "tag");

      private static final Map<Integer, _Fields> byId = new HashMap<Integer, _Fields>();
      private static final Map<String, _Fields> byName = new HashMap<String, _Fields>();

      static {
        for (_Fields field : EnumSet.allOf(_Fields.class)) {
          byId.put((int)field._thriftId, field);
          byName.put(field.getFieldName(), field);
        }
      }

      /**
       * Find the _Fields constant that matches fieldId, or null if its not found.
       */
      public static _Fields findByThriftId(int fieldId) {
        return byId.get(fieldId);
      }

      /**
       * Find the _Fields constant that matches fieldId, throwing an exception
       * if it is not found.
       */
      public static _Fields findByThriftIdOrThrow(int fieldId) {
        _Fields fields = findByThriftId(fieldId);
        if (fields == null) throw new IllegalArgumentException("Field " + fieldId + " doesn't exist!");
        return fields;
      }

      /**
       * Find the _Fields constant that matches name, or null if its not found.
       */
      public static _Fields findByName(String name) {
        return byName.get(name);
      }

      private final short _thriftId;
      private final String _fieldName;

      _Fields(short thriftId, String fieldName) {
        _thriftId = thriftId;
        _fieldName = fieldName;
      }

      public short getThriftFieldId() {
        return _thriftId;
      }

      public String getFieldName() {
        return _fieldName;
      }
    }

    // isset id assignments

    public static final Map<_Fields, FieldMetaData> metaDataMap = Collections.unmodifiableMap(new EnumMap<_Fields, FieldMetaData>(_Fields.class) {{
      put(_Fields.AUTHENTICATION_TOKEN, new FieldMetaData("authenticationToken", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.STRING)));
      put(_Fields.TAG, new FieldMetaData("tag", TFieldRequirementType.DEFAULT, 
          new StructMetaData(TType.STRUCT, com.evernote.edam.type.Tag.class)));
    }});

    static {
      FieldMetaData.addStructMetaDataMap(updateTag_args.class, metaDataMap);
    }

    public updateTag_args() {
    }

    public updateTag_args(
      String authenticationToken,
      com.evernote.edam.type.Tag tag)
    {
      this();
      this.authenticationToken = authenticationToken;
      this.tag = tag;
    }

    /**
     * Performs a deep copy on <i>other</i>.
     */
    public updateTag_args(updateTag_args other) {
      if (other.isSetAuthenticationToken()) {
        this.authenticationToken = other.authenticationToken;
      }
      if (other.isSetTag()) {
        this.tag = new com.evernote.edam.type.Tag(other.tag);
      }
    }

    public updateTag_args deepCopy() {
      return new updateTag_args(this);
    }

    @Deprecated
    public updateTag_args clone() {
      return new updateTag_args(this);
    }

    public String getAuthenticationToken() {
      return this.authenticationToken;
    }

    public void setAuthenticationToken(String authenticationToken) {
      this.authenticationToken = authenticationToken;
    }

    public void unsetAuthenticationToken() {
      this.authenticationToken = null;
    }

    /** Returns true if field authenticationToken is set (has been asigned a value) and false otherwise */
    public boolean isSetAuthenticationToken() {
      return this.authenticationToken != null;
    }

    public void setAuthenticationTokenIsSet(boolean value) {
      if (!value) {
        this.authenticationToken = null;
      }
    }

    public com.evernote.edam.type.Tag getTag() {
      return this.tag;
    }

    public void setTag(com.evernote.edam.type.Tag tag) {
      this.tag = tag;
    }

    public void unsetTag() {
      this.tag = null;
    }

    /** Returns true if field tag is set (has been asigned a value) and false otherwise */
    public boolean isSetTag() {
      return this.tag != null;
    }

    public void setTagIsSet(boolean value) {
      if (!value) {
        this.tag = null;
      }
    }

    public void setFieldValue(_Fields field, Object value) {
      switch (field) {
      case AUTHENTICATION_TOKEN:
        if (value == null) {
          unsetAuthenticationToken();
        } else {
          setAuthenticationToken((String)value);
        }
        break;

      case TAG:
        if (value == null) {
          unsetTag();
        } else {
          setTag((com.evernote.edam.type.Tag)value);
        }
        break;

      }
    }

    public void setFieldValue(int fieldID, Object value) {
      setFieldValue(_Fields.findByThriftIdOrThrow(fieldID), value);
    }

    public Object getFieldValue(_Fields field) {
      switch (field) {
      case AUTHENTICATION_TOKEN:
        return getAuthenticationToken();

      case TAG:
        return getTag();

      }
      throw new IllegalStateException();
    }

    public Object getFieldValue(int fieldId) {
      return getFieldValue(_Fields.findByThriftIdOrThrow(fieldId));
    }

    /** Returns true if field corresponding to fieldID is set (has been asigned a value) and false otherwise */
    public boolean isSet(_Fields field) {
      switch (field) {
      case AUTHENTICATION_TOKEN:
        return isSetAuthenticationToken();
      case TAG:
        return isSetTag();
      }
      throw new IllegalStateException();
    }

    public boolean isSet(int fieldID) {
      return isSet(_Fields.findByThriftIdOrThrow(fieldID));
    }

    public boolean equals(Object that) {
      if (that == null)
        return false;
      if (that instanceof updateTag_args)
        return this.equals((updateTag_args)that);
      return false;
    }

    public boolean equals(updateTag_args that) {
      if (that == null)
        return false;

      boolean this_present_authenticationToken = true && this.isSetAuthenticationToken();
      boolean that_present_authenticationToken = true && that.isSetAuthenticationToken();
      if (this_present_authenticationToken || that_present_authenticationToken) {
        if (!(this_present_authenticationToken && that_present_authenticationToken))
          return false;
        if (!this.authenticationToken.equals(that.authenticationToken))
          return false;
      }

      boolean this_present_tag = true && this.isSetTag();
      boolean that_present_tag = true && that.isSetTag();
      if (this_present_tag || that_present_tag) {
        if (!(this_present_tag && that_present_tag))
          return false;
        if (!this.tag.equals(that.tag))
          return false;
      }

      return true;
    }

    public int hashCode() {
      return 0;
    }

    public int compareTo(updateTag_args other) {
      if (!getClass().equals(other.getClass())) {
        return getClass().getName().compareTo(other.getClass().getName());
      }

      int lastComparison = 0;
      updateTag_args typedOther = (updateTag_args)other;

      lastComparison = Boolean.valueOf(isSetAuthenticationToken()).compareTo(isSetAuthenticationToken());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(authenticationToken, typedOther.authenticationToken);
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = Boolean.valueOf(isSetTag()).compareTo(isSetTag());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(tag, typedOther.tag);
      if (lastComparison != 0) {
        return lastComparison;
      }
      return 0;
    }

    public void read(TProtocol iprot) throws TException {
      TField field;
      iprot.readStructBegin();
      while (true)
      {
        field = iprot.readFieldBegin();
        if (field.type == TType.STOP) { 
          break;
        }
        _Fields fieldId = _Fields.findByThriftId(field.id);
        if (fieldId == null) {
          TProtocolUtil.skip(iprot, field.type);
        } else {
          switch (fieldId) {
            case AUTHENTICATION_TOKEN:
              if (field.type == TType.STRING) {
                this.authenticationToken = iprot.readString();
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
            case TAG:
              if (field.type == TType.STRUCT) {
                this.tag = new com.evernote.edam.type.Tag();
                this.tag.read(iprot);
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
          }
          iprot.readFieldEnd();
        }
      }
      iprot.readStructEnd();
      validate();
    }

    public void write(TProtocol oprot) throws TException {
      validate();

      oprot.writeStructBegin(STRUCT_DESC);
      if (this.authenticationToken != null) {
        oprot.writeFieldBegin(AUTHENTICATION_TOKEN_FIELD_DESC);
        oprot.writeString(this.authenticationToken);
        oprot.writeFieldEnd();
      }
      if (this.tag != null) {
        oprot.writeFieldBegin(TAG_FIELD_DESC);
        this.tag.write(oprot);
        oprot.writeFieldEnd();
      }
      oprot.writeFieldStop();
      oprot.writeStructEnd();
    }

    public String toString() {
      StringBuilder sb = new StringBuilder("updateTag_args(");
      boolean first = true;

      sb.append("authenticationToken:");
      if (this.authenticationToken == null) {
        sb.append("null");
      } else {
        sb.append(this.authenticationToken);
      }
      first = false;
      if (!first) sb.append(", ");
      sb.append("tag:");
      if (this.tag == null) {
        sb.append("null");
      } else {
        sb.append(this.tag);
      }
      first = false;
      sb.append(")");
      return sb.toString();
    }

    public void validate() throws TException {
      // check for required fields
    }

  }

  public static class updateTag_result implements TBase<updateTag_result._Fields>, java.io.Serializable, Cloneable, Comparable<updateTag_result>   {
    private static final TStruct STRUCT_DESC = new TStruct("updateTag_result");

    private static final TField SUCCESS_FIELD_DESC = new TField("success", TType.I32, (short)0);
    private static final TField USER_EXCEPTION_FIELD_DESC = new TField("userException", TType.STRUCT, (short)1);
    private static final TField SYSTEM_EXCEPTION_FIELD_DESC = new TField("systemException", TType.STRUCT, (short)2);
    private static final TField NOT_FOUND_EXCEPTION_FIELD_DESC = new TField("notFoundException", TType.STRUCT, (short)3);

    private int success;
    private com.evernote.edam.error.EDAMUserException userException;
    private com.evernote.edam.error.EDAMSystemException systemException;
    private com.evernote.edam.error.EDAMNotFoundException notFoundException;

    /** The set of fields this struct contains, along with convenience methods for finding and manipulating them. */
    public enum _Fields implements TFieldIdEnum {
      SUCCESS((short)0, "success"),
      USER_EXCEPTION((short)1, "userException"),
      SYSTEM_EXCEPTION((short)2, "systemException"),
      NOT_FOUND_EXCEPTION((short)3, "notFoundException");

      private static final Map<Integer, _Fields> byId = new HashMap<Integer, _Fields>();
      private static final Map<String, _Fields> byName = new HashMap<String, _Fields>();

      static {
        for (_Fields field : EnumSet.allOf(_Fields.class)) {
          byId.put((int)field._thriftId, field);
          byName.put(field.getFieldName(), field);
        }
      }

      /**
       * Find the _Fields constant that matches fieldId, or null if its not found.
       */
      public static _Fields findByThriftId(int fieldId) {
        return byId.get(fieldId);
      }

      /**
       * Find the _Fields constant that matches fieldId, throwing an exception
       * if it is not found.
       */
      public static _Fields findByThriftIdOrThrow(int fieldId) {
        _Fields fields = findByThriftId(fieldId);
        if (fields == null) throw new IllegalArgumentException("Field " + fieldId + " doesn't exist!");
        return fields;
      }

      /**
       * Find the _Fields constant that matches name, or null if its not found.
       */
      public static _Fields findByName(String name) {
        return byName.get(name);
      }

      private final short _thriftId;
      private final String _fieldName;

      _Fields(short thriftId, String fieldName) {
        _thriftId = thriftId;
        _fieldName = fieldName;
      }

      public short getThriftFieldId() {
        return _thriftId;
      }

      public String getFieldName() {
        return _fieldName;
      }
    }

    // isset id assignments
    private static final int __SUCCESS_ISSET_ID = 0;
    private BitSet __isset_bit_vector = new BitSet(1);

    public static final Map<_Fields, FieldMetaData> metaDataMap = Collections.unmodifiableMap(new EnumMap<_Fields, FieldMetaData>(_Fields.class) {{
      put(_Fields.SUCCESS, new FieldMetaData("success", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.I32)));
      put(_Fields.USER_EXCEPTION, new FieldMetaData("userException", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.STRUCT)));
      put(_Fields.SYSTEM_EXCEPTION, new FieldMetaData("systemException", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.STRUCT)));
      put(_Fields.NOT_FOUND_EXCEPTION, new FieldMetaData("notFoundException", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.STRUCT)));
    }});

    static {
      FieldMetaData.addStructMetaDataMap(updateTag_result.class, metaDataMap);
    }

    public updateTag_result() {
    }

    public updateTag_result(
      int success,
      com.evernote.edam.error.EDAMUserException userException,
      com.evernote.edam.error.EDAMSystemException systemException,
      com.evernote.edam.error.EDAMNotFoundException notFoundException)
    {
      this();
      this.success = success;
      setSuccessIsSet(true);
      this.userException = userException;
      this.systemException = systemException;
      this.notFoundException = notFoundException;
    }

    /**
     * Performs a deep copy on <i>other</i>.
     */
    public updateTag_result(updateTag_result other) {
      __isset_bit_vector.clear();
      __isset_bit_vector.or(other.__isset_bit_vector);
      this.success = other.success;
      if (other.isSetUserException()) {
        this.userException = new com.evernote.edam.error.EDAMUserException(other.userException);
      }
      if (other.isSetSystemException()) {
        this.systemException = new com.evernote.edam.error.EDAMSystemException(other.systemException);
      }
      if (other.isSetNotFoundException()) {
        this.notFoundException = new com.evernote.edam.error.EDAMNotFoundException(other.notFoundException);
      }
    }

    public updateTag_result deepCopy() {
      return new updateTag_result(this);
    }

    @Deprecated
    public updateTag_result clone() {
      return new updateTag_result(this);
    }

    public int getSuccess() {
      return this.success;
    }

    public void setSuccess(int success) {
      this.success = success;
      setSuccessIsSet(true);
    }

    public void unsetSuccess() {
      __isset_bit_vector.clear(__SUCCESS_ISSET_ID);
    }

    /** Returns true if field success is set (has been asigned a value) and false otherwise */
    public boolean isSetSuccess() {
      return __isset_bit_vector.get(__SUCCESS_ISSET_ID);
    }

    public void setSuccessIsSet(boolean value) {
      __isset_bit_vector.set(__SUCCESS_ISSET_ID, value);
    }

    public com.evernote.edam.error.EDAMUserException getUserException() {
      return this.userException;
    }

    public void setUserException(com.evernote.edam.error.EDAMUserException userException) {
      this.userException = userException;
    }

    public void unsetUserException() {
      this.userException = null;
    }

    /** Returns true if field userException is set (has been asigned a value) and false otherwise */
    public boolean isSetUserException() {
      return this.userException != null;
    }

    public void setUserExceptionIsSet(boolean value) {
      if (!value) {
        this.userException = null;
      }
    }

    public com.evernote.edam.error.EDAMSystemException getSystemException() {
      return this.systemException;
    }

    public void setSystemException(com.evernote.edam.error.EDAMSystemException systemException) {
      this.systemException = systemException;
    }

    public void unsetSystemException() {
      this.systemException = null;
    }

    /** Returns true if field systemException is set (has been asigned a value) and false otherwise */
    public boolean isSetSystemException() {
      return this.systemException != null;
    }

    public void setSystemExceptionIsSet(boolean value) {
      if (!value) {
        this.systemException = null;
      }
    }

    public com.evernote.edam.error.EDAMNotFoundException getNotFoundException() {
      return this.notFoundException;
    }

    public void setNotFoundException(com.evernote.edam.error.EDAMNotFoundException notFoundException) {
      this.notFoundException = notFoundException;
    }

    public void unsetNotFoundException() {
      this.notFoundException = null;
    }

    /** Returns true if field notFoundException is set (has been asigned a value) and false otherwise */
    public boolean isSetNotFoundException() {
      return this.notFoundException != null;
    }

    public void setNotFoundExceptionIsSet(boolean value) {
      if (!value) {
        this.notFoundException = null;
      }
    }

    public void setFieldValue(_Fields field, Object value) {
      switch (field) {
      case SUCCESS:
        if (value == null) {
          unsetSuccess();
        } else {
          setSuccess((Integer)value);
        }
        break;

      case USER_EXCEPTION:
        if (value == null) {
          unsetUserException();
        } else {
          setUserException((com.evernote.edam.error.EDAMUserException)value);
        }
        break;

      case SYSTEM_EXCEPTION:
        if (value == null) {
          unsetSystemException();
        } else {
          setSystemException((com.evernote.edam.error.EDAMSystemException)value);
        }
        break;

      case NOT_FOUND_EXCEPTION:
        if (value == null) {
          unsetNotFoundException();
        } else {
          setNotFoundException((com.evernote.edam.error.EDAMNotFoundException)value);
        }
        break;

      }
    }

    public void setFieldValue(int fieldID, Object value) {
      setFieldValue(_Fields.findByThriftIdOrThrow(fieldID), value);
    }

    public Object getFieldValue(_Fields field) {
      switch (field) {
      case SUCCESS:
        return new Integer(getSuccess());

      case USER_EXCEPTION:
        return getUserException();

      case SYSTEM_EXCEPTION:
        return getSystemException();

      case NOT_FOUND_EXCEPTION:
        return getNotFoundException();

      }
      throw new IllegalStateException();
    }

    public Object getFieldValue(int fieldId) {
      return getFieldValue(_Fields.findByThriftIdOrThrow(fieldId));
    }

    /** Returns true if field corresponding to fieldID is set (has been asigned a value) and false otherwise */
    public boolean isSet(_Fields field) {
      switch (field) {
      case SUCCESS:
        return isSetSuccess();
      case USER_EXCEPTION:
        return isSetUserException();
      case SYSTEM_EXCEPTION:
        return isSetSystemException();
      case NOT_FOUND_EXCEPTION:
        return isSetNotFoundException();
      }
      throw new IllegalStateException();
    }

    public boolean isSet(int fieldID) {
      return isSet(_Fields.findByThriftIdOrThrow(fieldID));
    }

    public boolean equals(Object that) {
      if (that == null)
        return false;
      if (that instanceof updateTag_result)
        return this.equals((updateTag_result)that);
      return false;
    }

    public boolean equals(updateTag_result that) {
      if (that == null)
        return false;

      boolean this_present_success = true;
      boolean that_present_success = true;
      if (this_present_success || that_present_success) {
        if (!(this_present_success && that_present_success))
          return false;
        if (this.success != that.success)
          return false;
      }

      boolean this_present_userException = true && this.isSetUserException();
      boolean that_present_userException = true && that.isSetUserException();
      if (this_present_userException || that_present_userException) {
        if (!(this_present_userException && that_present_userException))
          return false;
        if (!this.userException.equals(that.userException))
          return false;
      }

      boolean this_present_systemException = true && this.isSetSystemException();
      boolean that_present_systemException = true && that.isSetSystemException();
      if (this_present_systemException || that_present_systemException) {
        if (!(this_present_systemException && that_present_systemException))
          return false;
        if (!this.systemException.equals(that.systemException))
          return false;
      }

      boolean this_present_notFoundException = true && this.isSetNotFoundException();
      boolean that_present_notFoundException = true && that.isSetNotFoundException();
      if (this_present_notFoundException || that_present_notFoundException) {
        if (!(this_present_notFoundException && that_present_notFoundException))
          return false;
        if (!this.notFoundException.equals(that.notFoundException))
          return false;
      }

      return true;
    }

    public int hashCode() {
      return 0;
    }

    public int compareTo(updateTag_result other) {
      if (!getClass().equals(other.getClass())) {
        return getClass().getName().compareTo(other.getClass().getName());
      }

      int lastComparison = 0;
      updateTag_result typedOther = (updateTag_result)other;

      lastComparison = Boolean.valueOf(isSetSuccess()).compareTo(isSetSuccess());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(success, typedOther.success);
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = Boolean.valueOf(isSetUserException()).compareTo(isSetUserException());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(userException, typedOther.userException);
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = Boolean.valueOf(isSetSystemException()).compareTo(isSetSystemException());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(systemException, typedOther.systemException);
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = Boolean.valueOf(isSetNotFoundException()).compareTo(isSetNotFoundException());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(notFoundException, typedOther.notFoundException);
      if (lastComparison != 0) {
        return lastComparison;
      }
      return 0;
    }

    public void read(TProtocol iprot) throws TException {
      TField field;
      iprot.readStructBegin();
      while (true)
      {
        field = iprot.readFieldBegin();
        if (field.type == TType.STOP) { 
          break;
        }
        _Fields fieldId = _Fields.findByThriftId(field.id);
        if (fieldId == null) {
          TProtocolUtil.skip(iprot, field.type);
        } else {
          switch (fieldId) {
            case SUCCESS:
              if (field.type == TType.I32) {
                this.success = iprot.readI32();
                setSuccessIsSet(true);
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
            case USER_EXCEPTION:
              if (field.type == TType.STRUCT) {
                this.userException = new com.evernote.edam.error.EDAMUserException();
                this.userException.read(iprot);
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
            case SYSTEM_EXCEPTION:
              if (field.type == TType.STRUCT) {
                this.systemException = new com.evernote.edam.error.EDAMSystemException();
                this.systemException.read(iprot);
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
            case NOT_FOUND_EXCEPTION:
              if (field.type == TType.STRUCT) {
                this.notFoundException = new com.evernote.edam.error.EDAMNotFoundException();
                this.notFoundException.read(iprot);
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
          }
          iprot.readFieldEnd();
        }
      }
      iprot.readStructEnd();
      validate();
    }

    public void write(TProtocol oprot) throws TException {
      oprot.writeStructBegin(STRUCT_DESC);

      if (this.isSetSuccess()) {
        oprot.writeFieldBegin(SUCCESS_FIELD_DESC);
        oprot.writeI32(this.success);
        oprot.writeFieldEnd();
      } else if (this.isSetUserException()) {
        oprot.writeFieldBegin(USER_EXCEPTION_FIELD_DESC);
        this.userException.write(oprot);
        oprot.writeFieldEnd();
      } else if (this.isSetSystemException()) {
        oprot.writeFieldBegin(SYSTEM_EXCEPTION_FIELD_DESC);
        this.systemException.write(oprot);
        oprot.writeFieldEnd();
      } else if (this.isSetNotFoundException()) {
        oprot.writeFieldBegin(NOT_FOUND_EXCEPTION_FIELD_DESC);
        this.notFoundException.write(oprot);
        oprot.writeFieldEnd();
      }
      oprot.writeFieldStop();
      oprot.writeStructEnd();
    }

    public String toString() {
      StringBuilder sb = new StringBuilder("updateTag_result(");
      boolean first = true;

      sb.append("success:");
      sb.append(this.success);
      first = false;
      if (!first) sb.append(", ");
      sb.append("userException:");
      if (this.userException == null) {
        sb.append("null");
      } else {
        sb.append(this.userException);
      }
      first = false;
      if (!first) sb.append(", ");
      sb.append("systemException:");
      if (this.systemException == null) {
        sb.append("null");
      } else {
        sb.append(this.systemException);
      }
      first = false;
      if (!first) sb.append(", ");
      sb.append("notFoundException:");
      if (this.notFoundException == null) {
        sb.append("null");
      } else {
        sb.append(this.notFoundException);
      }
      first = false;
      sb.append(")");
      return sb.toString();
    }

    public void validate() throws TException {
      // check for required fields
    }

  }

  public static class untagAll_args implements TBase<untagAll_args._Fields>, java.io.Serializable, Cloneable, Comparable<untagAll_args>   {
    private static final TStruct STRUCT_DESC = new TStruct("untagAll_args");

    private static final TField AUTHENTICATION_TOKEN_FIELD_DESC = new TField("authenticationToken", TType.STRING, (short)1);
    private static final TField GUID_FIELD_DESC = new TField("guid", TType.STRING, (short)2);

    private String authenticationToken;
    private String guid;

    /** The set of fields this struct contains, along with convenience methods for finding and manipulating them. */
    public enum _Fields implements TFieldIdEnum {
      AUTHENTICATION_TOKEN((short)1, "authenticationToken"),
      GUID((short)2, "guid");

      private static final Map<Integer, _Fields> byId = new HashMap<Integer, _Fields>();
      private static final Map<String, _Fields> byName = new HashMap<String, _Fields>();

      static {
        for (_Fields field : EnumSet.allOf(_Fields.class)) {
          byId.put((int)field._thriftId, field);
          byName.put(field.getFieldName(), field);
        }
      }

      /**
       * Find the _Fields constant that matches fieldId, or null if its not found.
       */
      public static _Fields findByThriftId(int fieldId) {
        return byId.get(fieldId);
      }

      /**
       * Find the _Fields constant that matches fieldId, throwing an exception
       * if it is not found.
       */
      public static _Fields findByThriftIdOrThrow(int fieldId) {
        _Fields fields = findByThriftId(fieldId);
        if (fields == null) throw new IllegalArgumentException("Field " + fieldId + " doesn't exist!");
        return fields;
      }

      /**
       * Find the _Fields constant that matches name, or null if its not found.
       */
      public static _Fields findByName(String name) {
        return byName.get(name);
      }

      private final short _thriftId;
      private final String _fieldName;

      _Fields(short thriftId, String fieldName) {
        _thriftId = thriftId;
        _fieldName = fieldName;
      }

      public short getThriftFieldId() {
        return _thriftId;
      }

      public String getFieldName() {
        return _fieldName;
      }
    }

    // isset id assignments

    public static final Map<_Fields, FieldMetaData> metaDataMap = Collections.unmodifiableMap(new EnumMap<_Fields, FieldMetaData>(_Fields.class) {{
      put(_Fields.AUTHENTICATION_TOKEN, new FieldMetaData("authenticationToken", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.STRING)));
      put(_Fields.GUID, new FieldMetaData("guid", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.STRING)));
    }});

    static {
      FieldMetaData.addStructMetaDataMap(untagAll_args.class, metaDataMap);
    }

    public untagAll_args() {
    }

    public untagAll_args(
      String authenticationToken,
      String guid)
    {
      this();
      this.authenticationToken = authenticationToken;
      this.guid = guid;
    }

    /**
     * Performs a deep copy on <i>other</i>.
     */
    public untagAll_args(untagAll_args other) {
      if (other.isSetAuthenticationToken()) {
        this.authenticationToken = other.authenticationToken;
      }
      if (other.isSetGuid()) {
        this.guid = other.guid;
      }
    }

    public untagAll_args deepCopy() {
      return new untagAll_args(this);
    }

    @Deprecated
    public untagAll_args clone() {
      return new untagAll_args(this);
    }

    public String getAuthenticationToken() {
      return this.authenticationToken;
    }

    public void setAuthenticationToken(String authenticationToken) {
      this.authenticationToken = authenticationToken;
    }

    public void unsetAuthenticationToken() {
      this.authenticationToken = null;
    }

    /** Returns true if field authenticationToken is set (has been asigned a value) and false otherwise */
    public boolean isSetAuthenticationToken() {
      return this.authenticationToken != null;
    }

    public void setAuthenticationTokenIsSet(boolean value) {
      if (!value) {
        this.authenticationToken = null;
      }
    }

    public String getGuid() {
      return this.guid;
    }

    public void setGuid(String guid) {
      this.guid = guid;
    }

    public void unsetGuid() {
      this.guid = null;
    }

    /** Returns true if field guid is set (has been asigned a value) and false otherwise */
    public boolean isSetGuid() {
      return this.guid != null;
    }

    public void setGuidIsSet(boolean value) {
      if (!value) {
        this.guid = null;
      }
    }

    public void setFieldValue(_Fields field, Object value) {
      switch (field) {
      case AUTHENTICATION_TOKEN:
        if (value == null) {
          unsetAuthenticationToken();
        } else {
          setAuthenticationToken((String)value);
        }
        break;

      case GUID:
        if (value == null) {
          unsetGuid();
        } else {
          setGuid((String)value);
        }
        break;

      }
    }

    public void setFieldValue(int fieldID, Object value) {
      setFieldValue(_Fields.findByThriftIdOrThrow(fieldID), value);
    }

    public Object getFieldValue(_Fields field) {
      switch (field) {
      case AUTHENTICATION_TOKEN:
        return getAuthenticationToken();

      case GUID:
        return getGuid();

      }
      throw new IllegalStateException();
    }

    public Object getFieldValue(int fieldId) {
      return getFieldValue(_Fields.findByThriftIdOrThrow(fieldId));
    }

    /** Returns true if field corresponding to fieldID is set (has been asigned a value) and false otherwise */
    public boolean isSet(_Fields field) {
      switch (field) {
      case AUTHENTICATION_TOKEN:
        return isSetAuthenticationToken();
      case GUID:
        return isSetGuid();
      }
      throw new IllegalStateException();
    }

    public boolean isSet(int fieldID) {
      return isSet(_Fields.findByThriftIdOrThrow(fieldID));
    }

    public boolean equals(Object that) {
      if (that == null)
        return false;
      if (that instanceof untagAll_args)
        return this.equals((untagAll_args)that);
      return false;
    }

    public boolean equals(untagAll_args that) {
      if (that == null)
        return false;

      boolean this_present_authenticationToken = true && this.isSetAuthenticationToken();
      boolean that_present_authenticationToken = true && that.isSetAuthenticationToken();
      if (this_present_authenticationToken || that_present_authenticationToken) {
        if (!(this_present_authenticationToken && that_present_authenticationToken))
          return false;
        if (!this.authenticationToken.equals(that.authenticationToken))
          return false;
      }

      boolean this_present_guid = true && this.isSetGuid();
      boolean that_present_guid = true && that.isSetGuid();
      if (this_present_guid || that_present_guid) {
        if (!(this_present_guid && that_present_guid))
          return false;
        if (!this.guid.equals(that.guid))
          return false;
      }

      return true;
    }

    public int hashCode() {
      return 0;
    }

    public int compareTo(untagAll_args other) {
      if (!getClass().equals(other.getClass())) {
        return getClass().getName().compareTo(other.getClass().getName());
      }

      int lastComparison = 0;
      untagAll_args typedOther = (untagAll_args)other;

      lastComparison = Boolean.valueOf(isSetAuthenticationToken()).compareTo(isSetAuthenticationToken());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(authenticationToken, typedOther.authenticationToken);
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = Boolean.valueOf(isSetGuid()).compareTo(isSetGuid());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(guid, typedOther.guid);
      if (lastComparison != 0) {
        return lastComparison;
      }
      return 0;
    }

    public void read(TProtocol iprot) throws TException {
      TField field;
      iprot.readStructBegin();
      while (true)
      {
        field = iprot.readFieldBegin();
        if (field.type == TType.STOP) { 
          break;
        }
        _Fields fieldId = _Fields.findByThriftId(field.id);
        if (fieldId == null) {
          TProtocolUtil.skip(iprot, field.type);
        } else {
          switch (fieldId) {
            case AUTHENTICATION_TOKEN:
              if (field.type == TType.STRING) {
                this.authenticationToken = iprot.readString();
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
            case GUID:
              if (field.type == TType.STRING) {
                this.guid = iprot.readString();
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
          }
          iprot.readFieldEnd();
        }
      }
      iprot.readStructEnd();
      validate();
    }

    public void write(TProtocol oprot) throws TException {
      validate();

      oprot.writeStructBegin(STRUCT_DESC);
      if (this.authenticationToken != null) {
        oprot.writeFieldBegin(AUTHENTICATION_TOKEN_FIELD_DESC);
        oprot.writeString(this.authenticationToken);
        oprot.writeFieldEnd();
      }
      if (this.guid != null) {
        oprot.writeFieldBegin(GUID_FIELD_DESC);
        oprot.writeString(this.guid);
        oprot.writeFieldEnd();
      }
      oprot.writeFieldStop();
      oprot.writeStructEnd();
    }

    public String toString() {
      StringBuilder sb = new StringBuilder("untagAll_args(");
      boolean first = true;

      sb.append("authenticationToken:");
      if (this.authenticationToken == null) {
        sb.append("null");
      } else {
        sb.append(this.authenticationToken);
      }
      first = false;
      if (!first) sb.append(", ");
      sb.append("guid:");
      if (this.guid == null) {
        sb.append("null");
      } else {
        sb.append(this.guid);
      }
      first = false;
      sb.append(")");
      return sb.toString();
    }

    public void validate() throws TException {
      // check for required fields
    }

  }

  public static class untagAll_result implements TBase<untagAll_result._Fields>, java.io.Serializable, Cloneable, Comparable<untagAll_result>   {
    private static final TStruct STRUCT_DESC = new TStruct("untagAll_result");

    private static final TField USER_EXCEPTION_FIELD_DESC = new TField("userException", TType.STRUCT, (short)1);
    private static final TField SYSTEM_EXCEPTION_FIELD_DESC = new TField("systemException", TType.STRUCT, (short)2);
    private static final TField NOT_FOUND_EXCEPTION_FIELD_DESC = new TField("notFoundException", TType.STRUCT, (short)3);

    private com.evernote.edam.error.EDAMUserException userException;
    private com.evernote.edam.error.EDAMSystemException systemException;
    private com.evernote.edam.error.EDAMNotFoundException notFoundException;

    /** The set of fields this struct contains, along with convenience methods for finding and manipulating them. */
    public enum _Fields implements TFieldIdEnum {
      USER_EXCEPTION((short)1, "userException"),
      SYSTEM_EXCEPTION((short)2, "systemException"),
      NOT_FOUND_EXCEPTION((short)3, "notFoundException");

      private static final Map<Integer, _Fields> byId = new HashMap<Integer, _Fields>();
      private static final Map<String, _Fields> byName = new HashMap<String, _Fields>();

      static {
        for (_Fields field : EnumSet.allOf(_Fields.class)) {
          byId.put((int)field._thriftId, field);
          byName.put(field.getFieldName(), field);
        }
      }

      /**
       * Find the _Fields constant that matches fieldId, or null if its not found.
       */
      public static _Fields findByThriftId(int fieldId) {
        return byId.get(fieldId);
      }

      /**
       * Find the _Fields constant that matches fieldId, throwing an exception
       * if it is not found.
       */
      public static _Fields findByThriftIdOrThrow(int fieldId) {
        _Fields fields = findByThriftId(fieldId);
        if (fields == null) throw new IllegalArgumentException("Field " + fieldId + " doesn't exist!");
        return fields;
      }

      /**
       * Find the _Fields constant that matches name, or null if its not found.
       */
      public static _Fields findByName(String name) {
        return byName.get(name);
      }

      private final short _thriftId;
      private final String _fieldName;

      _Fields(short thriftId, String fieldName) {
        _thriftId = thriftId;
        _fieldName = fieldName;
      }

      public short getThriftFieldId() {
        return _thriftId;
      }

      public String getFieldName() {
        return _fieldName;
      }
    }

    // isset id assignments

    public static final Map<_Fields, FieldMetaData> metaDataMap = Collections.unmodifiableMap(new EnumMap<_Fields, FieldMetaData>(_Fields.class) {{
      put(_Fields.USER_EXCEPTION, new FieldMetaData("userException", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.STRUCT)));
      put(_Fields.SYSTEM_EXCEPTION, new FieldMetaData("systemException", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.STRUCT)));
      put(_Fields.NOT_FOUND_EXCEPTION, new FieldMetaData("notFoundException", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.STRUCT)));
    }});

    static {
      FieldMetaData.addStructMetaDataMap(untagAll_result.class, metaDataMap);
    }

    public untagAll_result() {
    }

    public untagAll_result(
      com.evernote.edam.error.EDAMUserException userException,
      com.evernote.edam.error.EDAMSystemException systemException,
      com.evernote.edam.error.EDAMNotFoundException notFoundException)
    {
      this();
      this.userException = userException;
      this.systemException = systemException;
      this.notFoundException = notFoundException;
    }

    /**
     * Performs a deep copy on <i>other</i>.
     */
    public untagAll_result(untagAll_result other) {
      if (other.isSetUserException()) {
        this.userException = new com.evernote.edam.error.EDAMUserException(other.userException);
      }
      if (other.isSetSystemException()) {
        this.systemException = new com.evernote.edam.error.EDAMSystemException(other.systemException);
      }
      if (other.isSetNotFoundException()) {
        this.notFoundException = new com.evernote.edam.error.EDAMNotFoundException(other.notFoundException);
      }
    }

    public untagAll_result deepCopy() {
      return new untagAll_result(this);
    }

    @Deprecated
    public untagAll_result clone() {
      return new untagAll_result(this);
    }

    public com.evernote.edam.error.EDAMUserException getUserException() {
      return this.userException;
    }

    public void setUserException(com.evernote.edam.error.EDAMUserException userException) {
      this.userException = userException;
    }

    public void unsetUserException() {
      this.userException = null;
    }

    /** Returns true if field userException is set (has been asigned a value) and false otherwise */
    public boolean isSetUserException() {
      return this.userException != null;
    }

    public void setUserExceptionIsSet(boolean value) {
      if (!value) {
        this.userException = null;
      }
    }

    public com.evernote.edam.error.EDAMSystemException getSystemException() {
      return this.systemException;
    }

    public void setSystemException(com.evernote.edam.error.EDAMSystemException systemException) {
      this.systemException = systemException;
    }

    public void unsetSystemException() {
      this.systemException = null;
    }

    /** Returns true if field systemException is set (has been asigned a value) and false otherwise */
    public boolean isSetSystemException() {
      return this.systemException != null;
    }

    public void setSystemExceptionIsSet(boolean value) {
      if (!value) {
        this.systemException = null;
      }
    }

    public com.evernote.edam.error.EDAMNotFoundException getNotFoundException() {
      return this.notFoundException;
    }

    public void setNotFoundException(com.evernote.edam.error.EDAMNotFoundException notFoundException) {
      this.notFoundException = notFoundException;
    }

    public void unsetNotFoundException() {
      this.notFoundException = null;
    }

    /** Returns true if field notFoundException is set (has been asigned a value) and false otherwise */
    public boolean isSetNotFoundException() {
      return this.notFoundException != null;
    }

    public void setNotFoundExceptionIsSet(boolean value) {
      if (!value) {
        this.notFoundException = null;
      }
    }

    public void setFieldValue(_Fields field, Object value) {
      switch (field) {
      case USER_EXCEPTION:
        if (value == null) {
          unsetUserException();
        } else {
          setUserException((com.evernote.edam.error.EDAMUserException)value);
        }
        break;

      case SYSTEM_EXCEPTION:
        if (value == null) {
          unsetSystemException();
        } else {
          setSystemException((com.evernote.edam.error.EDAMSystemException)value);
        }
        break;

      case NOT_FOUND_EXCEPTION:
        if (value == null) {
          unsetNotFoundException();
        } else {
          setNotFoundException((com.evernote.edam.error.EDAMNotFoundException)value);
        }
        break;

      }
    }

    public void setFieldValue(int fieldID, Object value) {
      setFieldValue(_Fields.findByThriftIdOrThrow(fieldID), value);
    }

    public Object getFieldValue(_Fields field) {
      switch (field) {
      case USER_EXCEPTION:
        return getUserException();

      case SYSTEM_EXCEPTION:
        return getSystemException();

      case NOT_FOUND_EXCEPTION:
        return getNotFoundException();

      }
      throw new IllegalStateException();
    }

    public Object getFieldValue(int fieldId) {
      return getFieldValue(_Fields.findByThriftIdOrThrow(fieldId));
    }

    /** Returns true if field corresponding to fieldID is set (has been asigned a value) and false otherwise */
    public boolean isSet(_Fields field) {
      switch (field) {
      case USER_EXCEPTION:
        return isSetUserException();
      case SYSTEM_EXCEPTION:
        return isSetSystemException();
      case NOT_FOUND_EXCEPTION:
        return isSetNotFoundException();
      }
      throw new IllegalStateException();
    }

    public boolean isSet(int fieldID) {
      return isSet(_Fields.findByThriftIdOrThrow(fieldID));
    }

    public boolean equals(Object that) {
      if (that == null)
        return false;
      if (that instanceof untagAll_result)
        return this.equals((untagAll_result)that);
      return false;
    }

    public boolean equals(untagAll_result that) {
      if (that == null)
        return false;

      boolean this_present_userException = true && this.isSetUserException();
      boolean that_present_userException = true && that.isSetUserException();
      if (this_present_userException || that_present_userException) {
        if (!(this_present_userException && that_present_userException))
          return false;
        if (!this.userException.equals(that.userException))
          return false;
      }

      boolean this_present_systemException = true && this.isSetSystemException();
      boolean that_present_systemException = true && that.isSetSystemException();
      if (this_present_systemException || that_present_systemException) {
        if (!(this_present_systemException && that_present_systemException))
          return false;
        if (!this.systemException.equals(that.systemException))
          return false;
      }

      boolean this_present_notFoundException = true && this.isSetNotFoundException();
      boolean that_present_notFoundException = true && that.isSetNotFoundException();
      if (this_present_notFoundException || that_present_notFoundException) {
        if (!(this_present_notFoundException && that_present_notFoundException))
          return false;
        if (!this.notFoundException.equals(that.notFoundException))
          return false;
      }

      return true;
    }

    public int hashCode() {
      return 0;
    }

    public int compareTo(untagAll_result other) {
      if (!getClass().equals(other.getClass())) {
        return getClass().getName().compareTo(other.getClass().getName());
      }

      int lastComparison = 0;
      untagAll_result typedOther = (untagAll_result)other;

      lastComparison = Boolean.valueOf(isSetUserException()).compareTo(isSetUserException());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(userException, typedOther.userException);
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = Boolean.valueOf(isSetSystemException()).compareTo(isSetSystemException());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(systemException, typedOther.systemException);
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = Boolean.valueOf(isSetNotFoundException()).compareTo(isSetNotFoundException());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(notFoundException, typedOther.notFoundException);
      if (lastComparison != 0) {
        return lastComparison;
      }
      return 0;
    }

    public void read(TProtocol iprot) throws TException {
      TField field;
      iprot.readStructBegin();
      while (true)
      {
        field = iprot.readFieldBegin();
        if (field.type == TType.STOP) { 
          break;
        }
        _Fields fieldId = _Fields.findByThriftId(field.id);
        if (fieldId == null) {
          TProtocolUtil.skip(iprot, field.type);
        } else {
          switch (fieldId) {
            case USER_EXCEPTION:
              if (field.type == TType.STRUCT) {
                this.userException = new com.evernote.edam.error.EDAMUserException();
                this.userException.read(iprot);
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
            case SYSTEM_EXCEPTION:
              if (field.type == TType.STRUCT) {
                this.systemException = new com.evernote.edam.error.EDAMSystemException();
                this.systemException.read(iprot);
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
            case NOT_FOUND_EXCEPTION:
              if (field.type == TType.STRUCT) {
                this.notFoundException = new com.evernote.edam.error.EDAMNotFoundException();
                this.notFoundException.read(iprot);
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
          }
          iprot.readFieldEnd();
        }
      }
      iprot.readStructEnd();
      validate();
    }

    public void write(TProtocol oprot) throws TException {
      oprot.writeStructBegin(STRUCT_DESC);

      if (this.isSetUserException()) {
        oprot.writeFieldBegin(USER_EXCEPTION_FIELD_DESC);
        this.userException.write(oprot);
        oprot.writeFieldEnd();
      } else if (this.isSetSystemException()) {
        oprot.writeFieldBegin(SYSTEM_EXCEPTION_FIELD_DESC);
        this.systemException.write(oprot);
        oprot.writeFieldEnd();
      } else if (this.isSetNotFoundException()) {
        oprot.writeFieldBegin(NOT_FOUND_EXCEPTION_FIELD_DESC);
        this.notFoundException.write(oprot);
        oprot.writeFieldEnd();
      }
      oprot.writeFieldStop();
      oprot.writeStructEnd();
    }

    public String toString() {
      StringBuilder sb = new StringBuilder("untagAll_result(");
      boolean first = true;

      sb.append("userException:");
      if (this.userException == null) {
        sb.append("null");
      } else {
        sb.append(this.userException);
      }
      first = false;
      if (!first) sb.append(", ");
      sb.append("systemException:");
      if (this.systemException == null) {
        sb.append("null");
      } else {
        sb.append(this.systemException);
      }
      first = false;
      if (!first) sb.append(", ");
      sb.append("notFoundException:");
      if (this.notFoundException == null) {
        sb.append("null");
      } else {
        sb.append(this.notFoundException);
      }
      first = false;
      sb.append(")");
      return sb.toString();
    }

    public void validate() throws TException {
      // check for required fields
    }

  }

  public static class expungeTag_args implements TBase<expungeTag_args._Fields>, java.io.Serializable, Cloneable, Comparable<expungeTag_args>   {
    private static final TStruct STRUCT_DESC = new TStruct("expungeTag_args");

    private static final TField AUTHENTICATION_TOKEN_FIELD_DESC = new TField("authenticationToken", TType.STRING, (short)1);
    private static final TField GUID_FIELD_DESC = new TField("guid", TType.STRING, (short)2);

    private String authenticationToken;
    private String guid;

    /** The set of fields this struct contains, along with convenience methods for finding and manipulating them. */
    public enum _Fields implements TFieldIdEnum {
      AUTHENTICATION_TOKEN((short)1, "authenticationToken"),
      GUID((short)2, "guid");

      private static final Map<Integer, _Fields> byId = new HashMap<Integer, _Fields>();
      private static final Map<String, _Fields> byName = new HashMap<String, _Fields>();

      static {
        for (_Fields field : EnumSet.allOf(_Fields.class)) {
          byId.put((int)field._thriftId, field);
          byName.put(field.getFieldName(), field);
        }
      }

      /**
       * Find the _Fields constant that matches fieldId, or null if its not found.
       */
      public static _Fields findByThriftId(int fieldId) {
        return byId.get(fieldId);
      }

      /**
       * Find the _Fields constant that matches fieldId, throwing an exception
       * if it is not found.
       */
      public static _Fields findByThriftIdOrThrow(int fieldId) {
        _Fields fields = findByThriftId(fieldId);
        if (fields == null) throw new IllegalArgumentException("Field " + fieldId + " doesn't exist!");
        return fields;
      }

      /**
       * Find the _Fields constant that matches name, or null if its not found.
       */
      public static _Fields findByName(String name) {
        return byName.get(name);
      }

      private final short _thriftId;
      private final String _fieldName;

      _Fields(short thriftId, String fieldName) {
        _thriftId = thriftId;
        _fieldName = fieldName;
      }

      public short getThriftFieldId() {
        return _thriftId;
      }

      public String getFieldName() {
        return _fieldName;
      }
    }

    // isset id assignments

    public static final Map<_Fields, FieldMetaData> metaDataMap = Collections.unmodifiableMap(new EnumMap<_Fields, FieldMetaData>(_Fields.class) {{
      put(_Fields.AUTHENTICATION_TOKEN, new FieldMetaData("authenticationToken", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.STRING)));
      put(_Fields.GUID, new FieldMetaData("guid", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.STRING)));
    }});

    static {
      FieldMetaData.addStructMetaDataMap(expungeTag_args.class, metaDataMap);
    }

    public expungeTag_args() {
    }

    public expungeTag_args(
      String authenticationToken,
      String guid)
    {
      this();
      this.authenticationToken = authenticationToken;
      this.guid = guid;
    }

    /**
     * Performs a deep copy on <i>other</i>.
     */
    public expungeTag_args(expungeTag_args other) {
      if (other.isSetAuthenticationToken()) {
        this.authenticationToken = other.authenticationToken;
      }
      if (other.isSetGuid()) {
        this.guid = other.guid;
      }
    }

    public expungeTag_args deepCopy() {
      return new expungeTag_args(this);
    }

    @Deprecated
    public expungeTag_args clone() {
      return new expungeTag_args(this);
    }

    public String getAuthenticationToken() {
      return this.authenticationToken;
    }

    public void setAuthenticationToken(String authenticationToken) {
      this.authenticationToken = authenticationToken;
    }

    public void unsetAuthenticationToken() {
      this.authenticationToken = null;
    }

    /** Returns true if field authenticationToken is set (has been asigned a value) and false otherwise */
    public boolean isSetAuthenticationToken() {
      return this.authenticationToken != null;
    }

    public void setAuthenticationTokenIsSet(boolean value) {
      if (!value) {
        this.authenticationToken = null;
      }
    }

    public String getGuid() {
      return this.guid;
    }

    public void setGuid(String guid) {
      this.guid = guid;
    }

    public void unsetGuid() {
      this.guid = null;
    }

    /** Returns true if field guid is set (has been asigned a value) and false otherwise */
    public boolean isSetGuid() {
      return this.guid != null;
    }

    public void setGuidIsSet(boolean value) {
      if (!value) {
        this.guid = null;
      }
    }

    public void setFieldValue(_Fields field, Object value) {
      switch (field) {
      case AUTHENTICATION_TOKEN:
        if (value == null) {
          unsetAuthenticationToken();
        } else {
          setAuthenticationToken((String)value);
        }
        break;

      case GUID:
        if (value == null) {
          unsetGuid();
        } else {
          setGuid((String)value);
        }
        break;

      }
    }

    public void setFieldValue(int fieldID, Object value) {
      setFieldValue(_Fields.findByThriftIdOrThrow(fieldID), value);
    }

    public Object getFieldValue(_Fields field) {
      switch (field) {
      case AUTHENTICATION_TOKEN:
        return getAuthenticationToken();

      case GUID:
        return getGuid();

      }
      throw new IllegalStateException();
    }

    public Object getFieldValue(int fieldId) {
      return getFieldValue(_Fields.findByThriftIdOrThrow(fieldId));
    }

    /** Returns true if field corresponding to fieldID is set (has been asigned a value) and false otherwise */
    public boolean isSet(_Fields field) {
      switch (field) {
      case AUTHENTICATION_TOKEN:
        return isSetAuthenticationToken();
      case GUID:
        return isSetGuid();
      }
      throw new IllegalStateException();
    }

    public boolean isSet(int fieldID) {
      return isSet(_Fields.findByThriftIdOrThrow(fieldID));
    }

    public boolean equals(Object that) {
      if (that == null)
        return false;
      if (that instanceof expungeTag_args)
        return this.equals((expungeTag_args)that);
      return false;
    }

    public boolean equals(expungeTag_args that) {
      if (that == null)
        return false;

      boolean this_present_authenticationToken = true && this.isSetAuthenticationToken();
      boolean that_present_authenticationToken = true && that.isSetAuthenticationToken();
      if (this_present_authenticationToken || that_present_authenticationToken) {
        if (!(this_present_authenticationToken && that_present_authenticationToken))
          return false;
        if (!this.authenticationToken.equals(that.authenticationToken))
          return false;
      }

      boolean this_present_guid = true && this.isSetGuid();
      boolean that_present_guid = true && that.isSetGuid();
      if (this_present_guid || that_present_guid) {
        if (!(this_present_guid && that_present_guid))
          return false;
        if (!this.guid.equals(that.guid))
          return false;
      }

      return true;
    }

    public int hashCode() {
      return 0;
    }

    public int compareTo(expungeTag_args other) {
      if (!getClass().equals(other.getClass())) {
        return getClass().getName().compareTo(other.getClass().getName());
      }

      int lastComparison = 0;
      expungeTag_args typedOther = (expungeTag_args)other;

      lastComparison = Boolean.valueOf(isSetAuthenticationToken()).compareTo(isSetAuthenticationToken());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(authenticationToken, typedOther.authenticationToken);
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = Boolean.valueOf(isSetGuid()).compareTo(isSetGuid());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(guid, typedOther.guid);
      if (lastComparison != 0) {
        return lastComparison;
      }
      return 0;
    }

    public void read(TProtocol iprot) throws TException {
      TField field;
      iprot.readStructBegin();
      while (true)
      {
        field = iprot.readFieldBegin();
        if (field.type == TType.STOP) { 
          break;
        }
        _Fields fieldId = _Fields.findByThriftId(field.id);
        if (fieldId == null) {
          TProtocolUtil.skip(iprot, field.type);
        } else {
          switch (fieldId) {
            case AUTHENTICATION_TOKEN:
              if (field.type == TType.STRING) {
                this.authenticationToken = iprot.readString();
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
            case GUID:
              if (field.type == TType.STRING) {
                this.guid = iprot.readString();
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
          }
          iprot.readFieldEnd();
        }
      }
      iprot.readStructEnd();
      validate();
    }

    public void write(TProtocol oprot) throws TException {
      validate();

      oprot.writeStructBegin(STRUCT_DESC);
      if (this.authenticationToken != null) {
        oprot.writeFieldBegin(AUTHENTICATION_TOKEN_FIELD_DESC);
        oprot.writeString(this.authenticationToken);
        oprot.writeFieldEnd();
      }
      if (this.guid != null) {
        oprot.writeFieldBegin(GUID_FIELD_DESC);
        oprot.writeString(this.guid);
        oprot.writeFieldEnd();
      }
      oprot.writeFieldStop();
      oprot.writeStructEnd();
    }

    public String toString() {
      StringBuilder sb = new StringBuilder("expungeTag_args(");
      boolean first = true;

      sb.append("authenticationToken:");
      if (this.authenticationToken == null) {
        sb.append("null");
      } else {
        sb.append(this.authenticationToken);
      }
      first = false;
      if (!first) sb.append(", ");
      sb.append("guid:");
      if (this.guid == null) {
        sb.append("null");
      } else {
        sb.append(this.guid);
      }
      first = false;
      sb.append(")");
      return sb.toString();
    }

    public void validate() throws TException {
      // check for required fields
    }

  }

  public static class expungeTag_result implements TBase<expungeTag_result._Fields>, java.io.Serializable, Cloneable, Comparable<expungeTag_result>   {
    private static final TStruct STRUCT_DESC = new TStruct("expungeTag_result");

    private static final TField SUCCESS_FIELD_DESC = new TField("success", TType.I32, (short)0);
    private static final TField USER_EXCEPTION_FIELD_DESC = new TField("userException", TType.STRUCT, (short)1);
    private static final TField SYSTEM_EXCEPTION_FIELD_DESC = new TField("systemException", TType.STRUCT, (short)2);
    private static final TField NOT_FOUND_EXCEPTION_FIELD_DESC = new TField("notFoundException", TType.STRUCT, (short)3);

    private int success;
    private com.evernote.edam.error.EDAMUserException userException;
    private com.evernote.edam.error.EDAMSystemException systemException;
    private com.evernote.edam.error.EDAMNotFoundException notFoundException;

    /** The set of fields this struct contains, along with convenience methods for finding and manipulating them. */
    public enum _Fields implements TFieldIdEnum {
      SUCCESS((short)0, "success"),
      USER_EXCEPTION((short)1, "userException"),
      SYSTEM_EXCEPTION((short)2, "systemException"),
      NOT_FOUND_EXCEPTION((short)3, "notFoundException");

      private static final Map<Integer, _Fields> byId = new HashMap<Integer, _Fields>();
      private static final Map<String, _Fields> byName = new HashMap<String, _Fields>();

      static {
        for (_Fields field : EnumSet.allOf(_Fields.class)) {
          byId.put((int)field._thriftId, field);
          byName.put(field.getFieldName(), field);
        }
      }

      /**
       * Find the _Fields constant that matches fieldId, or null if its not found.
       */
      public static _Fields findByThriftId(int fieldId) {
        return byId.get(fieldId);
      }

      /**
       * Find the _Fields constant that matches fieldId, throwing an exception
       * if it is not found.
       */
      public static _Fields findByThriftIdOrThrow(int fieldId) {
        _Fields fields = findByThriftId(fieldId);
        if (fields == null) throw new IllegalArgumentException("Field " + fieldId + " doesn't exist!");
        return fields;
      }

      /**
       * Find the _Fields constant that matches name, or null if its not found.
       */
      public static _Fields findByName(String name) {
        return byName.get(name);
      }

      private final short _thriftId;
      private final String _fieldName;

      _Fields(short thriftId, String fieldName) {
        _thriftId = thriftId;
        _fieldName = fieldName;
      }

      public short getThriftFieldId() {
        return _thriftId;
      }

      public String getFieldName() {
        return _fieldName;
      }
    }

    // isset id assignments
    private static final int __SUCCESS_ISSET_ID = 0;
    private BitSet __isset_bit_vector = new BitSet(1);

    public static final Map<_Fields, FieldMetaData> metaDataMap = Collections.unmodifiableMap(new EnumMap<_Fields, FieldMetaData>(_Fields.class) {{
      put(_Fields.SUCCESS, new FieldMetaData("success", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.I32)));
      put(_Fields.USER_EXCEPTION, new FieldMetaData("userException", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.STRUCT)));
      put(_Fields.SYSTEM_EXCEPTION, new FieldMetaData("systemException", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.STRUCT)));
      put(_Fields.NOT_FOUND_EXCEPTION, new FieldMetaData("notFoundException", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.STRUCT)));
    }});

    static {
      FieldMetaData.addStructMetaDataMap(expungeTag_result.class, metaDataMap);
    }

    public expungeTag_result() {
    }

    public expungeTag_result(
      int success,
      com.evernote.edam.error.EDAMUserException userException,
      com.evernote.edam.error.EDAMSystemException systemException,
      com.evernote.edam.error.EDAMNotFoundException notFoundException)
    {
      this();
      this.success = success;
      setSuccessIsSet(true);
      this.userException = userException;
      this.systemException = systemException;
      this.notFoundException = notFoundException;
    }

    /**
     * Performs a deep copy on <i>other</i>.
     */
    public expungeTag_result(expungeTag_result other) {
      __isset_bit_vector.clear();
      __isset_bit_vector.or(other.__isset_bit_vector);
      this.success = other.success;
      if (other.isSetUserException()) {
        this.userException = new com.evernote.edam.error.EDAMUserException(other.userException);
      }
      if (other.isSetSystemException()) {
        this.systemException = new com.evernote.edam.error.EDAMSystemException(other.systemException);
      }
      if (other.isSetNotFoundException()) {
        this.notFoundException = new com.evernote.edam.error.EDAMNotFoundException(other.notFoundException);
      }
    }

    public expungeTag_result deepCopy() {
      return new expungeTag_result(this);
    }

    @Deprecated
    public expungeTag_result clone() {
      return new expungeTag_result(this);
    }

    public int getSuccess() {
      return this.success;
    }

    public void setSuccess(int success) {
      this.success = success;
      setSuccessIsSet(true);
    }

    public void unsetSuccess() {
      __isset_bit_vector.clear(__SUCCESS_ISSET_ID);
    }

    /** Returns true if field success is set (has been asigned a value) and false otherwise */
    public boolean isSetSuccess() {
      return __isset_bit_vector.get(__SUCCESS_ISSET_ID);
    }

    public void setSuccessIsSet(boolean value) {
      __isset_bit_vector.set(__SUCCESS_ISSET_ID, value);
    }

    public com.evernote.edam.error.EDAMUserException getUserException() {
      return this.userException;
    }

    public void setUserException(com.evernote.edam.error.EDAMUserException userException) {
      this.userException = userException;
    }

    public void unsetUserException() {
      this.userException = null;
    }

    /** Returns true if field userException is set (has been asigned a value) and false otherwise */
    public boolean isSetUserException() {
      return this.userException != null;
    }

    public void setUserExceptionIsSet(boolean value) {
      if (!value) {
        this.userException = null;
      }
    }

    public com.evernote.edam.error.EDAMSystemException getSystemException() {
      return this.systemException;
    }

    public void setSystemException(com.evernote.edam.error.EDAMSystemException systemException) {
      this.systemException = systemException;
    }

    public void unsetSystemException() {
      this.systemException = null;
    }

    /** Returns true if field systemException is set (has been asigned a value) and false otherwise */
    public boolean isSetSystemException() {
      return this.systemException != null;
    }

    public void setSystemExceptionIsSet(boolean value) {
      if (!value) {
        this.systemException = null;
      }
    }

    public com.evernote.edam.error.EDAMNotFoundException getNotFoundException() {
      return this.notFoundException;
    }

    public void setNotFoundException(com.evernote.edam.error.EDAMNotFoundException notFoundException) {
      this.notFoundException = notFoundException;
    }

    public void unsetNotFoundException() {
      this.notFoundException = null;
    }

    /** Returns true if field notFoundException is set (has been asigned a value) and false otherwise */
    public boolean isSetNotFoundException() {
      return this.notFoundException != null;
    }

    public void setNotFoundExceptionIsSet(boolean value) {
      if (!value) {
        this.notFoundException = null;
      }
    }

    public void setFieldValue(_Fields field, Object value) {
      switch (field) {
      case SUCCESS:
        if (value == null) {
          unsetSuccess();
        } else {
          setSuccess((Integer)value);
        }
        break;

      case USER_EXCEPTION:
        if (value == null) {
          unsetUserException();
        } else {
          setUserException((com.evernote.edam.error.EDAMUserException)value);
        }
        break;

      case SYSTEM_EXCEPTION:
        if (value == null) {
          unsetSystemException();
        } else {
          setSystemException((com.evernote.edam.error.EDAMSystemException)value);
        }
        break;

      case NOT_FOUND_EXCEPTION:
        if (value == null) {
          unsetNotFoundException();
        } else {
          setNotFoundException((com.evernote.edam.error.EDAMNotFoundException)value);
        }
        break;

      }
    }

    public void setFieldValue(int fieldID, Object value) {
      setFieldValue(_Fields.findByThriftIdOrThrow(fieldID), value);
    }

    public Object getFieldValue(_Fields field) {
      switch (field) {
      case SUCCESS:
        return new Integer(getSuccess());

      case USER_EXCEPTION:
        return getUserException();

      case SYSTEM_EXCEPTION:
        return getSystemException();

      case NOT_FOUND_EXCEPTION:
        return getNotFoundException();

      }
      throw new IllegalStateException();
    }

    public Object getFieldValue(int fieldId) {
      return getFieldValue(_Fields.findByThriftIdOrThrow(fieldId));
    }

    /** Returns true if field corresponding to fieldID is set (has been asigned a value) and false otherwise */
    public boolean isSet(_Fields field) {
      switch (field) {
      case SUCCESS:
        return isSetSuccess();
      case USER_EXCEPTION:
        return isSetUserException();
      case SYSTEM_EXCEPTION:
        return isSetSystemException();
      case NOT_FOUND_EXCEPTION:
        return isSetNotFoundException();
      }
      throw new IllegalStateException();
    }

    public boolean isSet(int fieldID) {
      return isSet(_Fields.findByThriftIdOrThrow(fieldID));
    }

    public boolean equals(Object that) {
      if (that == null)
        return false;
      if (that instanceof expungeTag_result)
        return this.equals((expungeTag_result)that);
      return false;
    }

    public boolean equals(expungeTag_result that) {
      if (that == null)
        return false;

      boolean this_present_success = true;
      boolean that_present_success = true;
      if (this_present_success || that_present_success) {
        if (!(this_present_success && that_present_success))
          return false;
        if (this.success != that.success)
          return false;
      }

      boolean this_present_userException = true && this.isSetUserException();
      boolean that_present_userException = true && that.isSetUserException();
      if (this_present_userException || that_present_userException) {
        if (!(this_present_userException && that_present_userException))
          return false;
        if (!this.userException.equals(that.userException))
          return false;
      }

      boolean this_present_systemException = true && this.isSetSystemException();
      boolean that_present_systemException = true && that.isSetSystemException();
      if (this_present_systemException || that_present_systemException) {
        if (!(this_present_systemException && that_present_systemException))
          return false;
        if (!this.systemException.equals(that.systemException))
          return false;
      }

      boolean this_present_notFoundException = true && this.isSetNotFoundException();
      boolean that_present_notFoundException = true && that.isSetNotFoundException();
      if (this_present_notFoundException || that_present_notFoundException) {
        if (!(this_present_notFoundException && that_present_notFoundException))
          return false;
        if (!this.notFoundException.equals(that.notFoundException))
          return false;
      }

      return true;
    }

    public int hashCode() {
      return 0;
    }

    public int compareTo(expungeTag_result other) {
      if (!getClass().equals(other.getClass())) {
        return getClass().getName().compareTo(other.getClass().getName());
      }

      int lastComparison = 0;
      expungeTag_result typedOther = (expungeTag_result)other;

      lastComparison = Boolean.valueOf(isSetSuccess()).compareTo(isSetSuccess());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(success, typedOther.success);
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = Boolean.valueOf(isSetUserException()).compareTo(isSetUserException());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(userException, typedOther.userException);
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = Boolean.valueOf(isSetSystemException()).compareTo(isSetSystemException());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(systemException, typedOther.systemException);
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = Boolean.valueOf(isSetNotFoundException()).compareTo(isSetNotFoundException());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(notFoundException, typedOther.notFoundException);
      if (lastComparison != 0) {
        return lastComparison;
      }
      return 0;
    }

    public void read(TProtocol iprot) throws TException {
      TField field;
      iprot.readStructBegin();
      while (true)
      {
        field = iprot.readFieldBegin();
        if (field.type == TType.STOP) { 
          break;
        }
        _Fields fieldId = _Fields.findByThriftId(field.id);
        if (fieldId == null) {
          TProtocolUtil.skip(iprot, field.type);
        } else {
          switch (fieldId) {
            case SUCCESS:
              if (field.type == TType.I32) {
                this.success = iprot.readI32();
                setSuccessIsSet(true);
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
            case USER_EXCEPTION:
              if (field.type == TType.STRUCT) {
                this.userException = new com.evernote.edam.error.EDAMUserException();
                this.userException.read(iprot);
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
            case SYSTEM_EXCEPTION:
              if (field.type == TType.STRUCT) {
                this.systemException = new com.evernote.edam.error.EDAMSystemException();
                this.systemException.read(iprot);
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
            case NOT_FOUND_EXCEPTION:
              if (field.type == TType.STRUCT) {
                this.notFoundException = new com.evernote.edam.error.EDAMNotFoundException();
                this.notFoundException.read(iprot);
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
          }
          iprot.readFieldEnd();
        }
      }
      iprot.readStructEnd();
      validate();
    }

    public void write(TProtocol oprot) throws TException {
      oprot.writeStructBegin(STRUCT_DESC);

      if (this.isSetSuccess()) {
        oprot.writeFieldBegin(SUCCESS_FIELD_DESC);
        oprot.writeI32(this.success);
        oprot.writeFieldEnd();
      } else if (this.isSetUserException()) {
        oprot.writeFieldBegin(USER_EXCEPTION_FIELD_DESC);
        this.userException.write(oprot);
        oprot.writeFieldEnd();
      } else if (this.isSetSystemException()) {
        oprot.writeFieldBegin(SYSTEM_EXCEPTION_FIELD_DESC);
        this.systemException.write(oprot);
        oprot.writeFieldEnd();
      } else if (this.isSetNotFoundException()) {
        oprot.writeFieldBegin(NOT_FOUND_EXCEPTION_FIELD_DESC);
        this.notFoundException.write(oprot);
        oprot.writeFieldEnd();
      }
      oprot.writeFieldStop();
      oprot.writeStructEnd();
    }

    public String toString() {
      StringBuilder sb = new StringBuilder("expungeTag_result(");
      boolean first = true;

      sb.append("success:");
      sb.append(this.success);
      first = false;
      if (!first) sb.append(", ");
      sb.append("userException:");
      if (this.userException == null) {
        sb.append("null");
      } else {
        sb.append(this.userException);
      }
      first = false;
      if (!first) sb.append(", ");
      sb.append("systemException:");
      if (this.systemException == null) {
        sb.append("null");
      } else {
        sb.append(this.systemException);
      }
      first = false;
      if (!first) sb.append(", ");
      sb.append("notFoundException:");
      if (this.notFoundException == null) {
        sb.append("null");
      } else {
        sb.append(this.notFoundException);
      }
      first = false;
      sb.append(")");
      return sb.toString();
    }

    public void validate() throws TException {
      // check for required fields
    }

  }

  public static class listSearches_args implements TBase<listSearches_args._Fields>, java.io.Serializable, Cloneable, Comparable<listSearches_args>   {
    private static final TStruct STRUCT_DESC = new TStruct("listSearches_args");

    private static final TField AUTHENTICATION_TOKEN_FIELD_DESC = new TField("authenticationToken", TType.STRING, (short)1);

    private String authenticationToken;

    /** The set of fields this struct contains, along with convenience methods for finding and manipulating them. */
    public enum _Fields implements TFieldIdEnum {
      AUTHENTICATION_TOKEN((short)1, "authenticationToken");

      private static final Map<Integer, _Fields> byId = new HashMap<Integer, _Fields>();
      private static final Map<String, _Fields> byName = new HashMap<String, _Fields>();

      static {
        for (_Fields field : EnumSet.allOf(_Fields.class)) {
          byId.put((int)field._thriftId, field);
          byName.put(field.getFieldName(), field);
        }
      }

      /**
       * Find the _Fields constant that matches fieldId, or null if its not found.
       */
      public static _Fields findByThriftId(int fieldId) {
        return byId.get(fieldId);
      }

      /**
       * Find the _Fields constant that matches fieldId, throwing an exception
       * if it is not found.
       */
      public static _Fields findByThriftIdOrThrow(int fieldId) {
        _Fields fields = findByThriftId(fieldId);
        if (fields == null) throw new IllegalArgumentException("Field " + fieldId + " doesn't exist!");
        return fields;
      }

      /**
       * Find the _Fields constant that matches name, or null if its not found.
       */
      public static _Fields findByName(String name) {
        return byName.get(name);
      }

      private final short _thriftId;
      private final String _fieldName;

      _Fields(short thriftId, String fieldName) {
        _thriftId = thriftId;
        _fieldName = fieldName;
      }

      public short getThriftFieldId() {
        return _thriftId;
      }

      public String getFieldName() {
        return _fieldName;
      }
    }

    // isset id assignments

    public static final Map<_Fields, FieldMetaData> metaDataMap = Collections.unmodifiableMap(new EnumMap<_Fields, FieldMetaData>(_Fields.class) {{
      put(_Fields.AUTHENTICATION_TOKEN, new FieldMetaData("authenticationToken", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.STRING)));
    }});

    static {
      FieldMetaData.addStructMetaDataMap(listSearches_args.class, metaDataMap);
    }

    public listSearches_args() {
    }

    public listSearches_args(
      String authenticationToken)
    {
      this();
      this.authenticationToken = authenticationToken;
    }

    /**
     * Performs a deep copy on <i>other</i>.
     */
    public listSearches_args(listSearches_args other) {
      if (other.isSetAuthenticationToken()) {
        this.authenticationToken = other.authenticationToken;
      }
    }

    public listSearches_args deepCopy() {
      return new listSearches_args(this);
    }

    @Deprecated
    public listSearches_args clone() {
      return new listSearches_args(this);
    }

    public String getAuthenticationToken() {
      return this.authenticationToken;
    }

    public void setAuthenticationToken(String authenticationToken) {
      this.authenticationToken = authenticationToken;
    }

    public void unsetAuthenticationToken() {
      this.authenticationToken = null;
    }

    /** Returns true if field authenticationToken is set (has been asigned a value) and false otherwise */
    public boolean isSetAuthenticationToken() {
      return this.authenticationToken != null;
    }

    public void setAuthenticationTokenIsSet(boolean value) {
      if (!value) {
        this.authenticationToken = null;
      }
    }

    public void setFieldValue(_Fields field, Object value) {
      switch (field) {
      case AUTHENTICATION_TOKEN:
        if (value == null) {
          unsetAuthenticationToken();
        } else {
          setAuthenticationToken((String)value);
        }
        break;

      }
    }

    public void setFieldValue(int fieldID, Object value) {
      setFieldValue(_Fields.findByThriftIdOrThrow(fieldID), value);
    }

    public Object getFieldValue(_Fields field) {
      switch (field) {
      case AUTHENTICATION_TOKEN:
        return getAuthenticationToken();

      }
      throw new IllegalStateException();
    }

    public Object getFieldValue(int fieldId) {
      return getFieldValue(_Fields.findByThriftIdOrThrow(fieldId));
    }

    /** Returns true if field corresponding to fieldID is set (has been asigned a value) and false otherwise */
    public boolean isSet(_Fields field) {
      switch (field) {
      case AUTHENTICATION_TOKEN:
        return isSetAuthenticationToken();
      }
      throw new IllegalStateException();
    }

    public boolean isSet(int fieldID) {
      return isSet(_Fields.findByThriftIdOrThrow(fieldID));
    }

    public boolean equals(Object that) {
      if (that == null)
        return false;
      if (that instanceof listSearches_args)
        return this.equals((listSearches_args)that);
      return false;
    }

    public boolean equals(listSearches_args that) {
      if (that == null)
        return false;

      boolean this_present_authenticationToken = true && this.isSetAuthenticationToken();
      boolean that_present_authenticationToken = true && that.isSetAuthenticationToken();
      if (this_present_authenticationToken || that_present_authenticationToken) {
        if (!(this_present_authenticationToken && that_present_authenticationToken))
          return false;
        if (!this.authenticationToken.equals(that.authenticationToken))
          return false;
      }

      return true;
    }

    public int hashCode() {
      return 0;
    }

    public int compareTo(listSearches_args other) {
      if (!getClass().equals(other.getClass())) {
        return getClass().getName().compareTo(other.getClass().getName());
      }

      int lastComparison = 0;
      listSearches_args typedOther = (listSearches_args)other;

      lastComparison = Boolean.valueOf(isSetAuthenticationToken()).compareTo(isSetAuthenticationToken());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(authenticationToken, typedOther.authenticationToken);
      if (lastComparison != 0) {
        return lastComparison;
      }
      return 0;
    }

    public void read(TProtocol iprot) throws TException {
      TField field;
      iprot.readStructBegin();
      while (true)
      {
        field = iprot.readFieldBegin();
        if (field.type == TType.STOP) { 
          break;
        }
        _Fields fieldId = _Fields.findByThriftId(field.id);
        if (fieldId == null) {
          TProtocolUtil.skip(iprot, field.type);
        } else {
          switch (fieldId) {
            case AUTHENTICATION_TOKEN:
              if (field.type == TType.STRING) {
                this.authenticationToken = iprot.readString();
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
          }
          iprot.readFieldEnd();
        }
      }
      iprot.readStructEnd();
      validate();
    }

    public void write(TProtocol oprot) throws TException {
      validate();

      oprot.writeStructBegin(STRUCT_DESC);
      if (this.authenticationToken != null) {
        oprot.writeFieldBegin(AUTHENTICATION_TOKEN_FIELD_DESC);
        oprot.writeString(this.authenticationToken);
        oprot.writeFieldEnd();
      }
      oprot.writeFieldStop();
      oprot.writeStructEnd();
    }

    public String toString() {
      StringBuilder sb = new StringBuilder("listSearches_args(");
      boolean first = true;

      sb.append("authenticationToken:");
      if (this.authenticationToken == null) {
        sb.append("null");
      } else {
        sb.append(this.authenticationToken);
      }
      first = false;
      sb.append(")");
      return sb.toString();
    }

    public void validate() throws TException {
      // check for required fields
    }

  }

  public static class listSearches_result implements TBase<listSearches_result._Fields>, java.io.Serializable, Cloneable, Comparable<listSearches_result>   {
    private static final TStruct STRUCT_DESC = new TStruct("listSearches_result");

    private static final TField SUCCESS_FIELD_DESC = new TField("success", TType.LIST, (short)0);
    private static final TField USER_EXCEPTION_FIELD_DESC = new TField("userException", TType.STRUCT, (short)1);
    private static final TField SYSTEM_EXCEPTION_FIELD_DESC = new TField("systemException", TType.STRUCT, (short)2);

    private List<com.evernote.edam.type.SavedSearch> success;
    private com.evernote.edam.error.EDAMUserException userException;
    private com.evernote.edam.error.EDAMSystemException systemException;

    /** The set of fields this struct contains, along with convenience methods for finding and manipulating them. */
    public enum _Fields implements TFieldIdEnum {
      SUCCESS((short)0, "success"),
      USER_EXCEPTION((short)1, "userException"),
      SYSTEM_EXCEPTION((short)2, "systemException");

      private static final Map<Integer, _Fields> byId = new HashMap<Integer, _Fields>();
      private static final Map<String, _Fields> byName = new HashMap<String, _Fields>();

      static {
        for (_Fields field : EnumSet.allOf(_Fields.class)) {
          byId.put((int)field._thriftId, field);
          byName.put(field.getFieldName(), field);
        }
      }

      /**
       * Find the _Fields constant that matches fieldId, or null if its not found.
       */
      public static _Fields findByThriftId(int fieldId) {
        return byId.get(fieldId);
      }

      /**
       * Find the _Fields constant that matches fieldId, throwing an exception
       * if it is not found.
       */
      public static _Fields findByThriftIdOrThrow(int fieldId) {
        _Fields fields = findByThriftId(fieldId);
        if (fields == null) throw new IllegalArgumentException("Field " + fieldId + " doesn't exist!");
        return fields;
      }

      /**
       * Find the _Fields constant that matches name, or null if its not found.
       */
      public static _Fields findByName(String name) {
        return byName.get(name);
      }

      private final short _thriftId;
      private final String _fieldName;

      _Fields(short thriftId, String fieldName) {
        _thriftId = thriftId;
        _fieldName = fieldName;
      }

      public short getThriftFieldId() {
        return _thriftId;
      }

      public String getFieldName() {
        return _fieldName;
      }
    }

    // isset id assignments

    public static final Map<_Fields, FieldMetaData> metaDataMap = Collections.unmodifiableMap(new EnumMap<_Fields, FieldMetaData>(_Fields.class) {{
      put(_Fields.SUCCESS, new FieldMetaData("success", TFieldRequirementType.DEFAULT, 
          new ListMetaData(TType.LIST, 
              new StructMetaData(TType.STRUCT, com.evernote.edam.type.SavedSearch.class))));
      put(_Fields.USER_EXCEPTION, new FieldMetaData("userException", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.STRUCT)));
      put(_Fields.SYSTEM_EXCEPTION, new FieldMetaData("systemException", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.STRUCT)));
    }});

    static {
      FieldMetaData.addStructMetaDataMap(listSearches_result.class, metaDataMap);
    }

    public listSearches_result() {
    }

    public listSearches_result(
      List<com.evernote.edam.type.SavedSearch> success,
      com.evernote.edam.error.EDAMUserException userException,
      com.evernote.edam.error.EDAMSystemException systemException)
    {
      this();
      this.success = success;
      this.userException = userException;
      this.systemException = systemException;
    }

    /**
     * Performs a deep copy on <i>other</i>.
     */
    public listSearches_result(listSearches_result other) {
      if (other.isSetSuccess()) {
        List<com.evernote.edam.type.SavedSearch> __this__success = new ArrayList<com.evernote.edam.type.SavedSearch>();
        for (com.evernote.edam.type.SavedSearch other_element : other.success) {
          __this__success.add(new com.evernote.edam.type.SavedSearch(other_element));
        }
        this.success = __this__success;
      }
      if (other.isSetUserException()) {
        this.userException = new com.evernote.edam.error.EDAMUserException(other.userException);
      }
      if (other.isSetSystemException()) {
        this.systemException = new com.evernote.edam.error.EDAMSystemException(other.systemException);
      }
    }

    public listSearches_result deepCopy() {
      return new listSearches_result(this);
    }

    @Deprecated
    public listSearches_result clone() {
      return new listSearches_result(this);
    }

    public int getSuccessSize() {
      return (this.success == null) ? 0 : this.success.size();
    }

    public java.util.Iterator<com.evernote.edam.type.SavedSearch> getSuccessIterator() {
      return (this.success == null) ? null : this.success.iterator();
    }

    public void addToSuccess(com.evernote.edam.type.SavedSearch elem) {
      if (this.success == null) {
        this.success = new ArrayList<com.evernote.edam.type.SavedSearch>();
      }
      this.success.add(elem);
    }

    public List<com.evernote.edam.type.SavedSearch> getSuccess() {
      return this.success;
    }

    public void setSuccess(List<com.evernote.edam.type.SavedSearch> success) {
      this.success = success;
    }

    public void unsetSuccess() {
      this.success = null;
    }

    /** Returns true if field success is set (has been asigned a value) and false otherwise */
    public boolean isSetSuccess() {
      return this.success != null;
    }

    public void setSuccessIsSet(boolean value) {
      if (!value) {
        this.success = null;
      }
    }

    public com.evernote.edam.error.EDAMUserException getUserException() {
      return this.userException;
    }

    public void setUserException(com.evernote.edam.error.EDAMUserException userException) {
      this.userException = userException;
    }

    public void unsetUserException() {
      this.userException = null;
    }

    /** Returns true if field userException is set (has been asigned a value) and false otherwise */
    public boolean isSetUserException() {
      return this.userException != null;
    }

    public void setUserExceptionIsSet(boolean value) {
      if (!value) {
        this.userException = null;
      }
    }

    public com.evernote.edam.error.EDAMSystemException getSystemException() {
      return this.systemException;
    }

    public void setSystemException(com.evernote.edam.error.EDAMSystemException systemException) {
      this.systemException = systemException;
    }

    public void unsetSystemException() {
      this.systemException = null;
    }

    /** Returns true if field systemException is set (has been asigned a value) and false otherwise */
    public boolean isSetSystemException() {
      return this.systemException != null;
    }

    public void setSystemExceptionIsSet(boolean value) {
      if (!value) {
        this.systemException = null;
      }
    }

    public void setFieldValue(_Fields field, Object value) {
      switch (field) {
      case SUCCESS:
        if (value == null) {
          unsetSuccess();
        } else {
          setSuccess((List<com.evernote.edam.type.SavedSearch>)value);
        }
        break;

      case USER_EXCEPTION:
        if (value == null) {
          unsetUserException();
        } else {
          setUserException((com.evernote.edam.error.EDAMUserException)value);
        }
        break;

      case SYSTEM_EXCEPTION:
        if (value == null) {
          unsetSystemException();
        } else {
          setSystemException((com.evernote.edam.error.EDAMSystemException)value);
        }
        break;

      }
    }

    public void setFieldValue(int fieldID, Object value) {
      setFieldValue(_Fields.findByThriftIdOrThrow(fieldID), value);
    }

    public Object getFieldValue(_Fields field) {
      switch (field) {
      case SUCCESS:
        return getSuccess();

      case USER_EXCEPTION:
        return getUserException();

      case SYSTEM_EXCEPTION:
        return getSystemException();

      }
      throw new IllegalStateException();
    }

    public Object getFieldValue(int fieldId) {
      return getFieldValue(_Fields.findByThriftIdOrThrow(fieldId));
    }

    /** Returns true if field corresponding to fieldID is set (has been asigned a value) and false otherwise */
    public boolean isSet(_Fields field) {
      switch (field) {
      case SUCCESS:
        return isSetSuccess();
      case USER_EXCEPTION:
        return isSetUserException();
      case SYSTEM_EXCEPTION:
        return isSetSystemException();
      }
      throw new IllegalStateException();
    }

    public boolean isSet(int fieldID) {
      return isSet(_Fields.findByThriftIdOrThrow(fieldID));
    }

    public boolean equals(Object that) {
      if (that == null)
        return false;
      if (that instanceof listSearches_result)
        return this.equals((listSearches_result)that);
      return false;
    }

    public boolean equals(listSearches_result that) {
      if (that == null)
        return false;

      boolean this_present_success = true && this.isSetSuccess();
      boolean that_present_success = true && that.isSetSuccess();
      if (this_present_success || that_present_success) {
        if (!(this_present_success && that_present_success))
          return false;
        if (!this.success.equals(that.success))
          return false;
      }

      boolean this_present_userException = true && this.isSetUserException();
      boolean that_present_userException = true && that.isSetUserException();
      if (this_present_userException || that_present_userException) {
        if (!(this_present_userException && that_present_userException))
          return false;
        if (!this.userException.equals(that.userException))
          return false;
      }

      boolean this_present_systemException = true && this.isSetSystemException();
      boolean that_present_systemException = true && that.isSetSystemException();
      if (this_present_systemException || that_present_systemException) {
        if (!(this_present_systemException && that_present_systemException))
          return false;
        if (!this.systemException.equals(that.systemException))
          return false;
      }

      return true;
    }

    public int hashCode() {
      return 0;
    }

    public int compareTo(listSearches_result other) {
      if (!getClass().equals(other.getClass())) {
        return getClass().getName().compareTo(other.getClass().getName());
      }

      int lastComparison = 0;
      listSearches_result typedOther = (listSearches_result)other;

      lastComparison = Boolean.valueOf(isSetSuccess()).compareTo(isSetSuccess());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(success, typedOther.success);
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = Boolean.valueOf(isSetUserException()).compareTo(isSetUserException());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(userException, typedOther.userException);
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = Boolean.valueOf(isSetSystemException()).compareTo(isSetSystemException());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(systemException, typedOther.systemException);
      if (lastComparison != 0) {
        return lastComparison;
      }
      return 0;
    }

    public void read(TProtocol iprot) throws TException {
      TField field;
      iprot.readStructBegin();
      while (true)
      {
        field = iprot.readFieldBegin();
        if (field.type == TType.STOP) { 
          break;
        }
        _Fields fieldId = _Fields.findByThriftId(field.id);
        if (fieldId == null) {
          TProtocolUtil.skip(iprot, field.type);
        } else {
          switch (fieldId) {
            case SUCCESS:
              if (field.type == TType.LIST) {
                {
                  TList _list91 = iprot.readListBegin();
                  this.success = new ArrayList<com.evernote.edam.type.SavedSearch>(_list91.size);
                  for (int _i92 = 0; _i92 < _list91.size; ++_i92)
                  {
                    com.evernote.edam.type.SavedSearch _elem93;
                    _elem93 = new com.evernote.edam.type.SavedSearch();
                    _elem93.read(iprot);
                    this.success.add(_elem93);
                  }
                  iprot.readListEnd();
                }
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
            case USER_EXCEPTION:
              if (field.type == TType.STRUCT) {
                this.userException = new com.evernote.edam.error.EDAMUserException();
                this.userException.read(iprot);
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
            case SYSTEM_EXCEPTION:
              if (field.type == TType.STRUCT) {
                this.systemException = new com.evernote.edam.error.EDAMSystemException();
                this.systemException.read(iprot);
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
          }
          iprot.readFieldEnd();
        }
      }
      iprot.readStructEnd();
      validate();
    }

    public void write(TProtocol oprot) throws TException {
      oprot.writeStructBegin(STRUCT_DESC);

      if (this.isSetSuccess()) {
        oprot.writeFieldBegin(SUCCESS_FIELD_DESC);
        {
          oprot.writeListBegin(new TList(TType.STRUCT, this.success.size()));
          for (com.evernote.edam.type.SavedSearch _iter94 : this.success)
          {
            _iter94.write(oprot);
          }
          oprot.writeListEnd();
        }
        oprot.writeFieldEnd();
      } else if (this.isSetUserException()) {
        oprot.writeFieldBegin(USER_EXCEPTION_FIELD_DESC);
        this.userException.write(oprot);
        oprot.writeFieldEnd();
      } else if (this.isSetSystemException()) {
        oprot.writeFieldBegin(SYSTEM_EXCEPTION_FIELD_DESC);
        this.systemException.write(oprot);
        oprot.writeFieldEnd();
      }
      oprot.writeFieldStop();
      oprot.writeStructEnd();
    }

    public String toString() {
      StringBuilder sb = new StringBuilder("listSearches_result(");
      boolean first = true;

      sb.append("success:");
      if (this.success == null) {
        sb.append("null");
      } else {
        sb.append(this.success);
      }
      first = false;
      if (!first) sb.append(", ");
      sb.append("userException:");
      if (this.userException == null) {
        sb.append("null");
      } else {
        sb.append(this.userException);
      }
      first = false;
      if (!first) sb.append(", ");
      sb.append("systemException:");
      if (this.systemException == null) {
        sb.append("null");
      } else {
        sb.append(this.systemException);
      }
      first = false;
      sb.append(")");
      return sb.toString();
    }

    public void validate() throws TException {
      // check for required fields
    }

  }

  public static class getSearch_args implements TBase<getSearch_args._Fields>, java.io.Serializable, Cloneable, Comparable<getSearch_args>   {
    private static final TStruct STRUCT_DESC = new TStruct("getSearch_args");

    private static final TField AUTHENTICATION_TOKEN_FIELD_DESC = new TField("authenticationToken", TType.STRING, (short)1);
    private static final TField GUID_FIELD_DESC = new TField("guid", TType.STRING, (short)2);

    private String authenticationToken;
    private String guid;

    /** The set of fields this struct contains, along with convenience methods for finding and manipulating them. */
    public enum _Fields implements TFieldIdEnum {
      AUTHENTICATION_TOKEN((short)1, "authenticationToken"),
      GUID((short)2, "guid");

      private static final Map<Integer, _Fields> byId = new HashMap<Integer, _Fields>();
      private static final Map<String, _Fields> byName = new HashMap<String, _Fields>();

      static {
        for (_Fields field : EnumSet.allOf(_Fields.class)) {
          byId.put((int)field._thriftId, field);
          byName.put(field.getFieldName(), field);
        }
      }

      /**
       * Find the _Fields constant that matches fieldId, or null if its not found.
       */
      public static _Fields findByThriftId(int fieldId) {
        return byId.get(fieldId);
      }

      /**
       * Find the _Fields constant that matches fieldId, throwing an exception
       * if it is not found.
       */
      public static _Fields findByThriftIdOrThrow(int fieldId) {
        _Fields fields = findByThriftId(fieldId);
        if (fields == null) throw new IllegalArgumentException("Field " + fieldId + " doesn't exist!");
        return fields;
      }

      /**
       * Find the _Fields constant that matches name, or null if its not found.
       */
      public static _Fields findByName(String name) {
        return byName.get(name);
      }

      private final short _thriftId;
      private final String _fieldName;

      _Fields(short thriftId, String fieldName) {
        _thriftId = thriftId;
        _fieldName = fieldName;
      }

      public short getThriftFieldId() {
        return _thriftId;
      }

      public String getFieldName() {
        return _fieldName;
      }
    }

    // isset id assignments

    public static final Map<_Fields, FieldMetaData> metaDataMap = Collections.unmodifiableMap(new EnumMap<_Fields, FieldMetaData>(_Fields.class) {{
      put(_Fields.AUTHENTICATION_TOKEN, new FieldMetaData("authenticationToken", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.STRING)));
      put(_Fields.GUID, new FieldMetaData("guid", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.STRING)));
    }});

    static {
      FieldMetaData.addStructMetaDataMap(getSearch_args.class, metaDataMap);
    }

    public getSearch_args() {
    }

    public getSearch_args(
      String authenticationToken,
      String guid)
    {
      this();
      this.authenticationToken = authenticationToken;
      this.guid = guid;
    }

    /**
     * Performs a deep copy on <i>other</i>.
     */
    public getSearch_args(getSearch_args other) {
      if (other.isSetAuthenticationToken()) {
        this.authenticationToken = other.authenticationToken;
      }
      if (other.isSetGuid()) {
        this.guid = other.guid;
      }
    }

    public getSearch_args deepCopy() {
      return new getSearch_args(this);
    }

    @Deprecated
    public getSearch_args clone() {
      return new getSearch_args(this);
    }

    public String getAuthenticationToken() {
      return this.authenticationToken;
    }

    public void setAuthenticationToken(String authenticationToken) {
      this.authenticationToken = authenticationToken;
    }

    public void unsetAuthenticationToken() {
      this.authenticationToken = null;
    }

    /** Returns true if field authenticationToken is set (has been asigned a value) and false otherwise */
    public boolean isSetAuthenticationToken() {
      return this.authenticationToken != null;
    }

    public void setAuthenticationTokenIsSet(boolean value) {
      if (!value) {
        this.authenticationToken = null;
      }
    }

    public String getGuid() {
      return this.guid;
    }

    public void setGuid(String guid) {
      this.guid = guid;
    }

    public void unsetGuid() {
      this.guid = null;
    }

    /** Returns true if field guid is set (has been asigned a value) and false otherwise */
    public boolean isSetGuid() {
      return this.guid != null;
    }

    public void setGuidIsSet(boolean value) {
      if (!value) {
        this.guid = null;
      }
    }

    public void setFieldValue(_Fields field, Object value) {
      switch (field) {
      case AUTHENTICATION_TOKEN:
        if (value == null) {
          unsetAuthenticationToken();
        } else {
          setAuthenticationToken((String)value);
        }
        break;

      case GUID:
        if (value == null) {
          unsetGuid();
        } else {
          setGuid((String)value);
        }
        break;

      }
    }

    public void setFieldValue(int fieldID, Object value) {
      setFieldValue(_Fields.findByThriftIdOrThrow(fieldID), value);
    }

    public Object getFieldValue(_Fields field) {
      switch (field) {
      case AUTHENTICATION_TOKEN:
        return getAuthenticationToken();

      case GUID:
        return getGuid();

      }
      throw new IllegalStateException();
    }

    public Object getFieldValue(int fieldId) {
      return getFieldValue(_Fields.findByThriftIdOrThrow(fieldId));
    }

    /** Returns true if field corresponding to fieldID is set (has been asigned a value) and false otherwise */
    public boolean isSet(_Fields field) {
      switch (field) {
      case AUTHENTICATION_TOKEN:
        return isSetAuthenticationToken();
      case GUID:
        return isSetGuid();
      }
      throw new IllegalStateException();
    }

    public boolean isSet(int fieldID) {
      return isSet(_Fields.findByThriftIdOrThrow(fieldID));
    }

    public boolean equals(Object that) {
      if (that == null)
        return false;
      if (that instanceof getSearch_args)
        return this.equals((getSearch_args)that);
      return false;
    }

    public boolean equals(getSearch_args that) {
      if (that == null)
        return false;

      boolean this_present_authenticationToken = true && this.isSetAuthenticationToken();
      boolean that_present_authenticationToken = true && that.isSetAuthenticationToken();
      if (this_present_authenticationToken || that_present_authenticationToken) {
        if (!(this_present_authenticationToken && that_present_authenticationToken))
          return false;
        if (!this.authenticationToken.equals(that.authenticationToken))
          return false;
      }

      boolean this_present_guid = true && this.isSetGuid();
      boolean that_present_guid = true && that.isSetGuid();
      if (this_present_guid || that_present_guid) {
        if (!(this_present_guid && that_present_guid))
          return false;
        if (!this.guid.equals(that.guid))
          return false;
      }

      return true;
    }

    public int hashCode() {
      return 0;
    }

    public int compareTo(getSearch_args other) {
      if (!getClass().equals(other.getClass())) {
        return getClass().getName().compareTo(other.getClass().getName());
      }

      int lastComparison = 0;
      getSearch_args typedOther = (getSearch_args)other;

      lastComparison = Boolean.valueOf(isSetAuthenticationToken()).compareTo(isSetAuthenticationToken());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(authenticationToken, typedOther.authenticationToken);
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = Boolean.valueOf(isSetGuid()).compareTo(isSetGuid());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(guid, typedOther.guid);
      if (lastComparison != 0) {
        return lastComparison;
      }
      return 0;
    }

    public void read(TProtocol iprot) throws TException {
      TField field;
      iprot.readStructBegin();
      while (true)
      {
        field = iprot.readFieldBegin();
        if (field.type == TType.STOP) { 
          break;
        }
        _Fields fieldId = _Fields.findByThriftId(field.id);
        if (fieldId == null) {
          TProtocolUtil.skip(iprot, field.type);
        } else {
          switch (fieldId) {
            case AUTHENTICATION_TOKEN:
              if (field.type == TType.STRING) {
                this.authenticationToken = iprot.readString();
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
            case GUID:
              if (field.type == TType.STRING) {
                this.guid = iprot.readString();
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
          }
          iprot.readFieldEnd();
        }
      }
      iprot.readStructEnd();
      validate();
    }

    public void write(TProtocol oprot) throws TException {
      validate();

      oprot.writeStructBegin(STRUCT_DESC);
      if (this.authenticationToken != null) {
        oprot.writeFieldBegin(AUTHENTICATION_TOKEN_FIELD_DESC);
        oprot.writeString(this.authenticationToken);
        oprot.writeFieldEnd();
      }
      if (this.guid != null) {
        oprot.writeFieldBegin(GUID_FIELD_DESC);
        oprot.writeString(this.guid);
        oprot.writeFieldEnd();
      }
      oprot.writeFieldStop();
      oprot.writeStructEnd();
    }

    public String toString() {
      StringBuilder sb = new StringBuilder("getSearch_args(");
      boolean first = true;

      sb.append("authenticationToken:");
      if (this.authenticationToken == null) {
        sb.append("null");
      } else {
        sb.append(this.authenticationToken);
      }
      first = false;
      if (!first) sb.append(", ");
      sb.append("guid:");
      if (this.guid == null) {
        sb.append("null");
      } else {
        sb.append(this.guid);
      }
      first = false;
      sb.append(")");
      return sb.toString();
    }

    public void validate() throws TException {
      // check for required fields
    }

  }

  public static class getSearch_result implements TBase<getSearch_result._Fields>, java.io.Serializable, Cloneable, Comparable<getSearch_result>   {
    private static final TStruct STRUCT_DESC = new TStruct("getSearch_result");

    private static final TField SUCCESS_FIELD_DESC = new TField("success", TType.STRUCT, (short)0);
    private static final TField USER_EXCEPTION_FIELD_DESC = new TField("userException", TType.STRUCT, (short)1);
    private static final TField SYSTEM_EXCEPTION_FIELD_DESC = new TField("systemException", TType.STRUCT, (short)2);
    private static final TField NOT_FOUND_EXCEPTION_FIELD_DESC = new TField("notFoundException", TType.STRUCT, (short)3);

    private com.evernote.edam.type.SavedSearch success;
    private com.evernote.edam.error.EDAMUserException userException;
    private com.evernote.edam.error.EDAMSystemException systemException;
    private com.evernote.edam.error.EDAMNotFoundException notFoundException;

    /** The set of fields this struct contains, along with convenience methods for finding and manipulating them. */
    public enum _Fields implements TFieldIdEnum {
      SUCCESS((short)0, "success"),
      USER_EXCEPTION((short)1, "userException"),
      SYSTEM_EXCEPTION((short)2, "systemException"),
      NOT_FOUND_EXCEPTION((short)3, "notFoundException");

      private static final Map<Integer, _Fields> byId = new HashMap<Integer, _Fields>();
      private static final Map<String, _Fields> byName = new HashMap<String, _Fields>();

      static {
        for (_Fields field : EnumSet.allOf(_Fields.class)) {
          byId.put((int)field._thriftId, field);
          byName.put(field.getFieldName(), field);
        }
      }

      /**
       * Find the _Fields constant that matches fieldId, or null if its not found.
       */
      public static _Fields findByThriftId(int fieldId) {
        return byId.get(fieldId);
      }

      /**
       * Find the _Fields constant that matches fieldId, throwing an exception
       * if it is not found.
       */
      public static _Fields findByThriftIdOrThrow(int fieldId) {
        _Fields fields = findByThriftId(fieldId);
        if (fields == null) throw new IllegalArgumentException("Field " + fieldId + " doesn't exist!");
        return fields;
      }

      /**
       * Find the _Fields constant that matches name, or null if its not found.
       */
      public static _Fields findByName(String name) {
        return byName.get(name);
      }

      private final short _thriftId;
      private final String _fieldName;

      _Fields(short thriftId, String fieldName) {
        _thriftId = thriftId;
        _fieldName = fieldName;
      }

      public short getThriftFieldId() {
        return _thriftId;
      }

      public String getFieldName() {
        return _fieldName;
      }
    }

    // isset id assignments

    public static final Map<_Fields, FieldMetaData> metaDataMap = Collections.unmodifiableMap(new EnumMap<_Fields, FieldMetaData>(_Fields.class) {{
      put(_Fields.SUCCESS, new FieldMetaData("success", TFieldRequirementType.DEFAULT, 
          new StructMetaData(TType.STRUCT, com.evernote.edam.type.SavedSearch.class)));
      put(_Fields.USER_EXCEPTION, new FieldMetaData("userException", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.STRUCT)));
      put(_Fields.SYSTEM_EXCEPTION, new FieldMetaData("systemException", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.STRUCT)));
      put(_Fields.NOT_FOUND_EXCEPTION, new FieldMetaData("notFoundException", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.STRUCT)));
    }});

    static {
      FieldMetaData.addStructMetaDataMap(getSearch_result.class, metaDataMap);
    }

    public getSearch_result() {
    }

    public getSearch_result(
      com.evernote.edam.type.SavedSearch success,
      com.evernote.edam.error.EDAMUserException userException,
      com.evernote.edam.error.EDAMSystemException systemException,
      com.evernote.edam.error.EDAMNotFoundException notFoundException)
    {
      this();
      this.success = success;
      this.userException = userException;
      this.systemException = systemException;
      this.notFoundException = notFoundException;
    }

    /**
     * Performs a deep copy on <i>other</i>.
     */
    public getSearch_result(getSearch_result other) {
      if (other.isSetSuccess()) {
        this.success = new com.evernote.edam.type.SavedSearch(other.success);
      }
      if (other.isSetUserException()) {
        this.userException = new com.evernote.edam.error.EDAMUserException(other.userException);
      }
      if (other.isSetSystemException()) {
        this.systemException = new com.evernote.edam.error.EDAMSystemException(other.systemException);
      }
      if (other.isSetNotFoundException()) {
        this.notFoundException = new com.evernote.edam.error.EDAMNotFoundException(other.notFoundException);
      }
    }

    public getSearch_result deepCopy() {
      return new getSearch_result(this);
    }

    @Deprecated
    public getSearch_result clone() {
      return new getSearch_result(this);
    }

    public com.evernote.edam.type.SavedSearch getSuccess() {
      return this.success;
    }

    public void setSuccess(com.evernote.edam.type.SavedSearch success) {
      this.success = success;
    }

    public void unsetSuccess() {
      this.success = null;
    }

    /** Returns true if field success is set (has been asigned a value) and false otherwise */
    public boolean isSetSuccess() {
      return this.success != null;
    }

    public void setSuccessIsSet(boolean value) {
      if (!value) {
        this.success = null;
      }
    }

    public com.evernote.edam.error.EDAMUserException getUserException() {
      return this.userException;
    }

    public void setUserException(com.evernote.edam.error.EDAMUserException userException) {
      this.userException = userException;
    }

    public void unsetUserException() {
      this.userException = null;
    }

    /** Returns true if field userException is set (has been asigned a value) and false otherwise */
    public boolean isSetUserException() {
      return this.userException != null;
    }

    public void setUserExceptionIsSet(boolean value) {
      if (!value) {
        this.userException = null;
      }
    }

    public com.evernote.edam.error.EDAMSystemException getSystemException() {
      return this.systemException;
    }

    public void setSystemException(com.evernote.edam.error.EDAMSystemException systemException) {
      this.systemException = systemException;
    }

    public void unsetSystemException() {
      this.systemException = null;
    }

    /** Returns true if field systemException is set (has been asigned a value) and false otherwise */
    public boolean isSetSystemException() {
      return this.systemException != null;
    }

    public void setSystemExceptionIsSet(boolean value) {
      if (!value) {
        this.systemException = null;
      }
    }

    public com.evernote.edam.error.EDAMNotFoundException getNotFoundException() {
      return this.notFoundException;
    }

    public void setNotFoundException(com.evernote.edam.error.EDAMNotFoundException notFoundException) {
      this.notFoundException = notFoundException;
    }

    public void unsetNotFoundException() {
      this.notFoundException = null;
    }

    /** Returns true if field notFoundException is set (has been asigned a value) and false otherwise */
    public boolean isSetNotFoundException() {
      return this.notFoundException != null;
    }

    public void setNotFoundExceptionIsSet(boolean value) {
      if (!value) {
        this.notFoundException = null;
      }
    }

    public void setFieldValue(_Fields field, Object value) {
      switch (field) {
      case SUCCESS:
        if (value == null) {
          unsetSuccess();
        } else {
          setSuccess((com.evernote.edam.type.SavedSearch)value);
        }
        break;

      case USER_EXCEPTION:
        if (value == null) {
          unsetUserException();
        } else {
          setUserException((com.evernote.edam.error.EDAMUserException)value);
        }
        break;

      case SYSTEM_EXCEPTION:
        if (value == null) {
          unsetSystemException();
        } else {
          setSystemException((com.evernote.edam.error.EDAMSystemException)value);
        }
        break;

      case NOT_FOUND_EXCEPTION:
        if (value == null) {
          unsetNotFoundException();
        } else {
          setNotFoundException((com.evernote.edam.error.EDAMNotFoundException)value);
        }
        break;

      }
    }

    public void setFieldValue(int fieldID, Object value) {
      setFieldValue(_Fields.findByThriftIdOrThrow(fieldID), value);
    }

    public Object getFieldValue(_Fields field) {
      switch (field) {
      case SUCCESS:
        return getSuccess();

      case USER_EXCEPTION:
        return getUserException();

      case SYSTEM_EXCEPTION:
        return getSystemException();

      case NOT_FOUND_EXCEPTION:
        return getNotFoundException();

      }
      throw new IllegalStateException();
    }

    public Object getFieldValue(int fieldId) {
      return getFieldValue(_Fields.findByThriftIdOrThrow(fieldId));
    }

    /** Returns true if field corresponding to fieldID is set (has been asigned a value) and false otherwise */
    public boolean isSet(_Fields field) {
      switch (field) {
      case SUCCESS:
        return isSetSuccess();
      case USER_EXCEPTION:
        return isSetUserException();
      case SYSTEM_EXCEPTION:
        return isSetSystemException();
      case NOT_FOUND_EXCEPTION:
        return isSetNotFoundException();
      }
      throw new IllegalStateException();
    }

    public boolean isSet(int fieldID) {
      return isSet(_Fields.findByThriftIdOrThrow(fieldID));
    }

    public boolean equals(Object that) {
      if (that == null)
        return false;
      if (that instanceof getSearch_result)
        return this.equals((getSearch_result)that);
      return false;
    }

    public boolean equals(getSearch_result that) {
      if (that == null)
        return false;

      boolean this_present_success = true && this.isSetSuccess();
      boolean that_present_success = true && that.isSetSuccess();
      if (this_present_success || that_present_success) {
        if (!(this_present_success && that_present_success))
          return false;
        if (!this.success.equals(that.success))
          return false;
      }

      boolean this_present_userException = true && this.isSetUserException();
      boolean that_present_userException = true && that.isSetUserException();
      if (this_present_userException || that_present_userException) {
        if (!(this_present_userException && that_present_userException))
          return false;
        if (!this.userException.equals(that.userException))
          return false;
      }

      boolean this_present_systemException = true && this.isSetSystemException();
      boolean that_present_systemException = true && that.isSetSystemException();
      if (this_present_systemException || that_present_systemException) {
        if (!(this_present_systemException && that_present_systemException))
          return false;
        if (!this.systemException.equals(that.systemException))
          return false;
      }

      boolean this_present_notFoundException = true && this.isSetNotFoundException();
      boolean that_present_notFoundException = true && that.isSetNotFoundException();
      if (this_present_notFoundException || that_present_notFoundException) {
        if (!(this_present_notFoundException && that_present_notFoundException))
          return false;
        if (!this.notFoundException.equals(that.notFoundException))
          return false;
      }

      return true;
    }

    public int hashCode() {
      return 0;
    }

    public int compareTo(getSearch_result other) {
      if (!getClass().equals(other.getClass())) {
        return getClass().getName().compareTo(other.getClass().getName());
      }

      int lastComparison = 0;
      getSearch_result typedOther = (getSearch_result)other;

      lastComparison = Boolean.valueOf(isSetSuccess()).compareTo(isSetSuccess());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(success, typedOther.success);
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = Boolean.valueOf(isSetUserException()).compareTo(isSetUserException());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(userException, typedOther.userException);
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = Boolean.valueOf(isSetSystemException()).compareTo(isSetSystemException());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(systemException, typedOther.systemException);
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = Boolean.valueOf(isSetNotFoundException()).compareTo(isSetNotFoundException());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(notFoundException, typedOther.notFoundException);
      if (lastComparison != 0) {
        return lastComparison;
      }
      return 0;
    }

    public void read(TProtocol iprot) throws TException {
      TField field;
      iprot.readStructBegin();
      while (true)
      {
        field = iprot.readFieldBegin();
        if (field.type == TType.STOP) { 
          break;
        }
        _Fields fieldId = _Fields.findByThriftId(field.id);
        if (fieldId == null) {
          TProtocolUtil.skip(iprot, field.type);
        } else {
          switch (fieldId) {
            case SUCCESS:
              if (field.type == TType.STRUCT) {
                this.success = new com.evernote.edam.type.SavedSearch();
                this.success.read(iprot);
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
            case USER_EXCEPTION:
              if (field.type == TType.STRUCT) {
                this.userException = new com.evernote.edam.error.EDAMUserException();
                this.userException.read(iprot);
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
            case SYSTEM_EXCEPTION:
              if (field.type == TType.STRUCT) {
                this.systemException = new com.evernote.edam.error.EDAMSystemException();
                this.systemException.read(iprot);
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
            case NOT_FOUND_EXCEPTION:
              if (field.type == TType.STRUCT) {
                this.notFoundException = new com.evernote.edam.error.EDAMNotFoundException();
                this.notFoundException.read(iprot);
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
          }
          iprot.readFieldEnd();
        }
      }
      iprot.readStructEnd();
      validate();
    }

    public void write(TProtocol oprot) throws TException {
      oprot.writeStructBegin(STRUCT_DESC);

      if (this.isSetSuccess()) {
        oprot.writeFieldBegin(SUCCESS_FIELD_DESC);
        this.success.write(oprot);
        oprot.writeFieldEnd();
      } else if (this.isSetUserException()) {
        oprot.writeFieldBegin(USER_EXCEPTION_FIELD_DESC);
        this.userException.write(oprot);
        oprot.writeFieldEnd();
      } else if (this.isSetSystemException()) {
        oprot.writeFieldBegin(SYSTEM_EXCEPTION_FIELD_DESC);
        this.systemException.write(oprot);
        oprot.writeFieldEnd();
      } else if (this.isSetNotFoundException()) {
        oprot.writeFieldBegin(NOT_FOUND_EXCEPTION_FIELD_DESC);
        this.notFoundException.write(oprot);
        oprot.writeFieldEnd();
      }
      oprot.writeFieldStop();
      oprot.writeStructEnd();
    }

    public String toString() {
      StringBuilder sb = new StringBuilder("getSearch_result(");
      boolean first = true;

      sb.append("success:");
      if (this.success == null) {
        sb.append("null");
      } else {
        sb.append(this.success);
      }
      first = false;
      if (!first) sb.append(", ");
      sb.append("userException:");
      if (this.userException == null) {
        sb.append("null");
      } else {
        sb.append(this.userException);
      }
      first = false;
      if (!first) sb.append(", ");
      sb.append("systemException:");
      if (this.systemException == null) {
        sb.append("null");
      } else {
        sb.append(this.systemException);
      }
      first = false;
      if (!first) sb.append(", ");
      sb.append("notFoundException:");
      if (this.notFoundException == null) {
        sb.append("null");
      } else {
        sb.append(this.notFoundException);
      }
      first = false;
      sb.append(")");
      return sb.toString();
    }

    public void validate() throws TException {
      // check for required fields
    }

  }

  public static class createSearch_args implements TBase<createSearch_args._Fields>, java.io.Serializable, Cloneable, Comparable<createSearch_args>   {
    private static final TStruct STRUCT_DESC = new TStruct("createSearch_args");

    private static final TField AUTHENTICATION_TOKEN_FIELD_DESC = new TField("authenticationToken", TType.STRING, (short)1);
    private static final TField SEARCH_FIELD_DESC = new TField("search", TType.STRUCT, (short)2);

    private String authenticationToken;
    private com.evernote.edam.type.SavedSearch search;

    /** The set of fields this struct contains, along with convenience methods for finding and manipulating them. */
    public enum _Fields implements TFieldIdEnum {
      AUTHENTICATION_TOKEN((short)1, "authenticationToken"),
      SEARCH((short)2, "search");

      private static final Map<Integer, _Fields> byId = new HashMap<Integer, _Fields>();
      private static final Map<String, _Fields> byName = new HashMap<String, _Fields>();

      static {
        for (_Fields field : EnumSet.allOf(_Fields.class)) {
          byId.put((int)field._thriftId, field);
          byName.put(field.getFieldName(), field);
        }
      }

      /**
       * Find the _Fields constant that matches fieldId, or null if its not found.
       */
      public static _Fields findByThriftId(int fieldId) {
        return byId.get(fieldId);
      }

      /**
       * Find the _Fields constant that matches fieldId, throwing an exception
       * if it is not found.
       */
      public static _Fields findByThriftIdOrThrow(int fieldId) {
        _Fields fields = findByThriftId(fieldId);
        if (fields == null) throw new IllegalArgumentException("Field " + fieldId + " doesn't exist!");
        return fields;
      }

      /**
       * Find the _Fields constant that matches name, or null if its not found.
       */
      public static _Fields findByName(String name) {
        return byName.get(name);
      }

      private final short _thriftId;
      private final String _fieldName;

      _Fields(short thriftId, String fieldName) {
        _thriftId = thriftId;
        _fieldName = fieldName;
      }

      public short getThriftFieldId() {
        return _thriftId;
      }

      public String getFieldName() {
        return _fieldName;
      }
    }

    // isset id assignments

    public static final Map<_Fields, FieldMetaData> metaDataMap = Collections.unmodifiableMap(new EnumMap<_Fields, FieldMetaData>(_Fields.class) {{
      put(_Fields.AUTHENTICATION_TOKEN, new FieldMetaData("authenticationToken", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.STRING)));
      put(_Fields.SEARCH, new FieldMetaData("search", TFieldRequirementType.DEFAULT, 
          new StructMetaData(TType.STRUCT, com.evernote.edam.type.SavedSearch.class)));
    }});

    static {
      FieldMetaData.addStructMetaDataMap(createSearch_args.class, metaDataMap);
    }

    public createSearch_args() {
    }

    public createSearch_args(
      String authenticationToken,
      com.evernote.edam.type.SavedSearch search)
    {
      this();
      this.authenticationToken = authenticationToken;
      this.search = search;
    }

    /**
     * Performs a deep copy on <i>other</i>.
     */
    public createSearch_args(createSearch_args other) {
      if (other.isSetAuthenticationToken()) {
        this.authenticationToken = other.authenticationToken;
      }
      if (other.isSetSearch()) {
        this.search = new com.evernote.edam.type.SavedSearch(other.search);
      }
    }

    public createSearch_args deepCopy() {
      return new createSearch_args(this);
    }

    @Deprecated
    public createSearch_args clone() {
      return new createSearch_args(this);
    }

    public String getAuthenticationToken() {
      return this.authenticationToken;
    }

    public void setAuthenticationToken(String authenticationToken) {
      this.authenticationToken = authenticationToken;
    }

    public void unsetAuthenticationToken() {
      this.authenticationToken = null;
    }

    /** Returns true if field authenticationToken is set (has been asigned a value) and false otherwise */
    public boolean isSetAuthenticationToken() {
      return this.authenticationToken != null;
    }

    public void setAuthenticationTokenIsSet(boolean value) {
      if (!value) {
        this.authenticationToken = null;
      }
    }

    public com.evernote.edam.type.SavedSearch getSearch() {
      return this.search;
    }

    public void setSearch(com.evernote.edam.type.SavedSearch search) {
      this.search = search;
    }

    public void unsetSearch() {
      this.search = null;
    }

    /** Returns true if field search is set (has been asigned a value) and false otherwise */
    public boolean isSetSearch() {
      return this.search != null;
    }

    public void setSearchIsSet(boolean value) {
      if (!value) {
        this.search = null;
      }
    }

    public void setFieldValue(_Fields field, Object value) {
      switch (field) {
      case AUTHENTICATION_TOKEN:
        if (value == null) {
          unsetAuthenticationToken();
        } else {
          setAuthenticationToken((String)value);
        }
        break;

      case SEARCH:
        if (value == null) {
          unsetSearch();
        } else {
          setSearch((com.evernote.edam.type.SavedSearch)value);
        }
        break;

      }
    }

    public void setFieldValue(int fieldID, Object value) {
      setFieldValue(_Fields.findByThriftIdOrThrow(fieldID), value);
    }

    public Object getFieldValue(_Fields field) {
      switch (field) {
      case AUTHENTICATION_TOKEN:
        return getAuthenticationToken();

      case SEARCH:
        return getSearch();

      }
      throw new IllegalStateException();
    }

    public Object getFieldValue(int fieldId) {
      return getFieldValue(_Fields.findByThriftIdOrThrow(fieldId));
    }

    /** Returns true if field corresponding to fieldID is set (has been asigned a value) and false otherwise */
    public boolean isSet(_Fields field) {
      switch (field) {
      case AUTHENTICATION_TOKEN:
        return isSetAuthenticationToken();
      case SEARCH:
        return isSetSearch();
      }
      throw new IllegalStateException();
    }

    public boolean isSet(int fieldID) {
      return isSet(_Fields.findByThriftIdOrThrow(fieldID));
    }

    public boolean equals(Object that) {
      if (that == null)
        return false;
      if (that instanceof createSearch_args)
        return this.equals((createSearch_args)that);
      return false;
    }

    public boolean equals(createSearch_args that) {
      if (that == null)
        return false;

      boolean this_present_authenticationToken = true && this.isSetAuthenticationToken();
      boolean that_present_authenticationToken = true && that.isSetAuthenticationToken();
      if (this_present_authenticationToken || that_present_authenticationToken) {
        if (!(this_present_authenticationToken && that_present_authenticationToken))
          return false;
        if (!this.authenticationToken.equals(that.authenticationToken))
          return false;
      }

      boolean this_present_search = true && this.isSetSearch();
      boolean that_present_search = true && that.isSetSearch();
      if (this_present_search || that_present_search) {
        if (!(this_present_search && that_present_search))
          return false;
        if (!this.search.equals(that.search))
          return false;
      }

      return true;
    }

    public int hashCode() {
      return 0;
    }

    public int compareTo(createSearch_args other) {
      if (!getClass().equals(other.getClass())) {
        return getClass().getName().compareTo(other.getClass().getName());
      }

      int lastComparison = 0;
      createSearch_args typedOther = (createSearch_args)other;

      lastComparison = Boolean.valueOf(isSetAuthenticationToken()).compareTo(isSetAuthenticationToken());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(authenticationToken, typedOther.authenticationToken);
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = Boolean.valueOf(isSetSearch()).compareTo(isSetSearch());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(search, typedOther.search);
      if (lastComparison != 0) {
        return lastComparison;
      }
      return 0;
    }

    public void read(TProtocol iprot) throws TException {
      TField field;
      iprot.readStructBegin();
      while (true)
      {
        field = iprot.readFieldBegin();
        if (field.type == TType.STOP) { 
          break;
        }
        _Fields fieldId = _Fields.findByThriftId(field.id);
        if (fieldId == null) {
          TProtocolUtil.skip(iprot, field.type);
        } else {
          switch (fieldId) {
            case AUTHENTICATION_TOKEN:
              if (field.type == TType.STRING) {
                this.authenticationToken = iprot.readString();
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
            case SEARCH:
              if (field.type == TType.STRUCT) {
                this.search = new com.evernote.edam.type.SavedSearch();
                this.search.read(iprot);
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
          }
          iprot.readFieldEnd();
        }
      }
      iprot.readStructEnd();
      validate();
    }

    public void write(TProtocol oprot) throws TException {
      validate();

      oprot.writeStructBegin(STRUCT_DESC);
      if (this.authenticationToken != null) {
        oprot.writeFieldBegin(AUTHENTICATION_TOKEN_FIELD_DESC);
        oprot.writeString(this.authenticationToken);
        oprot.writeFieldEnd();
      }
      if (this.search != null) {
        oprot.writeFieldBegin(SEARCH_FIELD_DESC);
        this.search.write(oprot);
        oprot.writeFieldEnd();
      }
      oprot.writeFieldStop();
      oprot.writeStructEnd();
    }

    public String toString() {
      StringBuilder sb = new StringBuilder("createSearch_args(");
      boolean first = true;

      sb.append("authenticationToken:");
      if (this.authenticationToken == null) {
        sb.append("null");
      } else {
        sb.append(this.authenticationToken);
      }
      first = false;
      if (!first) sb.append(", ");
      sb.append("search:");
      if (this.search == null) {
        sb.append("null");
      } else {
        sb.append(this.search);
      }
      first = false;
      sb.append(")");
      return sb.toString();
    }

    public void validate() throws TException {
      // check for required fields
    }

  }

  public static class createSearch_result implements TBase<createSearch_result._Fields>, java.io.Serializable, Cloneable, Comparable<createSearch_result>   {
    private static final TStruct STRUCT_DESC = new TStruct("createSearch_result");

    private static final TField SUCCESS_FIELD_DESC = new TField("success", TType.STRUCT, (short)0);
    private static final TField USER_EXCEPTION_FIELD_DESC = new TField("userException", TType.STRUCT, (short)1);
    private static final TField SYSTEM_EXCEPTION_FIELD_DESC = new TField("systemException", TType.STRUCT, (short)2);

    private com.evernote.edam.type.SavedSearch success;
    private com.evernote.edam.error.EDAMUserException userException;
    private com.evernote.edam.error.EDAMSystemException systemException;

    /** The set of fields this struct contains, along with convenience methods for finding and manipulating them. */
    public enum _Fields implements TFieldIdEnum {
      SUCCESS((short)0, "success"),
      USER_EXCEPTION((short)1, "userException"),
      SYSTEM_EXCEPTION((short)2, "systemException");

      private static final Map<Integer, _Fields> byId = new HashMap<Integer, _Fields>();
      private static final Map<String, _Fields> byName = new HashMap<String, _Fields>();

      static {
        for (_Fields field : EnumSet.allOf(_Fields.class)) {
          byId.put((int)field._thriftId, field);
          byName.put(field.getFieldName(), field);
        }
      }

      /**
       * Find the _Fields constant that matches fieldId, or null if its not found.
       */
      public static _Fields findByThriftId(int fieldId) {
        return byId.get(fieldId);
      }

      /**
       * Find the _Fields constant that matches fieldId, throwing an exception
       * if it is not found.
       */
      public static _Fields findByThriftIdOrThrow(int fieldId) {
        _Fields fields = findByThriftId(fieldId);
        if (fields == null) throw new IllegalArgumentException("Field " + fieldId + " doesn't exist!");
        return fields;
      }

      /**
       * Find the _Fields constant that matches name, or null if its not found.
       */
      public static _Fields findByName(String name) {
        return byName.get(name);
      }

      private final short _thriftId;
      private final String _fieldName;

      _Fields(short thriftId, String fieldName) {
        _thriftId = thriftId;
        _fieldName = fieldName;
      }

      public short getThriftFieldId() {
        return _thriftId;
      }

      public String getFieldName() {
        return _fieldName;
      }
    }

    // isset id assignments

    public static final Map<_Fields, FieldMetaData> metaDataMap = Collections.unmodifiableMap(new EnumMap<_Fields, FieldMetaData>(_Fields.class) {{
      put(_Fields.SUCCESS, new FieldMetaData("success", TFieldRequirementType.DEFAULT, 
          new StructMetaData(TType.STRUCT, com.evernote.edam.type.SavedSearch.class)));
      put(_Fields.USER_EXCEPTION, new FieldMetaData("userException", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.STRUCT)));
      put(_Fields.SYSTEM_EXCEPTION, new FieldMetaData("systemException", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.STRUCT)));
    }});

    static {
      FieldMetaData.addStructMetaDataMap(createSearch_result.class, metaDataMap);
    }

    public createSearch_result() {
    }

    public createSearch_result(
      com.evernote.edam.type.SavedSearch success,
      com.evernote.edam.error.EDAMUserException userException,
      com.evernote.edam.error.EDAMSystemException systemException)
    {
      this();
      this.success = success;
      this.userException = userException;
      this.systemException = systemException;
    }

    /**
     * Performs a deep copy on <i>other</i>.
     */
    public createSearch_result(createSearch_result other) {
      if (other.isSetSuccess()) {
        this.success = new com.evernote.edam.type.SavedSearch(other.success);
      }
      if (other.isSetUserException()) {
        this.userException = new com.evernote.edam.error.EDAMUserException(other.userException);
      }
      if (other.isSetSystemException()) {
        this.systemException = new com.evernote.edam.error.EDAMSystemException(other.systemException);
      }
    }

    public createSearch_result deepCopy() {
      return new createSearch_result(this);
    }

    @Deprecated
    public createSearch_result clone() {
      return new createSearch_result(this);
    }

    public com.evernote.edam.type.SavedSearch getSuccess() {
      return this.success;
    }

    public void setSuccess(com.evernote.edam.type.SavedSearch success) {
      this.success = success;
    }

    public void unsetSuccess() {
      this.success = null;
    }

    /** Returns true if field success is set (has been asigned a value) and false otherwise */
    public boolean isSetSuccess() {
      return this.success != null;
    }

    public void setSuccessIsSet(boolean value) {
      if (!value) {
        this.success = null;
      }
    }

    public com.evernote.edam.error.EDAMUserException getUserException() {
      return this.userException;
    }

    public void setUserException(com.evernote.edam.error.EDAMUserException userException) {
      this.userException = userException;
    }

    public void unsetUserException() {
      this.userException = null;
    }

    /** Returns true if field userException is set (has been asigned a value) and false otherwise */
    public boolean isSetUserException() {
      return this.userException != null;
    }

    public void setUserExceptionIsSet(boolean value) {
      if (!value) {
        this.userException = null;
      }
    }

    public com.evernote.edam.error.EDAMSystemException getSystemException() {
      return this.systemException;
    }

    public void setSystemException(com.evernote.edam.error.EDAMSystemException systemException) {
      this.systemException = systemException;
    }

    public void unsetSystemException() {
      this.systemException = null;
    }

    /** Returns true if field systemException is set (has been asigned a value) and false otherwise */
    public boolean isSetSystemException() {
      return this.systemException != null;
    }

    public void setSystemExceptionIsSet(boolean value) {
      if (!value) {
        this.systemException = null;
      }
    }

    public void setFieldValue(_Fields field, Object value) {
      switch (field) {
      case SUCCESS:
        if (value == null) {
          unsetSuccess();
        } else {
          setSuccess((com.evernote.edam.type.SavedSearch)value);
        }
        break;

      case USER_EXCEPTION:
        if (value == null) {
          unsetUserException();
        } else {
          setUserException((com.evernote.edam.error.EDAMUserException)value);
        }
        break;

      case SYSTEM_EXCEPTION:
        if (value == null) {
          unsetSystemException();
        } else {
          setSystemException((com.evernote.edam.error.EDAMSystemException)value);
        }
        break;

      }
    }

    public void setFieldValue(int fieldID, Object value) {
      setFieldValue(_Fields.findByThriftIdOrThrow(fieldID), value);
    }

    public Object getFieldValue(_Fields field) {
      switch (field) {
      case SUCCESS:
        return getSuccess();

      case USER_EXCEPTION:
        return getUserException();

      case SYSTEM_EXCEPTION:
        return getSystemException();

      }
      throw new IllegalStateException();
    }

    public Object getFieldValue(int fieldId) {
      return getFieldValue(_Fields.findByThriftIdOrThrow(fieldId));
    }

    /** Returns true if field corresponding to fieldID is set (has been asigned a value) and false otherwise */
    public boolean isSet(_Fields field) {
      switch (field) {
      case SUCCESS:
        return isSetSuccess();
      case USER_EXCEPTION:
        return isSetUserException();
      case SYSTEM_EXCEPTION:
        return isSetSystemException();
      }
      throw new IllegalStateException();
    }

    public boolean isSet(int fieldID) {
      return isSet(_Fields.findByThriftIdOrThrow(fieldID));
    }

    public boolean equals(Object that) {
      if (that == null)
        return false;
      if (that instanceof createSearch_result)
        return this.equals((createSearch_result)that);
      return false;
    }

    public boolean equals(createSearch_result that) {
      if (that == null)
        return false;

      boolean this_present_success = true && this.isSetSuccess();
      boolean that_present_success = true && that.isSetSuccess();
      if (this_present_success || that_present_success) {
        if (!(this_present_success && that_present_success))
          return false;
        if (!this.success.equals(that.success))
          return false;
      }

      boolean this_present_userException = true && this.isSetUserException();
      boolean that_present_userException = true && that.isSetUserException();
      if (this_present_userException || that_present_userException) {
        if (!(this_present_userException && that_present_userException))
          return false;
        if (!this.userException.equals(that.userException))
          return false;
      }

      boolean this_present_systemException = true && this.isSetSystemException();
      boolean that_present_systemException = true && that.isSetSystemException();
      if (this_present_systemException || that_present_systemException) {
        if (!(this_present_systemException && that_present_systemException))
          return false;
        if (!this.systemException.equals(that.systemException))
          return false;
      }

      return true;
    }

    public int hashCode() {
      return 0;
    }

    public int compareTo(createSearch_result other) {
      if (!getClass().equals(other.getClass())) {
        return getClass().getName().compareTo(other.getClass().getName());
      }

      int lastComparison = 0;
      createSearch_result typedOther = (createSearch_result)other;

      lastComparison = Boolean.valueOf(isSetSuccess()).compareTo(isSetSuccess());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(success, typedOther.success);
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = Boolean.valueOf(isSetUserException()).compareTo(isSetUserException());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(userException, typedOther.userException);
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = Boolean.valueOf(isSetSystemException()).compareTo(isSetSystemException());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(systemException, typedOther.systemException);
      if (lastComparison != 0) {
        return lastComparison;
      }
      return 0;
    }

    public void read(TProtocol iprot) throws TException {
      TField field;
      iprot.readStructBegin();
      while (true)
      {
        field = iprot.readFieldBegin();
        if (field.type == TType.STOP) { 
          break;
        }
        _Fields fieldId = _Fields.findByThriftId(field.id);
        if (fieldId == null) {
          TProtocolUtil.skip(iprot, field.type);
        } else {
          switch (fieldId) {
            case SUCCESS:
              if (field.type == TType.STRUCT) {
                this.success = new com.evernote.edam.type.SavedSearch();
                this.success.read(iprot);
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
            case USER_EXCEPTION:
              if (field.type == TType.STRUCT) {
                this.userException = new com.evernote.edam.error.EDAMUserException();
                this.userException.read(iprot);
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
            case SYSTEM_EXCEPTION:
              if (field.type == TType.STRUCT) {
                this.systemException = new com.evernote.edam.error.EDAMSystemException();
                this.systemException.read(iprot);
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
          }
          iprot.readFieldEnd();
        }
      }
      iprot.readStructEnd();
      validate();
    }

    public void write(TProtocol oprot) throws TException {
      oprot.writeStructBegin(STRUCT_DESC);

      if (this.isSetSuccess()) {
        oprot.writeFieldBegin(SUCCESS_FIELD_DESC);
        this.success.write(oprot);
        oprot.writeFieldEnd();
      } else if (this.isSetUserException()) {
        oprot.writeFieldBegin(USER_EXCEPTION_FIELD_DESC);
        this.userException.write(oprot);
        oprot.writeFieldEnd();
      } else if (this.isSetSystemException()) {
        oprot.writeFieldBegin(SYSTEM_EXCEPTION_FIELD_DESC);
        this.systemException.write(oprot);
        oprot.writeFieldEnd();
      }
      oprot.writeFieldStop();
      oprot.writeStructEnd();
    }

    public String toString() {
      StringBuilder sb = new StringBuilder("createSearch_result(");
      boolean first = true;

      sb.append("success:");
      if (this.success == null) {
        sb.append("null");
      } else {
        sb.append(this.success);
      }
      first = false;
      if (!first) sb.append(", ");
      sb.append("userException:");
      if (this.userException == null) {
        sb.append("null");
      } else {
        sb.append(this.userException);
      }
      first = false;
      if (!first) sb.append(", ");
      sb.append("systemException:");
      if (this.systemException == null) {
        sb.append("null");
      } else {
        sb.append(this.systemException);
      }
      first = false;
      sb.append(")");
      return sb.toString();
    }

    public void validate() throws TException {
      // check for required fields
    }

  }

  public static class updateSearch_args implements TBase<updateSearch_args._Fields>, java.io.Serializable, Cloneable, Comparable<updateSearch_args>   {
    private static final TStruct STRUCT_DESC = new TStruct("updateSearch_args");

    private static final TField AUTHENTICATION_TOKEN_FIELD_DESC = new TField("authenticationToken", TType.STRING, (short)1);
    private static final TField SEARCH_FIELD_DESC = new TField("search", TType.STRUCT, (short)2);

    private String authenticationToken;
    private com.evernote.edam.type.SavedSearch search;

    /** The set of fields this struct contains, along with convenience methods for finding and manipulating them. */
    public enum _Fields implements TFieldIdEnum {
      AUTHENTICATION_TOKEN((short)1, "authenticationToken"),
      SEARCH((short)2, "search");

      private static final Map<Integer, _Fields> byId = new HashMap<Integer, _Fields>();
      private static final Map<String, _Fields> byName = new HashMap<String, _Fields>();

      static {
        for (_Fields field : EnumSet.allOf(_Fields.class)) {
          byId.put((int)field._thriftId, field);
          byName.put(field.getFieldName(), field);
        }
      }

      /**
       * Find the _Fields constant that matches fieldId, or null if its not found.
       */
      public static _Fields findByThriftId(int fieldId) {
        return byId.get(fieldId);
      }

      /**
       * Find the _Fields constant that matches fieldId, throwing an exception
       * if it is not found.
       */
      public static _Fields findByThriftIdOrThrow(int fieldId) {
        _Fields fields = findByThriftId(fieldId);
        if (fields == null) throw new IllegalArgumentException("Field " + fieldId + " doesn't exist!");
        return fields;
      }

      /**
       * Find the _Fields constant that matches name, or null if its not found.
       */
      public static _Fields findByName(String name) {
        return byName.get(name);
      }

      private final short _thriftId;
      private final String _fieldName;

      _Fields(short thriftId, String fieldName) {
        _thriftId = thriftId;
        _fieldName = fieldName;
      }

      public short getThriftFieldId() {
        return _thriftId;
      }

      public String getFieldName() {
        return _fieldName;
      }
    }

    // isset id assignments

    public static final Map<_Fields, FieldMetaData> metaDataMap = Collections.unmodifiableMap(new EnumMap<_Fields, FieldMetaData>(_Fields.class) {{
      put(_Fields.AUTHENTICATION_TOKEN, new FieldMetaData("authenticationToken", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.STRING)));
      put(_Fields.SEARCH, new FieldMetaData("search", TFieldRequirementType.DEFAULT, 
          new StructMetaData(TType.STRUCT, com.evernote.edam.type.SavedSearch.class)));
    }});

    static {
      FieldMetaData.addStructMetaDataMap(updateSearch_args.class, metaDataMap);
    }

    public updateSearch_args() {
    }

    public updateSearch_args(
      String authenticationToken,
      com.evernote.edam.type.SavedSearch search)
    {
      this();
      this.authenticationToken = authenticationToken;
      this.search = search;
    }

    /**
     * Performs a deep copy on <i>other</i>.
     */
    public updateSearch_args(updateSearch_args other) {
      if (other.isSetAuthenticationToken()) {
        this.authenticationToken = other.authenticationToken;
      }
      if (other.isSetSearch()) {
        this.search = new com.evernote.edam.type.SavedSearch(other.search);
      }
    }

    public updateSearch_args deepCopy() {
      return new updateSearch_args(this);
    }

    @Deprecated
    public updateSearch_args clone() {
      return new updateSearch_args(this);
    }

    public String getAuthenticationToken() {
      return this.authenticationToken;
    }

    public void setAuthenticationToken(String authenticationToken) {
      this.authenticationToken = authenticationToken;
    }

    public void unsetAuthenticationToken() {
      this.authenticationToken = null;
    }

    /** Returns true if field authenticationToken is set (has been asigned a value) and false otherwise */
    public boolean isSetAuthenticationToken() {
      return this.authenticationToken != null;
    }

    public void setAuthenticationTokenIsSet(boolean value) {
      if (!value) {
        this.authenticationToken = null;
      }
    }

    public com.evernote.edam.type.SavedSearch getSearch() {
      return this.search;
    }

    public void setSearch(com.evernote.edam.type.SavedSearch search) {
      this.search = search;
    }

    public void unsetSearch() {
      this.search = null;
    }

    /** Returns true if field search is set (has been asigned a value) and false otherwise */
    public boolean isSetSearch() {
      return this.search != null;
    }

    public void setSearchIsSet(boolean value) {
      if (!value) {
        this.search = null;
      }
    }

    public void setFieldValue(_Fields field, Object value) {
      switch (field) {
      case AUTHENTICATION_TOKEN:
        if (value == null) {
          unsetAuthenticationToken();
        } else {
          setAuthenticationToken((String)value);
        }
        break;

      case SEARCH:
        if (value == null) {
          unsetSearch();
        } else {
          setSearch((com.evernote.edam.type.SavedSearch)value);
        }
        break;

      }
    }

    public void setFieldValue(int fieldID, Object value) {
      setFieldValue(_Fields.findByThriftIdOrThrow(fieldID), value);
    }

    public Object getFieldValue(_Fields field) {
      switch (field) {
      case AUTHENTICATION_TOKEN:
        return getAuthenticationToken();

      case SEARCH:
        return getSearch();

      }
      throw new IllegalStateException();
    }

    public Object getFieldValue(int fieldId) {
      return getFieldValue(_Fields.findByThriftIdOrThrow(fieldId));
    }

    /** Returns true if field corresponding to fieldID is set (has been asigned a value) and false otherwise */
    public boolean isSet(_Fields field) {
      switch (field) {
      case AUTHENTICATION_TOKEN:
        return isSetAuthenticationToken();
      case SEARCH:
        return isSetSearch();
      }
      throw new IllegalStateException();
    }

    public boolean isSet(int fieldID) {
      return isSet(_Fields.findByThriftIdOrThrow(fieldID));
    }

    public boolean equals(Object that) {
      if (that == null)
        return false;
      if (that instanceof updateSearch_args)
        return this.equals((updateSearch_args)that);
      return false;
    }

    public boolean equals(updateSearch_args that) {
      if (that == null)
        return false;

      boolean this_present_authenticationToken = true && this.isSetAuthenticationToken();
      boolean that_present_authenticationToken = true && that.isSetAuthenticationToken();
      if (this_present_authenticationToken || that_present_authenticationToken) {
        if (!(this_present_authenticationToken && that_present_authenticationToken))
          return false;
        if (!this.authenticationToken.equals(that.authenticationToken))
          return false;
      }

      boolean this_present_search = true && this.isSetSearch();
      boolean that_present_search = true && that.isSetSearch();
      if (this_present_search || that_present_search) {
        if (!(this_present_search && that_present_search))
          return false;
        if (!this.search.equals(that.search))
          return false;
      }

      return true;
    }

    public int hashCode() {
      return 0;
    }

    public int compareTo(updateSearch_args other) {
      if (!getClass().equals(other.getClass())) {
        return getClass().getName().compareTo(other.getClass().getName());
      }

      int lastComparison = 0;
      updateSearch_args typedOther = (updateSearch_args)other;

      lastComparison = Boolean.valueOf(isSetAuthenticationToken()).compareTo(isSetAuthenticationToken());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(authenticationToken, typedOther.authenticationToken);
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = Boolean.valueOf(isSetSearch()).compareTo(isSetSearch());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(search, typedOther.search);
      if (lastComparison != 0) {
        return lastComparison;
      }
      return 0;
    }

    public void read(TProtocol iprot) throws TException {
      TField field;
      iprot.readStructBegin();
      while (true)
      {
        field = iprot.readFieldBegin();
        if (field.type == TType.STOP) { 
          break;
        }
        _Fields fieldId = _Fields.findByThriftId(field.id);
        if (fieldId == null) {
          TProtocolUtil.skip(iprot, field.type);
        } else {
          switch (fieldId) {
            case AUTHENTICATION_TOKEN:
              if (field.type == TType.STRING) {
                this.authenticationToken = iprot.readString();
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
            case SEARCH:
              if (field.type == TType.STRUCT) {
                this.search = new com.evernote.edam.type.SavedSearch();
                this.search.read(iprot);
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
          }
          iprot.readFieldEnd();
        }
      }
      iprot.readStructEnd();
      validate();
    }

    public void write(TProtocol oprot) throws TException {
      validate();

      oprot.writeStructBegin(STRUCT_DESC);
      if (this.authenticationToken != null) {
        oprot.writeFieldBegin(AUTHENTICATION_TOKEN_FIELD_DESC);
        oprot.writeString(this.authenticationToken);
        oprot.writeFieldEnd();
      }
      if (this.search != null) {
        oprot.writeFieldBegin(SEARCH_FIELD_DESC);
        this.search.write(oprot);
        oprot.writeFieldEnd();
      }
      oprot.writeFieldStop();
      oprot.writeStructEnd();
    }

    public String toString() {
      StringBuilder sb = new StringBuilder("updateSearch_args(");
      boolean first = true;

      sb.append("authenticationToken:");
      if (this.authenticationToken == null) {
        sb.append("null");
      } else {
        sb.append(this.authenticationToken);
      }
      first = false;
      if (!first) sb.append(", ");
      sb.append("search:");
      if (this.search == null) {
        sb.append("null");
      } else {
        sb.append(this.search);
      }
      first = false;
      sb.append(")");
      return sb.toString();
    }

    public void validate() throws TException {
      // check for required fields
    }

  }

  public static class updateSearch_result implements TBase<updateSearch_result._Fields>, java.io.Serializable, Cloneable, Comparable<updateSearch_result>   {
    private static final TStruct STRUCT_DESC = new TStruct("updateSearch_result");

    private static final TField SUCCESS_FIELD_DESC = new TField("success", TType.I32, (short)0);
    private static final TField USER_EXCEPTION_FIELD_DESC = new TField("userException", TType.STRUCT, (short)1);
    private static final TField SYSTEM_EXCEPTION_FIELD_DESC = new TField("systemException", TType.STRUCT, (short)2);
    private static final TField NOT_FOUND_EXCEPTION_FIELD_DESC = new TField("notFoundException", TType.STRUCT, (short)3);

    private int success;
    private com.evernote.edam.error.EDAMUserException userException;
    private com.evernote.edam.error.EDAMSystemException systemException;
    private com.evernote.edam.error.EDAMNotFoundException notFoundException;

    /** The set of fields this struct contains, along with convenience methods for finding and manipulating them. */
    public enum _Fields implements TFieldIdEnum {
      SUCCESS((short)0, "success"),
      USER_EXCEPTION((short)1, "userException"),
      SYSTEM_EXCEPTION((short)2, "systemException"),
      NOT_FOUND_EXCEPTION((short)3, "notFoundException");

      private static final Map<Integer, _Fields> byId = new HashMap<Integer, _Fields>();
      private static final Map<String, _Fields> byName = new HashMap<String, _Fields>();

      static {
        for (_Fields field : EnumSet.allOf(_Fields.class)) {
          byId.put((int)field._thriftId, field);
          byName.put(field.getFieldName(), field);
        }
      }

      /**
       * Find the _Fields constant that matches fieldId, or null if its not found.
       */
      public static _Fields findByThriftId(int fieldId) {
        return byId.get(fieldId);
      }

      /**
       * Find the _Fields constant that matches fieldId, throwing an exception
       * if it is not found.
       */
      public static _Fields findByThriftIdOrThrow(int fieldId) {
        _Fields fields = findByThriftId(fieldId);
        if (fields == null) throw new IllegalArgumentException("Field " + fieldId + " doesn't exist!");
        return fields;
      }

      /**
       * Find the _Fields constant that matches name, or null if its not found.
       */
      public static _Fields findByName(String name) {
        return byName.get(name);
      }

      private final short _thriftId;
      private final String _fieldName;

      _Fields(short thriftId, String fieldName) {
        _thriftId = thriftId;
        _fieldName = fieldName;
      }

      public short getThriftFieldId() {
        return _thriftId;
      }

      public String getFieldName() {
        return _fieldName;
      }
    }

    // isset id assignments
    private static final int __SUCCESS_ISSET_ID = 0;
    private BitSet __isset_bit_vector = new BitSet(1);

    public static final Map<_Fields, FieldMetaData> metaDataMap = Collections.unmodifiableMap(new EnumMap<_Fields, FieldMetaData>(_Fields.class) {{
      put(_Fields.SUCCESS, new FieldMetaData("success", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.I32)));
      put(_Fields.USER_EXCEPTION, new FieldMetaData("userException", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.STRUCT)));
      put(_Fields.SYSTEM_EXCEPTION, new FieldMetaData("systemException", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.STRUCT)));
      put(_Fields.NOT_FOUND_EXCEPTION, new FieldMetaData("notFoundException", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.STRUCT)));
    }});

    static {
      FieldMetaData.addStructMetaDataMap(updateSearch_result.class, metaDataMap);
    }

    public updateSearch_result() {
    }

    public updateSearch_result(
      int success,
      com.evernote.edam.error.EDAMUserException userException,
      com.evernote.edam.error.EDAMSystemException systemException,
      com.evernote.edam.error.EDAMNotFoundException notFoundException)
    {
      this();
      this.success = success;
      setSuccessIsSet(true);
      this.userException = userException;
      this.systemException = systemException;
      this.notFoundException = notFoundException;
    }

    /**
     * Performs a deep copy on <i>other</i>.
     */
    public updateSearch_result(updateSearch_result other) {
      __isset_bit_vector.clear();
      __isset_bit_vector.or(other.__isset_bit_vector);
      this.success = other.success;
      if (other.isSetUserException()) {
        this.userException = new com.evernote.edam.error.EDAMUserException(other.userException);
      }
      if (other.isSetSystemException()) {
        this.systemException = new com.evernote.edam.error.EDAMSystemException(other.systemException);
      }
      if (other.isSetNotFoundException()) {
        this.notFoundException = new com.evernote.edam.error.EDAMNotFoundException(other.notFoundException);
      }
    }

    public updateSearch_result deepCopy() {
      return new updateSearch_result(this);
    }

    @Deprecated
    public updateSearch_result clone() {
      return new updateSearch_result(this);
    }

    public int getSuccess() {
      return this.success;
    }

    public void setSuccess(int success) {
      this.success = success;
      setSuccessIsSet(true);
    }

    public void unsetSuccess() {
      __isset_bit_vector.clear(__SUCCESS_ISSET_ID);
    }

    /** Returns true if field success is set (has been asigned a value) and false otherwise */
    public boolean isSetSuccess() {
      return __isset_bit_vector.get(__SUCCESS_ISSET_ID);
    }

    public void setSuccessIsSet(boolean value) {
      __isset_bit_vector.set(__SUCCESS_ISSET_ID, value);
    }

    public com.evernote.edam.error.EDAMUserException getUserException() {
      return this.userException;
    }

    public void setUserException(com.evernote.edam.error.EDAMUserException userException) {
      this.userException = userException;
    }

    public void unsetUserException() {
      this.userException = null;
    }

    /** Returns true if field userException is set (has been asigned a value) and false otherwise */
    public boolean isSetUserException() {
      return this.userException != null;
    }

    public void setUserExceptionIsSet(boolean value) {
      if (!value) {
        this.userException = null;
      }
    }

    public com.evernote.edam.error.EDAMSystemException getSystemException() {
      return this.systemException;
    }

    public void setSystemException(com.evernote.edam.error.EDAMSystemException systemException) {
      this.systemException = systemException;
    }

    public void unsetSystemException() {
      this.systemException = null;
    }

    /** Returns true if field systemException is set (has been asigned a value) and false otherwise */
    public boolean isSetSystemException() {
      return this.systemException != null;
    }

    public void setSystemExceptionIsSet(boolean value) {
      if (!value) {
        this.systemException = null;
      }
    }

    public com.evernote.edam.error.EDAMNotFoundException getNotFoundException() {
      return this.notFoundException;
    }

    public void setNotFoundException(com.evernote.edam.error.EDAMNotFoundException notFoundException) {
      this.notFoundException = notFoundException;
    }

    public void unsetNotFoundException() {
      this.notFoundException = null;
    }

    /** Returns true if field notFoundException is set (has been asigned a value) and false otherwise */
    public boolean isSetNotFoundException() {
      return this.notFoundException != null;
    }

    public void setNotFoundExceptionIsSet(boolean value) {
      if (!value) {
        this.notFoundException = null;
      }
    }

    public void setFieldValue(_Fields field, Object value) {
      switch (field) {
      case SUCCESS:
        if (value == null) {
          unsetSuccess();
        } else {
          setSuccess((Integer)value);
        }
        break;

      case USER_EXCEPTION:
        if (value == null) {
          unsetUserException();
        } else {
          setUserException((com.evernote.edam.error.EDAMUserException)value);
        }
        break;

      case SYSTEM_EXCEPTION:
        if (value == null) {
          unsetSystemException();
        } else {
          setSystemException((com.evernote.edam.error.EDAMSystemException)value);
        }
        break;

      case NOT_FOUND_EXCEPTION:
        if (value == null) {
          unsetNotFoundException();
        } else {
          setNotFoundException((com.evernote.edam.error.EDAMNotFoundException)value);
        }
        break;

      }
    }

    public void setFieldValue(int fieldID, Object value) {
      setFieldValue(_Fields.findByThriftIdOrThrow(fieldID), value);
    }

    public Object getFieldValue(_Fields field) {
      switch (field) {
      case SUCCESS:
        return new Integer(getSuccess());

      case USER_EXCEPTION:
        return getUserException();

      case SYSTEM_EXCEPTION:
        return getSystemException();

      case NOT_FOUND_EXCEPTION:
        return getNotFoundException();

      }
      throw new IllegalStateException();
    }

    public Object getFieldValue(int fieldId) {
      return getFieldValue(_Fields.findByThriftIdOrThrow(fieldId));
    }

    /** Returns true if field corresponding to fieldID is set (has been asigned a value) and false otherwise */
    public boolean isSet(_Fields field) {
      switch (field) {
      case SUCCESS:
        return isSetSuccess();
      case USER_EXCEPTION:
        return isSetUserException();
      case SYSTEM_EXCEPTION:
        return isSetSystemException();
      case NOT_FOUND_EXCEPTION:
        return isSetNotFoundException();
      }
      throw new IllegalStateException();
    }

    public boolean isSet(int fieldID) {
      return isSet(_Fields.findByThriftIdOrThrow(fieldID));
    }

    public boolean equals(Object that) {
      if (that == null)
        return false;
      if (that instanceof updateSearch_result)
        return this.equals((updateSearch_result)that);
      return false;
    }

    public boolean equals(updateSearch_result that) {
      if (that == null)
        return false;

      boolean this_present_success = true;
      boolean that_present_success = true;
      if (this_present_success || that_present_success) {
        if (!(this_present_success && that_present_success))
          return false;
        if (this.success != that.success)
          return false;
      }

      boolean this_present_userException = true && this.isSetUserException();
      boolean that_present_userException = true && that.isSetUserException();
      if (this_present_userException || that_present_userException) {
        if (!(this_present_userException && that_present_userException))
          return false;
        if (!this.userException.equals(that.userException))
          return false;
      }

      boolean this_present_systemException = true && this.isSetSystemException();
      boolean that_present_systemException = true && that.isSetSystemException();
      if (this_present_systemException || that_present_systemException) {
        if (!(this_present_systemException && that_present_systemException))
          return false;
        if (!this.systemException.equals(that.systemException))
          return false;
      }

      boolean this_present_notFoundException = true && this.isSetNotFoundException();
      boolean that_present_notFoundException = true && that.isSetNotFoundException();
      if (this_present_notFoundException || that_present_notFoundException) {
        if (!(this_present_notFoundException && that_present_notFoundException))
          return false;
        if (!this.notFoundException.equals(that.notFoundException))
          return false;
      }

      return true;
    }

    public int hashCode() {
      return 0;
    }

    public int compareTo(updateSearch_result other) {
      if (!getClass().equals(other.getClass())) {
        return getClass().getName().compareTo(other.getClass().getName());
      }

      int lastComparison = 0;
      updateSearch_result typedOther = (updateSearch_result)other;

      lastComparison = Boolean.valueOf(isSetSuccess()).compareTo(isSetSuccess());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(success, typedOther.success);
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = Boolean.valueOf(isSetUserException()).compareTo(isSetUserException());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(userException, typedOther.userException);
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = Boolean.valueOf(isSetSystemException()).compareTo(isSetSystemException());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(systemException, typedOther.systemException);
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = Boolean.valueOf(isSetNotFoundException()).compareTo(isSetNotFoundException());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(notFoundException, typedOther.notFoundException);
      if (lastComparison != 0) {
        return lastComparison;
      }
      return 0;
    }

    public void read(TProtocol iprot) throws TException {
      TField field;
      iprot.readStructBegin();
      while (true)
      {
        field = iprot.readFieldBegin();
        if (field.type == TType.STOP) { 
          break;
        }
        _Fields fieldId = _Fields.findByThriftId(field.id);
        if (fieldId == null) {
          TProtocolUtil.skip(iprot, field.type);
        } else {
          switch (fieldId) {
            case SUCCESS:
              if (field.type == TType.I32) {
                this.success = iprot.readI32();
                setSuccessIsSet(true);
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
            case USER_EXCEPTION:
              if (field.type == TType.STRUCT) {
                this.userException = new com.evernote.edam.error.EDAMUserException();
                this.userException.read(iprot);
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
            case SYSTEM_EXCEPTION:
              if (field.type == TType.STRUCT) {
                this.systemException = new com.evernote.edam.error.EDAMSystemException();
                this.systemException.read(iprot);
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
            case NOT_FOUND_EXCEPTION:
              if (field.type == TType.STRUCT) {
                this.notFoundException = new com.evernote.edam.error.EDAMNotFoundException();
                this.notFoundException.read(iprot);
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
          }
          iprot.readFieldEnd();
        }
      }
      iprot.readStructEnd();
      validate();
    }

    public void write(TProtocol oprot) throws TException {
      oprot.writeStructBegin(STRUCT_DESC);

      if (this.isSetSuccess()) {
        oprot.writeFieldBegin(SUCCESS_FIELD_DESC);
        oprot.writeI32(this.success);
        oprot.writeFieldEnd();
      } else if (this.isSetUserException()) {
        oprot.writeFieldBegin(USER_EXCEPTION_FIELD_DESC);
        this.userException.write(oprot);
        oprot.writeFieldEnd();
      } else if (this.isSetSystemException()) {
        oprot.writeFieldBegin(SYSTEM_EXCEPTION_FIELD_DESC);
        this.systemException.write(oprot);
        oprot.writeFieldEnd();
      } else if (this.isSetNotFoundException()) {
        oprot.writeFieldBegin(NOT_FOUND_EXCEPTION_FIELD_DESC);
        this.notFoundException.write(oprot);
        oprot.writeFieldEnd();
      }
      oprot.writeFieldStop();
      oprot.writeStructEnd();
    }

    public String toString() {
      StringBuilder sb = new StringBuilder("updateSearch_result(");
      boolean first = true;

      sb.append("success:");
      sb.append(this.success);
      first = false;
      if (!first) sb.append(", ");
      sb.append("userException:");
      if (this.userException == null) {
        sb.append("null");
      } else {
        sb.append(this.userException);
      }
      first = false;
      if (!first) sb.append(", ");
      sb.append("systemException:");
      if (this.systemException == null) {
        sb.append("null");
      } else {
        sb.append(this.systemException);
      }
      first = false;
      if (!first) sb.append(", ");
      sb.append("notFoundException:");
      if (this.notFoundException == null) {
        sb.append("null");
      } else {
        sb.append(this.notFoundException);
      }
      first = false;
      sb.append(")");
      return sb.toString();
    }

    public void validate() throws TException {
      // check for required fields
    }

  }

  public static class expungeSearch_args implements TBase<expungeSearch_args._Fields>, java.io.Serializable, Cloneable, Comparable<expungeSearch_args>   {
    private static final TStruct STRUCT_DESC = new TStruct("expungeSearch_args");

    private static final TField AUTHENTICATION_TOKEN_FIELD_DESC = new TField("authenticationToken", TType.STRING, (short)1);
    private static final TField GUID_FIELD_DESC = new TField("guid", TType.STRING, (short)2);

    private String authenticationToken;
    private String guid;

    /** The set of fields this struct contains, along with convenience methods for finding and manipulating them. */
    public enum _Fields implements TFieldIdEnum {
      AUTHENTICATION_TOKEN((short)1, "authenticationToken"),
      GUID((short)2, "guid");

      private static final Map<Integer, _Fields> byId = new HashMap<Integer, _Fields>();
      private static final Map<String, _Fields> byName = new HashMap<String, _Fields>();

      static {
        for (_Fields field : EnumSet.allOf(_Fields.class)) {
          byId.put((int)field._thriftId, field);
          byName.put(field.getFieldName(), field);
        }
      }

      /**
       * Find the _Fields constant that matches fieldId, or null if its not found.
       */
      public static _Fields findByThriftId(int fieldId) {
        return byId.get(fieldId);
      }

      /**
       * Find the _Fields constant that matches fieldId, throwing an exception
       * if it is not found.
       */
      public static _Fields findByThriftIdOrThrow(int fieldId) {
        _Fields fields = findByThriftId(fieldId);
        if (fields == null) throw new IllegalArgumentException("Field " + fieldId + " doesn't exist!");
        return fields;
      }

      /**
       * Find the _Fields constant that matches name, or null if its not found.
       */
      public static _Fields findByName(String name) {
        return byName.get(name);
      }

      private final short _thriftId;
      private final String _fieldName;

      _Fields(short thriftId, String fieldName) {
        _thriftId = thriftId;
        _fieldName = fieldName;
      }

      public short getThriftFieldId() {
        return _thriftId;
      }

      public String getFieldName() {
        return _fieldName;
      }
    }

    // isset id assignments

    public static final Map<_Fields, FieldMetaData> metaDataMap = Collections.unmodifiableMap(new EnumMap<_Fields, FieldMetaData>(_Fields.class) {{
      put(_Fields.AUTHENTICATION_TOKEN, new FieldMetaData("authenticationToken", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.STRING)));
      put(_Fields.GUID, new FieldMetaData("guid", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.STRING)));
    }});

    static {
      FieldMetaData.addStructMetaDataMap(expungeSearch_args.class, metaDataMap);
    }

    public expungeSearch_args() {
    }

    public expungeSearch_args(
      String authenticationToken,
      String guid)
    {
      this();
      this.authenticationToken = authenticationToken;
      this.guid = guid;
    }

    /**
     * Performs a deep copy on <i>other</i>.
     */
    public expungeSearch_args(expungeSearch_args other) {
      if (other.isSetAuthenticationToken()) {
        this.authenticationToken = other.authenticationToken;
      }
      if (other.isSetGuid()) {
        this.guid = other.guid;
      }
    }

    public expungeSearch_args deepCopy() {
      return new expungeSearch_args(this);
    }

    @Deprecated
    public expungeSearch_args clone() {
      return new expungeSearch_args(this);
    }

    public String getAuthenticationToken() {
      return this.authenticationToken;
    }

    public void setAuthenticationToken(String authenticationToken) {
      this.authenticationToken = authenticationToken;
    }

    public void unsetAuthenticationToken() {
      this.authenticationToken = null;
    }

    /** Returns true if field authenticationToken is set (has been asigned a value) and false otherwise */
    public boolean isSetAuthenticationToken() {
      return this.authenticationToken != null;
    }

    public void setAuthenticationTokenIsSet(boolean value) {
      if (!value) {
        this.authenticationToken = null;
      }
    }

    public String getGuid() {
      return this.guid;
    }

    public void setGuid(String guid) {
      this.guid = guid;
    }

    public void unsetGuid() {
      this.guid = null;
    }

    /** Returns true if field guid is set (has been asigned a value) and false otherwise */
    public boolean isSetGuid() {
      return this.guid != null;
    }

    public void setGuidIsSet(boolean value) {
      if (!value) {
        this.guid = null;
      }
    }

    public void setFieldValue(_Fields field, Object value) {
      switch (field) {
      case AUTHENTICATION_TOKEN:
        if (value == null) {
          unsetAuthenticationToken();
        } else {
          setAuthenticationToken((String)value);
        }
        break;

      case GUID:
        if (value == null) {
          unsetGuid();
        } else {
          setGuid((String)value);
        }
        break;

      }
    }

    public void setFieldValue(int fieldID, Object value) {
      setFieldValue(_Fields.findByThriftIdOrThrow(fieldID), value);
    }

    public Object getFieldValue(_Fields field) {
      switch (field) {
      case AUTHENTICATION_TOKEN:
        return getAuthenticationToken();

      case GUID:
        return getGuid();

      }
      throw new IllegalStateException();
    }

    public Object getFieldValue(int fieldId) {
      return getFieldValue(_Fields.findByThriftIdOrThrow(fieldId));
    }

    /** Returns true if field corresponding to fieldID is set (has been asigned a value) and false otherwise */
    public boolean isSet(_Fields field) {
      switch (field) {
      case AUTHENTICATION_TOKEN:
        return isSetAuthenticationToken();
      case GUID:
        return isSetGuid();
      }
      throw new IllegalStateException();
    }

    public boolean isSet(int fieldID) {
      return isSet(_Fields.findByThriftIdOrThrow(fieldID));
    }

    public boolean equals(Object that) {
      if (that == null)
        return false;
      if (that instanceof expungeSearch_args)
        return this.equals((expungeSearch_args)that);
      return false;
    }

    public boolean equals(expungeSearch_args that) {
      if (that == null)
        return false;

      boolean this_present_authenticationToken = true && this.isSetAuthenticationToken();
      boolean that_present_authenticationToken = true && that.isSetAuthenticationToken();
      if (this_present_authenticationToken || that_present_authenticationToken) {
        if (!(this_present_authenticationToken && that_present_authenticationToken))
          return false;
        if (!this.authenticationToken.equals(that.authenticationToken))
          return false;
      }

      boolean this_present_guid = true && this.isSetGuid();
      boolean that_present_guid = true && that.isSetGuid();
      if (this_present_guid || that_present_guid) {
        if (!(this_present_guid && that_present_guid))
          return false;
        if (!this.guid.equals(that.guid))
          return false;
      }

      return true;
    }

    public int hashCode() {
      return 0;
    }

    public int compareTo(expungeSearch_args other) {
      if (!getClass().equals(other.getClass())) {
        return getClass().getName().compareTo(other.getClass().getName());
      }

      int lastComparison = 0;
      expungeSearch_args typedOther = (expungeSearch_args)other;

      lastComparison = Boolean.valueOf(isSetAuthenticationToken()).compareTo(isSetAuthenticationToken());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(authenticationToken, typedOther.authenticationToken);
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = Boolean.valueOf(isSetGuid()).compareTo(isSetGuid());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(guid, typedOther.guid);
      if (lastComparison != 0) {
        return lastComparison;
      }
      return 0;
    }

    public void read(TProtocol iprot) throws TException {
      TField field;
      iprot.readStructBegin();
      while (true)
      {
        field = iprot.readFieldBegin();
        if (field.type == TType.STOP) { 
          break;
        }
        _Fields fieldId = _Fields.findByThriftId(field.id);
        if (fieldId == null) {
          TProtocolUtil.skip(iprot, field.type);
        } else {
          switch (fieldId) {
            case AUTHENTICATION_TOKEN:
              if (field.type == TType.STRING) {
                this.authenticationToken = iprot.readString();
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
            case GUID:
              if (field.type == TType.STRING) {
                this.guid = iprot.readString();
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
          }
          iprot.readFieldEnd();
        }
      }
      iprot.readStructEnd();
      validate();
    }

    public void write(TProtocol oprot) throws TException {
      validate();

      oprot.writeStructBegin(STRUCT_DESC);
      if (this.authenticationToken != null) {
        oprot.writeFieldBegin(AUTHENTICATION_TOKEN_FIELD_DESC);
        oprot.writeString(this.authenticationToken);
        oprot.writeFieldEnd();
      }
      if (this.guid != null) {
        oprot.writeFieldBegin(GUID_FIELD_DESC);
        oprot.writeString(this.guid);
        oprot.writeFieldEnd();
      }
      oprot.writeFieldStop();
      oprot.writeStructEnd();
    }

    public String toString() {
      StringBuilder sb = new StringBuilder("expungeSearch_args(");
      boolean first = true;

      sb.append("authenticationToken:");
      if (this.authenticationToken == null) {
        sb.append("null");
      } else {
        sb.append(this.authenticationToken);
      }
      first = false;
      if (!first) sb.append(", ");
      sb.append("guid:");
      if (this.guid == null) {
        sb.append("null");
      } else {
        sb.append(this.guid);
      }
      first = false;
      sb.append(")");
      return sb.toString();
    }

    public void validate() throws TException {
      // check for required fields
    }

  }

  public static class expungeSearch_result implements TBase<expungeSearch_result._Fields>, java.io.Serializable, Cloneable, Comparable<expungeSearch_result>   {
    private static final TStruct STRUCT_DESC = new TStruct("expungeSearch_result");

    private static final TField SUCCESS_FIELD_DESC = new TField("success", TType.I32, (short)0);
    private static final TField USER_EXCEPTION_FIELD_DESC = new TField("userException", TType.STRUCT, (short)1);
    private static final TField SYSTEM_EXCEPTION_FIELD_DESC = new TField("systemException", TType.STRUCT, (short)2);
    private static final TField NOT_FOUND_EXCEPTION_FIELD_DESC = new TField("notFoundException", TType.STRUCT, (short)3);

    private int success;
    private com.evernote.edam.error.EDAMUserException userException;
    private com.evernote.edam.error.EDAMSystemException systemException;
    private com.evernote.edam.error.EDAMNotFoundException notFoundException;

    /** The set of fields this struct contains, along with convenience methods for finding and manipulating them. */
    public enum _Fields implements TFieldIdEnum {
      SUCCESS((short)0, "success"),
      USER_EXCEPTION((short)1, "userException"),
      SYSTEM_EXCEPTION((short)2, "systemException"),
      NOT_FOUND_EXCEPTION((short)3, "notFoundException");

      private static final Map<Integer, _Fields> byId = new HashMap<Integer, _Fields>();
      private static final Map<String, _Fields> byName = new HashMap<String, _Fields>();

      static {
        for (_Fields field : EnumSet.allOf(_Fields.class)) {
          byId.put((int)field._thriftId, field);
          byName.put(field.getFieldName(), field);
        }
      }

      /**
       * Find the _Fields constant that matches fieldId, or null if its not found.
       */
      public static _Fields findByThriftId(int fieldId) {
        return byId.get(fieldId);
      }

      /**
       * Find the _Fields constant that matches fieldId, throwing an exception
       * if it is not found.
       */
      public static _Fields findByThriftIdOrThrow(int fieldId) {
        _Fields fields = findByThriftId(fieldId);
        if (fields == null) throw new IllegalArgumentException("Field " + fieldId + " doesn't exist!");
        return fields;
      }

      /**
       * Find the _Fields constant that matches name, or null if its not found.
       */
      public static _Fields findByName(String name) {
        return byName.get(name);
      }

      private final short _thriftId;
      private final String _fieldName;

      _Fields(short thriftId, String fieldName) {
        _thriftId = thriftId;
        _fieldName = fieldName;
      }

      public short getThriftFieldId() {
        return _thriftId;
      }

      public String getFieldName() {
        return _fieldName;
      }
    }

    // isset id assignments
    private static final int __SUCCESS_ISSET_ID = 0;
    private BitSet __isset_bit_vector = new BitSet(1);

    public static final Map<_Fields, FieldMetaData> metaDataMap = Collections.unmodifiableMap(new EnumMap<_Fields, FieldMetaData>(_Fields.class) {{
      put(_Fields.SUCCESS, new FieldMetaData("success", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.I32)));
      put(_Fields.USER_EXCEPTION, new FieldMetaData("userException", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.STRUCT)));
      put(_Fields.SYSTEM_EXCEPTION, new FieldMetaData("systemException", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.STRUCT)));
      put(_Fields.NOT_FOUND_EXCEPTION, new FieldMetaData("notFoundException", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.STRUCT)));
    }});

    static {
      FieldMetaData.addStructMetaDataMap(expungeSearch_result.class, metaDataMap);
    }

    public expungeSearch_result() {
    }

    public expungeSearch_result(
      int success,
      com.evernote.edam.error.EDAMUserException userException,
      com.evernote.edam.error.EDAMSystemException systemException,
      com.evernote.edam.error.EDAMNotFoundException notFoundException)
    {
      this();
      this.success = success;
      setSuccessIsSet(true);
      this.userException = userException;
      this.systemException = systemException;
      this.notFoundException = notFoundException;
    }

    /**
     * Performs a deep copy on <i>other</i>.
     */
    public expungeSearch_result(expungeSearch_result other) {
      __isset_bit_vector.clear();
      __isset_bit_vector.or(other.__isset_bit_vector);
      this.success = other.success;
      if (other.isSetUserException()) {
        this.userException = new com.evernote.edam.error.EDAMUserException(other.userException);
      }
      if (other.isSetSystemException()) {
        this.systemException = new com.evernote.edam.error.EDAMSystemException(other.systemException);
      }
      if (other.isSetNotFoundException()) {
        this.notFoundException = new com.evernote.edam.error.EDAMNotFoundException(other.notFoundException);
      }
    }

    public expungeSearch_result deepCopy() {
      return new expungeSearch_result(this);
    }

    @Deprecated
    public expungeSearch_result clone() {
      return new expungeSearch_result(this);
    }

    public int getSuccess() {
      return this.success;
    }

    public void setSuccess(int success) {
      this.success = success;
      setSuccessIsSet(true);
    }

    public void unsetSuccess() {
      __isset_bit_vector.clear(__SUCCESS_ISSET_ID);
    }

    /** Returns true if field success is set (has been asigned a value) and false otherwise */
    public boolean isSetSuccess() {
      return __isset_bit_vector.get(__SUCCESS_ISSET_ID);
    }

    public void setSuccessIsSet(boolean value) {
      __isset_bit_vector.set(__SUCCESS_ISSET_ID, value);
    }

    public com.evernote.edam.error.EDAMUserException getUserException() {
      return this.userException;
    }

    public void setUserException(com.evernote.edam.error.EDAMUserException userException) {
      this.userException = userException;
    }

    public void unsetUserException() {
      this.userException = null;
    }

    /** Returns true if field userException is set (has been asigned a value) and false otherwise */
    public boolean isSetUserException() {
      return this.userException != null;
    }

    public void setUserExceptionIsSet(boolean value) {
      if (!value) {
        this.userException = null;
      }
    }

    public com.evernote.edam.error.EDAMSystemException getSystemException() {
      return this.systemException;
    }

    public void setSystemException(com.evernote.edam.error.EDAMSystemException systemException) {
      this.systemException = systemException;
    }

    public void unsetSystemException() {
      this.systemException = null;
    }

    /** Returns true if field systemException is set (has been asigned a value) and false otherwise */
    public boolean isSetSystemException() {
      return this.systemException != null;
    }

    public void setSystemExceptionIsSet(boolean value) {
      if (!value) {
        this.systemException = null;
      }
    }

    public com.evernote.edam.error.EDAMNotFoundException getNotFoundException() {
      return this.notFoundException;
    }

    public void setNotFoundException(com.evernote.edam.error.EDAMNotFoundException notFoundException) {
      this.notFoundException = notFoundException;
    }

    public void unsetNotFoundException() {
      this.notFoundException = null;
    }

    /** Returns true if field notFoundException is set (has been asigned a value) and false otherwise */
    public boolean isSetNotFoundException() {
      return this.notFoundException != null;
    }

    public void setNotFoundExceptionIsSet(boolean value) {
      if (!value) {
        this.notFoundException = null;
      }
    }

    public void setFieldValue(_Fields field, Object value) {
      switch (field) {
      case SUCCESS:
        if (value == null) {
          unsetSuccess();
        } else {
          setSuccess((Integer)value);
        }
        break;

      case USER_EXCEPTION:
        if (value == null) {
          unsetUserException();
        } else {
          setUserException((com.evernote.edam.error.EDAMUserException)value);
        }
        break;

      case SYSTEM_EXCEPTION:
        if (value == null) {
          unsetSystemException();
        } else {
          setSystemException((com.evernote.edam.error.EDAMSystemException)value);
        }
        break;

      case NOT_FOUND_EXCEPTION:
        if (value == null) {
          unsetNotFoundException();
        } else {
          setNotFoundException((com.evernote.edam.error.EDAMNotFoundException)value);
        }
        break;

      }
    }

    public void setFieldValue(int fieldID, Object value) {
      setFieldValue(_Fields.findByThriftIdOrThrow(fieldID), value);
    }

    public Object getFieldValue(_Fields field) {
      switch (field) {
      case SUCCESS:
        return new Integer(getSuccess());

      case USER_EXCEPTION:
        return getUserException();

      case SYSTEM_EXCEPTION:
        return getSystemException();

      case NOT_FOUND_EXCEPTION:
        return getNotFoundException();

      }
      throw new IllegalStateException();
    }

    public Object getFieldValue(int fieldId) {
      return getFieldValue(_Fields.findByThriftIdOrThrow(fieldId));
    }

    /** Returns true if field corresponding to fieldID is set (has been asigned a value) and false otherwise */
    public boolean isSet(_Fields field) {
      switch (field) {
      case SUCCESS:
        return isSetSuccess();
      case USER_EXCEPTION:
        return isSetUserException();
      case SYSTEM_EXCEPTION:
        return isSetSystemException();
      case NOT_FOUND_EXCEPTION:
        return isSetNotFoundException();
      }
      throw new IllegalStateException();
    }

    public boolean isSet(int fieldID) {
      return isSet(_Fields.findByThriftIdOrThrow(fieldID));
    }

    public boolean equals(Object that) {
      if (that == null)
        return false;
      if (that instanceof expungeSearch_result)
        return this.equals((expungeSearch_result)that);
      return false;
    }

    public boolean equals(expungeSearch_result that) {
      if (that == null)
        return false;

      boolean this_present_success = true;
      boolean that_present_success = true;
      if (this_present_success || that_present_success) {
        if (!(this_present_success && that_present_success))
          return false;
        if (this.success != that.success)
          return false;
      }

      boolean this_present_userException = true && this.isSetUserException();
      boolean that_present_userException = true && that.isSetUserException();
      if (this_present_userException || that_present_userException) {
        if (!(this_present_userException && that_present_userException))
          return false;
        if (!this.userException.equals(that.userException))
          return false;
      }

      boolean this_present_systemException = true && this.isSetSystemException();
      boolean that_present_systemException = true && that.isSetSystemException();
      if (this_present_systemException || that_present_systemException) {
        if (!(this_present_systemException && that_present_systemException))
          return false;
        if (!this.systemException.equals(that.systemException))
          return false;
      }

      boolean this_present_notFoundException = true && this.isSetNotFoundException();
      boolean that_present_notFoundException = true && that.isSetNotFoundException();
      if (this_present_notFoundException || that_present_notFoundException) {
        if (!(this_present_notFoundException && that_present_notFoundException))
          return false;
        if (!this.notFoundException.equals(that.notFoundException))
          return false;
      }

      return true;
    }

    public int hashCode() {
      return 0;
    }

    public int compareTo(expungeSearch_result other) {
      if (!getClass().equals(other.getClass())) {
        return getClass().getName().compareTo(other.getClass().getName());
      }

      int lastComparison = 0;
      expungeSearch_result typedOther = (expungeSearch_result)other;

      lastComparison = Boolean.valueOf(isSetSuccess()).compareTo(isSetSuccess());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(success, typedOther.success);
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = Boolean.valueOf(isSetUserException()).compareTo(isSetUserException());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(userException, typedOther.userException);
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = Boolean.valueOf(isSetSystemException()).compareTo(isSetSystemException());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(systemException, typedOther.systemException);
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = Boolean.valueOf(isSetNotFoundException()).compareTo(isSetNotFoundException());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(notFoundException, typedOther.notFoundException);
      if (lastComparison != 0) {
        return lastComparison;
      }
      return 0;
    }

    public void read(TProtocol iprot) throws TException {
      TField field;
      iprot.readStructBegin();
      while (true)
      {
        field = iprot.readFieldBegin();
        if (field.type == TType.STOP) { 
          break;
        }
        _Fields fieldId = _Fields.findByThriftId(field.id);
        if (fieldId == null) {
          TProtocolUtil.skip(iprot, field.type);
        } else {
          switch (fieldId) {
            case SUCCESS:
              if (field.type == TType.I32) {
                this.success = iprot.readI32();
                setSuccessIsSet(true);
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
            case USER_EXCEPTION:
              if (field.type == TType.STRUCT) {
                this.userException = new com.evernote.edam.error.EDAMUserException();
                this.userException.read(iprot);
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
            case SYSTEM_EXCEPTION:
              if (field.type == TType.STRUCT) {
                this.systemException = new com.evernote.edam.error.EDAMSystemException();
                this.systemException.read(iprot);
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
            case NOT_FOUND_EXCEPTION:
              if (field.type == TType.STRUCT) {
                this.notFoundException = new com.evernote.edam.error.EDAMNotFoundException();
                this.notFoundException.read(iprot);
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
          }
          iprot.readFieldEnd();
        }
      }
      iprot.readStructEnd();
      validate();
    }

    public void write(TProtocol oprot) throws TException {
      oprot.writeStructBegin(STRUCT_DESC);

      if (this.isSetSuccess()) {
        oprot.writeFieldBegin(SUCCESS_FIELD_DESC);
        oprot.writeI32(this.success);
        oprot.writeFieldEnd();
      } else if (this.isSetUserException()) {
        oprot.writeFieldBegin(USER_EXCEPTION_FIELD_DESC);
        this.userException.write(oprot);
        oprot.writeFieldEnd();
      } else if (this.isSetSystemException()) {
        oprot.writeFieldBegin(SYSTEM_EXCEPTION_FIELD_DESC);
        this.systemException.write(oprot);
        oprot.writeFieldEnd();
      } else if (this.isSetNotFoundException()) {
        oprot.writeFieldBegin(NOT_FOUND_EXCEPTION_FIELD_DESC);
        this.notFoundException.write(oprot);
        oprot.writeFieldEnd();
      }
      oprot.writeFieldStop();
      oprot.writeStructEnd();
    }

    public String toString() {
      StringBuilder sb = new StringBuilder("expungeSearch_result(");
      boolean first = true;

      sb.append("success:");
      sb.append(this.success);
      first = false;
      if (!first) sb.append(", ");
      sb.append("userException:");
      if (this.userException == null) {
        sb.append("null");
      } else {
        sb.append(this.userException);
      }
      first = false;
      if (!first) sb.append(", ");
      sb.append("systemException:");
      if (this.systemException == null) {
        sb.append("null");
      } else {
        sb.append(this.systemException);
      }
      first = false;
      if (!first) sb.append(", ");
      sb.append("notFoundException:");
      if (this.notFoundException == null) {
        sb.append("null");
      } else {
        sb.append(this.notFoundException);
      }
      first = false;
      sb.append(")");
      return sb.toString();
    }

    public void validate() throws TException {
      // check for required fields
    }

  }

  public static class findNotes_args implements TBase<findNotes_args._Fields>, java.io.Serializable, Cloneable, Comparable<findNotes_args>   {
    private static final TStruct STRUCT_DESC = new TStruct("findNotes_args");

    private static final TField AUTHENTICATION_TOKEN_FIELD_DESC = new TField("authenticationToken", TType.STRING, (short)1);
    private static final TField FILTER_FIELD_DESC = new TField("filter", TType.STRUCT, (short)2);
    private static final TField OFFSET_FIELD_DESC = new TField("offset", TType.I32, (short)3);
    private static final TField MAX_NOTES_FIELD_DESC = new TField("maxNotes", TType.I32, (short)4);

    private String authenticationToken;
    private NoteFilter filter;
    private int offset;
    private int maxNotes;

    /** The set of fields this struct contains, along with convenience methods for finding and manipulating them. */
    public enum _Fields implements TFieldIdEnum {
      AUTHENTICATION_TOKEN((short)1, "authenticationToken"),
      FILTER((short)2, "filter"),
      OFFSET((short)3, "offset"),
      MAX_NOTES((short)4, "maxNotes");

      private static final Map<Integer, _Fields> byId = new HashMap<Integer, _Fields>();
      private static final Map<String, _Fields> byName = new HashMap<String, _Fields>();

      static {
        for (_Fields field : EnumSet.allOf(_Fields.class)) {
          byId.put((int)field._thriftId, field);
          byName.put(field.getFieldName(), field);
        }
      }

      /**
       * Find the _Fields constant that matches fieldId, or null if its not found.
       */
      public static _Fields findByThriftId(int fieldId) {
        return byId.get(fieldId);
      }

      /**
       * Find the _Fields constant that matches fieldId, throwing an exception
       * if it is not found.
       */
      public static _Fields findByThriftIdOrThrow(int fieldId) {
        _Fields fields = findByThriftId(fieldId);
        if (fields == null) throw new IllegalArgumentException("Field " + fieldId + " doesn't exist!");
        return fields;
      }

      /**
       * Find the _Fields constant that matches name, or null if its not found.
       */
      public static _Fields findByName(String name) {
        return byName.get(name);
      }

      private final short _thriftId;
      private final String _fieldName;

      _Fields(short thriftId, String fieldName) {
        _thriftId = thriftId;
        _fieldName = fieldName;
      }

      public short getThriftFieldId() {
        return _thriftId;
      }

      public String getFieldName() {
        return _fieldName;
      }
    }

    // isset id assignments
    private static final int __OFFSET_ISSET_ID = 0;
    private static final int __MAXNOTES_ISSET_ID = 1;
    private BitSet __isset_bit_vector = new BitSet(2);

    public static final Map<_Fields, FieldMetaData> metaDataMap = Collections.unmodifiableMap(new EnumMap<_Fields, FieldMetaData>(_Fields.class) {{
      put(_Fields.AUTHENTICATION_TOKEN, new FieldMetaData("authenticationToken", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.STRING)));
      put(_Fields.FILTER, new FieldMetaData("filter", TFieldRequirementType.DEFAULT, 
          new StructMetaData(TType.STRUCT, NoteFilter.class)));
      put(_Fields.OFFSET, new FieldMetaData("offset", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.I32)));
      put(_Fields.MAX_NOTES, new FieldMetaData("maxNotes", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.I32)));
    }});

    static {
      FieldMetaData.addStructMetaDataMap(findNotes_args.class, metaDataMap);
    }

    public findNotes_args() {
    }

    public findNotes_args(
      String authenticationToken,
      NoteFilter filter,
      int offset,
      int maxNotes)
    {
      this();
      this.authenticationToken = authenticationToken;
      this.filter = filter;
      this.offset = offset;
      setOffsetIsSet(true);
      this.maxNotes = maxNotes;
      setMaxNotesIsSet(true);
    }

    /**
     * Performs a deep copy on <i>other</i>.
     */
    public findNotes_args(findNotes_args other) {
      __isset_bit_vector.clear();
      __isset_bit_vector.or(other.__isset_bit_vector);
      if (other.isSetAuthenticationToken()) {
        this.authenticationToken = other.authenticationToken;
      }
      if (other.isSetFilter()) {
        this.filter = new NoteFilter(other.filter);
      }
      this.offset = other.offset;
      this.maxNotes = other.maxNotes;
    }

    public findNotes_args deepCopy() {
      return new findNotes_args(this);
    }

    @Deprecated
    public findNotes_args clone() {
      return new findNotes_args(this);
    }

    public String getAuthenticationToken() {
      return this.authenticationToken;
    }

    public void setAuthenticationToken(String authenticationToken) {
      this.authenticationToken = authenticationToken;
    }

    public void unsetAuthenticationToken() {
      this.authenticationToken = null;
    }

    /** Returns true if field authenticationToken is set (has been asigned a value) and false otherwise */
    public boolean isSetAuthenticationToken() {
      return this.authenticationToken != null;
    }

    public void setAuthenticationTokenIsSet(boolean value) {
      if (!value) {
        this.authenticationToken = null;
      }
    }

    public NoteFilter getFilter() {
      return this.filter;
    }

    public void setFilter(NoteFilter filter) {
      this.filter = filter;
    }

    public void unsetFilter() {
      this.filter = null;
    }

    /** Returns true if field filter is set (has been asigned a value) and false otherwise */
    public boolean isSetFilter() {
      return this.filter != null;
    }

    public void setFilterIsSet(boolean value) {
      if (!value) {
        this.filter = null;
      }
    }

    public int getOffset() {
      return this.offset;
    }

    public void setOffset(int offset) {
      this.offset = offset;
      setOffsetIsSet(true);
    }

    public void unsetOffset() {
      __isset_bit_vector.clear(__OFFSET_ISSET_ID);
    }

    /** Returns true if field offset is set (has been asigned a value) and false otherwise */
    public boolean isSetOffset() {
      return __isset_bit_vector.get(__OFFSET_ISSET_ID);
    }

    public void setOffsetIsSet(boolean value) {
      __isset_bit_vector.set(__OFFSET_ISSET_ID, value);
    }

    public int getMaxNotes() {
      return this.maxNotes;
    }

    public void setMaxNotes(int maxNotes) {
      this.maxNotes = maxNotes;
      setMaxNotesIsSet(true);
    }

    public void unsetMaxNotes() {
      __isset_bit_vector.clear(__MAXNOTES_ISSET_ID);
    }

    /** Returns true if field maxNotes is set (has been asigned a value) and false otherwise */
    public boolean isSetMaxNotes() {
      return __isset_bit_vector.get(__MAXNOTES_ISSET_ID);
    }

    public void setMaxNotesIsSet(boolean value) {
      __isset_bit_vector.set(__MAXNOTES_ISSET_ID, value);
    }

    public void setFieldValue(_Fields field, Object value) {
      switch (field) {
      case AUTHENTICATION_TOKEN:
        if (value == null) {
          unsetAuthenticationToken();
        } else {
          setAuthenticationToken((String)value);
        }
        break;

      case FILTER:
        if (value == null) {
          unsetFilter();
        } else {
          setFilter((NoteFilter)value);
        }
        break;

      case OFFSET:
        if (value == null) {
          unsetOffset();
        } else {
          setOffset((Integer)value);
        }
        break;

      case MAX_NOTES:
        if (value == null) {
          unsetMaxNotes();
        } else {
          setMaxNotes((Integer)value);
        }
        break;

      }
    }

    public void setFieldValue(int fieldID, Object value) {
      setFieldValue(_Fields.findByThriftIdOrThrow(fieldID), value);
    }

    public Object getFieldValue(_Fields field) {
      switch (field) {
      case AUTHENTICATION_TOKEN:
        return getAuthenticationToken();

      case FILTER:
        return getFilter();

      case OFFSET:
        return new Integer(getOffset());

      case MAX_NOTES:
        return new Integer(getMaxNotes());

      }
      throw new IllegalStateException();
    }

    public Object getFieldValue(int fieldId) {
      return getFieldValue(_Fields.findByThriftIdOrThrow(fieldId));
    }

    /** Returns true if field corresponding to fieldID is set (has been asigned a value) and false otherwise */
    public boolean isSet(_Fields field) {
      switch (field) {
      case AUTHENTICATION_TOKEN:
        return isSetAuthenticationToken();
      case FILTER:
        return isSetFilter();
      case OFFSET:
        return isSetOffset();
      case MAX_NOTES:
        return isSetMaxNotes();
      }
      throw new IllegalStateException();
    }

    public boolean isSet(int fieldID) {
      return isSet(_Fields.findByThriftIdOrThrow(fieldID));
    }

    public boolean equals(Object that) {
      if (that == null)
        return false;
      if (that instanceof findNotes_args)
        return this.equals((findNotes_args)that);
      return false;
    }

    public boolean equals(findNotes_args that) {
      if (that == null)
        return false;

      boolean this_present_authenticationToken = true && this.isSetAuthenticationToken();
      boolean that_present_authenticationToken = true && that.isSetAuthenticationToken();
      if (this_present_authenticationToken || that_present_authenticationToken) {
        if (!(this_present_authenticationToken && that_present_authenticationToken))
          return false;
        if (!this.authenticationToken.equals(that.authenticationToken))
          return false;
      }

      boolean this_present_filter = true && this.isSetFilter();
      boolean that_present_filter = true && that.isSetFilter();
      if (this_present_filter || that_present_filter) {
        if (!(this_present_filter && that_present_filter))
          return false;
        if (!this.filter.equals(that.filter))
          return false;
      }

      boolean this_present_offset = true;
      boolean that_present_offset = true;
      if (this_present_offset || that_present_offset) {
        if (!(this_present_offset && that_present_offset))
          return false;
        if (this.offset != that.offset)
          return false;
      }

      boolean this_present_maxNotes = true;
      boolean that_present_maxNotes = true;
      if (this_present_maxNotes || that_present_maxNotes) {
        if (!(this_present_maxNotes && that_present_maxNotes))
          return false;
        if (this.maxNotes != that.maxNotes)
          return false;
      }

      return true;
    }

    public int hashCode() {
      return 0;
    }

    public int compareTo(findNotes_args other) {
      if (!getClass().equals(other.getClass())) {
        return getClass().getName().compareTo(other.getClass().getName());
      }

      int lastComparison = 0;
      findNotes_args typedOther = (findNotes_args)other;

      lastComparison = Boolean.valueOf(isSetAuthenticationToken()).compareTo(isSetAuthenticationToken());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(authenticationToken, typedOther.authenticationToken);
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = Boolean.valueOf(isSetFilter()).compareTo(isSetFilter());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(filter, typedOther.filter);
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = Boolean.valueOf(isSetOffset()).compareTo(isSetOffset());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(offset, typedOther.offset);
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = Boolean.valueOf(isSetMaxNotes()).compareTo(isSetMaxNotes());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(maxNotes, typedOther.maxNotes);
      if (lastComparison != 0) {
        return lastComparison;
      }
      return 0;
    }

    public void read(TProtocol iprot) throws TException {
      TField field;
      iprot.readStructBegin();
      while (true)
      {
        field = iprot.readFieldBegin();
        if (field.type == TType.STOP) { 
          break;
        }
        _Fields fieldId = _Fields.findByThriftId(field.id);
        if (fieldId == null) {
          TProtocolUtil.skip(iprot, field.type);
        } else {
          switch (fieldId) {
            case AUTHENTICATION_TOKEN:
              if (field.type == TType.STRING) {
                this.authenticationToken = iprot.readString();
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
            case FILTER:
              if (field.type == TType.STRUCT) {
                this.filter = new NoteFilter();
                this.filter.read(iprot);
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
            case OFFSET:
              if (field.type == TType.I32) {
                this.offset = iprot.readI32();
                setOffsetIsSet(true);
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
            case MAX_NOTES:
              if (field.type == TType.I32) {
                this.maxNotes = iprot.readI32();
                setMaxNotesIsSet(true);
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
          }
          iprot.readFieldEnd();
        }
      }
      iprot.readStructEnd();
      validate();
    }

    public void write(TProtocol oprot) throws TException {
      validate();

      oprot.writeStructBegin(STRUCT_DESC);
      if (this.authenticationToken != null) {
        oprot.writeFieldBegin(AUTHENTICATION_TOKEN_FIELD_DESC);
        oprot.writeString(this.authenticationToken);
        oprot.writeFieldEnd();
      }
      if (this.filter != null) {
        oprot.writeFieldBegin(FILTER_FIELD_DESC);
        this.filter.write(oprot);
        oprot.writeFieldEnd();
      }
      oprot.writeFieldBegin(OFFSET_FIELD_DESC);
      oprot.writeI32(this.offset);
      oprot.writeFieldEnd();
      oprot.writeFieldBegin(MAX_NOTES_FIELD_DESC);
      oprot.writeI32(this.maxNotes);
      oprot.writeFieldEnd();
      oprot.writeFieldStop();
      oprot.writeStructEnd();
    }

    public String toString() {
      StringBuilder sb = new StringBuilder("findNotes_args(");
      boolean first = true;

      sb.append("authenticationToken:");
      if (this.authenticationToken == null) {
        sb.append("null");
      } else {
        sb.append(this.authenticationToken);
      }
      first = false;
      if (!first) sb.append(", ");
      sb.append("filter:");
      if (this.filter == null) {
        sb.append("null");
      } else {
        sb.append(this.filter);
      }
      first = false;
      if (!first) sb.append(", ");
      sb.append("offset:");
      sb.append(this.offset);
      first = false;
      if (!first) sb.append(", ");
      sb.append("maxNotes:");
      sb.append(this.maxNotes);
      first = false;
      sb.append(")");
      return sb.toString();
    }

    public void validate() throws TException {
      // check for required fields
    }

  }

  public static class findNotes_result implements TBase<findNotes_result._Fields>, java.io.Serializable, Cloneable, Comparable<findNotes_result>   {
    private static final TStruct STRUCT_DESC = new TStruct("findNotes_result");

    private static final TField SUCCESS_FIELD_DESC = new TField("success", TType.STRUCT, (short)0);
    private static final TField USER_EXCEPTION_FIELD_DESC = new TField("userException", TType.STRUCT, (short)1);
    private static final TField SYSTEM_EXCEPTION_FIELD_DESC = new TField("systemException", TType.STRUCT, (short)2);
    private static final TField NOT_FOUND_EXCEPTION_FIELD_DESC = new TField("notFoundException", TType.STRUCT, (short)3);

    private NoteList success;
    private com.evernote.edam.error.EDAMUserException userException;
    private com.evernote.edam.error.EDAMSystemException systemException;
    private com.evernote.edam.error.EDAMNotFoundException notFoundException;

    /** The set of fields this struct contains, along with convenience methods for finding and manipulating them. */
    public enum _Fields implements TFieldIdEnum {
      SUCCESS((short)0, "success"),
      USER_EXCEPTION((short)1, "userException"),
      SYSTEM_EXCEPTION((short)2, "systemException"),
      NOT_FOUND_EXCEPTION((short)3, "notFoundException");

      private static final Map<Integer, _Fields> byId = new HashMap<Integer, _Fields>();
      private static final Map<String, _Fields> byName = new HashMap<String, _Fields>();

      static {
        for (_Fields field : EnumSet.allOf(_Fields.class)) {
          byId.put((int)field._thriftId, field);
          byName.put(field.getFieldName(), field);
        }
      }

      /**
       * Find the _Fields constant that matches fieldId, or null if its not found.
       */
      public static _Fields findByThriftId(int fieldId) {
        return byId.get(fieldId);
      }

      /**
       * Find the _Fields constant that matches fieldId, throwing an exception
       * if it is not found.
       */
      public static _Fields findByThriftIdOrThrow(int fieldId) {
        _Fields fields = findByThriftId(fieldId);
        if (fields == null) throw new IllegalArgumentException("Field " + fieldId + " doesn't exist!");
        return fields;
      }

      /**
       * Find the _Fields constant that matches name, or null if its not found.
       */
      public static _Fields findByName(String name) {
        return byName.get(name);
      }

      private final short _thriftId;
      private final String _fieldName;

      _Fields(short thriftId, String fieldName) {
        _thriftId = thriftId;
        _fieldName = fieldName;
      }

      public short getThriftFieldId() {
        return _thriftId;
      }

      public String getFieldName() {
        return _fieldName;
      }
    }

    // isset id assignments

    public static final Map<_Fields, FieldMetaData> metaDataMap = Collections.unmodifiableMap(new EnumMap<_Fields, FieldMetaData>(_Fields.class) {{
      put(_Fields.SUCCESS, new FieldMetaData("success", TFieldRequirementType.DEFAULT, 
          new StructMetaData(TType.STRUCT, NoteList.class)));
      put(_Fields.USER_EXCEPTION, new FieldMetaData("userException", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.STRUCT)));
      put(_Fields.SYSTEM_EXCEPTION, new FieldMetaData("systemException", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.STRUCT)));
      put(_Fields.NOT_FOUND_EXCEPTION, new FieldMetaData("notFoundException", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.STRUCT)));
    }});

    static {
      FieldMetaData.addStructMetaDataMap(findNotes_result.class, metaDataMap);
    }

    public findNotes_result() {
    }

    public findNotes_result(
      NoteList success,
      com.evernote.edam.error.EDAMUserException userException,
      com.evernote.edam.error.EDAMSystemException systemException,
      com.evernote.edam.error.EDAMNotFoundException notFoundException)
    {
      this();
      this.success = success;
      this.userException = userException;
      this.systemException = systemException;
      this.notFoundException = notFoundException;
    }

    /**
     * Performs a deep copy on <i>other</i>.
     */
    public findNotes_result(findNotes_result other) {
      if (other.isSetSuccess()) {
        this.success = new NoteList(other.success);
      }
      if (other.isSetUserException()) {
        this.userException = new com.evernote.edam.error.EDAMUserException(other.userException);
      }
      if (other.isSetSystemException()) {
        this.systemException = new com.evernote.edam.error.EDAMSystemException(other.systemException);
      }
      if (other.isSetNotFoundException()) {
        this.notFoundException = new com.evernote.edam.error.EDAMNotFoundException(other.notFoundException);
      }
    }

    public findNotes_result deepCopy() {
      return new findNotes_result(this);
    }

    @Deprecated
    public findNotes_result clone() {
      return new findNotes_result(this);
    }

    public NoteList getSuccess() {
      return this.success;
    }

    public void setSuccess(NoteList success) {
      this.success = success;
    }

    public void unsetSuccess() {
      this.success = null;
    }

    /** Returns true if field success is set (has been asigned a value) and false otherwise */
    public boolean isSetSuccess() {
      return this.success != null;
    }

    public void setSuccessIsSet(boolean value) {
      if (!value) {
        this.success = null;
      }
    }

    public com.evernote.edam.error.EDAMUserException getUserException() {
      return this.userException;
    }

    public void setUserException(com.evernote.edam.error.EDAMUserException userException) {
      this.userException = userException;
    }

    public void unsetUserException() {
      this.userException = null;
    }

    /** Returns true if field userException is set (has been asigned a value) and false otherwise */
    public boolean isSetUserException() {
      return this.userException != null;
    }

    public void setUserExceptionIsSet(boolean value) {
      if (!value) {
        this.userException = null;
      }
    }

    public com.evernote.edam.error.EDAMSystemException getSystemException() {
      return this.systemException;
    }

    public void setSystemException(com.evernote.edam.error.EDAMSystemException systemException) {
      this.systemException = systemException;
    }

    public void unsetSystemException() {
      this.systemException = null;
    }

    /** Returns true if field systemException is set (has been asigned a value) and false otherwise */
    public boolean isSetSystemException() {
      return this.systemException != null;
    }

    public void setSystemExceptionIsSet(boolean value) {
      if (!value) {
        this.systemException = null;
      }
    }

    public com.evernote.edam.error.EDAMNotFoundException getNotFoundException() {
      return this.notFoundException;
    }

    public void setNotFoundException(com.evernote.edam.error.EDAMNotFoundException notFoundException) {
      this.notFoundException = notFoundException;
    }

    public void unsetNotFoundException() {
      this.notFoundException = null;
    }

    /** Returns true if field notFoundException is set (has been asigned a value) and false otherwise */
    public boolean isSetNotFoundException() {
      return this.notFoundException != null;
    }

    public void setNotFoundExceptionIsSet(boolean value) {
      if (!value) {
        this.notFoundException = null;
      }
    }

    public void setFieldValue(_Fields field, Object value) {
      switch (field) {
      case SUCCESS:
        if (value == null) {
          unsetSuccess();
        } else {
          setSuccess((NoteList)value);
        }
        break;

      case USER_EXCEPTION:
        if (value == null) {
          unsetUserException();
        } else {
          setUserException((com.evernote.edam.error.EDAMUserException)value);
        }
        break;

      case SYSTEM_EXCEPTION:
        if (value == null) {
          unsetSystemException();
        } else {
          setSystemException((com.evernote.edam.error.EDAMSystemException)value);
        }
        break;

      case NOT_FOUND_EXCEPTION:
        if (value == null) {
          unsetNotFoundException();
        } else {
          setNotFoundException((com.evernote.edam.error.EDAMNotFoundException)value);
        }
        break;

      }
    }

    public void setFieldValue(int fieldID, Object value) {
      setFieldValue(_Fields.findByThriftIdOrThrow(fieldID), value);
    }

    public Object getFieldValue(_Fields field) {
      switch (field) {
      case SUCCESS:
        return getSuccess();

      case USER_EXCEPTION:
        return getUserException();

      case SYSTEM_EXCEPTION:
        return getSystemException();

      case NOT_FOUND_EXCEPTION:
        return getNotFoundException();

      }
      throw new IllegalStateException();
    }

    public Object getFieldValue(int fieldId) {
      return getFieldValue(_Fields.findByThriftIdOrThrow(fieldId));
    }

    /** Returns true if field corresponding to fieldID is set (has been asigned a value) and false otherwise */
    public boolean isSet(_Fields field) {
      switch (field) {
      case SUCCESS:
        return isSetSuccess();
      case USER_EXCEPTION:
        return isSetUserException();
      case SYSTEM_EXCEPTION:
        return isSetSystemException();
      case NOT_FOUND_EXCEPTION:
        return isSetNotFoundException();
      }
      throw new IllegalStateException();
    }

    public boolean isSet(int fieldID) {
      return isSet(_Fields.findByThriftIdOrThrow(fieldID));
    }

    public boolean equals(Object that) {
      if (that == null)
        return false;
      if (that instanceof findNotes_result)
        return this.equals((findNotes_result)that);
      return false;
    }

    public boolean equals(findNotes_result that) {
      if (that == null)
        return false;

      boolean this_present_success = true && this.isSetSuccess();
      boolean that_present_success = true && that.isSetSuccess();
      if (this_present_success || that_present_success) {
        if (!(this_present_success && that_present_success))
          return false;
        if (!this.success.equals(that.success))
          return false;
      }

      boolean this_present_userException = true && this.isSetUserException();
      boolean that_present_userException = true && that.isSetUserException();
      if (this_present_userException || that_present_userException) {
        if (!(this_present_userException && that_present_userException))
          return false;
        if (!this.userException.equals(that.userException))
          return false;
      }

      boolean this_present_systemException = true && this.isSetSystemException();
      boolean that_present_systemException = true && that.isSetSystemException();
      if (this_present_systemException || that_present_systemException) {
        if (!(this_present_systemException && that_present_systemException))
          return false;
        if (!this.systemException.equals(that.systemException))
          return false;
      }

      boolean this_present_notFoundException = true && this.isSetNotFoundException();
      boolean that_present_notFoundException = true && that.isSetNotFoundException();
      if (this_present_notFoundException || that_present_notFoundException) {
        if (!(this_present_notFoundException && that_present_notFoundException))
          return false;
        if (!this.notFoundException.equals(that.notFoundException))
          return false;
      }

      return true;
    }

    public int hashCode() {
      return 0;
    }

    public int compareTo(findNotes_result other) {
      if (!getClass().equals(other.getClass())) {
        return getClass().getName().compareTo(other.getClass().getName());
      }

      int lastComparison = 0;
      findNotes_result typedOther = (findNotes_result)other;

      lastComparison = Boolean.valueOf(isSetSuccess()).compareTo(isSetSuccess());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(success, typedOther.success);
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = Boolean.valueOf(isSetUserException()).compareTo(isSetUserException());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(userException, typedOther.userException);
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = Boolean.valueOf(isSetSystemException()).compareTo(isSetSystemException());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(systemException, typedOther.systemException);
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = Boolean.valueOf(isSetNotFoundException()).compareTo(isSetNotFoundException());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(notFoundException, typedOther.notFoundException);
      if (lastComparison != 0) {
        return lastComparison;
      }
      return 0;
    }

    public void read(TProtocol iprot) throws TException {
      TField field;
      iprot.readStructBegin();
      while (true)
      {
        field = iprot.readFieldBegin();
        if (field.type == TType.STOP) { 
          break;
        }
        _Fields fieldId = _Fields.findByThriftId(field.id);
        if (fieldId == null) {
          TProtocolUtil.skip(iprot, field.type);
        } else {
          switch (fieldId) {
            case SUCCESS:
              if (field.type == TType.STRUCT) {
                this.success = new NoteList();
                this.success.read(iprot);
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
            case USER_EXCEPTION:
              if (field.type == TType.STRUCT) {
                this.userException = new com.evernote.edam.error.EDAMUserException();
                this.userException.read(iprot);
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
            case SYSTEM_EXCEPTION:
              if (field.type == TType.STRUCT) {
                this.systemException = new com.evernote.edam.error.EDAMSystemException();
                this.systemException.read(iprot);
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
            case NOT_FOUND_EXCEPTION:
              if (field.type == TType.STRUCT) {
                this.notFoundException = new com.evernote.edam.error.EDAMNotFoundException();
                this.notFoundException.read(iprot);
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
          }
          iprot.readFieldEnd();
        }
      }
      iprot.readStructEnd();
      validate();
    }

    public void write(TProtocol oprot) throws TException {
      oprot.writeStructBegin(STRUCT_DESC);

      if (this.isSetSuccess()) {
        oprot.writeFieldBegin(SUCCESS_FIELD_DESC);
        this.success.write(oprot);
        oprot.writeFieldEnd();
      } else if (this.isSetUserException()) {
        oprot.writeFieldBegin(USER_EXCEPTION_FIELD_DESC);
        this.userException.write(oprot);
        oprot.writeFieldEnd();
      } else if (this.isSetSystemException()) {
        oprot.writeFieldBegin(SYSTEM_EXCEPTION_FIELD_DESC);
        this.systemException.write(oprot);
        oprot.writeFieldEnd();
      } else if (this.isSetNotFoundException()) {
        oprot.writeFieldBegin(NOT_FOUND_EXCEPTION_FIELD_DESC);
        this.notFoundException.write(oprot);
        oprot.writeFieldEnd();
      }
      oprot.writeFieldStop();
      oprot.writeStructEnd();
    }

    public String toString() {
      StringBuilder sb = new StringBuilder("findNotes_result(");
      boolean first = true;

      sb.append("success:");
      if (this.success == null) {
        sb.append("null");
      } else {
        sb.append(this.success);
      }
      first = false;
      if (!first) sb.append(", ");
      sb.append("userException:");
      if (this.userException == null) {
        sb.append("null");
      } else {
        sb.append(this.userException);
      }
      first = false;
      if (!first) sb.append(", ");
      sb.append("systemException:");
      if (this.systemException == null) {
        sb.append("null");
      } else {
        sb.append(this.systemException);
      }
      first = false;
      if (!first) sb.append(", ");
      sb.append("notFoundException:");
      if (this.notFoundException == null) {
        sb.append("null");
      } else {
        sb.append(this.notFoundException);
      }
      first = false;
      sb.append(")");
      return sb.toString();
    }

    public void validate() throws TException {
      // check for required fields
    }

  }

  public static class findNoteCounts_args implements TBase<findNoteCounts_args._Fields>, java.io.Serializable, Cloneable, Comparable<findNoteCounts_args>   {
    private static final TStruct STRUCT_DESC = new TStruct("findNoteCounts_args");

    private static final TField AUTHENTICATION_TOKEN_FIELD_DESC = new TField("authenticationToken", TType.STRING, (short)1);
    private static final TField FILTER_FIELD_DESC = new TField("filter", TType.STRUCT, (short)2);
    private static final TField WITH_TRASH_FIELD_DESC = new TField("withTrash", TType.BOOL, (short)3);

    private String authenticationToken;
    private NoteFilter filter;
    private boolean withTrash;

    /** The set of fields this struct contains, along with convenience methods for finding and manipulating them. */
    public enum _Fields implements TFieldIdEnum {
      AUTHENTICATION_TOKEN((short)1, "authenticationToken"),
      FILTER((short)2, "filter"),
      WITH_TRASH((short)3, "withTrash");

      private static final Map<Integer, _Fields> byId = new HashMap<Integer, _Fields>();
      private static final Map<String, _Fields> byName = new HashMap<String, _Fields>();

      static {
        for (_Fields field : EnumSet.allOf(_Fields.class)) {
          byId.put((int)field._thriftId, field);
          byName.put(field.getFieldName(), field);
        }
      }

      /**
       * Find the _Fields constant that matches fieldId, or null if its not found.
       */
      public static _Fields findByThriftId(int fieldId) {
        return byId.get(fieldId);
      }

      /**
       * Find the _Fields constant that matches fieldId, throwing an exception
       * if it is not found.
       */
      public static _Fields findByThriftIdOrThrow(int fieldId) {
        _Fields fields = findByThriftId(fieldId);
        if (fields == null) throw new IllegalArgumentException("Field " + fieldId + " doesn't exist!");
        return fields;
      }

      /**
       * Find the _Fields constant that matches name, or null if its not found.
       */
      public static _Fields findByName(String name) {
        return byName.get(name);
      }

      private final short _thriftId;
      private final String _fieldName;

      _Fields(short thriftId, String fieldName) {
        _thriftId = thriftId;
        _fieldName = fieldName;
      }

      public short getThriftFieldId() {
        return _thriftId;
      }

      public String getFieldName() {
        return _fieldName;
      }
    }

    // isset id assignments
    private static final int __WITHTRASH_ISSET_ID = 0;
    private BitSet __isset_bit_vector = new BitSet(1);

    public static final Map<_Fields, FieldMetaData> metaDataMap = Collections.unmodifiableMap(new EnumMap<_Fields, FieldMetaData>(_Fields.class) {{
      put(_Fields.AUTHENTICATION_TOKEN, new FieldMetaData("authenticationToken", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.STRING)));
      put(_Fields.FILTER, new FieldMetaData("filter", TFieldRequirementType.DEFAULT, 
          new StructMetaData(TType.STRUCT, NoteFilter.class)));
      put(_Fields.WITH_TRASH, new FieldMetaData("withTrash", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.BOOL)));
    }});

    static {
      FieldMetaData.addStructMetaDataMap(findNoteCounts_args.class, metaDataMap);
    }

    public findNoteCounts_args() {
    }

    public findNoteCounts_args(
      String authenticationToken,
      NoteFilter filter,
      boolean withTrash)
    {
      this();
      this.authenticationToken = authenticationToken;
      this.filter = filter;
      this.withTrash = withTrash;
      setWithTrashIsSet(true);
    }

    /**
     * Performs a deep copy on <i>other</i>.
     */
    public findNoteCounts_args(findNoteCounts_args other) {
      __isset_bit_vector.clear();
      __isset_bit_vector.or(other.__isset_bit_vector);
      if (other.isSetAuthenticationToken()) {
        this.authenticationToken = other.authenticationToken;
      }
      if (other.isSetFilter()) {
        this.filter = new NoteFilter(other.filter);
      }
      this.withTrash = other.withTrash;
    }

    public findNoteCounts_args deepCopy() {
      return new findNoteCounts_args(this);
    }

    @Deprecated
    public findNoteCounts_args clone() {
      return new findNoteCounts_args(this);
    }

    public String getAuthenticationToken() {
      return this.authenticationToken;
    }

    public void setAuthenticationToken(String authenticationToken) {
      this.authenticationToken = authenticationToken;
    }

    public void unsetAuthenticationToken() {
      this.authenticationToken = null;
    }

    /** Returns true if field authenticationToken is set (has been asigned a value) and false otherwise */
    public boolean isSetAuthenticationToken() {
      return this.authenticationToken != null;
    }

    public void setAuthenticationTokenIsSet(boolean value) {
      if (!value) {
        this.authenticationToken = null;
      }
    }

    public NoteFilter getFilter() {
      return this.filter;
    }

    public void setFilter(NoteFilter filter) {
      this.filter = filter;
    }

    public void unsetFilter() {
      this.filter = null;
    }

    /** Returns true if field filter is set (has been asigned a value) and false otherwise */
    public boolean isSetFilter() {
      return this.filter != null;
    }

    public void setFilterIsSet(boolean value) {
      if (!value) {
        this.filter = null;
      }
    }

    public boolean isWithTrash() {
      return this.withTrash;
    }

    public void setWithTrash(boolean withTrash) {
      this.withTrash = withTrash;
      setWithTrashIsSet(true);
    }

    public void unsetWithTrash() {
      __isset_bit_vector.clear(__WITHTRASH_ISSET_ID);
    }

    /** Returns true if field withTrash is set (has been asigned a value) and false otherwise */
    public boolean isSetWithTrash() {
      return __isset_bit_vector.get(__WITHTRASH_ISSET_ID);
    }

    public void setWithTrashIsSet(boolean value) {
      __isset_bit_vector.set(__WITHTRASH_ISSET_ID, value);
    }

    public void setFieldValue(_Fields field, Object value) {
      switch (field) {
      case AUTHENTICATION_TOKEN:
        if (value == null) {
          unsetAuthenticationToken();
        } else {
          setAuthenticationToken((String)value);
        }
        break;

      case FILTER:
        if (value == null) {
          unsetFilter();
        } else {
          setFilter((NoteFilter)value);
        }
        break;

      case WITH_TRASH:
        if (value == null) {
          unsetWithTrash();
        } else {
          setWithTrash((Boolean)value);
        }
        break;

      }
    }

    public void setFieldValue(int fieldID, Object value) {
      setFieldValue(_Fields.findByThriftIdOrThrow(fieldID), value);
    }

    public Object getFieldValue(_Fields field) {
      switch (field) {
      case AUTHENTICATION_TOKEN:
        return getAuthenticationToken();

      case FILTER:
        return getFilter();

      case WITH_TRASH:
        return new Boolean(isWithTrash());

      }
      throw new IllegalStateException();
    }

    public Object getFieldValue(int fieldId) {
      return getFieldValue(_Fields.findByThriftIdOrThrow(fieldId));
    }

    /** Returns true if field corresponding to fieldID is set (has been asigned a value) and false otherwise */
    public boolean isSet(_Fields field) {
      switch (field) {
      case AUTHENTICATION_TOKEN:
        return isSetAuthenticationToken();
      case FILTER:
        return isSetFilter();
      case WITH_TRASH:
        return isSetWithTrash();
      }
      throw new IllegalStateException();
    }

    public boolean isSet(int fieldID) {
      return isSet(_Fields.findByThriftIdOrThrow(fieldID));
    }

    public boolean equals(Object that) {
      if (that == null)
        return false;
      if (that instanceof findNoteCounts_args)
        return this.equals((findNoteCounts_args)that);
      return false;
    }

    public boolean equals(findNoteCounts_args that) {
      if (that == null)
        return false;

      boolean this_present_authenticationToken = true && this.isSetAuthenticationToken();
      boolean that_present_authenticationToken = true && that.isSetAuthenticationToken();
      if (this_present_authenticationToken || that_present_authenticationToken) {
        if (!(this_present_authenticationToken && that_present_authenticationToken))
          return false;
        if (!this.authenticationToken.equals(that.authenticationToken))
          return false;
      }

      boolean this_present_filter = true && this.isSetFilter();
      boolean that_present_filter = true && that.isSetFilter();
      if (this_present_filter || that_present_filter) {
        if (!(this_present_filter && that_present_filter))
          return false;
        if (!this.filter.equals(that.filter))
          return false;
      }

      boolean this_present_withTrash = true;
      boolean that_present_withTrash = true;
      if (this_present_withTrash || that_present_withTrash) {
        if (!(this_present_withTrash && that_present_withTrash))
          return false;
        if (this.withTrash != that.withTrash)
          return false;
      }

      return true;
    }

    public int hashCode() {
      return 0;
    }

    public int compareTo(findNoteCounts_args other) {
      if (!getClass().equals(other.getClass())) {
        return getClass().getName().compareTo(other.getClass().getName());
      }

      int lastComparison = 0;
      findNoteCounts_args typedOther = (findNoteCounts_args)other;

      lastComparison = Boolean.valueOf(isSetAuthenticationToken()).compareTo(isSetAuthenticationToken());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(authenticationToken, typedOther.authenticationToken);
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = Boolean.valueOf(isSetFilter()).compareTo(isSetFilter());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(filter, typedOther.filter);
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = Boolean.valueOf(isSetWithTrash()).compareTo(isSetWithTrash());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(withTrash, typedOther.withTrash);
      if (lastComparison != 0) {
        return lastComparison;
      }
      return 0;
    }

    public void read(TProtocol iprot) throws TException {
      TField field;
      iprot.readStructBegin();
      while (true)
      {
        field = iprot.readFieldBegin();
        if (field.type == TType.STOP) { 
          break;
        }
        _Fields fieldId = _Fields.findByThriftId(field.id);
        if (fieldId == null) {
          TProtocolUtil.skip(iprot, field.type);
        } else {
          switch (fieldId) {
            case AUTHENTICATION_TOKEN:
              if (field.type == TType.STRING) {
                this.authenticationToken = iprot.readString();
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
            case FILTER:
              if (field.type == TType.STRUCT) {
                this.filter = new NoteFilter();
                this.filter.read(iprot);
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
            case WITH_TRASH:
              if (field.type == TType.BOOL) {
                this.withTrash = iprot.readBool();
                setWithTrashIsSet(true);
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
          }
          iprot.readFieldEnd();
        }
      }
      iprot.readStructEnd();
      validate();
    }

    public void write(TProtocol oprot) throws TException {
      validate();

      oprot.writeStructBegin(STRUCT_DESC);
      if (this.authenticationToken != null) {
        oprot.writeFieldBegin(AUTHENTICATION_TOKEN_FIELD_DESC);
        oprot.writeString(this.authenticationToken);
        oprot.writeFieldEnd();
      }
      if (this.filter != null) {
        oprot.writeFieldBegin(FILTER_FIELD_DESC);
        this.filter.write(oprot);
        oprot.writeFieldEnd();
      }
      oprot.writeFieldBegin(WITH_TRASH_FIELD_DESC);
      oprot.writeBool(this.withTrash);
      oprot.writeFieldEnd();
      oprot.writeFieldStop();
      oprot.writeStructEnd();
    }

    public String toString() {
      StringBuilder sb = new StringBuilder("findNoteCounts_args(");
      boolean first = true;

      sb.append("authenticationToken:");
      if (this.authenticationToken == null) {
        sb.append("null");
      } else {
        sb.append(this.authenticationToken);
      }
      first = false;
      if (!first) sb.append(", ");
      sb.append("filter:");
      if (this.filter == null) {
        sb.append("null");
      } else {
        sb.append(this.filter);
      }
      first = false;
      if (!first) sb.append(", ");
      sb.append("withTrash:");
      sb.append(this.withTrash);
      first = false;
      sb.append(")");
      return sb.toString();
    }

    public void validate() throws TException {
      // check for required fields
    }

  }

  public static class findNoteCounts_result implements TBase<findNoteCounts_result._Fields>, java.io.Serializable, Cloneable   {
    private static final TStruct STRUCT_DESC = new TStruct("findNoteCounts_result");

    private static final TField SUCCESS_FIELD_DESC = new TField("success", TType.STRUCT, (short)0);
    private static final TField USER_EXCEPTION_FIELD_DESC = new TField("userException", TType.STRUCT, (short)1);
    private static final TField SYSTEM_EXCEPTION_FIELD_DESC = new TField("systemException", TType.STRUCT, (short)2);
    private static final TField NOT_FOUND_EXCEPTION_FIELD_DESC = new TField("notFoundException", TType.STRUCT, (short)3);

    private NoteCollectionCounts success;
    private com.evernote.edam.error.EDAMUserException userException;
    private com.evernote.edam.error.EDAMSystemException systemException;
    private com.evernote.edam.error.EDAMNotFoundException notFoundException;

    /** The set of fields this struct contains, along with convenience methods for finding and manipulating them. */
    public enum _Fields implements TFieldIdEnum {
      SUCCESS((short)0, "success"),
      USER_EXCEPTION((short)1, "userException"),
      SYSTEM_EXCEPTION((short)2, "systemException"),
      NOT_FOUND_EXCEPTION((short)3, "notFoundException");

      private static final Map<Integer, _Fields> byId = new HashMap<Integer, _Fields>();
      private static final Map<String, _Fields> byName = new HashMap<String, _Fields>();

      static {
        for (_Fields field : EnumSet.allOf(_Fields.class)) {
          byId.put((int)field._thriftId, field);
          byName.put(field.getFieldName(), field);
        }
      }

      /**
       * Find the _Fields constant that matches fieldId, or null if its not found.
       */
      public static _Fields findByThriftId(int fieldId) {
        return byId.get(fieldId);
      }

      /**
       * Find the _Fields constant that matches fieldId, throwing an exception
       * if it is not found.
       */
      public static _Fields findByThriftIdOrThrow(int fieldId) {
        _Fields fields = findByThriftId(fieldId);
        if (fields == null) throw new IllegalArgumentException("Field " + fieldId + " doesn't exist!");
        return fields;
      }

      /**
       * Find the _Fields constant that matches name, or null if its not found.
       */
      public static _Fields findByName(String name) {
        return byName.get(name);
      }

      private final short _thriftId;
      private final String _fieldName;

      _Fields(short thriftId, String fieldName) {
        _thriftId = thriftId;
        _fieldName = fieldName;
      }

      public short getThriftFieldId() {
        return _thriftId;
      }

      public String getFieldName() {
        return _fieldName;
      }
    }

    // isset id assignments

    public static final Map<_Fields, FieldMetaData> metaDataMap = Collections.unmodifiableMap(new EnumMap<_Fields, FieldMetaData>(_Fields.class) {{
      put(_Fields.SUCCESS, new FieldMetaData("success", TFieldRequirementType.DEFAULT, 
          new StructMetaData(TType.STRUCT, NoteCollectionCounts.class)));
      put(_Fields.USER_EXCEPTION, new FieldMetaData("userException", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.STRUCT)));
      put(_Fields.SYSTEM_EXCEPTION, new FieldMetaData("systemException", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.STRUCT)));
      put(_Fields.NOT_FOUND_EXCEPTION, new FieldMetaData("notFoundException", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.STRUCT)));
    }});

    static {
      FieldMetaData.addStructMetaDataMap(findNoteCounts_result.class, metaDataMap);
    }

    public findNoteCounts_result() {
    }

    public findNoteCounts_result(
      NoteCollectionCounts success,
      com.evernote.edam.error.EDAMUserException userException,
      com.evernote.edam.error.EDAMSystemException systemException,
      com.evernote.edam.error.EDAMNotFoundException notFoundException)
    {
      this();
      this.success = success;
      this.userException = userException;
      this.systemException = systemException;
      this.notFoundException = notFoundException;
    }

    /**
     * Performs a deep copy on <i>other</i>.
     */
    public findNoteCounts_result(findNoteCounts_result other) {
      if (other.isSetSuccess()) {
        this.success = new NoteCollectionCounts(other.success);
      }
      if (other.isSetUserException()) {
        this.userException = new com.evernote.edam.error.EDAMUserException(other.userException);
      }
      if (other.isSetSystemException()) {
        this.systemException = new com.evernote.edam.error.EDAMSystemException(other.systemException);
      }
      if (other.isSetNotFoundException()) {
        this.notFoundException = new com.evernote.edam.error.EDAMNotFoundException(other.notFoundException);
      }
    }

    public findNoteCounts_result deepCopy() {
      return new findNoteCounts_result(this);
    }

    @Deprecated
    public findNoteCounts_result clone() {
      return new findNoteCounts_result(this);
    }

    public NoteCollectionCounts getSuccess() {
      return this.success;
    }

    public void setSuccess(NoteCollectionCounts success) {
      this.success = success;
    }

    public void unsetSuccess() {
      this.success = null;
    }

    /** Returns true if field success is set (has been asigned a value) and false otherwise */
    public boolean isSetSuccess() {
      return this.success != null;
    }

    public void setSuccessIsSet(boolean value) {
      if (!value) {
        this.success = null;
      }
    }

    public com.evernote.edam.error.EDAMUserException getUserException() {
      return this.userException;
    }

    public void setUserException(com.evernote.edam.error.EDAMUserException userException) {
      this.userException = userException;
    }

    public void unsetUserException() {
      this.userException = null;
    }

    /** Returns true if field userException is set (has been asigned a value) and false otherwise */
    public boolean isSetUserException() {
      return this.userException != null;
    }

    public void setUserExceptionIsSet(boolean value) {
      if (!value) {
        this.userException = null;
      }
    }

    public com.evernote.edam.error.EDAMSystemException getSystemException() {
      return this.systemException;
    }

    public void setSystemException(com.evernote.edam.error.EDAMSystemException systemException) {
      this.systemException = systemException;
    }

    public void unsetSystemException() {
      this.systemException = null;
    }

    /** Returns true if field systemException is set (has been asigned a value) and false otherwise */
    public boolean isSetSystemException() {
      return this.systemException != null;
    }

    public void setSystemExceptionIsSet(boolean value) {
      if (!value) {
        this.systemException = null;
      }
    }

    public com.evernote.edam.error.EDAMNotFoundException getNotFoundException() {
      return this.notFoundException;
    }

    public void setNotFoundException(com.evernote.edam.error.EDAMNotFoundException notFoundException) {
      this.notFoundException = notFoundException;
    }

    public void unsetNotFoundException() {
      this.notFoundException = null;
    }

    /** Returns true if field notFoundException is set (has been asigned a value) and false otherwise */
    public boolean isSetNotFoundException() {
      return this.notFoundException != null;
    }

    public void setNotFoundExceptionIsSet(boolean value) {
      if (!value) {
        this.notFoundException = null;
      }
    }

    public void setFieldValue(_Fields field, Object value) {
      switch (field) {
      case SUCCESS:
        if (value == null) {
          unsetSuccess();
        } else {
          setSuccess((NoteCollectionCounts)value);
        }
        break;

      case USER_EXCEPTION:
        if (value == null) {
          unsetUserException();
        } else {
          setUserException((com.evernote.edam.error.EDAMUserException)value);
        }
        break;

      case SYSTEM_EXCEPTION:
        if (value == null) {
          unsetSystemException();
        } else {
          setSystemException((com.evernote.edam.error.EDAMSystemException)value);
        }
        break;

      case NOT_FOUND_EXCEPTION:
        if (value == null) {
          unsetNotFoundException();
        } else {
          setNotFoundException((com.evernote.edam.error.EDAMNotFoundException)value);
        }
        break;

      }
    }

    public void setFieldValue(int fieldID, Object value) {
      setFieldValue(_Fields.findByThriftIdOrThrow(fieldID), value);
    }

    public Object getFieldValue(_Fields field) {
      switch (field) {
      case SUCCESS:
        return getSuccess();

      case USER_EXCEPTION:
        return getUserException();

      case SYSTEM_EXCEPTION:
        return getSystemException();

      case NOT_FOUND_EXCEPTION:
        return getNotFoundException();

      }
      throw new IllegalStateException();
    }

    public Object getFieldValue(int fieldId) {
      return getFieldValue(_Fields.findByThriftIdOrThrow(fieldId));
    }

    /** Returns true if field corresponding to fieldID is set (has been asigned a value) and false otherwise */
    public boolean isSet(_Fields field) {
      switch (field) {
      case SUCCESS:
        return isSetSuccess();
      case USER_EXCEPTION:
        return isSetUserException();
      case SYSTEM_EXCEPTION:
        return isSetSystemException();
      case NOT_FOUND_EXCEPTION:
        return isSetNotFoundException();
      }
      throw new IllegalStateException();
    }

    public boolean isSet(int fieldID) {
      return isSet(_Fields.findByThriftIdOrThrow(fieldID));
    }

    public boolean equals(Object that) {
      if (that == null)
        return false;
      if (that instanceof findNoteCounts_result)
        return this.equals((findNoteCounts_result)that);
      return false;
    }

    public boolean equals(findNoteCounts_result that) {
      if (that == null)
        return false;

      boolean this_present_success = true && this.isSetSuccess();
      boolean that_present_success = true && that.isSetSuccess();
      if (this_present_success || that_present_success) {
        if (!(this_present_success && that_present_success))
          return false;
        if (!this.success.equals(that.success))
          return false;
      }

      boolean this_present_userException = true && this.isSetUserException();
      boolean that_present_userException = true && that.isSetUserException();
      if (this_present_userException || that_present_userException) {
        if (!(this_present_userException && that_present_userException))
          return false;
        if (!this.userException.equals(that.userException))
          return false;
      }

      boolean this_present_systemException = true && this.isSetSystemException();
      boolean that_present_systemException = true && that.isSetSystemException();
      if (this_present_systemException || that_present_systemException) {
        if (!(this_present_systemException && that_present_systemException))
          return false;
        if (!this.systemException.equals(that.systemException))
          return false;
      }

      boolean this_present_notFoundException = true && this.isSetNotFoundException();
      boolean that_present_notFoundException = true && that.isSetNotFoundException();
      if (this_present_notFoundException || that_present_notFoundException) {
        if (!(this_present_notFoundException && that_present_notFoundException))
          return false;
        if (!this.notFoundException.equals(that.notFoundException))
          return false;
      }

      return true;
    }

    public int hashCode() {
      return 0;
    }

    public void read(TProtocol iprot) throws TException {
      TField field;
      iprot.readStructBegin();
      while (true)
      {
        field = iprot.readFieldBegin();
        if (field.type == TType.STOP) { 
          break;
        }
        _Fields fieldId = _Fields.findByThriftId(field.id);
        if (fieldId == null) {
          TProtocolUtil.skip(iprot, field.type);
        } else {
          switch (fieldId) {
            case SUCCESS:
              if (field.type == TType.STRUCT) {
                this.success = new NoteCollectionCounts();
                this.success.read(iprot);
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
            case USER_EXCEPTION:
              if (field.type == TType.STRUCT) {
                this.userException = new com.evernote.edam.error.EDAMUserException();
                this.userException.read(iprot);
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
            case SYSTEM_EXCEPTION:
              if (field.type == TType.STRUCT) {
                this.systemException = new com.evernote.edam.error.EDAMSystemException();
                this.systemException.read(iprot);
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
            case NOT_FOUND_EXCEPTION:
              if (field.type == TType.STRUCT) {
                this.notFoundException = new com.evernote.edam.error.EDAMNotFoundException();
                this.notFoundException.read(iprot);
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
          }
          iprot.readFieldEnd();
        }
      }
      iprot.readStructEnd();
      validate();
    }

    public void write(TProtocol oprot) throws TException {
      oprot.writeStructBegin(STRUCT_DESC);

      if (this.isSetSuccess()) {
        oprot.writeFieldBegin(SUCCESS_FIELD_DESC);
        this.success.write(oprot);
        oprot.writeFieldEnd();
      } else if (this.isSetUserException()) {
        oprot.writeFieldBegin(USER_EXCEPTION_FIELD_DESC);
        this.userException.write(oprot);
        oprot.writeFieldEnd();
      } else if (this.isSetSystemException()) {
        oprot.writeFieldBegin(SYSTEM_EXCEPTION_FIELD_DESC);
        this.systemException.write(oprot);
        oprot.writeFieldEnd();
      } else if (this.isSetNotFoundException()) {
        oprot.writeFieldBegin(NOT_FOUND_EXCEPTION_FIELD_DESC);
        this.notFoundException.write(oprot);
        oprot.writeFieldEnd();
      }
      oprot.writeFieldStop();
      oprot.writeStructEnd();
    }

    public String toString() {
      StringBuilder sb = new StringBuilder("findNoteCounts_result(");
      boolean first = true;

      sb.append("success:");
      if (this.success == null) {
        sb.append("null");
      } else {
        sb.append(this.success);
      }
      first = false;
      if (!first) sb.append(", ");
      sb.append("userException:");
      if (this.userException == null) {
        sb.append("null");
      } else {
        sb.append(this.userException);
      }
      first = false;
      if (!first) sb.append(", ");
      sb.append("systemException:");
      if (this.systemException == null) {
        sb.append("null");
      } else {
        sb.append(this.systemException);
      }
      first = false;
      if (!first) sb.append(", ");
      sb.append("notFoundException:");
      if (this.notFoundException == null) {
        sb.append("null");
      } else {
        sb.append(this.notFoundException);
      }
      first = false;
      sb.append(")");
      return sb.toString();
    }

    public void validate() throws TException {
      // check for required fields
    }

  }

  public static class getNote_args implements TBase<getNote_args._Fields>, java.io.Serializable, Cloneable, Comparable<getNote_args>   {
    private static final TStruct STRUCT_DESC = new TStruct("getNote_args");

    private static final TField AUTHENTICATION_TOKEN_FIELD_DESC = new TField("authenticationToken", TType.STRING, (short)1);
    private static final TField GUID_FIELD_DESC = new TField("guid", TType.STRING, (short)2);
    private static final TField WITH_CONTENT_FIELD_DESC = new TField("withContent", TType.BOOL, (short)3);
    private static final TField WITH_RESOURCES_DATA_FIELD_DESC = new TField("withResourcesData", TType.BOOL, (short)4);
    private static final TField WITH_RESOURCES_RECOGNITION_FIELD_DESC = new TField("withResourcesRecognition", TType.BOOL, (short)5);
    private static final TField WITH_RESOURCES_ALTERNATE_DATA_FIELD_DESC = new TField("withResourcesAlternateData", TType.BOOL, (short)6);

    private String authenticationToken;
    private String guid;
    private boolean withContent;
    private boolean withResourcesData;
    private boolean withResourcesRecognition;
    private boolean withResourcesAlternateData;

    /** The set of fields this struct contains, along with convenience methods for finding and manipulating them. */
    public enum _Fields implements TFieldIdEnum {
      AUTHENTICATION_TOKEN((short)1, "authenticationToken"),
      GUID((short)2, "guid"),
      WITH_CONTENT((short)3, "withContent"),
      WITH_RESOURCES_DATA((short)4, "withResourcesData"),
      WITH_RESOURCES_RECOGNITION((short)5, "withResourcesRecognition"),
      WITH_RESOURCES_ALTERNATE_DATA((short)6, "withResourcesAlternateData");

      private static final Map<Integer, _Fields> byId = new HashMap<Integer, _Fields>();
      private static final Map<String, _Fields> byName = new HashMap<String, _Fields>();

      static {
        for (_Fields field : EnumSet.allOf(_Fields.class)) {
          byId.put((int)field._thriftId, field);
          byName.put(field.getFieldName(), field);
        }
      }

      /**
       * Find the _Fields constant that matches fieldId, or null if its not found.
       */
      public static _Fields findByThriftId(int fieldId) {
        return byId.get(fieldId);
      }

      /**
       * Find the _Fields constant that matches fieldId, throwing an exception
       * if it is not found.
       */
      public static _Fields findByThriftIdOrThrow(int fieldId) {
        _Fields fields = findByThriftId(fieldId);
        if (fields == null) throw new IllegalArgumentException("Field " + fieldId + " doesn't exist!");
        return fields;
      }

      /**
       * Find the _Fields constant that matches name, or null if its not found.
       */
      public static _Fields findByName(String name) {
        return byName.get(name);
      }

      private final short _thriftId;
      private final String _fieldName;

      _Fields(short thriftId, String fieldName) {
        _thriftId = thriftId;
        _fieldName = fieldName;
      }

      public short getThriftFieldId() {
        return _thriftId;
      }

      public String getFieldName() {
        return _fieldName;
      }
    }

    // isset id assignments
    private static final int __WITHCONTENT_ISSET_ID = 0;
    private static final int __WITHRESOURCESDATA_ISSET_ID = 1;
    private static final int __WITHRESOURCESRECOGNITION_ISSET_ID = 2;
    private static final int __WITHRESOURCESALTERNATEDATA_ISSET_ID = 3;
    private BitSet __isset_bit_vector = new BitSet(4);

    public static final Map<_Fields, FieldMetaData> metaDataMap = Collections.unmodifiableMap(new EnumMap<_Fields, FieldMetaData>(_Fields.class) {{
      put(_Fields.AUTHENTICATION_TOKEN, new FieldMetaData("authenticationToken", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.STRING)));
      put(_Fields.GUID, new FieldMetaData("guid", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.STRING)));
      put(_Fields.WITH_CONTENT, new FieldMetaData("withContent", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.BOOL)));
      put(_Fields.WITH_RESOURCES_DATA, new FieldMetaData("withResourcesData", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.BOOL)));
      put(_Fields.WITH_RESOURCES_RECOGNITION, new FieldMetaData("withResourcesRecognition", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.BOOL)));
      put(_Fields.WITH_RESOURCES_ALTERNATE_DATA, new FieldMetaData("withResourcesAlternateData", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.BOOL)));
    }});

    static {
      FieldMetaData.addStructMetaDataMap(getNote_args.class, metaDataMap);
    }

    public getNote_args() {
    }

    public getNote_args(
      String authenticationToken,
      String guid,
      boolean withContent,
      boolean withResourcesData,
      boolean withResourcesRecognition,
      boolean withResourcesAlternateData)
    {
      this();
      this.authenticationToken = authenticationToken;
      this.guid = guid;
      this.withContent = withContent;
      setWithContentIsSet(true);
      this.withResourcesData = withResourcesData;
      setWithResourcesDataIsSet(true);
      this.withResourcesRecognition = withResourcesRecognition;
      setWithResourcesRecognitionIsSet(true);
      this.withResourcesAlternateData = withResourcesAlternateData;
      setWithResourcesAlternateDataIsSet(true);
    }

    /**
     * Performs a deep copy on <i>other</i>.
     */
    public getNote_args(getNote_args other) {
      __isset_bit_vector.clear();
      __isset_bit_vector.or(other.__isset_bit_vector);
      if (other.isSetAuthenticationToken()) {
        this.authenticationToken = other.authenticationToken;
      }
      if (other.isSetGuid()) {
        this.guid = other.guid;
      }
      this.withContent = other.withContent;
      this.withResourcesData = other.withResourcesData;
      this.withResourcesRecognition = other.withResourcesRecognition;
      this.withResourcesAlternateData = other.withResourcesAlternateData;
    }

    public getNote_args deepCopy() {
      return new getNote_args(this);
    }

    @Deprecated
    public getNote_args clone() {
      return new getNote_args(this);
    }

    public String getAuthenticationToken() {
      return this.authenticationToken;
    }

    public void setAuthenticationToken(String authenticationToken) {
      this.authenticationToken = authenticationToken;
    }

    public void unsetAuthenticationToken() {
      this.authenticationToken = null;
    }

    /** Returns true if field authenticationToken is set (has been asigned a value) and false otherwise */
    public boolean isSetAuthenticationToken() {
      return this.authenticationToken != null;
    }

    public void setAuthenticationTokenIsSet(boolean value) {
      if (!value) {
        this.authenticationToken = null;
      }
    }

    public String getGuid() {
      return this.guid;
    }

    public void setGuid(String guid) {
      this.guid = guid;
    }

    public void unsetGuid() {
      this.guid = null;
    }

    /** Returns true if field guid is set (has been asigned a value) and false otherwise */
    public boolean isSetGuid() {
      return this.guid != null;
    }

    public void setGuidIsSet(boolean value) {
      if (!value) {
        this.guid = null;
      }
    }

    public boolean isWithContent() {
      return this.withContent;
    }

    public void setWithContent(boolean withContent) {
      this.withContent = withContent;
      setWithContentIsSet(true);
    }

    public void unsetWithContent() {
      __isset_bit_vector.clear(__WITHCONTENT_ISSET_ID);
    }

    /** Returns true if field withContent is set (has been asigned a value) and false otherwise */
    public boolean isSetWithContent() {
      return __isset_bit_vector.get(__WITHCONTENT_ISSET_ID);
    }

    public void setWithContentIsSet(boolean value) {
      __isset_bit_vector.set(__WITHCONTENT_ISSET_ID, value);
    }

    public boolean isWithResourcesData() {
      return this.withResourcesData;
    }

    public void setWithResourcesData(boolean withResourcesData) {
      this.withResourcesData = withResourcesData;
      setWithResourcesDataIsSet(true);
    }

    public void unsetWithResourcesData() {
      __isset_bit_vector.clear(__WITHRESOURCESDATA_ISSET_ID);
    }

    /** Returns true if field withResourcesData is set (has been asigned a value) and false otherwise */
    public boolean isSetWithResourcesData() {
      return __isset_bit_vector.get(__WITHRESOURCESDATA_ISSET_ID);
    }

    public void setWithResourcesDataIsSet(boolean value) {
      __isset_bit_vector.set(__WITHRESOURCESDATA_ISSET_ID, value);
    }

    public boolean isWithResourcesRecognition() {
      return this.withResourcesRecognition;
    }

    public void setWithResourcesRecognition(boolean withResourcesRecognition) {
      this.withResourcesRecognition = withResourcesRecognition;
      setWithResourcesRecognitionIsSet(true);
    }

    public void unsetWithResourcesRecognition() {
      __isset_bit_vector.clear(__WITHRESOURCESRECOGNITION_ISSET_ID);
    }

    /** Returns true if field withResourcesRecognition is set (has been asigned a value) and false otherwise */
    public boolean isSetWithResourcesRecognition() {
      return __isset_bit_vector.get(__WITHRESOURCESRECOGNITION_ISSET_ID);
    }

    public void setWithResourcesRecognitionIsSet(boolean value) {
      __isset_bit_vector.set(__WITHRESOURCESRECOGNITION_ISSET_ID, value);
    }

    public boolean isWithResourcesAlternateData() {
      return this.withResourcesAlternateData;
    }

    public void setWithResourcesAlternateData(boolean withResourcesAlternateData) {
      this.withResourcesAlternateData = withResourcesAlternateData;
      setWithResourcesAlternateDataIsSet(true);
    }

    public void unsetWithResourcesAlternateData() {
      __isset_bit_vector.clear(__WITHRESOURCESALTERNATEDATA_ISSET_ID);
    }

    /** Returns true if field withResourcesAlternateData is set (has been asigned a value) and false otherwise */
    public boolean isSetWithResourcesAlternateData() {
      return __isset_bit_vector.get(__WITHRESOURCESALTERNATEDATA_ISSET_ID);
    }

    public void setWithResourcesAlternateDataIsSet(boolean value) {
      __isset_bit_vector.set(__WITHRESOURCESALTERNATEDATA_ISSET_ID, value);
    }

    public void setFieldValue(_Fields field, Object value) {
      switch (field) {
      case AUTHENTICATION_TOKEN:
        if (value == null) {
          unsetAuthenticationToken();
        } else {
          setAuthenticationToken((String)value);
        }
        break;

      case GUID:
        if (value == null) {
          unsetGuid();
        } else {
          setGuid((String)value);
        }
        break;

      case WITH_CONTENT:
        if (value == null) {
          unsetWithContent();
        } else {
          setWithContent((Boolean)value);
        }
        break;

      case WITH_RESOURCES_DATA:
        if (value == null) {
          unsetWithResourcesData();
        } else {
          setWithResourcesData((Boolean)value);
        }
        break;

      case WITH_RESOURCES_RECOGNITION:
        if (value == null) {
          unsetWithResourcesRecognition();
        } else {
          setWithResourcesRecognition((Boolean)value);
        }
        break;

      case WITH_RESOURCES_ALTERNATE_DATA:
        if (value == null) {
          unsetWithResourcesAlternateData();
        } else {
          setWithResourcesAlternateData((Boolean)value);
        }
        break;

      }
    }

    public void setFieldValue(int fieldID, Object value) {
      setFieldValue(_Fields.findByThriftIdOrThrow(fieldID), value);
    }

    public Object getFieldValue(_Fields field) {
      switch (field) {
      case AUTHENTICATION_TOKEN:
        return getAuthenticationToken();

      case GUID:
        return getGuid();

      case WITH_CONTENT:
        return new Boolean(isWithContent());

      case WITH_RESOURCES_DATA:
        return new Boolean(isWithResourcesData());

      case WITH_RESOURCES_RECOGNITION:
        return new Boolean(isWithResourcesRecognition());

      case WITH_RESOURCES_ALTERNATE_DATA:
        return new Boolean(isWithResourcesAlternateData());

      }
      throw new IllegalStateException();
    }

    public Object getFieldValue(int fieldId) {
      return getFieldValue(_Fields.findByThriftIdOrThrow(fieldId));
    }

    /** Returns true if field corresponding to fieldID is set (has been asigned a value) and false otherwise */
    public boolean isSet(_Fields field) {
      switch (field) {
      case AUTHENTICATION_TOKEN:
        return isSetAuthenticationToken();
      case GUID:
        return isSetGuid();
      case WITH_CONTENT:
        return isSetWithContent();
      case WITH_RESOURCES_DATA:
        return isSetWithResourcesData();
      case WITH_RESOURCES_RECOGNITION:
        return isSetWithResourcesRecognition();
      case WITH_RESOURCES_ALTERNATE_DATA:
        return isSetWithResourcesAlternateData();
      }
      throw new IllegalStateException();
    }

    public boolean isSet(int fieldID) {
      return isSet(_Fields.findByThriftIdOrThrow(fieldID));
    }

    public boolean equals(Object that) {
      if (that == null)
        return false;
      if (that instanceof getNote_args)
        return this.equals((getNote_args)that);
      return false;
    }

    public boolean equals(getNote_args that) {
      if (that == null)
        return false;

      boolean this_present_authenticationToken = true && this.isSetAuthenticationToken();
      boolean that_present_authenticationToken = true && that.isSetAuthenticationToken();
      if (this_present_authenticationToken || that_present_authenticationToken) {
        if (!(this_present_authenticationToken && that_present_authenticationToken))
          return false;
        if (!this.authenticationToken.equals(that.authenticationToken))
          return false;
      }

      boolean this_present_guid = true && this.isSetGuid();
      boolean that_present_guid = true && that.isSetGuid();
      if (this_present_guid || that_present_guid) {
        if (!(this_present_guid && that_present_guid))
          return false;
        if (!this.guid.equals(that.guid))
          return false;
      }

      boolean this_present_withContent = true;
      boolean that_present_withContent = true;
      if (this_present_withContent || that_present_withContent) {
        if (!(this_present_withContent && that_present_withContent))
          return false;
        if (this.withContent != that.withContent)
          return false;
      }

      boolean this_present_withResourcesData = true;
      boolean that_present_withResourcesData = true;
      if (this_present_withResourcesData || that_present_withResourcesData) {
        if (!(this_present_withResourcesData && that_present_withResourcesData))
          return false;
        if (this.withResourcesData != that.withResourcesData)
          return false;
      }

      boolean this_present_withResourcesRecognition = true;
      boolean that_present_withResourcesRecognition = true;
      if (this_present_withResourcesRecognition || that_present_withResourcesRecognition) {
        if (!(this_present_withResourcesRecognition && that_present_withResourcesRecognition))
          return false;
        if (this.withResourcesRecognition != that.withResourcesRecognition)
          return false;
      }

      boolean this_present_withResourcesAlternateData = true;
      boolean that_present_withResourcesAlternateData = true;
      if (this_present_withResourcesAlternateData || that_present_withResourcesAlternateData) {
        if (!(this_present_withResourcesAlternateData && that_present_withResourcesAlternateData))
          return false;
        if (this.withResourcesAlternateData != that.withResourcesAlternateData)
          return false;
      }

      return true;
    }

    public int hashCode() {
      return 0;
    }

    public int compareTo(getNote_args other) {
      if (!getClass().equals(other.getClass())) {
        return getClass().getName().compareTo(other.getClass().getName());
      }

      int lastComparison = 0;
      getNote_args typedOther = (getNote_args)other;

      lastComparison = Boolean.valueOf(isSetAuthenticationToken()).compareTo(isSetAuthenticationToken());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(authenticationToken, typedOther.authenticationToken);
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = Boolean.valueOf(isSetGuid()).compareTo(isSetGuid());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(guid, typedOther.guid);
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = Boolean.valueOf(isSetWithContent()).compareTo(isSetWithContent());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(withContent, typedOther.withContent);
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = Boolean.valueOf(isSetWithResourcesData()).compareTo(isSetWithResourcesData());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(withResourcesData, typedOther.withResourcesData);
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = Boolean.valueOf(isSetWithResourcesRecognition()).compareTo(isSetWithResourcesRecognition());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(withResourcesRecognition, typedOther.withResourcesRecognition);
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = Boolean.valueOf(isSetWithResourcesAlternateData()).compareTo(isSetWithResourcesAlternateData());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(withResourcesAlternateData, typedOther.withResourcesAlternateData);
      if (lastComparison != 0) {
        return lastComparison;
      }
      return 0;
    }

    public void read(TProtocol iprot) throws TException {
      TField field;
      iprot.readStructBegin();
      while (true)
      {
        field = iprot.readFieldBegin();
        if (field.type == TType.STOP) { 
          break;
        }
        _Fields fieldId = _Fields.findByThriftId(field.id);
        if (fieldId == null) {
          TProtocolUtil.skip(iprot, field.type);
        } else {
          switch (fieldId) {
            case AUTHENTICATION_TOKEN:
              if (field.type == TType.STRING) {
                this.authenticationToken = iprot.readString();
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
            case GUID:
              if (field.type == TType.STRING) {
                this.guid = iprot.readString();
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
            case WITH_CONTENT:
              if (field.type == TType.BOOL) {
                this.withContent = iprot.readBool();
                setWithContentIsSet(true);
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
            case WITH_RESOURCES_DATA:
              if (field.type == TType.BOOL) {
                this.withResourcesData = iprot.readBool();
                setWithResourcesDataIsSet(true);
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
            case WITH_RESOURCES_RECOGNITION:
              if (field.type == TType.BOOL) {
                this.withResourcesRecognition = iprot.readBool();
                setWithResourcesRecognitionIsSet(true);
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
            case WITH_RESOURCES_ALTERNATE_DATA:
              if (field.type == TType.BOOL) {
                this.withResourcesAlternateData = iprot.readBool();
                setWithResourcesAlternateDataIsSet(true);
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
          }
          iprot.readFieldEnd();
        }
      }
      iprot.readStructEnd();
      validate();
    }

    public void write(TProtocol oprot) throws TException {
      validate();

      oprot.writeStructBegin(STRUCT_DESC);
      if (this.authenticationToken != null) {
        oprot.writeFieldBegin(AUTHENTICATION_TOKEN_FIELD_DESC);
        oprot.writeString(this.authenticationToken);
        oprot.writeFieldEnd();
      }
      if (this.guid != null) {
        oprot.writeFieldBegin(GUID_FIELD_DESC);
        oprot.writeString(this.guid);
        oprot.writeFieldEnd();
      }
      oprot.writeFieldBegin(WITH_CONTENT_FIELD_DESC);
      oprot.writeBool(this.withContent);
      oprot.writeFieldEnd();
      oprot.writeFieldBegin(WITH_RESOURCES_DATA_FIELD_DESC);
      oprot.writeBool(this.withResourcesData);
      oprot.writeFieldEnd();
      oprot.writeFieldBegin(WITH_RESOURCES_RECOGNITION_FIELD_DESC);
      oprot.writeBool(this.withResourcesRecognition);
      oprot.writeFieldEnd();
      oprot.writeFieldBegin(WITH_RESOURCES_ALTERNATE_DATA_FIELD_DESC);
      oprot.writeBool(this.withResourcesAlternateData);
      oprot.writeFieldEnd();
      oprot.writeFieldStop();
      oprot.writeStructEnd();
    }

    public String toString() {
      StringBuilder sb = new StringBuilder("getNote_args(");
      boolean first = true;

      sb.append("authenticationToken:");
      if (this.authenticationToken == null) {
        sb.append("null");
      } else {
        sb.append(this.authenticationToken);
      }
      first = false;
      if (!first) sb.append(", ");
      sb.append("guid:");
      if (this.guid == null) {
        sb.append("null");
      } else {
        sb.append(this.guid);
      }
      first = false;
      if (!first) sb.append(", ");
      sb.append("withContent:");
      sb.append(this.withContent);
      first = false;
      if (!first) sb.append(", ");
      sb.append("withResourcesData:");
      sb.append(this.withResourcesData);
      first = false;
      if (!first) sb.append(", ");
      sb.append("withResourcesRecognition:");
      sb.append(this.withResourcesRecognition);
      first = false;
      if (!first) sb.append(", ");
      sb.append("withResourcesAlternateData:");
      sb.append(this.withResourcesAlternateData);
      first = false;
      sb.append(")");
      return sb.toString();
    }

    public void validate() throws TException {
      // check for required fields
    }

  }

  public static class getNote_result implements TBase<getNote_result._Fields>, java.io.Serializable, Cloneable, Comparable<getNote_result>   {
    private static final TStruct STRUCT_DESC = new TStruct("getNote_result");

    private static final TField SUCCESS_FIELD_DESC = new TField("success", TType.STRUCT, (short)0);
    private static final TField USER_EXCEPTION_FIELD_DESC = new TField("userException", TType.STRUCT, (short)1);
    private static final TField SYSTEM_EXCEPTION_FIELD_DESC = new TField("systemException", TType.STRUCT, (short)2);
    private static final TField NOT_FOUND_EXCEPTION_FIELD_DESC = new TField("notFoundException", TType.STRUCT, (short)3);

    private com.evernote.edam.type.Note success;
    private com.evernote.edam.error.EDAMUserException userException;
    private com.evernote.edam.error.EDAMSystemException systemException;
    private com.evernote.edam.error.EDAMNotFoundException notFoundException;

    /** The set of fields this struct contains, along with convenience methods for finding and manipulating them. */
    public enum _Fields implements TFieldIdEnum {
      SUCCESS((short)0, "success"),
      USER_EXCEPTION((short)1, "userException"),
      SYSTEM_EXCEPTION((short)2, "systemException"),
      NOT_FOUND_EXCEPTION((short)3, "notFoundException");

      private static final Map<Integer, _Fields> byId = new HashMap<Integer, _Fields>();
      private static final Map<String, _Fields> byName = new HashMap<String, _Fields>();

      static {
        for (_Fields field : EnumSet.allOf(_Fields.class)) {
          byId.put((int)field._thriftId, field);
          byName.put(field.getFieldName(), field);
        }
      }

      /**
       * Find the _Fields constant that matches fieldId, or null if its not found.
       */
      public static _Fields findByThriftId(int fieldId) {
        return byId.get(fieldId);
      }

      /**
       * Find the _Fields constant that matches fieldId, throwing an exception
       * if it is not found.
       */
      public static _Fields findByThriftIdOrThrow(int fieldId) {
        _Fields fields = findByThriftId(fieldId);
        if (fields == null) throw new IllegalArgumentException("Field " + fieldId + " doesn't exist!");
        return fields;
      }

      /**
       * Find the _Fields constant that matches name, or null if its not found.
       */
      public static _Fields findByName(String name) {
        return byName.get(name);
      }

      private final short _thriftId;
      private final String _fieldName;

      _Fields(short thriftId, String fieldName) {
        _thriftId = thriftId;
        _fieldName = fieldName;
      }

      public short getThriftFieldId() {
        return _thriftId;
      }

      public String getFieldName() {
        return _fieldName;
      }
    }

    // isset id assignments

    public static final Map<_Fields, FieldMetaData> metaDataMap = Collections.unmodifiableMap(new EnumMap<_Fields, FieldMetaData>(_Fields.class) {{
      put(_Fields.SUCCESS, new FieldMetaData("success", TFieldRequirementType.DEFAULT, 
          new StructMetaData(TType.STRUCT, com.evernote.edam.type.Note.class)));
      put(_Fields.USER_EXCEPTION, new FieldMetaData("userException", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.STRUCT)));
      put(_Fields.SYSTEM_EXCEPTION, new FieldMetaData("systemException", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.STRUCT)));
      put(_Fields.NOT_FOUND_EXCEPTION, new FieldMetaData("notFoundException", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.STRUCT)));
    }});

    static {
      FieldMetaData.addStructMetaDataMap(getNote_result.class, metaDataMap);
    }

    public getNote_result() {
    }

    public getNote_result(
      com.evernote.edam.type.Note success,
      com.evernote.edam.error.EDAMUserException userException,
      com.evernote.edam.error.EDAMSystemException systemException,
      com.evernote.edam.error.EDAMNotFoundException notFoundException)
    {
      this();
      this.success = success;
      this.userException = userException;
      this.systemException = systemException;
      this.notFoundException = notFoundException;
    }

    /**
     * Performs a deep copy on <i>other</i>.
     */
    public getNote_result(getNote_result other) {
      if (other.isSetSuccess()) {
        this.success = new com.evernote.edam.type.Note(other.success);
      }
      if (other.isSetUserException()) {
        this.userException = new com.evernote.edam.error.EDAMUserException(other.userException);
      }
      if (other.isSetSystemException()) {
        this.systemException = new com.evernote.edam.error.EDAMSystemException(other.systemException);
      }
      if (other.isSetNotFoundException()) {
        this.notFoundException = new com.evernote.edam.error.EDAMNotFoundException(other.notFoundException);
      }
    }

    public getNote_result deepCopy() {
      return new getNote_result(this);
    }

    @Deprecated
    public getNote_result clone() {
      return new getNote_result(this);
    }

    public com.evernote.edam.type.Note getSuccess() {
      return this.success;
    }

    public void setSuccess(com.evernote.edam.type.Note success) {
      this.success = success;
    }

    public void unsetSuccess() {
      this.success = null;
    }

    /** Returns true if field success is set (has been asigned a value) and false otherwise */
    public boolean isSetSuccess() {
      return this.success != null;
    }

    public void setSuccessIsSet(boolean value) {
      if (!value) {
        this.success = null;
      }
    }

    public com.evernote.edam.error.EDAMUserException getUserException() {
      return this.userException;
    }

    public void setUserException(com.evernote.edam.error.EDAMUserException userException) {
      this.userException = userException;
    }

    public void unsetUserException() {
      this.userException = null;
    }

    /** Returns true if field userException is set (has been asigned a value) and false otherwise */
    public boolean isSetUserException() {
      return this.userException != null;
    }

    public void setUserExceptionIsSet(boolean value) {
      if (!value) {
        this.userException = null;
      }
    }

    public com.evernote.edam.error.EDAMSystemException getSystemException() {
      return this.systemException;
    }

    public void setSystemException(com.evernote.edam.error.EDAMSystemException systemException) {
      this.systemException = systemException;
    }

    public void unsetSystemException() {
      this.systemException = null;
    }

    /** Returns true if field systemException is set (has been asigned a value) and false otherwise */
    public boolean isSetSystemException() {
      return this.systemException != null;
    }

    public void setSystemExceptionIsSet(boolean value) {
      if (!value) {
        this.systemException = null;
      }
    }

    public com.evernote.edam.error.EDAMNotFoundException getNotFoundException() {
      return this.notFoundException;
    }

    public void setNotFoundException(com.evernote.edam.error.EDAMNotFoundException notFoundException) {
      this.notFoundException = notFoundException;
    }

    public void unsetNotFoundException() {
      this.notFoundException = null;
    }

    /** Returns true if field notFoundException is set (has been asigned a value) and false otherwise */
    public boolean isSetNotFoundException() {
      return this.notFoundException != null;
    }

    public void setNotFoundExceptionIsSet(boolean value) {
      if (!value) {
        this.notFoundException = null;
      }
    }

    public void setFieldValue(_Fields field, Object value) {
      switch (field) {
      case SUCCESS:
        if (value == null) {
          unsetSuccess();
        } else {
          setSuccess((com.evernote.edam.type.Note)value);
        }
        break;

      case USER_EXCEPTION:
        if (value == null) {
          unsetUserException();
        } else {
          setUserException((com.evernote.edam.error.EDAMUserException)value);
        }
        break;

      case SYSTEM_EXCEPTION:
        if (value == null) {
          unsetSystemException();
        } else {
          setSystemException((com.evernote.edam.error.EDAMSystemException)value);
        }
        break;

      case NOT_FOUND_EXCEPTION:
        if (value == null) {
          unsetNotFoundException();
        } else {
          setNotFoundException((com.evernote.edam.error.EDAMNotFoundException)value);
        }
        break;

      }
    }

    public void setFieldValue(int fieldID, Object value) {
      setFieldValue(_Fields.findByThriftIdOrThrow(fieldID), value);
    }

    public Object getFieldValue(_Fields field) {
      switch (field) {
      case SUCCESS:
        return getSuccess();

      case USER_EXCEPTION:
        return getUserException();

      case SYSTEM_EXCEPTION:
        return getSystemException();

      case NOT_FOUND_EXCEPTION:
        return getNotFoundException();

      }
      throw new IllegalStateException();
    }

    public Object getFieldValue(int fieldId) {
      return getFieldValue(_Fields.findByThriftIdOrThrow(fieldId));
    }

    /** Returns true if field corresponding to fieldID is set (has been asigned a value) and false otherwise */
    public boolean isSet(_Fields field) {
      switch (field) {
      case SUCCESS:
        return isSetSuccess();
      case USER_EXCEPTION:
        return isSetUserException();
      case SYSTEM_EXCEPTION:
        return isSetSystemException();
      case NOT_FOUND_EXCEPTION:
        return isSetNotFoundException();
      }
      throw new IllegalStateException();
    }

    public boolean isSet(int fieldID) {
      return isSet(_Fields.findByThriftIdOrThrow(fieldID));
    }

    public boolean equals(Object that) {
      if (that == null)
        return false;
      if (that instanceof getNote_result)
        return this.equals((getNote_result)that);
      return false;
    }

    public boolean equals(getNote_result that) {
      if (that == null)
        return false;

      boolean this_present_success = true && this.isSetSuccess();
      boolean that_present_success = true && that.isSetSuccess();
      if (this_present_success || that_present_success) {
        if (!(this_present_success && that_present_success))
          return false;
        if (!this.success.equals(that.success))
          return false;
      }

      boolean this_present_userException = true && this.isSetUserException();
      boolean that_present_userException = true && that.isSetUserException();
      if (this_present_userException || that_present_userException) {
        if (!(this_present_userException && that_present_userException))
          return false;
        if (!this.userException.equals(that.userException))
          return false;
      }

      boolean this_present_systemException = true && this.isSetSystemException();
      boolean that_present_systemException = true && that.isSetSystemException();
      if (this_present_systemException || that_present_systemException) {
        if (!(this_present_systemException && that_present_systemException))
          return false;
        if (!this.systemException.equals(that.systemException))
          return false;
      }

      boolean this_present_notFoundException = true && this.isSetNotFoundException();
      boolean that_present_notFoundException = true && that.isSetNotFoundException();
      if (this_present_notFoundException || that_present_notFoundException) {
        if (!(this_present_notFoundException && that_present_notFoundException))
          return false;
        if (!this.notFoundException.equals(that.notFoundException))
          return false;
      }

      return true;
    }

    public int hashCode() {
      return 0;
    }

    public int compareTo(getNote_result other) {
      if (!getClass().equals(other.getClass())) {
        return getClass().getName().compareTo(other.getClass().getName());
      }

      int lastComparison = 0;
      getNote_result typedOther = (getNote_result)other;

      lastComparison = Boolean.valueOf(isSetSuccess()).compareTo(isSetSuccess());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(success, typedOther.success);
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = Boolean.valueOf(isSetUserException()).compareTo(isSetUserException());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(userException, typedOther.userException);
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = Boolean.valueOf(isSetSystemException()).compareTo(isSetSystemException());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(systemException, typedOther.systemException);
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = Boolean.valueOf(isSetNotFoundException()).compareTo(isSetNotFoundException());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(notFoundException, typedOther.notFoundException);
      if (lastComparison != 0) {
        return lastComparison;
      }
      return 0;
    }

    public void read(TProtocol iprot) throws TException {
      TField field;
      iprot.readStructBegin();
      while (true)
      {
        field = iprot.readFieldBegin();
        if (field.type == TType.STOP) { 
          break;
        }
        _Fields fieldId = _Fields.findByThriftId(field.id);
        if (fieldId == null) {
          TProtocolUtil.skip(iprot, field.type);
        } else {
          switch (fieldId) {
            case SUCCESS:
              if (field.type == TType.STRUCT) {
                this.success = new com.evernote.edam.type.Note();
                this.success.read(iprot);
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
            case USER_EXCEPTION:
              if (field.type == TType.STRUCT) {
                this.userException = new com.evernote.edam.error.EDAMUserException();
                this.userException.read(iprot);
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
            case SYSTEM_EXCEPTION:
              if (field.type == TType.STRUCT) {
                this.systemException = new com.evernote.edam.error.EDAMSystemException();
                this.systemException.read(iprot);
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
            case NOT_FOUND_EXCEPTION:
              if (field.type == TType.STRUCT) {
                this.notFoundException = new com.evernote.edam.error.EDAMNotFoundException();
                this.notFoundException.read(iprot);
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
          }
          iprot.readFieldEnd();
        }
      }
      iprot.readStructEnd();
      validate();
    }

    public void write(TProtocol oprot) throws TException {
      oprot.writeStructBegin(STRUCT_DESC);

      if (this.isSetSuccess()) {
        oprot.writeFieldBegin(SUCCESS_FIELD_DESC);
        this.success.write(oprot);
        oprot.writeFieldEnd();
      } else if (this.isSetUserException()) {
        oprot.writeFieldBegin(USER_EXCEPTION_FIELD_DESC);
        this.userException.write(oprot);
        oprot.writeFieldEnd();
      } else if (this.isSetSystemException()) {
        oprot.writeFieldBegin(SYSTEM_EXCEPTION_FIELD_DESC);
        this.systemException.write(oprot);
        oprot.writeFieldEnd();
      } else if (this.isSetNotFoundException()) {
        oprot.writeFieldBegin(NOT_FOUND_EXCEPTION_FIELD_DESC);
        this.notFoundException.write(oprot);
        oprot.writeFieldEnd();
      }
      oprot.writeFieldStop();
      oprot.writeStructEnd();
    }

    public String toString() {
      StringBuilder sb = new StringBuilder("getNote_result(");
      boolean first = true;

      sb.append("success:");
      if (this.success == null) {
        sb.append("null");
      } else {
        sb.append(this.success);
      }
      first = false;
      if (!first) sb.append(", ");
      sb.append("userException:");
      if (this.userException == null) {
        sb.append("null");
      } else {
        sb.append(this.userException);
      }
      first = false;
      if (!first) sb.append(", ");
      sb.append("systemException:");
      if (this.systemException == null) {
        sb.append("null");
      } else {
        sb.append(this.systemException);
      }
      first = false;
      if (!first) sb.append(", ");
      sb.append("notFoundException:");
      if (this.notFoundException == null) {
        sb.append("null");
      } else {
        sb.append(this.notFoundException);
      }
      first = false;
      sb.append(")");
      return sb.toString();
    }

    public void validate() throws TException {
      // check for required fields
    }

  }

  public static class getNoteContent_args implements TBase<getNoteContent_args._Fields>, java.io.Serializable, Cloneable, Comparable<getNoteContent_args>   {
    private static final TStruct STRUCT_DESC = new TStruct("getNoteContent_args");

    private static final TField AUTHENTICATION_TOKEN_FIELD_DESC = new TField("authenticationToken", TType.STRING, (short)1);
    private static final TField GUID_FIELD_DESC = new TField("guid", TType.STRING, (short)2);

    private String authenticationToken;
    private String guid;

    /** The set of fields this struct contains, along with convenience methods for finding and manipulating them. */
    public enum _Fields implements TFieldIdEnum {
      AUTHENTICATION_TOKEN((short)1, "authenticationToken"),
      GUID((short)2, "guid");

      private static final Map<Integer, _Fields> byId = new HashMap<Integer, _Fields>();
      private static final Map<String, _Fields> byName = new HashMap<String, _Fields>();

      static {
        for (_Fields field : EnumSet.allOf(_Fields.class)) {
          byId.put((int)field._thriftId, field);
          byName.put(field.getFieldName(), field);
        }
      }

      /**
       * Find the _Fields constant that matches fieldId, or null if its not found.
       */
      public static _Fields findByThriftId(int fieldId) {
        return byId.get(fieldId);
      }

      /**
       * Find the _Fields constant that matches fieldId, throwing an exception
       * if it is not found.
       */
      public static _Fields findByThriftIdOrThrow(int fieldId) {
        _Fields fields = findByThriftId(fieldId);
        if (fields == null) throw new IllegalArgumentException("Field " + fieldId + " doesn't exist!");
        return fields;
      }

      /**
       * Find the _Fields constant that matches name, or null if its not found.
       */
      public static _Fields findByName(String name) {
        return byName.get(name);
      }

      private final short _thriftId;
      private final String _fieldName;

      _Fields(short thriftId, String fieldName) {
        _thriftId = thriftId;
        _fieldName = fieldName;
      }

      public short getThriftFieldId() {
        return _thriftId;
      }

      public String getFieldName() {
        return _fieldName;
      }
    }

    // isset id assignments

    public static final Map<_Fields, FieldMetaData> metaDataMap = Collections.unmodifiableMap(new EnumMap<_Fields, FieldMetaData>(_Fields.class) {{
      put(_Fields.AUTHENTICATION_TOKEN, new FieldMetaData("authenticationToken", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.STRING)));
      put(_Fields.GUID, new FieldMetaData("guid", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.STRING)));
    }});

    static {
      FieldMetaData.addStructMetaDataMap(getNoteContent_args.class, metaDataMap);
    }

    public getNoteContent_args() {
    }

    public getNoteContent_args(
      String authenticationToken,
      String guid)
    {
      this();
      this.authenticationToken = authenticationToken;
      this.guid = guid;
    }

    /**
     * Performs a deep copy on <i>other</i>.
     */
    public getNoteContent_args(getNoteContent_args other) {
      if (other.isSetAuthenticationToken()) {
        this.authenticationToken = other.authenticationToken;
      }
      if (other.isSetGuid()) {
        this.guid = other.guid;
      }
    }

    public getNoteContent_args deepCopy() {
      return new getNoteContent_args(this);
    }

    @Deprecated
    public getNoteContent_args clone() {
      return new getNoteContent_args(this);
    }

    public String getAuthenticationToken() {
      return this.authenticationToken;
    }

    public void setAuthenticationToken(String authenticationToken) {
      this.authenticationToken = authenticationToken;
    }

    public void unsetAuthenticationToken() {
      this.authenticationToken = null;
    }

    /** Returns true if field authenticationToken is set (has been asigned a value) and false otherwise */
    public boolean isSetAuthenticationToken() {
      return this.authenticationToken != null;
    }

    public void setAuthenticationTokenIsSet(boolean value) {
      if (!value) {
        this.authenticationToken = null;
      }
    }

    public String getGuid() {
      return this.guid;
    }

    public void setGuid(String guid) {
      this.guid = guid;
    }

    public void unsetGuid() {
      this.guid = null;
    }

    /** Returns true if field guid is set (has been asigned a value) and false otherwise */
    public boolean isSetGuid() {
      return this.guid != null;
    }

    public void setGuidIsSet(boolean value) {
      if (!value) {
        this.guid = null;
      }
    }

    public void setFieldValue(_Fields field, Object value) {
      switch (field) {
      case AUTHENTICATION_TOKEN:
        if (value == null) {
          unsetAuthenticationToken();
        } else {
          setAuthenticationToken((String)value);
        }
        break;

      case GUID:
        if (value == null) {
          unsetGuid();
        } else {
          setGuid((String)value);
        }
        break;

      }
    }

    public void setFieldValue(int fieldID, Object value) {
      setFieldValue(_Fields.findByThriftIdOrThrow(fieldID), value);
    }

    public Object getFieldValue(_Fields field) {
      switch (field) {
      case AUTHENTICATION_TOKEN:
        return getAuthenticationToken();

      case GUID:
        return getGuid();

      }
      throw new IllegalStateException();
    }

    public Object getFieldValue(int fieldId) {
      return getFieldValue(_Fields.findByThriftIdOrThrow(fieldId));
    }

    /** Returns true if field corresponding to fieldID is set (has been asigned a value) and false otherwise */
    public boolean isSet(_Fields field) {
      switch (field) {
      case AUTHENTICATION_TOKEN:
        return isSetAuthenticationToken();
      case GUID:
        return isSetGuid();
      }
      throw new IllegalStateException();
    }

    public boolean isSet(int fieldID) {
      return isSet(_Fields.findByThriftIdOrThrow(fieldID));
    }

    public boolean equals(Object that) {
      if (that == null)
        return false;
      if (that instanceof getNoteContent_args)
        return this.equals((getNoteContent_args)that);
      return false;
    }

    public boolean equals(getNoteContent_args that) {
      if (that == null)
        return false;

      boolean this_present_authenticationToken = true && this.isSetAuthenticationToken();
      boolean that_present_authenticationToken = true && that.isSetAuthenticationToken();
      if (this_present_authenticationToken || that_present_authenticationToken) {
        if (!(this_present_authenticationToken && that_present_authenticationToken))
          return false;
        if (!this.authenticationToken.equals(that.authenticationToken))
          return false;
      }

      boolean this_present_guid = true && this.isSetGuid();
      boolean that_present_guid = true && that.isSetGuid();
      if (this_present_guid || that_present_guid) {
        if (!(this_present_guid && that_present_guid))
          return false;
        if (!this.guid.equals(that.guid))
          return false;
      }

      return true;
    }

    public int hashCode() {
      return 0;
    }

    public int compareTo(getNoteContent_args other) {
      if (!getClass().equals(other.getClass())) {
        return getClass().getName().compareTo(other.getClass().getName());
      }

      int lastComparison = 0;
      getNoteContent_args typedOther = (getNoteContent_args)other;

      lastComparison = Boolean.valueOf(isSetAuthenticationToken()).compareTo(isSetAuthenticationToken());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(authenticationToken, typedOther.authenticationToken);
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = Boolean.valueOf(isSetGuid()).compareTo(isSetGuid());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(guid, typedOther.guid);
      if (lastComparison != 0) {
        return lastComparison;
      }
      return 0;
    }

    public void read(TProtocol iprot) throws TException {
      TField field;
      iprot.readStructBegin();
      while (true)
      {
        field = iprot.readFieldBegin();
        if (field.type == TType.STOP) { 
          break;
        }
        _Fields fieldId = _Fields.findByThriftId(field.id);
        if (fieldId == null) {
          TProtocolUtil.skip(iprot, field.type);
        } else {
          switch (fieldId) {
            case AUTHENTICATION_TOKEN:
              if (field.type == TType.STRING) {
                this.authenticationToken = iprot.readString();
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
            case GUID:
              if (field.type == TType.STRING) {
                this.guid = iprot.readString();
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
          }
          iprot.readFieldEnd();
        }
      }
      iprot.readStructEnd();
      validate();
    }

    public void write(TProtocol oprot) throws TException {
      validate();

      oprot.writeStructBegin(STRUCT_DESC);
      if (this.authenticationToken != null) {
        oprot.writeFieldBegin(AUTHENTICATION_TOKEN_FIELD_DESC);
        oprot.writeString(this.authenticationToken);
        oprot.writeFieldEnd();
      }
      if (this.guid != null) {
        oprot.writeFieldBegin(GUID_FIELD_DESC);
        oprot.writeString(this.guid);
        oprot.writeFieldEnd();
      }
      oprot.writeFieldStop();
      oprot.writeStructEnd();
    }

    public String toString() {
      StringBuilder sb = new StringBuilder("getNoteContent_args(");
      boolean first = true;

      sb.append("authenticationToken:");
      if (this.authenticationToken == null) {
        sb.append("null");
      } else {
        sb.append(this.authenticationToken);
      }
      first = false;
      if (!first) sb.append(", ");
      sb.append("guid:");
      if (this.guid == null) {
        sb.append("null");
      } else {
        sb.append(this.guid);
      }
      first = false;
      sb.append(")");
      return sb.toString();
    }

    public void validate() throws TException {
      // check for required fields
    }

  }

  public static class getNoteContent_result implements TBase<getNoteContent_result._Fields>, java.io.Serializable, Cloneable, Comparable<getNoteContent_result>   {
    private static final TStruct STRUCT_DESC = new TStruct("getNoteContent_result");

    private static final TField SUCCESS_FIELD_DESC = new TField("success", TType.STRING, (short)0);
    private static final TField USER_EXCEPTION_FIELD_DESC = new TField("userException", TType.STRUCT, (short)1);
    private static final TField SYSTEM_EXCEPTION_FIELD_DESC = new TField("systemException", TType.STRUCT, (short)2);
    private static final TField NOT_FOUND_EXCEPTION_FIELD_DESC = new TField("notFoundException", TType.STRUCT, (short)3);

    private String success;
    private com.evernote.edam.error.EDAMUserException userException;
    private com.evernote.edam.error.EDAMSystemException systemException;
    private com.evernote.edam.error.EDAMNotFoundException notFoundException;

    /** The set of fields this struct contains, along with convenience methods for finding and manipulating them. */
    public enum _Fields implements TFieldIdEnum {
      SUCCESS((short)0, "success"),
      USER_EXCEPTION((short)1, "userException"),
      SYSTEM_EXCEPTION((short)2, "systemException"),
      NOT_FOUND_EXCEPTION((short)3, "notFoundException");

      private static final Map<Integer, _Fields> byId = new HashMap<Integer, _Fields>();
      private static final Map<String, _Fields> byName = new HashMap<String, _Fields>();

      static {
        for (_Fields field : EnumSet.allOf(_Fields.class)) {
          byId.put((int)field._thriftId, field);
          byName.put(field.getFieldName(), field);
        }
      }

      /**
       * Find the _Fields constant that matches fieldId, or null if its not found.
       */
      public static _Fields findByThriftId(int fieldId) {
        return byId.get(fieldId);
      }

      /**
       * Find the _Fields constant that matches fieldId, throwing an exception
       * if it is not found.
       */
      public static _Fields findByThriftIdOrThrow(int fieldId) {
        _Fields fields = findByThriftId(fieldId);
        if (fields == null) throw new IllegalArgumentException("Field " + fieldId + " doesn't exist!");
        return fields;
      }

      /**
       * Find the _Fields constant that matches name, or null if its not found.
       */
      public static _Fields findByName(String name) {
        return byName.get(name);
      }

      private final short _thriftId;
      private final String _fieldName;

      _Fields(short thriftId, String fieldName) {
        _thriftId = thriftId;
        _fieldName = fieldName;
      }

      public short getThriftFieldId() {
        return _thriftId;
      }

      public String getFieldName() {
        return _fieldName;
      }
    }

    // isset id assignments

    public static final Map<_Fields, FieldMetaData> metaDataMap = Collections.unmodifiableMap(new EnumMap<_Fields, FieldMetaData>(_Fields.class) {{
      put(_Fields.SUCCESS, new FieldMetaData("success", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.STRING)));
      put(_Fields.USER_EXCEPTION, new FieldMetaData("userException", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.STRUCT)));
      put(_Fields.SYSTEM_EXCEPTION, new FieldMetaData("systemException", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.STRUCT)));
      put(_Fields.NOT_FOUND_EXCEPTION, new FieldMetaData("notFoundException", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.STRUCT)));
    }});

    static {
      FieldMetaData.addStructMetaDataMap(getNoteContent_result.class, metaDataMap);
    }

    public getNoteContent_result() {
    }

    public getNoteContent_result(
      String success,
      com.evernote.edam.error.EDAMUserException userException,
      com.evernote.edam.error.EDAMSystemException systemException,
      com.evernote.edam.error.EDAMNotFoundException notFoundException)
    {
      this();
      this.success = success;
      this.userException = userException;
      this.systemException = systemException;
      this.notFoundException = notFoundException;
    }

    /**
     * Performs a deep copy on <i>other</i>.
     */
    public getNoteContent_result(getNoteContent_result other) {
      if (other.isSetSuccess()) {
        this.success = other.success;
      }
      if (other.isSetUserException()) {
        this.userException = new com.evernote.edam.error.EDAMUserException(other.userException);
      }
      if (other.isSetSystemException()) {
        this.systemException = new com.evernote.edam.error.EDAMSystemException(other.systemException);
      }
      if (other.isSetNotFoundException()) {
        this.notFoundException = new com.evernote.edam.error.EDAMNotFoundException(other.notFoundException);
      }
    }

    public getNoteContent_result deepCopy() {
      return new getNoteContent_result(this);
    }

    @Deprecated
    public getNoteContent_result clone() {
      return new getNoteContent_result(this);
    }

    public String getSuccess() {
      return this.success;
    }

    public void setSuccess(String success) {
      this.success = success;
    }

    public void unsetSuccess() {
      this.success = null;
    }

    /** Returns true if field success is set (has been asigned a value) and false otherwise */
    public boolean isSetSuccess() {
      return this.success != null;
    }

    public void setSuccessIsSet(boolean value) {
      if (!value) {
        this.success = null;
      }
    }

    public com.evernote.edam.error.EDAMUserException getUserException() {
      return this.userException;
    }

    public void setUserException(com.evernote.edam.error.EDAMUserException userException) {
      this.userException = userException;
    }

    public void unsetUserException() {
      this.userException = null;
    }

    /** Returns true if field userException is set (has been asigned a value) and false otherwise */
    public boolean isSetUserException() {
      return this.userException != null;
    }

    public void setUserExceptionIsSet(boolean value) {
      if (!value) {
        this.userException = null;
      }
    }

    public com.evernote.edam.error.EDAMSystemException getSystemException() {
      return this.systemException;
    }

    public void setSystemException(com.evernote.edam.error.EDAMSystemException systemException) {
      this.systemException = systemException;
    }

    public void unsetSystemException() {
      this.systemException = null;
    }

    /** Returns true if field systemException is set (has been asigned a value) and false otherwise */
    public boolean isSetSystemException() {
      return this.systemException != null;
    }

    public void setSystemExceptionIsSet(boolean value) {
      if (!value) {
        this.systemException = null;
      }
    }

    public com.evernote.edam.error.EDAMNotFoundException getNotFoundException() {
      return this.notFoundException;
    }

    public void setNotFoundException(com.evernote.edam.error.EDAMNotFoundException notFoundException) {
      this.notFoundException = notFoundException;
    }

    public void unsetNotFoundException() {
      this.notFoundException = null;
    }

    /** Returns true if field notFoundException is set (has been asigned a value) and false otherwise */
    public boolean isSetNotFoundException() {
      return this.notFoundException != null;
    }

    public void setNotFoundExceptionIsSet(boolean value) {
      if (!value) {
        this.notFoundException = null;
      }
    }

    public void setFieldValue(_Fields field, Object value) {
      switch (field) {
      case SUCCESS:
        if (value == null) {
          unsetSuccess();
        } else {
          setSuccess((String)value);
        }
        break;

      case USER_EXCEPTION:
        if (value == null) {
          unsetUserException();
        } else {
          setUserException((com.evernote.edam.error.EDAMUserException)value);
        }
        break;

      case SYSTEM_EXCEPTION:
        if (value == null) {
          unsetSystemException();
        } else {
          setSystemException((com.evernote.edam.error.EDAMSystemException)value);
        }
        break;

      case NOT_FOUND_EXCEPTION:
        if (value == null) {
          unsetNotFoundException();
        } else {
          setNotFoundException((com.evernote.edam.error.EDAMNotFoundException)value);
        }
        break;

      }
    }

    public void setFieldValue(int fieldID, Object value) {
      setFieldValue(_Fields.findByThriftIdOrThrow(fieldID), value);
    }

    public Object getFieldValue(_Fields field) {
      switch (field) {
      case SUCCESS:
        return getSuccess();

      case USER_EXCEPTION:
        return getUserException();

      case SYSTEM_EXCEPTION:
        return getSystemException();

      case NOT_FOUND_EXCEPTION:
        return getNotFoundException();

      }
      throw new IllegalStateException();
    }

    public Object getFieldValue(int fieldId) {
      return getFieldValue(_Fields.findByThriftIdOrThrow(fieldId));
    }

    /** Returns true if field corresponding to fieldID is set (has been asigned a value) and false otherwise */
    public boolean isSet(_Fields field) {
      switch (field) {
      case SUCCESS:
        return isSetSuccess();
      case USER_EXCEPTION:
        return isSetUserException();
      case SYSTEM_EXCEPTION:
        return isSetSystemException();
      case NOT_FOUND_EXCEPTION:
        return isSetNotFoundException();
      }
      throw new IllegalStateException();
    }

    public boolean isSet(int fieldID) {
      return isSet(_Fields.findByThriftIdOrThrow(fieldID));
    }

    public boolean equals(Object that) {
      if (that == null)
        return false;
      if (that instanceof getNoteContent_result)
        return this.equals((getNoteContent_result)that);
      return false;
    }

    public boolean equals(getNoteContent_result that) {
      if (that == null)
        return false;

      boolean this_present_success = true && this.isSetSuccess();
      boolean that_present_success = true && that.isSetSuccess();
      if (this_present_success || that_present_success) {
        if (!(this_present_success && that_present_success))
          return false;
        if (!this.success.equals(that.success))
          return false;
      }

      boolean this_present_userException = true && this.isSetUserException();
      boolean that_present_userException = true && that.isSetUserException();
      if (this_present_userException || that_present_userException) {
        if (!(this_present_userException && that_present_userException))
          return false;
        if (!this.userException.equals(that.userException))
          return false;
      }

      boolean this_present_systemException = true && this.isSetSystemException();
      boolean that_present_systemException = true && that.isSetSystemException();
      if (this_present_systemException || that_present_systemException) {
        if (!(this_present_systemException && that_present_systemException))
          return false;
        if (!this.systemException.equals(that.systemException))
          return false;
      }

      boolean this_present_notFoundException = true && this.isSetNotFoundException();
      boolean that_present_notFoundException = true && that.isSetNotFoundException();
      if (this_present_notFoundException || that_present_notFoundException) {
        if (!(this_present_notFoundException && that_present_notFoundException))
          return false;
        if (!this.notFoundException.equals(that.notFoundException))
          return false;
      }

      return true;
    }

    public int hashCode() {
      return 0;
    }

    public int compareTo(getNoteContent_result other) {
      if (!getClass().equals(other.getClass())) {
        return getClass().getName().compareTo(other.getClass().getName());
      }

      int lastComparison = 0;
      getNoteContent_result typedOther = (getNoteContent_result)other;

      lastComparison = Boolean.valueOf(isSetSuccess()).compareTo(isSetSuccess());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(success, typedOther.success);
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = Boolean.valueOf(isSetUserException()).compareTo(isSetUserException());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(userException, typedOther.userException);
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = Boolean.valueOf(isSetSystemException()).compareTo(isSetSystemException());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(systemException, typedOther.systemException);
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = Boolean.valueOf(isSetNotFoundException()).compareTo(isSetNotFoundException());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(notFoundException, typedOther.notFoundException);
      if (lastComparison != 0) {
        return lastComparison;
      }
      return 0;
    }

    public void read(TProtocol iprot) throws TException {
      TField field;
      iprot.readStructBegin();
      while (true)
      {
        field = iprot.readFieldBegin();
        if (field.type == TType.STOP) { 
          break;
        }
        _Fields fieldId = _Fields.findByThriftId(field.id);
        if (fieldId == null) {
          TProtocolUtil.skip(iprot, field.type);
        } else {
          switch (fieldId) {
            case SUCCESS:
              if (field.type == TType.STRING) {
                this.success = iprot.readString();
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
            case USER_EXCEPTION:
              if (field.type == TType.STRUCT) {
                this.userException = new com.evernote.edam.error.EDAMUserException();
                this.userException.read(iprot);
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
            case SYSTEM_EXCEPTION:
              if (field.type == TType.STRUCT) {
                this.systemException = new com.evernote.edam.error.EDAMSystemException();
                this.systemException.read(iprot);
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
            case NOT_FOUND_EXCEPTION:
              if (field.type == TType.STRUCT) {
                this.notFoundException = new com.evernote.edam.error.EDAMNotFoundException();
                this.notFoundException.read(iprot);
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
          }
          iprot.readFieldEnd();
        }
      }
      iprot.readStructEnd();
      validate();
    }

    public void write(TProtocol oprot) throws TException {
      oprot.writeStructBegin(STRUCT_DESC);

      if (this.isSetSuccess()) {
        oprot.writeFieldBegin(SUCCESS_FIELD_DESC);
        oprot.writeString(this.success);
        oprot.writeFieldEnd();
      } else if (this.isSetUserException()) {
        oprot.writeFieldBegin(USER_EXCEPTION_FIELD_DESC);
        this.userException.write(oprot);
        oprot.writeFieldEnd();
      } else if (this.isSetSystemException()) {
        oprot.writeFieldBegin(SYSTEM_EXCEPTION_FIELD_DESC);
        this.systemException.write(oprot);
        oprot.writeFieldEnd();
      } else if (this.isSetNotFoundException()) {
        oprot.writeFieldBegin(NOT_FOUND_EXCEPTION_FIELD_DESC);
        this.notFoundException.write(oprot);
        oprot.writeFieldEnd();
      }
      oprot.writeFieldStop();
      oprot.writeStructEnd();
    }

    public String toString() {
      StringBuilder sb = new StringBuilder("getNoteContent_result(");
      boolean first = true;

      sb.append("success:");
      if (this.success == null) {
        sb.append("null");
      } else {
        sb.append(this.success);
      }
      first = false;
      if (!first) sb.append(", ");
      sb.append("userException:");
      if (this.userException == null) {
        sb.append("null");
      } else {
        sb.append(this.userException);
      }
      first = false;
      if (!first) sb.append(", ");
      sb.append("systemException:");
      if (this.systemException == null) {
        sb.append("null");
      } else {
        sb.append(this.systemException);
      }
      first = false;
      if (!first) sb.append(", ");
      sb.append("notFoundException:");
      if (this.notFoundException == null) {
        sb.append("null");
      } else {
        sb.append(this.notFoundException);
      }
      first = false;
      sb.append(")");
      return sb.toString();
    }

    public void validate() throws TException {
      // check for required fields
    }

  }

  public static class getNoteSearchText_args implements TBase<getNoteSearchText_args._Fields>, java.io.Serializable, Cloneable, Comparable<getNoteSearchText_args>   {
    private static final TStruct STRUCT_DESC = new TStruct("getNoteSearchText_args");

    private static final TField AUTHENTICATION_TOKEN_FIELD_DESC = new TField("authenticationToken", TType.STRING, (short)1);
    private static final TField GUID_FIELD_DESC = new TField("guid", TType.STRING, (short)2);

    private String authenticationToken;
    private String guid;

    /** The set of fields this struct contains, along with convenience methods for finding and manipulating them. */
    public enum _Fields implements TFieldIdEnum {
      AUTHENTICATION_TOKEN((short)1, "authenticationToken"),
      GUID((short)2, "guid");

      private static final Map<Integer, _Fields> byId = new HashMap<Integer, _Fields>();
      private static final Map<String, _Fields> byName = new HashMap<String, _Fields>();

      static {
        for (_Fields field : EnumSet.allOf(_Fields.class)) {
          byId.put((int)field._thriftId, field);
          byName.put(field.getFieldName(), field);
        }
      }

      /**
       * Find the _Fields constant that matches fieldId, or null if its not found.
       */
      public static _Fields findByThriftId(int fieldId) {
        return byId.get(fieldId);
      }

      /**
       * Find the _Fields constant that matches fieldId, throwing an exception
       * if it is not found.
       */
      public static _Fields findByThriftIdOrThrow(int fieldId) {
        _Fields fields = findByThriftId(fieldId);
        if (fields == null) throw new IllegalArgumentException("Field " + fieldId + " doesn't exist!");
        return fields;
      }

      /**
       * Find the _Fields constant that matches name, or null if its not found.
       */
      public static _Fields findByName(String name) {
        return byName.get(name);
      }

      private final short _thriftId;
      private final String _fieldName;

      _Fields(short thriftId, String fieldName) {
        _thriftId = thriftId;
        _fieldName = fieldName;
      }

      public short getThriftFieldId() {
        return _thriftId;
      }

      public String getFieldName() {
        return _fieldName;
      }
    }

    // isset id assignments

    public static final Map<_Fields, FieldMetaData> metaDataMap = Collections.unmodifiableMap(new EnumMap<_Fields, FieldMetaData>(_Fields.class) {{
      put(_Fields.AUTHENTICATION_TOKEN, new FieldMetaData("authenticationToken", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.STRING)));
      put(_Fields.GUID, new FieldMetaData("guid", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.STRING)));
    }});

    static {
      FieldMetaData.addStructMetaDataMap(getNoteSearchText_args.class, metaDataMap);
    }

    public getNoteSearchText_args() {
    }

    public getNoteSearchText_args(
      String authenticationToken,
      String guid)
    {
      this();
      this.authenticationToken = authenticationToken;
      this.guid = guid;
    }

    /**
     * Performs a deep copy on <i>other</i>.
     */
    public getNoteSearchText_args(getNoteSearchText_args other) {
      if (other.isSetAuthenticationToken()) {
        this.authenticationToken = other.authenticationToken;
      }
      if (other.isSetGuid()) {
        this.guid = other.guid;
      }
    }

    public getNoteSearchText_args deepCopy() {
      return new getNoteSearchText_args(this);
    }

    @Deprecated
    public getNoteSearchText_args clone() {
      return new getNoteSearchText_args(this);
    }

    public String getAuthenticationToken() {
      return this.authenticationToken;
    }

    public void setAuthenticationToken(String authenticationToken) {
      this.authenticationToken = authenticationToken;
    }

    public void unsetAuthenticationToken() {
      this.authenticationToken = null;
    }

    /** Returns true if field authenticationToken is set (has been asigned a value) and false otherwise */
    public boolean isSetAuthenticationToken() {
      return this.authenticationToken != null;
    }

    public void setAuthenticationTokenIsSet(boolean value) {
      if (!value) {
        this.authenticationToken = null;
      }
    }

    public String getGuid() {
      return this.guid;
    }

    public void setGuid(String guid) {
      this.guid = guid;
    }

    public void unsetGuid() {
      this.guid = null;
    }

    /** Returns true if field guid is set (has been asigned a value) and false otherwise */
    public boolean isSetGuid() {
      return this.guid != null;
    }

    public void setGuidIsSet(boolean value) {
      if (!value) {
        this.guid = null;
      }
    }

    public void setFieldValue(_Fields field, Object value) {
      switch (field) {
      case AUTHENTICATION_TOKEN:
        if (value == null) {
          unsetAuthenticationToken();
        } else {
          setAuthenticationToken((String)value);
        }
        break;

      case GUID:
        if (value == null) {
          unsetGuid();
        } else {
          setGuid((String)value);
        }
        break;

      }
    }

    public void setFieldValue(int fieldID, Object value) {
      setFieldValue(_Fields.findByThriftIdOrThrow(fieldID), value);
    }

    public Object getFieldValue(_Fields field) {
      switch (field) {
      case AUTHENTICATION_TOKEN:
        return getAuthenticationToken();

      case GUID:
        return getGuid();

      }
      throw new IllegalStateException();
    }

    public Object getFieldValue(int fieldId) {
      return getFieldValue(_Fields.findByThriftIdOrThrow(fieldId));
    }

    /** Returns true if field corresponding to fieldID is set (has been asigned a value) and false otherwise */
    public boolean isSet(_Fields field) {
      switch (field) {
      case AUTHENTICATION_TOKEN:
        return isSetAuthenticationToken();
      case GUID:
        return isSetGuid();
      }
      throw new IllegalStateException();
    }

    public boolean isSet(int fieldID) {
      return isSet(_Fields.findByThriftIdOrThrow(fieldID));
    }

    public boolean equals(Object that) {
      if (that == null)
        return false;
      if (that instanceof getNoteSearchText_args)
        return this.equals((getNoteSearchText_args)that);
      return false;
    }

    public boolean equals(getNoteSearchText_args that) {
      if (that == null)
        return false;

      boolean this_present_authenticationToken = true && this.isSetAuthenticationToken();
      boolean that_present_authenticationToken = true && that.isSetAuthenticationToken();
      if (this_present_authenticationToken || that_present_authenticationToken) {
        if (!(this_present_authenticationToken && that_present_authenticationToken))
          return false;
        if (!this.authenticationToken.equals(that.authenticationToken))
          return false;
      }

      boolean this_present_guid = true && this.isSetGuid();
      boolean that_present_guid = true && that.isSetGuid();
      if (this_present_guid || that_present_guid) {
        if (!(this_present_guid && that_present_guid))
          return false;
        if (!this.guid.equals(that.guid))
          return false;
      }

      return true;
    }

    public int hashCode() {
      return 0;
    }

    public int compareTo(getNoteSearchText_args other) {
      if (!getClass().equals(other.getClass())) {
        return getClass().getName().compareTo(other.getClass().getName());
      }

      int lastComparison = 0;
      getNoteSearchText_args typedOther = (getNoteSearchText_args)other;

      lastComparison = Boolean.valueOf(isSetAuthenticationToken()).compareTo(isSetAuthenticationToken());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(authenticationToken, typedOther.authenticationToken);
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = Boolean.valueOf(isSetGuid()).compareTo(isSetGuid());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(guid, typedOther.guid);
      if (lastComparison != 0) {
        return lastComparison;
      }
      return 0;
    }

    public void read(TProtocol iprot) throws TException {
      TField field;
      iprot.readStructBegin();
      while (true)
      {
        field = iprot.readFieldBegin();
        if (field.type == TType.STOP) { 
          break;
        }
        _Fields fieldId = _Fields.findByThriftId(field.id);
        if (fieldId == null) {
          TProtocolUtil.skip(iprot, field.type);
        } else {
          switch (fieldId) {
            case AUTHENTICATION_TOKEN:
              if (field.type == TType.STRING) {
                this.authenticationToken = iprot.readString();
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
            case GUID:
              if (field.type == TType.STRING) {
                this.guid = iprot.readString();
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
          }
          iprot.readFieldEnd();
        }
      }
      iprot.readStructEnd();
      validate();
    }

    public void write(TProtocol oprot) throws TException {
      validate();

      oprot.writeStructBegin(STRUCT_DESC);
      if (this.authenticationToken != null) {
        oprot.writeFieldBegin(AUTHENTICATION_TOKEN_FIELD_DESC);
        oprot.writeString(this.authenticationToken);
        oprot.writeFieldEnd();
      }
      if (this.guid != null) {
        oprot.writeFieldBegin(GUID_FIELD_DESC);
        oprot.writeString(this.guid);
        oprot.writeFieldEnd();
      }
      oprot.writeFieldStop();
      oprot.writeStructEnd();
    }

    public String toString() {
      StringBuilder sb = new StringBuilder("getNoteSearchText_args(");
      boolean first = true;

      sb.append("authenticationToken:");
      if (this.authenticationToken == null) {
        sb.append("null");
      } else {
        sb.append(this.authenticationToken);
      }
      first = false;
      if (!first) sb.append(", ");
      sb.append("guid:");
      if (this.guid == null) {
        sb.append("null");
      } else {
        sb.append(this.guid);
      }
      first = false;
      sb.append(")");
      return sb.toString();
    }

    public void validate() throws TException {
      // check for required fields
    }

  }

  public static class getNoteSearchText_result implements TBase<getNoteSearchText_result._Fields>, java.io.Serializable, Cloneable, Comparable<getNoteSearchText_result>   {
    private static final TStruct STRUCT_DESC = new TStruct("getNoteSearchText_result");

    private static final TField SUCCESS_FIELD_DESC = new TField("success", TType.STRING, (short)0);
    private static final TField USER_EXCEPTION_FIELD_DESC = new TField("userException", TType.STRUCT, (short)1);
    private static final TField SYSTEM_EXCEPTION_FIELD_DESC = new TField("systemException", TType.STRUCT, (short)2);
    private static final TField NOT_FOUND_EXCEPTION_FIELD_DESC = new TField("notFoundException", TType.STRUCT, (short)3);

    private String success;
    private com.evernote.edam.error.EDAMUserException userException;
    private com.evernote.edam.error.EDAMSystemException systemException;
    private com.evernote.edam.error.EDAMNotFoundException notFoundException;

    /** The set of fields this struct contains, along with convenience methods for finding and manipulating them. */
    public enum _Fields implements TFieldIdEnum {
      SUCCESS((short)0, "success"),
      USER_EXCEPTION((short)1, "userException"),
      SYSTEM_EXCEPTION((short)2, "systemException"),
      NOT_FOUND_EXCEPTION((short)3, "notFoundException");

      private static final Map<Integer, _Fields> byId = new HashMap<Integer, _Fields>();
      private static final Map<String, _Fields> byName = new HashMap<String, _Fields>();

      static {
        for (_Fields field : EnumSet.allOf(_Fields.class)) {
          byId.put((int)field._thriftId, field);
          byName.put(field.getFieldName(), field);
        }
      }

      /**
       * Find the _Fields constant that matches fieldId, or null if its not found.
       */
      public static _Fields findByThriftId(int fieldId) {
        return byId.get(fieldId);
      }

      /**
       * Find the _Fields constant that matches fieldId, throwing an exception
       * if it is not found.
       */
      public static _Fields findByThriftIdOrThrow(int fieldId) {
        _Fields fields = findByThriftId(fieldId);
        if (fields == null) throw new IllegalArgumentException("Field " + fieldId + " doesn't exist!");
        return fields;
      }

      /**
       * Find the _Fields constant that matches name, or null if its not found.
       */
      public static _Fields findByName(String name) {
        return byName.get(name);
      }

      private final short _thriftId;
      private final String _fieldName;

      _Fields(short thriftId, String fieldName) {
        _thriftId = thriftId;
        _fieldName = fieldName;
      }

      public short getThriftFieldId() {
        return _thriftId;
      }

      public String getFieldName() {
        return _fieldName;
      }
    }

    // isset id assignments

    public static final Map<_Fields, FieldMetaData> metaDataMap = Collections.unmodifiableMap(new EnumMap<_Fields, FieldMetaData>(_Fields.class) {{
      put(_Fields.SUCCESS, new FieldMetaData("success", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.STRING)));
      put(_Fields.USER_EXCEPTION, new FieldMetaData("userException", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.STRUCT)));
      put(_Fields.SYSTEM_EXCEPTION, new FieldMetaData("systemException", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.STRUCT)));
      put(_Fields.NOT_FOUND_EXCEPTION, new FieldMetaData("notFoundException", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.STRUCT)));
    }});

    static {
      FieldMetaData.addStructMetaDataMap(getNoteSearchText_result.class, metaDataMap);
    }

    public getNoteSearchText_result() {
    }

    public getNoteSearchText_result(
      String success,
      com.evernote.edam.error.EDAMUserException userException,
      com.evernote.edam.error.EDAMSystemException systemException,
      com.evernote.edam.error.EDAMNotFoundException notFoundException)
    {
      this();
      this.success = success;
      this.userException = userException;
      this.systemException = systemException;
      this.notFoundException = notFoundException;
    }

    /**
     * Performs a deep copy on <i>other</i>.
     */
    public getNoteSearchText_result(getNoteSearchText_result other) {
      if (other.isSetSuccess()) {
        this.success = other.success;
      }
      if (other.isSetUserException()) {
        this.userException = new com.evernote.edam.error.EDAMUserException(other.userException);
      }
      if (other.isSetSystemException()) {
        this.systemException = new com.evernote.edam.error.EDAMSystemException(other.systemException);
      }
      if (other.isSetNotFoundException()) {
        this.notFoundException = new com.evernote.edam.error.EDAMNotFoundException(other.notFoundException);
      }
    }

    public getNoteSearchText_result deepCopy() {
      return new getNoteSearchText_result(this);
    }

    @Deprecated
    public getNoteSearchText_result clone() {
      return new getNoteSearchText_result(this);
    }

    public String getSuccess() {
      return this.success;
    }

    public void setSuccess(String success) {
      this.success = success;
    }

    public void unsetSuccess() {
      this.success = null;
    }

    /** Returns true if field success is set (has been asigned a value) and false otherwise */
    public boolean isSetSuccess() {
      return this.success != null;
    }

    public void setSuccessIsSet(boolean value) {
      if (!value) {
        this.success = null;
      }
    }

    public com.evernote.edam.error.EDAMUserException getUserException() {
      return this.userException;
    }

    public void setUserException(com.evernote.edam.error.EDAMUserException userException) {
      this.userException = userException;
    }

    public void unsetUserException() {
      this.userException = null;
    }

    /** Returns true if field userException is set (has been asigned a value) and false otherwise */
    public boolean isSetUserException() {
      return this.userException != null;
    }

    public void setUserExceptionIsSet(boolean value) {
      if (!value) {
        this.userException = null;
      }
    }

    public com.evernote.edam.error.EDAMSystemException getSystemException() {
      return this.systemException;
    }

    public void setSystemException(com.evernote.edam.error.EDAMSystemException systemException) {
      this.systemException = systemException;
    }

    public void unsetSystemException() {
      this.systemException = null;
    }

    /** Returns true if field systemException is set (has been asigned a value) and false otherwise */
    public boolean isSetSystemException() {
      return this.systemException != null;
    }

    public void setSystemExceptionIsSet(boolean value) {
      if (!value) {
        this.systemException = null;
      }
    }

    public com.evernote.edam.error.EDAMNotFoundException getNotFoundException() {
      return this.notFoundException;
    }

    public void setNotFoundException(com.evernote.edam.error.EDAMNotFoundException notFoundException) {
      this.notFoundException = notFoundException;
    }

    public void unsetNotFoundException() {
      this.notFoundException = null;
    }

    /** Returns true if field notFoundException is set (has been asigned a value) and false otherwise */
    public boolean isSetNotFoundException() {
      return this.notFoundException != null;
    }

    public void setNotFoundExceptionIsSet(boolean value) {
      if (!value) {
        this.notFoundException = null;
      }
    }

    public void setFieldValue(_Fields field, Object value) {
      switch (field) {
      case SUCCESS:
        if (value == null) {
          unsetSuccess();
        } else {
          setSuccess((String)value);
        }
        break;

      case USER_EXCEPTION:
        if (value == null) {
          unsetUserException();
        } else {
          setUserException((com.evernote.edam.error.EDAMUserException)value);
        }
        break;

      case SYSTEM_EXCEPTION:
        if (value == null) {
          unsetSystemException();
        } else {
          setSystemException((com.evernote.edam.error.EDAMSystemException)value);
        }
        break;

      case NOT_FOUND_EXCEPTION:
        if (value == null) {
          unsetNotFoundException();
        } else {
          setNotFoundException((com.evernote.edam.error.EDAMNotFoundException)value);
        }
        break;

      }
    }

    public void setFieldValue(int fieldID, Object value) {
      setFieldValue(_Fields.findByThriftIdOrThrow(fieldID), value);
    }

    public Object getFieldValue(_Fields field) {
      switch (field) {
      case SUCCESS:
        return getSuccess();

      case USER_EXCEPTION:
        return getUserException();

      case SYSTEM_EXCEPTION:
        return getSystemException();

      case NOT_FOUND_EXCEPTION:
        return getNotFoundException();

      }
      throw new IllegalStateException();
    }

    public Object getFieldValue(int fieldId) {
      return getFieldValue(_Fields.findByThriftIdOrThrow(fieldId));
    }

    /** Returns true if field corresponding to fieldID is set (has been asigned a value) and false otherwise */
    public boolean isSet(_Fields field) {
      switch (field) {
      case SUCCESS:
        return isSetSuccess();
      case USER_EXCEPTION:
        return isSetUserException();
      case SYSTEM_EXCEPTION:
        return isSetSystemException();
      case NOT_FOUND_EXCEPTION:
        return isSetNotFoundException();
      }
      throw new IllegalStateException();
    }

    public boolean isSet(int fieldID) {
      return isSet(_Fields.findByThriftIdOrThrow(fieldID));
    }

    public boolean equals(Object that) {
      if (that == null)
        return false;
      if (that instanceof getNoteSearchText_result)
        return this.equals((getNoteSearchText_result)that);
      return false;
    }

    public boolean equals(getNoteSearchText_result that) {
      if (that == null)
        return false;

      boolean this_present_success = true && this.isSetSuccess();
      boolean that_present_success = true && that.isSetSuccess();
      if (this_present_success || that_present_success) {
        if (!(this_present_success && that_present_success))
          return false;
        if (!this.success.equals(that.success))
          return false;
      }

      boolean this_present_userException = true && this.isSetUserException();
      boolean that_present_userException = true && that.isSetUserException();
      if (this_present_userException || that_present_userException) {
        if (!(this_present_userException && that_present_userException))
          return false;
        if (!this.userException.equals(that.userException))
          return false;
      }

      boolean this_present_systemException = true && this.isSetSystemException();
      boolean that_present_systemException = true && that.isSetSystemException();
      if (this_present_systemException || that_present_systemException) {
        if (!(this_present_systemException && that_present_systemException))
          return false;
        if (!this.systemException.equals(that.systemException))
          return false;
      }

      boolean this_present_notFoundException = true && this.isSetNotFoundException();
      boolean that_present_notFoundException = true && that.isSetNotFoundException();
      if (this_present_notFoundException || that_present_notFoundException) {
        if (!(this_present_notFoundException && that_present_notFoundException))
          return false;
        if (!this.notFoundException.equals(that.notFoundException))
          return false;
      }

      return true;
    }

    public int hashCode() {
      return 0;
    }

    public int compareTo(getNoteSearchText_result other) {
      if (!getClass().equals(other.getClass())) {
        return getClass().getName().compareTo(other.getClass().getName());
      }

      int lastComparison = 0;
      getNoteSearchText_result typedOther = (getNoteSearchText_result)other;

      lastComparison = Boolean.valueOf(isSetSuccess()).compareTo(isSetSuccess());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(success, typedOther.success);
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = Boolean.valueOf(isSetUserException()).compareTo(isSetUserException());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(userException, typedOther.userException);
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = Boolean.valueOf(isSetSystemException()).compareTo(isSetSystemException());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(systemException, typedOther.systemException);
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = Boolean.valueOf(isSetNotFoundException()).compareTo(isSetNotFoundException());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(notFoundException, typedOther.notFoundException);
      if (lastComparison != 0) {
        return lastComparison;
      }
      return 0;
    }

    public void read(TProtocol iprot) throws TException {
      TField field;
      iprot.readStructBegin();
      while (true)
      {
        field = iprot.readFieldBegin();
        if (field.type == TType.STOP) { 
          break;
        }
        _Fields fieldId = _Fields.findByThriftId(field.id);
        if (fieldId == null) {
          TProtocolUtil.skip(iprot, field.type);
        } else {
          switch (fieldId) {
            case SUCCESS:
              if (field.type == TType.STRING) {
                this.success = iprot.readString();
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
            case USER_EXCEPTION:
              if (field.type == TType.STRUCT) {
                this.userException = new com.evernote.edam.error.EDAMUserException();
                this.userException.read(iprot);
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
            case SYSTEM_EXCEPTION:
              if (field.type == TType.STRUCT) {
                this.systemException = new com.evernote.edam.error.EDAMSystemException();
                this.systemException.read(iprot);
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
            case NOT_FOUND_EXCEPTION:
              if (field.type == TType.STRUCT) {
                this.notFoundException = new com.evernote.edam.error.EDAMNotFoundException();
                this.notFoundException.read(iprot);
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
          }
          iprot.readFieldEnd();
        }
      }
      iprot.readStructEnd();
      validate();
    }

    public void write(TProtocol oprot) throws TException {
      oprot.writeStructBegin(STRUCT_DESC);

      if (this.isSetSuccess()) {
        oprot.writeFieldBegin(SUCCESS_FIELD_DESC);
        oprot.writeString(this.success);
        oprot.writeFieldEnd();
      } else if (this.isSetUserException()) {
        oprot.writeFieldBegin(USER_EXCEPTION_FIELD_DESC);
        this.userException.write(oprot);
        oprot.writeFieldEnd();
      } else if (this.isSetSystemException()) {
        oprot.writeFieldBegin(SYSTEM_EXCEPTION_FIELD_DESC);
        this.systemException.write(oprot);
        oprot.writeFieldEnd();
      } else if (this.isSetNotFoundException()) {
        oprot.writeFieldBegin(NOT_FOUND_EXCEPTION_FIELD_DESC);
        this.notFoundException.write(oprot);
        oprot.writeFieldEnd();
      }
      oprot.writeFieldStop();
      oprot.writeStructEnd();
    }

    public String toString() {
      StringBuilder sb = new StringBuilder("getNoteSearchText_result(");
      boolean first = true;

      sb.append("success:");
      if (this.success == null) {
        sb.append("null");
      } else {
        sb.append(this.success);
      }
      first = false;
      if (!first) sb.append(", ");
      sb.append("userException:");
      if (this.userException == null) {
        sb.append("null");
      } else {
        sb.append(this.userException);
      }
      first = false;
      if (!first) sb.append(", ");
      sb.append("systemException:");
      if (this.systemException == null) {
        sb.append("null");
      } else {
        sb.append(this.systemException);
      }
      first = false;
      if (!first) sb.append(", ");
      sb.append("notFoundException:");
      if (this.notFoundException == null) {
        sb.append("null");
      } else {
        sb.append(this.notFoundException);
      }
      first = false;
      sb.append(")");
      return sb.toString();
    }

    public void validate() throws TException {
      // check for required fields
    }

  }

  public static class getNoteTagNames_args implements TBase<getNoteTagNames_args._Fields>, java.io.Serializable, Cloneable, Comparable<getNoteTagNames_args>   {
    private static final TStruct STRUCT_DESC = new TStruct("getNoteTagNames_args");

    private static final TField AUTHENTICATION_TOKEN_FIELD_DESC = new TField("authenticationToken", TType.STRING, (short)1);
    private static final TField GUID_FIELD_DESC = new TField("guid", TType.STRING, (short)2);

    private String authenticationToken;
    private String guid;

    /** The set of fields this struct contains, along with convenience methods for finding and manipulating them. */
    public enum _Fields implements TFieldIdEnum {
      AUTHENTICATION_TOKEN((short)1, "authenticationToken"),
      GUID((short)2, "guid");

      private static final Map<Integer, _Fields> byId = new HashMap<Integer, _Fields>();
      private static final Map<String, _Fields> byName = new HashMap<String, _Fields>();

      static {
        for (_Fields field : EnumSet.allOf(_Fields.class)) {
          byId.put((int)field._thriftId, field);
          byName.put(field.getFieldName(), field);
        }
      }

      /**
       * Find the _Fields constant that matches fieldId, or null if its not found.
       */
      public static _Fields findByThriftId(int fieldId) {
        return byId.get(fieldId);
      }

      /**
       * Find the _Fields constant that matches fieldId, throwing an exception
       * if it is not found.
       */
      public static _Fields findByThriftIdOrThrow(int fieldId) {
        _Fields fields = findByThriftId(fieldId);
        if (fields == null) throw new IllegalArgumentException("Field " + fieldId + " doesn't exist!");
        return fields;
      }

      /**
       * Find the _Fields constant that matches name, or null if its not found.
       */
      public static _Fields findByName(String name) {
        return byName.get(name);
      }

      private final short _thriftId;
      private final String _fieldName;

      _Fields(short thriftId, String fieldName) {
        _thriftId = thriftId;
        _fieldName = fieldName;
      }

      public short getThriftFieldId() {
        return _thriftId;
      }

      public String getFieldName() {
        return _fieldName;
      }
    }

    // isset id assignments

    public static final Map<_Fields, FieldMetaData> metaDataMap = Collections.unmodifiableMap(new EnumMap<_Fields, FieldMetaData>(_Fields.class) {{
      put(_Fields.AUTHENTICATION_TOKEN, new FieldMetaData("authenticationToken", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.STRING)));
      put(_Fields.GUID, new FieldMetaData("guid", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.STRING)));
    }});

    static {
      FieldMetaData.addStructMetaDataMap(getNoteTagNames_args.class, metaDataMap);
    }

    public getNoteTagNames_args() {
    }

    public getNoteTagNames_args(
      String authenticationToken,
      String guid)
    {
      this();
      this.authenticationToken = authenticationToken;
      this.guid = guid;
    }

    /**
     * Performs a deep copy on <i>other</i>.
     */
    public getNoteTagNames_args(getNoteTagNames_args other) {
      if (other.isSetAuthenticationToken()) {
        this.authenticationToken = other.authenticationToken;
      }
      if (other.isSetGuid()) {
        this.guid = other.guid;
      }
    }

    public getNoteTagNames_args deepCopy() {
      return new getNoteTagNames_args(this);
    }

    @Deprecated
    public getNoteTagNames_args clone() {
      return new getNoteTagNames_args(this);
    }

    public String getAuthenticationToken() {
      return this.authenticationToken;
    }

    public void setAuthenticationToken(String authenticationToken) {
      this.authenticationToken = authenticationToken;
    }

    public void unsetAuthenticationToken() {
      this.authenticationToken = null;
    }

    /** Returns true if field authenticationToken is set (has been asigned a value) and false otherwise */
    public boolean isSetAuthenticationToken() {
      return this.authenticationToken != null;
    }

    public void setAuthenticationTokenIsSet(boolean value) {
      if (!value) {
        this.authenticationToken = null;
      }
    }

    public String getGuid() {
      return this.guid;
    }

    public void setGuid(String guid) {
      this.guid = guid;
    }

    public void unsetGuid() {
      this.guid = null;
    }

    /** Returns true if field guid is set (has been asigned a value) and false otherwise */
    public boolean isSetGuid() {
      return this.guid != null;
    }

    public void setGuidIsSet(boolean value) {
      if (!value) {
        this.guid = null;
      }
    }

    public void setFieldValue(_Fields field, Object value) {
      switch (field) {
      case AUTHENTICATION_TOKEN:
        if (value == null) {
          unsetAuthenticationToken();
        } else {
          setAuthenticationToken((String)value);
        }
        break;

      case GUID:
        if (value == null) {
          unsetGuid();
        } else {
          setGuid((String)value);
        }
        break;

      }
    }

    public void setFieldValue(int fieldID, Object value) {
      setFieldValue(_Fields.findByThriftIdOrThrow(fieldID), value);
    }

    public Object getFieldValue(_Fields field) {
      switch (field) {
      case AUTHENTICATION_TOKEN:
        return getAuthenticationToken();

      case GUID:
        return getGuid();

      }
      throw new IllegalStateException();
    }

    public Object getFieldValue(int fieldId) {
      return getFieldValue(_Fields.findByThriftIdOrThrow(fieldId));
    }

    /** Returns true if field corresponding to fieldID is set (has been asigned a value) and false otherwise */
    public boolean isSet(_Fields field) {
      switch (field) {
      case AUTHENTICATION_TOKEN:
        return isSetAuthenticationToken();
      case GUID:
        return isSetGuid();
      }
      throw new IllegalStateException();
    }

    public boolean isSet(int fieldID) {
      return isSet(_Fields.findByThriftIdOrThrow(fieldID));
    }

    public boolean equals(Object that) {
      if (that == null)
        return false;
      if (that instanceof getNoteTagNames_args)
        return this.equals((getNoteTagNames_args)that);
      return false;
    }

    public boolean equals(getNoteTagNames_args that) {
      if (that == null)
        return false;

      boolean this_present_authenticationToken = true && this.isSetAuthenticationToken();
      boolean that_present_authenticationToken = true && that.isSetAuthenticationToken();
      if (this_present_authenticationToken || that_present_authenticationToken) {
        if (!(this_present_authenticationToken && that_present_authenticationToken))
          return false;
        if (!this.authenticationToken.equals(that.authenticationToken))
          return false;
      }

      boolean this_present_guid = true && this.isSetGuid();
      boolean that_present_guid = true && that.isSetGuid();
      if (this_present_guid || that_present_guid) {
        if (!(this_present_guid && that_present_guid))
          return false;
        if (!this.guid.equals(that.guid))
          return false;
      }

      return true;
    }

    public int hashCode() {
      return 0;
    }

    public int compareTo(getNoteTagNames_args other) {
      if (!getClass().equals(other.getClass())) {
        return getClass().getName().compareTo(other.getClass().getName());
      }

      int lastComparison = 0;
      getNoteTagNames_args typedOther = (getNoteTagNames_args)other;

      lastComparison = Boolean.valueOf(isSetAuthenticationToken()).compareTo(isSetAuthenticationToken());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(authenticationToken, typedOther.authenticationToken);
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = Boolean.valueOf(isSetGuid()).compareTo(isSetGuid());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(guid, typedOther.guid);
      if (lastComparison != 0) {
        return lastComparison;
      }
      return 0;
    }

    public void read(TProtocol iprot) throws TException {
      TField field;
      iprot.readStructBegin();
      while (true)
      {
        field = iprot.readFieldBegin();
        if (field.type == TType.STOP) { 
          break;
        }
        _Fields fieldId = _Fields.findByThriftId(field.id);
        if (fieldId == null) {
          TProtocolUtil.skip(iprot, field.type);
        } else {
          switch (fieldId) {
            case AUTHENTICATION_TOKEN:
              if (field.type == TType.STRING) {
                this.authenticationToken = iprot.readString();
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
            case GUID:
              if (field.type == TType.STRING) {
                this.guid = iprot.readString();
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
          }
          iprot.readFieldEnd();
        }
      }
      iprot.readStructEnd();
      validate();
    }

    public void write(TProtocol oprot) throws TException {
      validate();

      oprot.writeStructBegin(STRUCT_DESC);
      if (this.authenticationToken != null) {
        oprot.writeFieldBegin(AUTHENTICATION_TOKEN_FIELD_DESC);
        oprot.writeString(this.authenticationToken);
        oprot.writeFieldEnd();
      }
      if (this.guid != null) {
        oprot.writeFieldBegin(GUID_FIELD_DESC);
        oprot.writeString(this.guid);
        oprot.writeFieldEnd();
      }
      oprot.writeFieldStop();
      oprot.writeStructEnd();
    }

    public String toString() {
      StringBuilder sb = new StringBuilder("getNoteTagNames_args(");
      boolean first = true;

      sb.append("authenticationToken:");
      if (this.authenticationToken == null) {
        sb.append("null");
      } else {
        sb.append(this.authenticationToken);
      }
      first = false;
      if (!first) sb.append(", ");
      sb.append("guid:");
      if (this.guid == null) {
        sb.append("null");
      } else {
        sb.append(this.guid);
      }
      first = false;
      sb.append(")");
      return sb.toString();
    }

    public void validate() throws TException {
      // check for required fields
    }

  }

  public static class getNoteTagNames_result implements TBase<getNoteTagNames_result._Fields>, java.io.Serializable, Cloneable, Comparable<getNoteTagNames_result>   {
    private static final TStruct STRUCT_DESC = new TStruct("getNoteTagNames_result");

    private static final TField SUCCESS_FIELD_DESC = new TField("success", TType.LIST, (short)0);
    private static final TField USER_EXCEPTION_FIELD_DESC = new TField("userException", TType.STRUCT, (short)1);
    private static final TField SYSTEM_EXCEPTION_FIELD_DESC = new TField("systemException", TType.STRUCT, (short)2);
    private static final TField NOT_FOUND_EXCEPTION_FIELD_DESC = new TField("notFoundException", TType.STRUCT, (short)3);

    private List<String> success;
    private com.evernote.edam.error.EDAMUserException userException;
    private com.evernote.edam.error.EDAMSystemException systemException;
    private com.evernote.edam.error.EDAMNotFoundException notFoundException;

    /** The set of fields this struct contains, along with convenience methods for finding and manipulating them. */
    public enum _Fields implements TFieldIdEnum {
      SUCCESS((short)0, "success"),
      USER_EXCEPTION((short)1, "userException"),
      SYSTEM_EXCEPTION((short)2, "systemException"),
      NOT_FOUND_EXCEPTION((short)3, "notFoundException");

      private static final Map<Integer, _Fields> byId = new HashMap<Integer, _Fields>();
      private static final Map<String, _Fields> byName = new HashMap<String, _Fields>();

      static {
        for (_Fields field : EnumSet.allOf(_Fields.class)) {
          byId.put((int)field._thriftId, field);
          byName.put(field.getFieldName(), field);
        }
      }

      /**
       * Find the _Fields constant that matches fieldId, or null if its not found.
       */
      public static _Fields findByThriftId(int fieldId) {
        return byId.get(fieldId);
      }

      /**
       * Find the _Fields constant that matches fieldId, throwing an exception
       * if it is not found.
       */
      public static _Fields findByThriftIdOrThrow(int fieldId) {
        _Fields fields = findByThriftId(fieldId);
        if (fields == null) throw new IllegalArgumentException("Field " + fieldId + " doesn't exist!");
        return fields;
      }

      /**
       * Find the _Fields constant that matches name, or null if its not found.
       */
      public static _Fields findByName(String name) {
        return byName.get(name);
      }

      private final short _thriftId;
      private final String _fieldName;

      _Fields(short thriftId, String fieldName) {
        _thriftId = thriftId;
        _fieldName = fieldName;
      }

      public short getThriftFieldId() {
        return _thriftId;
      }

      public String getFieldName() {
        return _fieldName;
      }
    }

    // isset id assignments

    public static final Map<_Fields, FieldMetaData> metaDataMap = Collections.unmodifiableMap(new EnumMap<_Fields, FieldMetaData>(_Fields.class) {{
      put(_Fields.SUCCESS, new FieldMetaData("success", TFieldRequirementType.DEFAULT, 
          new ListMetaData(TType.LIST, 
              new FieldValueMetaData(TType.STRING))));
      put(_Fields.USER_EXCEPTION, new FieldMetaData("userException", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.STRUCT)));
      put(_Fields.SYSTEM_EXCEPTION, new FieldMetaData("systemException", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.STRUCT)));
      put(_Fields.NOT_FOUND_EXCEPTION, new FieldMetaData("notFoundException", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.STRUCT)));
    }});

    static {
      FieldMetaData.addStructMetaDataMap(getNoteTagNames_result.class, metaDataMap);
    }

    public getNoteTagNames_result() {
    }

    public getNoteTagNames_result(
      List<String> success,
      com.evernote.edam.error.EDAMUserException userException,
      com.evernote.edam.error.EDAMSystemException systemException,
      com.evernote.edam.error.EDAMNotFoundException notFoundException)
    {
      this();
      this.success = success;
      this.userException = userException;
      this.systemException = systemException;
      this.notFoundException = notFoundException;
    }

    /**
     * Performs a deep copy on <i>other</i>.
     */
    public getNoteTagNames_result(getNoteTagNames_result other) {
      if (other.isSetSuccess()) {
        List<String> __this__success = new ArrayList<String>();
        for (String other_element : other.success) {
          __this__success.add(other_element);
        }
        this.success = __this__success;
      }
      if (other.isSetUserException()) {
        this.userException = new com.evernote.edam.error.EDAMUserException(other.userException);
      }
      if (other.isSetSystemException()) {
        this.systemException = new com.evernote.edam.error.EDAMSystemException(other.systemException);
      }
      if (other.isSetNotFoundException()) {
        this.notFoundException = new com.evernote.edam.error.EDAMNotFoundException(other.notFoundException);
      }
    }

    public getNoteTagNames_result deepCopy() {
      return new getNoteTagNames_result(this);
    }

    @Deprecated
    public getNoteTagNames_result clone() {
      return new getNoteTagNames_result(this);
    }

    public int getSuccessSize() {
      return (this.success == null) ? 0 : this.success.size();
    }

    public java.util.Iterator<String> getSuccessIterator() {
      return (this.success == null) ? null : this.success.iterator();
    }

    public void addToSuccess(String elem) {
      if (this.success == null) {
        this.success = new ArrayList<String>();
      }
      this.success.add(elem);
    }

    public List<String> getSuccess() {
      return this.success;
    }

    public void setSuccess(List<String> success) {
      this.success = success;
    }

    public void unsetSuccess() {
      this.success = null;
    }

    /** Returns true if field success is set (has been asigned a value) and false otherwise */
    public boolean isSetSuccess() {
      return this.success != null;
    }

    public void setSuccessIsSet(boolean value) {
      if (!value) {
        this.success = null;
      }
    }

    public com.evernote.edam.error.EDAMUserException getUserException() {
      return this.userException;
    }

    public void setUserException(com.evernote.edam.error.EDAMUserException userException) {
      this.userException = userException;
    }

    public void unsetUserException() {
      this.userException = null;
    }

    /** Returns true if field userException is set (has been asigned a value) and false otherwise */
    public boolean isSetUserException() {
      return this.userException != null;
    }

    public void setUserExceptionIsSet(boolean value) {
      if (!value) {
        this.userException = null;
      }
    }

    public com.evernote.edam.error.EDAMSystemException getSystemException() {
      return this.systemException;
    }

    public void setSystemException(com.evernote.edam.error.EDAMSystemException systemException) {
      this.systemException = systemException;
    }

    public void unsetSystemException() {
      this.systemException = null;
    }

    /** Returns true if field systemException is set (has been asigned a value) and false otherwise */
    public boolean isSetSystemException() {
      return this.systemException != null;
    }

    public void setSystemExceptionIsSet(boolean value) {
      if (!value) {
        this.systemException = null;
      }
    }

    public com.evernote.edam.error.EDAMNotFoundException getNotFoundException() {
      return this.notFoundException;
    }

    public void setNotFoundException(com.evernote.edam.error.EDAMNotFoundException notFoundException) {
      this.notFoundException = notFoundException;
    }

    public void unsetNotFoundException() {
      this.notFoundException = null;
    }

    /** Returns true if field notFoundException is set (has been asigned a value) and false otherwise */
    public boolean isSetNotFoundException() {
      return this.notFoundException != null;
    }

    public void setNotFoundExceptionIsSet(boolean value) {
      if (!value) {
        this.notFoundException = null;
      }
    }

    public void setFieldValue(_Fields field, Object value) {
      switch (field) {
      case SUCCESS:
        if (value == null) {
          unsetSuccess();
        } else {
          setSuccess((List<String>)value);
        }
        break;

      case USER_EXCEPTION:
        if (value == null) {
          unsetUserException();
        } else {
          setUserException((com.evernote.edam.error.EDAMUserException)value);
        }
        break;

      case SYSTEM_EXCEPTION:
        if (value == null) {
          unsetSystemException();
        } else {
          setSystemException((com.evernote.edam.error.EDAMSystemException)value);
        }
        break;

      case NOT_FOUND_EXCEPTION:
        if (value == null) {
          unsetNotFoundException();
        } else {
          setNotFoundException((com.evernote.edam.error.EDAMNotFoundException)value);
        }
        break;

      }
    }

    public void setFieldValue(int fieldID, Object value) {
      setFieldValue(_Fields.findByThriftIdOrThrow(fieldID), value);
    }

    public Object getFieldValue(_Fields field) {
      switch (field) {
      case SUCCESS:
        return getSuccess();

      case USER_EXCEPTION:
        return getUserException();

      case SYSTEM_EXCEPTION:
        return getSystemException();

      case NOT_FOUND_EXCEPTION:
        return getNotFoundException();

      }
      throw new IllegalStateException();
    }

    public Object getFieldValue(int fieldId) {
      return getFieldValue(_Fields.findByThriftIdOrThrow(fieldId));
    }

    /** Returns true if field corresponding to fieldID is set (has been asigned a value) and false otherwise */
    public boolean isSet(_Fields field) {
      switch (field) {
      case SUCCESS:
        return isSetSuccess();
      case USER_EXCEPTION:
        return isSetUserException();
      case SYSTEM_EXCEPTION:
        return isSetSystemException();
      case NOT_FOUND_EXCEPTION:
        return isSetNotFoundException();
      }
      throw new IllegalStateException();
    }

    public boolean isSet(int fieldID) {
      return isSet(_Fields.findByThriftIdOrThrow(fieldID));
    }

    public boolean equals(Object that) {
      if (that == null)
        return false;
      if (that instanceof getNoteTagNames_result)
        return this.equals((getNoteTagNames_result)that);
      return false;
    }

    public boolean equals(getNoteTagNames_result that) {
      if (that == null)
        return false;

      boolean this_present_success = true && this.isSetSuccess();
      boolean that_present_success = true && that.isSetSuccess();
      if (this_present_success || that_present_success) {
        if (!(this_present_success && that_present_success))
          return false;
        if (!this.success.equals(that.success))
          return false;
      }

      boolean this_present_userException = true && this.isSetUserException();
      boolean that_present_userException = true && that.isSetUserException();
      if (this_present_userException || that_present_userException) {
        if (!(this_present_userException && that_present_userException))
          return false;
        if (!this.userException.equals(that.userException))
          return false;
      }

      boolean this_present_systemException = true && this.isSetSystemException();
      boolean that_present_systemException = true && that.isSetSystemException();
      if (this_present_systemException || that_present_systemException) {
        if (!(this_present_systemException && that_present_systemException))
          return false;
        if (!this.systemException.equals(that.systemException))
          return false;
      }

      boolean this_present_notFoundException = true && this.isSetNotFoundException();
      boolean that_present_notFoundException = true && that.isSetNotFoundException();
      if (this_present_notFoundException || that_present_notFoundException) {
        if (!(this_present_notFoundException && that_present_notFoundException))
          return false;
        if (!this.notFoundException.equals(that.notFoundException))
          return false;
      }

      return true;
    }

    public int hashCode() {
      return 0;
    }

    public int compareTo(getNoteTagNames_result other) {
      if (!getClass().equals(other.getClass())) {
        return getClass().getName().compareTo(other.getClass().getName());
      }

      int lastComparison = 0;
      getNoteTagNames_result typedOther = (getNoteTagNames_result)other;

      lastComparison = Boolean.valueOf(isSetSuccess()).compareTo(isSetSuccess());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(success, typedOther.success);
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = Boolean.valueOf(isSetUserException()).compareTo(isSetUserException());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(userException, typedOther.userException);
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = Boolean.valueOf(isSetSystemException()).compareTo(isSetSystemException());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(systemException, typedOther.systemException);
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = Boolean.valueOf(isSetNotFoundException()).compareTo(isSetNotFoundException());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(notFoundException, typedOther.notFoundException);
      if (lastComparison != 0) {
        return lastComparison;
      }
      return 0;
    }

    public void read(TProtocol iprot) throws TException {
      TField field;
      iprot.readStructBegin();
      while (true)
      {
        field = iprot.readFieldBegin();
        if (field.type == TType.STOP) { 
          break;
        }
        _Fields fieldId = _Fields.findByThriftId(field.id);
        if (fieldId == null) {
          TProtocolUtil.skip(iprot, field.type);
        } else {
          switch (fieldId) {
            case SUCCESS:
              if (field.type == TType.LIST) {
                {
                  TList _list95 = iprot.readListBegin();
                  this.success = new ArrayList<String>(_list95.size);
                  for (int _i96 = 0; _i96 < _list95.size; ++_i96)
                  {
                    String _elem97;
                    _elem97 = iprot.readString();
                    this.success.add(_elem97);
                  }
                  iprot.readListEnd();
                }
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
            case USER_EXCEPTION:
              if (field.type == TType.STRUCT) {
                this.userException = new com.evernote.edam.error.EDAMUserException();
                this.userException.read(iprot);
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
            case SYSTEM_EXCEPTION:
              if (field.type == TType.STRUCT) {
                this.systemException = new com.evernote.edam.error.EDAMSystemException();
                this.systemException.read(iprot);
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
            case NOT_FOUND_EXCEPTION:
              if (field.type == TType.STRUCT) {
                this.notFoundException = new com.evernote.edam.error.EDAMNotFoundException();
                this.notFoundException.read(iprot);
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
          }
          iprot.readFieldEnd();
        }
      }
      iprot.readStructEnd();
      validate();
    }

    public void write(TProtocol oprot) throws TException {
      oprot.writeStructBegin(STRUCT_DESC);

      if (this.isSetSuccess()) {
        oprot.writeFieldBegin(SUCCESS_FIELD_DESC);
        {
          oprot.writeListBegin(new TList(TType.STRING, this.success.size()));
          for (String _iter98 : this.success)
          {
            oprot.writeString(_iter98);
          }
          oprot.writeListEnd();
        }
        oprot.writeFieldEnd();
      } else if (this.isSetUserException()) {
        oprot.writeFieldBegin(USER_EXCEPTION_FIELD_DESC);
        this.userException.write(oprot);
        oprot.writeFieldEnd();
      } else if (this.isSetSystemException()) {
        oprot.writeFieldBegin(SYSTEM_EXCEPTION_FIELD_DESC);
        this.systemException.write(oprot);
        oprot.writeFieldEnd();
      } else if (this.isSetNotFoundException()) {
        oprot.writeFieldBegin(NOT_FOUND_EXCEPTION_FIELD_DESC);
        this.notFoundException.write(oprot);
        oprot.writeFieldEnd();
      }
      oprot.writeFieldStop();
      oprot.writeStructEnd();
    }

    public String toString() {
      StringBuilder sb = new StringBuilder("getNoteTagNames_result(");
      boolean first = true;

      sb.append("success:");
      if (this.success == null) {
        sb.append("null");
      } else {
        sb.append(this.success);
      }
      first = false;
      if (!first) sb.append(", ");
      sb.append("userException:");
      if (this.userException == null) {
        sb.append("null");
      } else {
        sb.append(this.userException);
      }
      first = false;
      if (!first) sb.append(", ");
      sb.append("systemException:");
      if (this.systemException == null) {
        sb.append("null");
      } else {
        sb.append(this.systemException);
      }
      first = false;
      if (!first) sb.append(", ");
      sb.append("notFoundException:");
      if (this.notFoundException == null) {
        sb.append("null");
      } else {
        sb.append(this.notFoundException);
      }
      first = false;
      sb.append(")");
      return sb.toString();
    }

    public void validate() throws TException {
      // check for required fields
    }

  }

  public static class createNote_args implements TBase<createNote_args._Fields>, java.io.Serializable, Cloneable, Comparable<createNote_args>   {
    private static final TStruct STRUCT_DESC = new TStruct("createNote_args");

    private static final TField AUTHENTICATION_TOKEN_FIELD_DESC = new TField("authenticationToken", TType.STRING, (short)1);
    private static final TField NOTE_FIELD_DESC = new TField("note", TType.STRUCT, (short)2);

    private String authenticationToken;
    private com.evernote.edam.type.Note note;

    /** The set of fields this struct contains, along with convenience methods for finding and manipulating them. */
    public enum _Fields implements TFieldIdEnum {
      AUTHENTICATION_TOKEN((short)1, "authenticationToken"),
      NOTE((short)2, "note");

      private static final Map<Integer, _Fields> byId = new HashMap<Integer, _Fields>();
      private static final Map<String, _Fields> byName = new HashMap<String, _Fields>();

      static {
        for (_Fields field : EnumSet.allOf(_Fields.class)) {
          byId.put((int)field._thriftId, field);
          byName.put(field.getFieldName(), field);
        }
      }

      /**
       * Find the _Fields constant that matches fieldId, or null if its not found.
       */
      public static _Fields findByThriftId(int fieldId) {
        return byId.get(fieldId);
      }

      /**
       * Find the _Fields constant that matches fieldId, throwing an exception
       * if it is not found.
       */
      public static _Fields findByThriftIdOrThrow(int fieldId) {
        _Fields fields = findByThriftId(fieldId);
        if (fields == null) throw new IllegalArgumentException("Field " + fieldId + " doesn't exist!");
        return fields;
      }

      /**
       * Find the _Fields constant that matches name, or null if its not found.
       */
      public static _Fields findByName(String name) {
        return byName.get(name);
      }

      private final short _thriftId;
      private final String _fieldName;

      _Fields(short thriftId, String fieldName) {
        _thriftId = thriftId;
        _fieldName = fieldName;
      }

      public short getThriftFieldId() {
        return _thriftId;
      }

      public String getFieldName() {
        return _fieldName;
      }
    }

    // isset id assignments

    public static final Map<_Fields, FieldMetaData> metaDataMap = Collections.unmodifiableMap(new EnumMap<_Fields, FieldMetaData>(_Fields.class) {{
      put(_Fields.AUTHENTICATION_TOKEN, new FieldMetaData("authenticationToken", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.STRING)));
      put(_Fields.NOTE, new FieldMetaData("note", TFieldRequirementType.DEFAULT, 
          new StructMetaData(TType.STRUCT, com.evernote.edam.type.Note.class)));
    }});

    static {
      FieldMetaData.addStructMetaDataMap(createNote_args.class, metaDataMap);
    }

    public createNote_args() {
    }

    public createNote_args(
      String authenticationToken,
      com.evernote.edam.type.Note note)
    {
      this();
      this.authenticationToken = authenticationToken;
      this.note = note;
    }

    /**
     * Performs a deep copy on <i>other</i>.
     */
    public createNote_args(createNote_args other) {
      if (other.isSetAuthenticationToken()) {
        this.authenticationToken = other.authenticationToken;
      }
      if (other.isSetNote()) {
        this.note = new com.evernote.edam.type.Note(other.note);
      }
    }

    public createNote_args deepCopy() {
      return new createNote_args(this);
    }

    @Deprecated
    public createNote_args clone() {
      return new createNote_args(this);
    }

    public String getAuthenticationToken() {
      return this.authenticationToken;
    }

    public void setAuthenticationToken(String authenticationToken) {
      this.authenticationToken = authenticationToken;
    }

    public void unsetAuthenticationToken() {
      this.authenticationToken = null;
    }

    /** Returns true if field authenticationToken is set (has been asigned a value) and false otherwise */
    public boolean isSetAuthenticationToken() {
      return this.authenticationToken != null;
    }

    public void setAuthenticationTokenIsSet(boolean value) {
      if (!value) {
        this.authenticationToken = null;
      }
    }

    public com.evernote.edam.type.Note getNote() {
      return this.note;
    }

    public void setNote(com.evernote.edam.type.Note note) {
      this.note = note;
    }

    public void unsetNote() {
      this.note = null;
    }

    /** Returns true if field note is set (has been asigned a value) and false otherwise */
    public boolean isSetNote() {
      return this.note != null;
    }

    public void setNoteIsSet(boolean value) {
      if (!value) {
        this.note = null;
      }
    }

    public void setFieldValue(_Fields field, Object value) {
      switch (field) {
      case AUTHENTICATION_TOKEN:
        if (value == null) {
          unsetAuthenticationToken();
        } else {
          setAuthenticationToken((String)value);
        }
        break;

      case NOTE:
        if (value == null) {
          unsetNote();
        } else {
          setNote((com.evernote.edam.type.Note)value);
        }
        break;

      }
    }

    public void setFieldValue(int fieldID, Object value) {
      setFieldValue(_Fields.findByThriftIdOrThrow(fieldID), value);
    }

    public Object getFieldValue(_Fields field) {
      switch (field) {
      case AUTHENTICATION_TOKEN:
        return getAuthenticationToken();

      case NOTE:
        return getNote();

      }
      throw new IllegalStateException();
    }

    public Object getFieldValue(int fieldId) {
      return getFieldValue(_Fields.findByThriftIdOrThrow(fieldId));
    }

    /** Returns true if field corresponding to fieldID is set (has been asigned a value) and false otherwise */
    public boolean isSet(_Fields field) {
      switch (field) {
      case AUTHENTICATION_TOKEN:
        return isSetAuthenticationToken();
      case NOTE:
        return isSetNote();
      }
      throw new IllegalStateException();
    }

    public boolean isSet(int fieldID) {
      return isSet(_Fields.findByThriftIdOrThrow(fieldID));
    }

    public boolean equals(Object that) {
      if (that == null)
        return false;
      if (that instanceof createNote_args)
        return this.equals((createNote_args)that);
      return false;
    }

    public boolean equals(createNote_args that) {
      if (that == null)
        return false;

      boolean this_present_authenticationToken = true && this.isSetAuthenticationToken();
      boolean that_present_authenticationToken = true && that.isSetAuthenticationToken();
      if (this_present_authenticationToken || that_present_authenticationToken) {
        if (!(this_present_authenticationToken && that_present_authenticationToken))
          return false;
        if (!this.authenticationToken.equals(that.authenticationToken))
          return false;
      }

      boolean this_present_note = true && this.isSetNote();
      boolean that_present_note = true && that.isSetNote();
      if (this_present_note || that_present_note) {
        if (!(this_present_note && that_present_note))
          return false;
        if (!this.note.equals(that.note))
          return false;
      }

      return true;
    }

    public int hashCode() {
      return 0;
    }

    public int compareTo(createNote_args other) {
      if (!getClass().equals(other.getClass())) {
        return getClass().getName().compareTo(other.getClass().getName());
      }

      int lastComparison = 0;
      createNote_args typedOther = (createNote_args)other;

      lastComparison = Boolean.valueOf(isSetAuthenticationToken()).compareTo(isSetAuthenticationToken());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(authenticationToken, typedOther.authenticationToken);
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = Boolean.valueOf(isSetNote()).compareTo(isSetNote());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(note, typedOther.note);
      if (lastComparison != 0) {
        return lastComparison;
      }
      return 0;
    }

    public void read(TProtocol iprot) throws TException {
      TField field;
      iprot.readStructBegin();
      while (true)
      {
        field = iprot.readFieldBegin();
        if (field.type == TType.STOP) { 
          break;
        }
        _Fields fieldId = _Fields.findByThriftId(field.id);
        if (fieldId == null) {
          TProtocolUtil.skip(iprot, field.type);
        } else {
          switch (fieldId) {
            case AUTHENTICATION_TOKEN:
              if (field.type == TType.STRING) {
                this.authenticationToken = iprot.readString();
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
            case NOTE:
              if (field.type == TType.STRUCT) {
                this.note = new com.evernote.edam.type.Note();
                this.note.read(iprot);
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
          }
          iprot.readFieldEnd();
        }
      }
      iprot.readStructEnd();
      validate();
    }

    public void write(TProtocol oprot) throws TException {
      validate();

      oprot.writeStructBegin(STRUCT_DESC);
      if (this.authenticationToken != null) {
        oprot.writeFieldBegin(AUTHENTICATION_TOKEN_FIELD_DESC);
        oprot.writeString(this.authenticationToken);
        oprot.writeFieldEnd();
      }
      if (this.note != null) {
        oprot.writeFieldBegin(NOTE_FIELD_DESC);
        this.note.write(oprot);
        oprot.writeFieldEnd();
      }
      oprot.writeFieldStop();
      oprot.writeStructEnd();
    }

    public String toString() {
      StringBuilder sb = new StringBuilder("createNote_args(");
      boolean first = true;

      sb.append("authenticationToken:");
      if (this.authenticationToken == null) {
        sb.append("null");
      } else {
        sb.append(this.authenticationToken);
      }
      first = false;
      if (!first) sb.append(", ");
      sb.append("note:");
      if (this.note == null) {
        sb.append("null");
      } else {
        sb.append(this.note);
      }
      first = false;
      sb.append(")");
      return sb.toString();
    }

    public void validate() throws TException {
      // check for required fields
    }

  }

  public static class createNote_result implements TBase<createNote_result._Fields>, java.io.Serializable, Cloneable, Comparable<createNote_result>   {
    private static final TStruct STRUCT_DESC = new TStruct("createNote_result");

    private static final TField SUCCESS_FIELD_DESC = new TField("success", TType.STRUCT, (short)0);
    private static final TField USER_EXCEPTION_FIELD_DESC = new TField("userException", TType.STRUCT, (short)1);
    private static final TField SYSTEM_EXCEPTION_FIELD_DESC = new TField("systemException", TType.STRUCT, (short)2);
    private static final TField NOT_FOUND_EXCEPTION_FIELD_DESC = new TField("notFoundException", TType.STRUCT, (short)3);

    private com.evernote.edam.type.Note success;
    private com.evernote.edam.error.EDAMUserException userException;
    private com.evernote.edam.error.EDAMSystemException systemException;
    private com.evernote.edam.error.EDAMNotFoundException notFoundException;

    /** The set of fields this struct contains, along with convenience methods for finding and manipulating them. */
    public enum _Fields implements TFieldIdEnum {
      SUCCESS((short)0, "success"),
      USER_EXCEPTION((short)1, "userException"),
      SYSTEM_EXCEPTION((short)2, "systemException"),
      NOT_FOUND_EXCEPTION((short)3, "notFoundException");

      private static final Map<Integer, _Fields> byId = new HashMap<Integer, _Fields>();
      private static final Map<String, _Fields> byName = new HashMap<String, _Fields>();

      static {
        for (_Fields field : EnumSet.allOf(_Fields.class)) {
          byId.put((int)field._thriftId, field);
          byName.put(field.getFieldName(), field);
        }
      }

      /**
       * Find the _Fields constant that matches fieldId, or null if its not found.
       */
      public static _Fields findByThriftId(int fieldId) {
        return byId.get(fieldId);
      }

      /**
       * Find the _Fields constant that matches fieldId, throwing an exception
       * if it is not found.
       */
      public static _Fields findByThriftIdOrThrow(int fieldId) {
        _Fields fields = findByThriftId(fieldId);
        if (fields == null) throw new IllegalArgumentException("Field " + fieldId + " doesn't exist!");
        return fields;
      }

      /**
       * Find the _Fields constant that matches name, or null if its not found.
       */
      public static _Fields findByName(String name) {
        return byName.get(name);
      }

      private final short _thriftId;
      private final String _fieldName;

      _Fields(short thriftId, String fieldName) {
        _thriftId = thriftId;
        _fieldName = fieldName;
      }

      public short getThriftFieldId() {
        return _thriftId;
      }

      public String getFieldName() {
        return _fieldName;
      }
    }

    // isset id assignments

    public static final Map<_Fields, FieldMetaData> metaDataMap = Collections.unmodifiableMap(new EnumMap<_Fields, FieldMetaData>(_Fields.class) {{
      put(_Fields.SUCCESS, new FieldMetaData("success", TFieldRequirementType.DEFAULT, 
          new StructMetaData(TType.STRUCT, com.evernote.edam.type.Note.class)));
      put(_Fields.USER_EXCEPTION, new FieldMetaData("userException", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.STRUCT)));
      put(_Fields.SYSTEM_EXCEPTION, new FieldMetaData("systemException", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.STRUCT)));
      put(_Fields.NOT_FOUND_EXCEPTION, new FieldMetaData("notFoundException", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.STRUCT)));
    }});

    static {
      FieldMetaData.addStructMetaDataMap(createNote_result.class, metaDataMap);
    }

    public createNote_result() {
    }

    public createNote_result(
      com.evernote.edam.type.Note success,
      com.evernote.edam.error.EDAMUserException userException,
      com.evernote.edam.error.EDAMSystemException systemException,
      com.evernote.edam.error.EDAMNotFoundException notFoundException)
    {
      this();
      this.success = success;
      this.userException = userException;
      this.systemException = systemException;
      this.notFoundException = notFoundException;
    }

    /**
     * Performs a deep copy on <i>other</i>.
     */
    public createNote_result(createNote_result other) {
      if (other.isSetSuccess()) {
        this.success = new com.evernote.edam.type.Note(other.success);
      }
      if (other.isSetUserException()) {
        this.userException = new com.evernote.edam.error.EDAMUserException(other.userException);
      }
      if (other.isSetSystemException()) {
        this.systemException = new com.evernote.edam.error.EDAMSystemException(other.systemException);
      }
      if (other.isSetNotFoundException()) {
        this.notFoundException = new com.evernote.edam.error.EDAMNotFoundException(other.notFoundException);
      }
    }

    public createNote_result deepCopy() {
      return new createNote_result(this);
    }

    @Deprecated
    public createNote_result clone() {
      return new createNote_result(this);
    }

    public com.evernote.edam.type.Note getSuccess() {
      return this.success;
    }

    public void setSuccess(com.evernote.edam.type.Note success) {
      this.success = success;
    }

    public void unsetSuccess() {
      this.success = null;
    }

    /** Returns true if field success is set (has been asigned a value) and false otherwise */
    public boolean isSetSuccess() {
      return this.success != null;
    }

    public void setSuccessIsSet(boolean value) {
      if (!value) {
        this.success = null;
      }
    }

    public com.evernote.edam.error.EDAMUserException getUserException() {
      return this.userException;
    }

    public void setUserException(com.evernote.edam.error.EDAMUserException userException) {
      this.userException = userException;
    }

    public void unsetUserException() {
      this.userException = null;
    }

    /** Returns true if field userException is set (has been asigned a value) and false otherwise */
    public boolean isSetUserException() {
      return this.userException != null;
    }

    public void setUserExceptionIsSet(boolean value) {
      if (!value) {
        this.userException = null;
      }
    }

    public com.evernote.edam.error.EDAMSystemException getSystemException() {
      return this.systemException;
    }

    public void setSystemException(com.evernote.edam.error.EDAMSystemException systemException) {
      this.systemException = systemException;
    }

    public void unsetSystemException() {
      this.systemException = null;
    }

    /** Returns true if field systemException is set (has been asigned a value) and false otherwise */
    public boolean isSetSystemException() {
      return this.systemException != null;
    }

    public void setSystemExceptionIsSet(boolean value) {
      if (!value) {
        this.systemException = null;
      }
    }

    public com.evernote.edam.error.EDAMNotFoundException getNotFoundException() {
      return this.notFoundException;
    }

    public void setNotFoundException(com.evernote.edam.error.EDAMNotFoundException notFoundException) {
      this.notFoundException = notFoundException;
    }

    public void unsetNotFoundException() {
      this.notFoundException = null;
    }

    /** Returns true if field notFoundException is set (has been asigned a value) and false otherwise */
    public boolean isSetNotFoundException() {
      return this.notFoundException != null;
    }

    public void setNotFoundExceptionIsSet(boolean value) {
      if (!value) {
        this.notFoundException = null;
      }
    }

    public void setFieldValue(_Fields field, Object value) {
      switch (field) {
      case SUCCESS:
        if (value == null) {
          unsetSuccess();
        } else {
          setSuccess((com.evernote.edam.type.Note)value);
        }
        break;

      case USER_EXCEPTION:
        if (value == null) {
          unsetUserException();
        } else {
          setUserException((com.evernote.edam.error.EDAMUserException)value);
        }
        break;

      case SYSTEM_EXCEPTION:
        if (value == null) {
          unsetSystemException();
        } else {
          setSystemException((com.evernote.edam.error.EDAMSystemException)value);
        }
        break;

      case NOT_FOUND_EXCEPTION:
        if (value == null) {
          unsetNotFoundException();
        } else {
          setNotFoundException((com.evernote.edam.error.EDAMNotFoundException)value);
        }
        break;

      }
    }

    public void setFieldValue(int fieldID, Object value) {
      setFieldValue(_Fields.findByThriftIdOrThrow(fieldID), value);
    }

    public Object getFieldValue(_Fields field) {
      switch (field) {
      case SUCCESS:
        return getSuccess();

      case USER_EXCEPTION:
        return getUserException();

      case SYSTEM_EXCEPTION:
        return getSystemException();

      case NOT_FOUND_EXCEPTION:
        return getNotFoundException();

      }
      throw new IllegalStateException();
    }

    public Object getFieldValue(int fieldId) {
      return getFieldValue(_Fields.findByThriftIdOrThrow(fieldId));
    }

    /** Returns true if field corresponding to fieldID is set (has been asigned a value) and false otherwise */
    public boolean isSet(_Fields field) {
      switch (field) {
      case SUCCESS:
        return isSetSuccess();
      case USER_EXCEPTION:
        return isSetUserException();
      case SYSTEM_EXCEPTION:
        return isSetSystemException();
      case NOT_FOUND_EXCEPTION:
        return isSetNotFoundException();
      }
      throw new IllegalStateException();
    }

    public boolean isSet(int fieldID) {
      return isSet(_Fields.findByThriftIdOrThrow(fieldID));
    }

    public boolean equals(Object that) {
      if (that == null)
        return false;
      if (that instanceof createNote_result)
        return this.equals((createNote_result)that);
      return false;
    }

    public boolean equals(createNote_result that) {
      if (that == null)
        return false;

      boolean this_present_success = true && this.isSetSuccess();
      boolean that_present_success = true && that.isSetSuccess();
      if (this_present_success || that_present_success) {
        if (!(this_present_success && that_present_success))
          return false;
        if (!this.success.equals(that.success))
          return false;
      }

      boolean this_present_userException = true && this.isSetUserException();
      boolean that_present_userException = true && that.isSetUserException();
      if (this_present_userException || that_present_userException) {
        if (!(this_present_userException && that_present_userException))
          return false;
        if (!this.userException.equals(that.userException))
          return false;
      }

      boolean this_present_systemException = true && this.isSetSystemException();
      boolean that_present_systemException = true && that.isSetSystemException();
      if (this_present_systemException || that_present_systemException) {
        if (!(this_present_systemException && that_present_systemException))
          return false;
        if (!this.systemException.equals(that.systemException))
          return false;
      }

      boolean this_present_notFoundException = true && this.isSetNotFoundException();
      boolean that_present_notFoundException = true && that.isSetNotFoundException();
      if (this_present_notFoundException || that_present_notFoundException) {
        if (!(this_present_notFoundException && that_present_notFoundException))
          return false;
        if (!this.notFoundException.equals(that.notFoundException))
          return false;
      }

      return true;
    }

    public int hashCode() {
      return 0;
    }

    public int compareTo(createNote_result other) {
      if (!getClass().equals(other.getClass())) {
        return getClass().getName().compareTo(other.getClass().getName());
      }

      int lastComparison = 0;
      createNote_result typedOther = (createNote_result)other;

      lastComparison = Boolean.valueOf(isSetSuccess()).compareTo(isSetSuccess());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(success, typedOther.success);
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = Boolean.valueOf(isSetUserException()).compareTo(isSetUserException());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(userException, typedOther.userException);
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = Boolean.valueOf(isSetSystemException()).compareTo(isSetSystemException());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(systemException, typedOther.systemException);
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = Boolean.valueOf(isSetNotFoundException()).compareTo(isSetNotFoundException());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(notFoundException, typedOther.notFoundException);
      if (lastComparison != 0) {
        return lastComparison;
      }
      return 0;
    }

    public void read(TProtocol iprot) throws TException {
      TField field;
      iprot.readStructBegin();
      while (true)
      {
        field = iprot.readFieldBegin();
        if (field.type == TType.STOP) { 
          break;
        }
        _Fields fieldId = _Fields.findByThriftId(field.id);
        if (fieldId == null) {
          TProtocolUtil.skip(iprot, field.type);
        } else {
          switch (fieldId) {
            case SUCCESS:
              if (field.type == TType.STRUCT) {
                this.success = new com.evernote.edam.type.Note();
                this.success.read(iprot);
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
            case USER_EXCEPTION:
              if (field.type == TType.STRUCT) {
                this.userException = new com.evernote.edam.error.EDAMUserException();
                this.userException.read(iprot);
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
            case SYSTEM_EXCEPTION:
              if (field.type == TType.STRUCT) {
                this.systemException = new com.evernote.edam.error.EDAMSystemException();
                this.systemException.read(iprot);
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
            case NOT_FOUND_EXCEPTION:
              if (field.type == TType.STRUCT) {
                this.notFoundException = new com.evernote.edam.error.EDAMNotFoundException();
                this.notFoundException.read(iprot);
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
          }
          iprot.readFieldEnd();
        }
      }
      iprot.readStructEnd();
      validate();
    }

    public void write(TProtocol oprot) throws TException {
      oprot.writeStructBegin(STRUCT_DESC);

      if (this.isSetSuccess()) {
        oprot.writeFieldBegin(SUCCESS_FIELD_DESC);
        this.success.write(oprot);
        oprot.writeFieldEnd();
      } else if (this.isSetUserException()) {
        oprot.writeFieldBegin(USER_EXCEPTION_FIELD_DESC);
        this.userException.write(oprot);
        oprot.writeFieldEnd();
      } else if (this.isSetSystemException()) {
        oprot.writeFieldBegin(SYSTEM_EXCEPTION_FIELD_DESC);
        this.systemException.write(oprot);
        oprot.writeFieldEnd();
      } else if (this.isSetNotFoundException()) {
        oprot.writeFieldBegin(NOT_FOUND_EXCEPTION_FIELD_DESC);
        this.notFoundException.write(oprot);
        oprot.writeFieldEnd();
      }
      oprot.writeFieldStop();
      oprot.writeStructEnd();
    }

    public String toString() {
      StringBuilder sb = new StringBuilder("createNote_result(");
      boolean first = true;

      sb.append("success:");
      if (this.success == null) {
        sb.append("null");
      } else {
        sb.append(this.success);
      }
      first = false;
      if (!first) sb.append(", ");
      sb.append("userException:");
      if (this.userException == null) {
        sb.append("null");
      } else {
        sb.append(this.userException);
      }
      first = false;
      if (!first) sb.append(", ");
      sb.append("systemException:");
      if (this.systemException == null) {
        sb.append("null");
      } else {
        sb.append(this.systemException);
      }
      first = false;
      if (!first) sb.append(", ");
      sb.append("notFoundException:");
      if (this.notFoundException == null) {
        sb.append("null");
      } else {
        sb.append(this.notFoundException);
      }
      first = false;
      sb.append(")");
      return sb.toString();
    }

    public void validate() throws TException {
      // check for required fields
    }

  }

  public static class updateNote_args implements TBase<updateNote_args._Fields>, java.io.Serializable, Cloneable, Comparable<updateNote_args>   {
    private static final TStruct STRUCT_DESC = new TStruct("updateNote_args");

    private static final TField AUTHENTICATION_TOKEN_FIELD_DESC = new TField("authenticationToken", TType.STRING, (short)1);
    private static final TField NOTE_FIELD_DESC = new TField("note", TType.STRUCT, (short)2);

    private String authenticationToken;
    private com.evernote.edam.type.Note note;

    /** The set of fields this struct contains, along with convenience methods for finding and manipulating them. */
    public enum _Fields implements TFieldIdEnum {
      AUTHENTICATION_TOKEN((short)1, "authenticationToken"),
      NOTE((short)2, "note");

      private static final Map<Integer, _Fields> byId = new HashMap<Integer, _Fields>();
      private static final Map<String, _Fields> byName = new HashMap<String, _Fields>();

      static {
        for (_Fields field : EnumSet.allOf(_Fields.class)) {
          byId.put((int)field._thriftId, field);
          byName.put(field.getFieldName(), field);
        }
      }

      /**
       * Find the _Fields constant that matches fieldId, or null if its not found.
       */
      public static _Fields findByThriftId(int fieldId) {
        return byId.get(fieldId);
      }

      /**
       * Find the _Fields constant that matches fieldId, throwing an exception
       * if it is not found.
       */
      public static _Fields findByThriftIdOrThrow(int fieldId) {
        _Fields fields = findByThriftId(fieldId);
        if (fields == null) throw new IllegalArgumentException("Field " + fieldId + " doesn't exist!");
        return fields;
      }

      /**
       * Find the _Fields constant that matches name, or null if its not found.
       */
      public static _Fields findByName(String name) {
        return byName.get(name);
      }

      private final short _thriftId;
      private final String _fieldName;

      _Fields(short thriftId, String fieldName) {
        _thriftId = thriftId;
        _fieldName = fieldName;
      }

      public short getThriftFieldId() {
        return _thriftId;
      }

      public String getFieldName() {
        return _fieldName;
      }
    }

    // isset id assignments

    public static final Map<_Fields, FieldMetaData> metaDataMap = Collections.unmodifiableMap(new EnumMap<_Fields, FieldMetaData>(_Fields.class) {{
      put(_Fields.AUTHENTICATION_TOKEN, new FieldMetaData("authenticationToken", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.STRING)));
      put(_Fields.NOTE, new FieldMetaData("note", TFieldRequirementType.DEFAULT, 
          new StructMetaData(TType.STRUCT, com.evernote.edam.type.Note.class)));
    }});

    static {
      FieldMetaData.addStructMetaDataMap(updateNote_args.class, metaDataMap);
    }

    public updateNote_args() {
    }

    public updateNote_args(
      String authenticationToken,
      com.evernote.edam.type.Note note)
    {
      this();
      this.authenticationToken = authenticationToken;
      this.note = note;
    }

    /**
     * Performs a deep copy on <i>other</i>.
     */
    public updateNote_args(updateNote_args other) {
      if (other.isSetAuthenticationToken()) {
        this.authenticationToken = other.authenticationToken;
      }
      if (other.isSetNote()) {
        this.note = new com.evernote.edam.type.Note(other.note);
      }
    }

    public updateNote_args deepCopy() {
      return new updateNote_args(this);
    }

    @Deprecated
    public updateNote_args clone() {
      return new updateNote_args(this);
    }

    public String getAuthenticationToken() {
      return this.authenticationToken;
    }

    public void setAuthenticationToken(String authenticationToken) {
      this.authenticationToken = authenticationToken;
    }

    public void unsetAuthenticationToken() {
      this.authenticationToken = null;
    }

    /** Returns true if field authenticationToken is set (has been asigned a value) and false otherwise */
    public boolean isSetAuthenticationToken() {
      return this.authenticationToken != null;
    }

    public void setAuthenticationTokenIsSet(boolean value) {
      if (!value) {
        this.authenticationToken = null;
      }
    }

    public com.evernote.edam.type.Note getNote() {
      return this.note;
    }

    public void setNote(com.evernote.edam.type.Note note) {
      this.note = note;
    }

    public void unsetNote() {
      this.note = null;
    }

    /** Returns true if field note is set (has been asigned a value) and false otherwise */
    public boolean isSetNote() {
      return this.note != null;
    }

    public void setNoteIsSet(boolean value) {
      if (!value) {
        this.note = null;
      }
    }

    public void setFieldValue(_Fields field, Object value) {
      switch (field) {
      case AUTHENTICATION_TOKEN:
        if (value == null) {
          unsetAuthenticationToken();
        } else {
          setAuthenticationToken((String)value);
        }
        break;

      case NOTE:
        if (value == null) {
          unsetNote();
        } else {
          setNote((com.evernote.edam.type.Note)value);
        }
        break;

      }
    }

    public void setFieldValue(int fieldID, Object value) {
      setFieldValue(_Fields.findByThriftIdOrThrow(fieldID), value);
    }

    public Object getFieldValue(_Fields field) {
      switch (field) {
      case AUTHENTICATION_TOKEN:
        return getAuthenticationToken();

      case NOTE:
        return getNote();

      }
      throw new IllegalStateException();
    }

    public Object getFieldValue(int fieldId) {
      return getFieldValue(_Fields.findByThriftIdOrThrow(fieldId));
    }

    /** Returns true if field corresponding to fieldID is set (has been asigned a value) and false otherwise */
    public boolean isSet(_Fields field) {
      switch (field) {
      case AUTHENTICATION_TOKEN:
        return isSetAuthenticationToken();
      case NOTE:
        return isSetNote();
      }
      throw new IllegalStateException();
    }

    public boolean isSet(int fieldID) {
      return isSet(_Fields.findByThriftIdOrThrow(fieldID));
    }

    public boolean equals(Object that) {
      if (that == null)
        return false;
      if (that instanceof updateNote_args)
        return this.equals((updateNote_args)that);
      return false;
    }

    public boolean equals(updateNote_args that) {
      if (that == null)
        return false;

      boolean this_present_authenticationToken = true && this.isSetAuthenticationToken();
      boolean that_present_authenticationToken = true && that.isSetAuthenticationToken();
      if (this_present_authenticationToken || that_present_authenticationToken) {
        if (!(this_present_authenticationToken && that_present_authenticationToken))
          return false;
        if (!this.authenticationToken.equals(that.authenticationToken))
          return false;
      }

      boolean this_present_note = true && this.isSetNote();
      boolean that_present_note = true && that.isSetNote();
      if (this_present_note || that_present_note) {
        if (!(this_present_note && that_present_note))
          return false;
        if (!this.note.equals(that.note))
          return false;
      }

      return true;
    }

    public int hashCode() {
      return 0;
    }

    public int compareTo(updateNote_args other) {
      if (!getClass().equals(other.getClass())) {
        return getClass().getName().compareTo(other.getClass().getName());
      }

      int lastComparison = 0;
      updateNote_args typedOther = (updateNote_args)other;

      lastComparison = Boolean.valueOf(isSetAuthenticationToken()).compareTo(isSetAuthenticationToken());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(authenticationToken, typedOther.authenticationToken);
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = Boolean.valueOf(isSetNote()).compareTo(isSetNote());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(note, typedOther.note);
      if (lastComparison != 0) {
        return lastComparison;
      }
      return 0;
    }

    public void read(TProtocol iprot) throws TException {
      TField field;
      iprot.readStructBegin();
      while (true)
      {
        field = iprot.readFieldBegin();
        if (field.type == TType.STOP) { 
          break;
        }
        _Fields fieldId = _Fields.findByThriftId(field.id);
        if (fieldId == null) {
          TProtocolUtil.skip(iprot, field.type);
        } else {
          switch (fieldId) {
            case AUTHENTICATION_TOKEN:
              if (field.type == TType.STRING) {
                this.authenticationToken = iprot.readString();
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
            case NOTE:
              if (field.type == TType.STRUCT) {
                this.note = new com.evernote.edam.type.Note();
                this.note.read(iprot);
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
          }
          iprot.readFieldEnd();
        }
      }
      iprot.readStructEnd();
      validate();
    }

    public void write(TProtocol oprot) throws TException {
      validate();

      oprot.writeStructBegin(STRUCT_DESC);
      if (this.authenticationToken != null) {
        oprot.writeFieldBegin(AUTHENTICATION_TOKEN_FIELD_DESC);
        oprot.writeString(this.authenticationToken);
        oprot.writeFieldEnd();
      }
      if (this.note != null) {
        oprot.writeFieldBegin(NOTE_FIELD_DESC);
        this.note.write(oprot);
        oprot.writeFieldEnd();
      }
      oprot.writeFieldStop();
      oprot.writeStructEnd();
    }

    public String toString() {
      StringBuilder sb = new StringBuilder("updateNote_args(");
      boolean first = true;

      sb.append("authenticationToken:");
      if (this.authenticationToken == null) {
        sb.append("null");
      } else {
        sb.append(this.authenticationToken);
      }
      first = false;
      if (!first) sb.append(", ");
      sb.append("note:");
      if (this.note == null) {
        sb.append("null");
      } else {
        sb.append(this.note);
      }
      first = false;
      sb.append(")");
      return sb.toString();
    }

    public void validate() throws TException {
      // check for required fields
    }

  }

  public static class updateNote_result implements TBase<updateNote_result._Fields>, java.io.Serializable, Cloneable, Comparable<updateNote_result>   {
    private static final TStruct STRUCT_DESC = new TStruct("updateNote_result");

    private static final TField SUCCESS_FIELD_DESC = new TField("success", TType.STRUCT, (short)0);
    private static final TField USER_EXCEPTION_FIELD_DESC = new TField("userException", TType.STRUCT, (short)1);
    private static final TField SYSTEM_EXCEPTION_FIELD_DESC = new TField("systemException", TType.STRUCT, (short)2);
    private static final TField NOT_FOUND_EXCEPTION_FIELD_DESC = new TField("notFoundException", TType.STRUCT, (short)3);

    private com.evernote.edam.type.Note success;
    private com.evernote.edam.error.EDAMUserException userException;
    private com.evernote.edam.error.EDAMSystemException systemException;
    private com.evernote.edam.error.EDAMNotFoundException notFoundException;

    /** The set of fields this struct contains, along with convenience methods for finding and manipulating them. */
    public enum _Fields implements TFieldIdEnum {
      SUCCESS((short)0, "success"),
      USER_EXCEPTION((short)1, "userException"),
      SYSTEM_EXCEPTION((short)2, "systemException"),
      NOT_FOUND_EXCEPTION((short)3, "notFoundException");

      private static final Map<Integer, _Fields> byId = new HashMap<Integer, _Fields>();
      private static final Map<String, _Fields> byName = new HashMap<String, _Fields>();

      static {
        for (_Fields field : EnumSet.allOf(_Fields.class)) {
          byId.put((int)field._thriftId, field);
          byName.put(field.getFieldName(), field);
        }
      }

      /**
       * Find the _Fields constant that matches fieldId, or null if its not found.
       */
      public static _Fields findByThriftId(int fieldId) {
        return byId.get(fieldId);
      }

      /**
       * Find the _Fields constant that matches fieldId, throwing an exception
       * if it is not found.
       */
      public static _Fields findByThriftIdOrThrow(int fieldId) {
        _Fields fields = findByThriftId(fieldId);
        if (fields == null) throw new IllegalArgumentException("Field " + fieldId + " doesn't exist!");
        return fields;
      }

      /**
       * Find the _Fields constant that matches name, or null if its not found.
       */
      public static _Fields findByName(String name) {
        return byName.get(name);
      }

      private final short _thriftId;
      private final String _fieldName;

      _Fields(short thriftId, String fieldName) {
        _thriftId = thriftId;
        _fieldName = fieldName;
      }

      public short getThriftFieldId() {
        return _thriftId;
      }

      public String getFieldName() {
        return _fieldName;
      }
    }

    // isset id assignments

    public static final Map<_Fields, FieldMetaData> metaDataMap = Collections.unmodifiableMap(new EnumMap<_Fields, FieldMetaData>(_Fields.class) {{
      put(_Fields.SUCCESS, new FieldMetaData("success", TFieldRequirementType.DEFAULT, 
          new StructMetaData(TType.STRUCT, com.evernote.edam.type.Note.class)));
      put(_Fields.USER_EXCEPTION, new FieldMetaData("userException", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.STRUCT)));
      put(_Fields.SYSTEM_EXCEPTION, new FieldMetaData("systemException", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.STRUCT)));
      put(_Fields.NOT_FOUND_EXCEPTION, new FieldMetaData("notFoundException", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.STRUCT)));
    }});

    static {
      FieldMetaData.addStructMetaDataMap(updateNote_result.class, metaDataMap);
    }

    public updateNote_result() {
    }

    public updateNote_result(
      com.evernote.edam.type.Note success,
      com.evernote.edam.error.EDAMUserException userException,
      com.evernote.edam.error.EDAMSystemException systemException,
      com.evernote.edam.error.EDAMNotFoundException notFoundException)
    {
      this();
      this.success = success;
      this.userException = userException;
      this.systemException = systemException;
      this.notFoundException = notFoundException;
    }

    /**
     * Performs a deep copy on <i>other</i>.
     */
    public updateNote_result(updateNote_result other) {
      if (other.isSetSuccess()) {
        this.success = new com.evernote.edam.type.Note(other.success);
      }
      if (other.isSetUserException()) {
        this.userException = new com.evernote.edam.error.EDAMUserException(other.userException);
      }
      if (other.isSetSystemException()) {
        this.systemException = new com.evernote.edam.error.EDAMSystemException(other.systemException);
      }
      if (other.isSetNotFoundException()) {
        this.notFoundException = new com.evernote.edam.error.EDAMNotFoundException(other.notFoundException);
      }
    }

    public updateNote_result deepCopy() {
      return new updateNote_result(this);
    }

    @Deprecated
    public updateNote_result clone() {
      return new updateNote_result(this);
    }

    public com.evernote.edam.type.Note getSuccess() {
      return this.success;
    }

    public void setSuccess(com.evernote.edam.type.Note success) {
      this.success = success;
    }

    public void unsetSuccess() {
      this.success = null;
    }

    /** Returns true if field success is set (has been asigned a value) and false otherwise */
    public boolean isSetSuccess() {
      return this.success != null;
    }

    public void setSuccessIsSet(boolean value) {
      if (!value) {
        this.success = null;
      }
    }

    public com.evernote.edam.error.EDAMUserException getUserException() {
      return this.userException;
    }

    public void setUserException(com.evernote.edam.error.EDAMUserException userException) {
      this.userException = userException;
    }

    public void unsetUserException() {
      this.userException = null;
    }

    /** Returns true if field userException is set (has been asigned a value) and false otherwise */
    public boolean isSetUserException() {
      return this.userException != null;
    }

    public void setUserExceptionIsSet(boolean value) {
      if (!value) {
        this.userException = null;
      }
    }

    public com.evernote.edam.error.EDAMSystemException getSystemException() {
      return this.systemException;
    }

    public void setSystemException(com.evernote.edam.error.EDAMSystemException systemException) {
      this.systemException = systemException;
    }

    public void unsetSystemException() {
      this.systemException = null;
    }

    /** Returns true if field systemException is set (has been asigned a value) and false otherwise */
    public boolean isSetSystemException() {
      return this.systemException != null;
    }

    public void setSystemExceptionIsSet(boolean value) {
      if (!value) {
        this.systemException = null;
      }
    }

    public com.evernote.edam.error.EDAMNotFoundException getNotFoundException() {
      return this.notFoundException;
    }

    public void setNotFoundException(com.evernote.edam.error.EDAMNotFoundException notFoundException) {
      this.notFoundException = notFoundException;
    }

    public void unsetNotFoundException() {
      this.notFoundException = null;
    }

    /** Returns true if field notFoundException is set (has been asigned a value) and false otherwise */
    public boolean isSetNotFoundException() {
      return this.notFoundException != null;
    }

    public void setNotFoundExceptionIsSet(boolean value) {
      if (!value) {
        this.notFoundException = null;
      }
    }

    public void setFieldValue(_Fields field, Object value) {
      switch (field) {
      case SUCCESS:
        if (value == null) {
          unsetSuccess();
        } else {
          setSuccess((com.evernote.edam.type.Note)value);
        }
        break;

      case USER_EXCEPTION:
        if (value == null) {
          unsetUserException();
        } else {
          setUserException((com.evernote.edam.error.EDAMUserException)value);
        }
        break;

      case SYSTEM_EXCEPTION:
        if (value == null) {
          unsetSystemException();
        } else {
          setSystemException((com.evernote.edam.error.EDAMSystemException)value);
        }
        break;

      case NOT_FOUND_EXCEPTION:
        if (value == null) {
          unsetNotFoundException();
        } else {
          setNotFoundException((com.evernote.edam.error.EDAMNotFoundException)value);
        }
        break;

      }
    }

    public void setFieldValue(int fieldID, Object value) {
      setFieldValue(_Fields.findByThriftIdOrThrow(fieldID), value);
    }

    public Object getFieldValue(_Fields field) {
      switch (field) {
      case SUCCESS:
        return getSuccess();

      case USER_EXCEPTION:
        return getUserException();

      case SYSTEM_EXCEPTION:
        return getSystemException();

      case NOT_FOUND_EXCEPTION:
        return getNotFoundException();

      }
      throw new IllegalStateException();
    }

    public Object getFieldValue(int fieldId) {
      return getFieldValue(_Fields.findByThriftIdOrThrow(fieldId));
    }

    /** Returns true if field corresponding to fieldID is set (has been asigned a value) and false otherwise */
    public boolean isSet(_Fields field) {
      switch (field) {
      case SUCCESS:
        return isSetSuccess();
      case USER_EXCEPTION:
        return isSetUserException();
      case SYSTEM_EXCEPTION:
        return isSetSystemException();
      case NOT_FOUND_EXCEPTION:
        return isSetNotFoundException();
      }
      throw new IllegalStateException();
    }

    public boolean isSet(int fieldID) {
      return isSet(_Fields.findByThriftIdOrThrow(fieldID));
    }

    public boolean equals(Object that) {
      if (that == null)
        return false;
      if (that instanceof updateNote_result)
        return this.equals((updateNote_result)that);
      return false;
    }

    public boolean equals(updateNote_result that) {
      if (that == null)
        return false;

      boolean this_present_success = true && this.isSetSuccess();
      boolean that_present_success = true && that.isSetSuccess();
      if (this_present_success || that_present_success) {
        if (!(this_present_success && that_present_success))
          return false;
        if (!this.success.equals(that.success))
          return false;
      }

      boolean this_present_userException = true && this.isSetUserException();
      boolean that_present_userException = true && that.isSetUserException();
      if (this_present_userException || that_present_userException) {
        if (!(this_present_userException && that_present_userException))
          return false;
        if (!this.userException.equals(that.userException))
          return false;
      }

      boolean this_present_systemException = true && this.isSetSystemException();
      boolean that_present_systemException = true && that.isSetSystemException();
      if (this_present_systemException || that_present_systemException) {
        if (!(this_present_systemException && that_present_systemException))
          return false;
        if (!this.systemException.equals(that.systemException))
          return false;
      }

      boolean this_present_notFoundException = true && this.isSetNotFoundException();
      boolean that_present_notFoundException = true && that.isSetNotFoundException();
      if (this_present_notFoundException || that_present_notFoundException) {
        if (!(this_present_notFoundException && that_present_notFoundException))
          return false;
        if (!this.notFoundException.equals(that.notFoundException))
          return false;
      }

      return true;
    }

    public int hashCode() {
      return 0;
    }

    public int compareTo(updateNote_result other) {
      if (!getClass().equals(other.getClass())) {
        return getClass().getName().compareTo(other.getClass().getName());
      }

      int lastComparison = 0;
      updateNote_result typedOther = (updateNote_result)other;

      lastComparison = Boolean.valueOf(isSetSuccess()).compareTo(isSetSuccess());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(success, typedOther.success);
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = Boolean.valueOf(isSetUserException()).compareTo(isSetUserException());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(userException, typedOther.userException);
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = Boolean.valueOf(isSetSystemException()).compareTo(isSetSystemException());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(systemException, typedOther.systemException);
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = Boolean.valueOf(isSetNotFoundException()).compareTo(isSetNotFoundException());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(notFoundException, typedOther.notFoundException);
      if (lastComparison != 0) {
        return lastComparison;
      }
      return 0;
    }

    public void read(TProtocol iprot) throws TException {
      TField field;
      iprot.readStructBegin();
      while (true)
      {
        field = iprot.readFieldBegin();
        if (field.type == TType.STOP) { 
          break;
        }
        _Fields fieldId = _Fields.findByThriftId(field.id);
        if (fieldId == null) {
          TProtocolUtil.skip(iprot, field.type);
        } else {
          switch (fieldId) {
            case SUCCESS:
              if (field.type == TType.STRUCT) {
                this.success = new com.evernote.edam.type.Note();
                this.success.read(iprot);
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
            case USER_EXCEPTION:
              if (field.type == TType.STRUCT) {
                this.userException = new com.evernote.edam.error.EDAMUserException();
                this.userException.read(iprot);
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
            case SYSTEM_EXCEPTION:
              if (field.type == TType.STRUCT) {
                this.systemException = new com.evernote.edam.error.EDAMSystemException();
                this.systemException.read(iprot);
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
            case NOT_FOUND_EXCEPTION:
              if (field.type == TType.STRUCT) {
                this.notFoundException = new com.evernote.edam.error.EDAMNotFoundException();
                this.notFoundException.read(iprot);
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
          }
          iprot.readFieldEnd();
        }
      }
      iprot.readStructEnd();
      validate();
    }

    public void write(TProtocol oprot) throws TException {
      oprot.writeStructBegin(STRUCT_DESC);

      if (this.isSetSuccess()) {
        oprot.writeFieldBegin(SUCCESS_FIELD_DESC);
        this.success.write(oprot);
        oprot.writeFieldEnd();
      } else if (this.isSetUserException()) {
        oprot.writeFieldBegin(USER_EXCEPTION_FIELD_DESC);
        this.userException.write(oprot);
        oprot.writeFieldEnd();
      } else if (this.isSetSystemException()) {
        oprot.writeFieldBegin(SYSTEM_EXCEPTION_FIELD_DESC);
        this.systemException.write(oprot);
        oprot.writeFieldEnd();
      } else if (this.isSetNotFoundException()) {
        oprot.writeFieldBegin(NOT_FOUND_EXCEPTION_FIELD_DESC);
        this.notFoundException.write(oprot);
        oprot.writeFieldEnd();
      }
      oprot.writeFieldStop();
      oprot.writeStructEnd();
    }

    public String toString() {
      StringBuilder sb = new StringBuilder("updateNote_result(");
      boolean first = true;

      sb.append("success:");
      if (this.success == null) {
        sb.append("null");
      } else {
        sb.append(this.success);
      }
      first = false;
      if (!first) sb.append(", ");
      sb.append("userException:");
      if (this.userException == null) {
        sb.append("null");
      } else {
        sb.append(this.userException);
      }
      first = false;
      if (!first) sb.append(", ");
      sb.append("systemException:");
      if (this.systemException == null) {
        sb.append("null");
      } else {
        sb.append(this.systemException);
      }
      first = false;
      if (!first) sb.append(", ");
      sb.append("notFoundException:");
      if (this.notFoundException == null) {
        sb.append("null");
      } else {
        sb.append(this.notFoundException);
      }
      first = false;
      sb.append(")");
      return sb.toString();
    }

    public void validate() throws TException {
      // check for required fields
    }

  }

  public static class deleteNote_args implements TBase<deleteNote_args._Fields>, java.io.Serializable, Cloneable, Comparable<deleteNote_args>   {
    private static final TStruct STRUCT_DESC = new TStruct("deleteNote_args");

    private static final TField AUTHENTICATION_TOKEN_FIELD_DESC = new TField("authenticationToken", TType.STRING, (short)1);
    private static final TField GUID_FIELD_DESC = new TField("guid", TType.STRING, (short)2);

    private String authenticationToken;
    private String guid;

    /** The set of fields this struct contains, along with convenience methods for finding and manipulating them. */
    public enum _Fields implements TFieldIdEnum {
      AUTHENTICATION_TOKEN((short)1, "authenticationToken"),
      GUID((short)2, "guid");

      private static final Map<Integer, _Fields> byId = new HashMap<Integer, _Fields>();
      private static final Map<String, _Fields> byName = new HashMap<String, _Fields>();

      static {
        for (_Fields field : EnumSet.allOf(_Fields.class)) {
          byId.put((int)field._thriftId, field);
          byName.put(field.getFieldName(), field);
        }
      }

      /**
       * Find the _Fields constant that matches fieldId, or null if its not found.
       */
      public static _Fields findByThriftId(int fieldId) {
        return byId.get(fieldId);
      }

      /**
       * Find the _Fields constant that matches fieldId, throwing an exception
       * if it is not found.
       */
      public static _Fields findByThriftIdOrThrow(int fieldId) {
        _Fields fields = findByThriftId(fieldId);
        if (fields == null) throw new IllegalArgumentException("Field " + fieldId + " doesn't exist!");
        return fields;
      }

      /**
       * Find the _Fields constant that matches name, or null if its not found.
       */
      public static _Fields findByName(String name) {
        return byName.get(name);
      }

      private final short _thriftId;
      private final String _fieldName;

      _Fields(short thriftId, String fieldName) {
        _thriftId = thriftId;
        _fieldName = fieldName;
      }

      public short getThriftFieldId() {
        return _thriftId;
      }

      public String getFieldName() {
        return _fieldName;
      }
    }

    // isset id assignments

    public static final Map<_Fields, FieldMetaData> metaDataMap = Collections.unmodifiableMap(new EnumMap<_Fields, FieldMetaData>(_Fields.class) {{
      put(_Fields.AUTHENTICATION_TOKEN, new FieldMetaData("authenticationToken", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.STRING)));
      put(_Fields.GUID, new FieldMetaData("guid", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.STRING)));
    }});

    static {
      FieldMetaData.addStructMetaDataMap(deleteNote_args.class, metaDataMap);
    }

    public deleteNote_args() {
    }

    public deleteNote_args(
      String authenticationToken,
      String guid)
    {
      this();
      this.authenticationToken = authenticationToken;
      this.guid = guid;
    }

    /**
     * Performs a deep copy on <i>other</i>.
     */
    public deleteNote_args(deleteNote_args other) {
      if (other.isSetAuthenticationToken()) {
        this.authenticationToken = other.authenticationToken;
      }
      if (other.isSetGuid()) {
        this.guid = other.guid;
      }
    }

    public deleteNote_args deepCopy() {
      return new deleteNote_args(this);
    }

    @Deprecated
    public deleteNote_args clone() {
      return new deleteNote_args(this);
    }

    public String getAuthenticationToken() {
      return this.authenticationToken;
    }

    public void setAuthenticationToken(String authenticationToken) {
      this.authenticationToken = authenticationToken;
    }

    public void unsetAuthenticationToken() {
      this.authenticationToken = null;
    }

    /** Returns true if field authenticationToken is set (has been asigned a value) and false otherwise */
    public boolean isSetAuthenticationToken() {
      return this.authenticationToken != null;
    }

    public void setAuthenticationTokenIsSet(boolean value) {
      if (!value) {
        this.authenticationToken = null;
      }
    }

    public String getGuid() {
      return this.guid;
    }

    public void setGuid(String guid) {
      this.guid = guid;
    }

    public void unsetGuid() {
      this.guid = null;
    }

    /** Returns true if field guid is set (has been asigned a value) and false otherwise */
    public boolean isSetGuid() {
      return this.guid != null;
    }

    public void setGuidIsSet(boolean value) {
      if (!value) {
        this.guid = null;
      }
    }

    public void setFieldValue(_Fields field, Object value) {
      switch (field) {
      case AUTHENTICATION_TOKEN:
        if (value == null) {
          unsetAuthenticationToken();
        } else {
          setAuthenticationToken((String)value);
        }
        break;

      case GUID:
        if (value == null) {
          unsetGuid();
        } else {
          setGuid((String)value);
        }
        break;

      }
    }

    public void setFieldValue(int fieldID, Object value) {
      setFieldValue(_Fields.findByThriftIdOrThrow(fieldID), value);
    }

    public Object getFieldValue(_Fields field) {
      switch (field) {
      case AUTHENTICATION_TOKEN:
        return getAuthenticationToken();

      case GUID:
        return getGuid();

      }
      throw new IllegalStateException();
    }

    public Object getFieldValue(int fieldId) {
      return getFieldValue(_Fields.findByThriftIdOrThrow(fieldId));
    }

    /** Returns true if field corresponding to fieldID is set (has been asigned a value) and false otherwise */
    public boolean isSet(_Fields field) {
      switch (field) {
      case AUTHENTICATION_TOKEN:
        return isSetAuthenticationToken();
      case GUID:
        return isSetGuid();
      }
      throw new IllegalStateException();
    }

    public boolean isSet(int fieldID) {
      return isSet(_Fields.findByThriftIdOrThrow(fieldID));
    }

    public boolean equals(Object that) {
      if (that == null)
        return false;
      if (that instanceof deleteNote_args)
        return this.equals((deleteNote_args)that);
      return false;
    }

    public boolean equals(deleteNote_args that) {
      if (that == null)
        return false;

      boolean this_present_authenticationToken = true && this.isSetAuthenticationToken();
      boolean that_present_authenticationToken = true && that.isSetAuthenticationToken();
      if (this_present_authenticationToken || that_present_authenticationToken) {
        if (!(this_present_authenticationToken && that_present_authenticationToken))
          return false;
        if (!this.authenticationToken.equals(that.authenticationToken))
          return false;
      }

      boolean this_present_guid = true && this.isSetGuid();
      boolean that_present_guid = true && that.isSetGuid();
      if (this_present_guid || that_present_guid) {
        if (!(this_present_guid && that_present_guid))
          return false;
        if (!this.guid.equals(that.guid))
          return false;
      }

      return true;
    }

    public int hashCode() {
      return 0;
    }

    public int compareTo(deleteNote_args other) {
      if (!getClass().equals(other.getClass())) {
        return getClass().getName().compareTo(other.getClass().getName());
      }

      int lastComparison = 0;
      deleteNote_args typedOther = (deleteNote_args)other;

      lastComparison = Boolean.valueOf(isSetAuthenticationToken()).compareTo(isSetAuthenticationToken());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(authenticationToken, typedOther.authenticationToken);
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = Boolean.valueOf(isSetGuid()).compareTo(isSetGuid());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(guid, typedOther.guid);
      if (lastComparison != 0) {
        return lastComparison;
      }
      return 0;
    }

    public void read(TProtocol iprot) throws TException {
      TField field;
      iprot.readStructBegin();
      while (true)
      {
        field = iprot.readFieldBegin();
        if (field.type == TType.STOP) { 
          break;
        }
        _Fields fieldId = _Fields.findByThriftId(field.id);
        if (fieldId == null) {
          TProtocolUtil.skip(iprot, field.type);
        } else {
          switch (fieldId) {
            case AUTHENTICATION_TOKEN:
              if (field.type == TType.STRING) {
                this.authenticationToken = iprot.readString();
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
            case GUID:
              if (field.type == TType.STRING) {
                this.guid = iprot.readString();
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
          }
          iprot.readFieldEnd();
        }
      }
      iprot.readStructEnd();
      validate();
    }

    public void write(TProtocol oprot) throws TException {
      validate();

      oprot.writeStructBegin(STRUCT_DESC);
      if (this.authenticationToken != null) {
        oprot.writeFieldBegin(AUTHENTICATION_TOKEN_FIELD_DESC);
        oprot.writeString(this.authenticationToken);
        oprot.writeFieldEnd();
      }
      if (this.guid != null) {
        oprot.writeFieldBegin(GUID_FIELD_DESC);
        oprot.writeString(this.guid);
        oprot.writeFieldEnd();
      }
      oprot.writeFieldStop();
      oprot.writeStructEnd();
    }

    public String toString() {
      StringBuilder sb = new StringBuilder("deleteNote_args(");
      boolean first = true;

      sb.append("authenticationToken:");
      if (this.authenticationToken == null) {
        sb.append("null");
      } else {
        sb.append(this.authenticationToken);
      }
      first = false;
      if (!first) sb.append(", ");
      sb.append("guid:");
      if (this.guid == null) {
        sb.append("null");
      } else {
        sb.append(this.guid);
      }
      first = false;
      sb.append(")");
      return sb.toString();
    }

    public void validate() throws TException {
      // check for required fields
    }

  }

  public static class deleteNote_result implements TBase<deleteNote_result._Fields>, java.io.Serializable, Cloneable, Comparable<deleteNote_result>   {
    private static final TStruct STRUCT_DESC = new TStruct("deleteNote_result");

    private static final TField SUCCESS_FIELD_DESC = new TField("success", TType.I32, (short)0);
    private static final TField USER_EXCEPTION_FIELD_DESC = new TField("userException", TType.STRUCT, (short)1);
    private static final TField SYSTEM_EXCEPTION_FIELD_DESC = new TField("systemException", TType.STRUCT, (short)2);
    private static final TField NOT_FOUND_EXCEPTION_FIELD_DESC = new TField("notFoundException", TType.STRUCT, (short)3);

    private int success;
    private com.evernote.edam.error.EDAMUserException userException;
    private com.evernote.edam.error.EDAMSystemException systemException;
    private com.evernote.edam.error.EDAMNotFoundException notFoundException;

    /** The set of fields this struct contains, along with convenience methods for finding and manipulating them. */
    public enum _Fields implements TFieldIdEnum {
      SUCCESS((short)0, "success"),
      USER_EXCEPTION((short)1, "userException"),
      SYSTEM_EXCEPTION((short)2, "systemException"),
      NOT_FOUND_EXCEPTION((short)3, "notFoundException");

      private static final Map<Integer, _Fields> byId = new HashMap<Integer, _Fields>();
      private static final Map<String, _Fields> byName = new HashMap<String, _Fields>();

      static {
        for (_Fields field : EnumSet.allOf(_Fields.class)) {
          byId.put((int)field._thriftId, field);
          byName.put(field.getFieldName(), field);
        }
      }

      /**
       * Find the _Fields constant that matches fieldId, or null if its not found.
       */
      public static _Fields findByThriftId(int fieldId) {
        return byId.get(fieldId);
      }

      /**
       * Find the _Fields constant that matches fieldId, throwing an exception
       * if it is not found.
       */
      public static _Fields findByThriftIdOrThrow(int fieldId) {
        _Fields fields = findByThriftId(fieldId);
        if (fields == null) throw new IllegalArgumentException("Field " + fieldId + " doesn't exist!");
        return fields;
      }

      /**
       * Find the _Fields constant that matches name, or null if its not found.
       */
      public static _Fields findByName(String name) {
        return byName.get(name);
      }

      private final short _thriftId;
      private final String _fieldName;

      _Fields(short thriftId, String fieldName) {
        _thriftId = thriftId;
        _fieldName = fieldName;
      }

      public short getThriftFieldId() {
        return _thriftId;
      }

      public String getFieldName() {
        return _fieldName;
      }
    }

    // isset id assignments
    private static final int __SUCCESS_ISSET_ID = 0;
    private BitSet __isset_bit_vector = new BitSet(1);

    public static final Map<_Fields, FieldMetaData> metaDataMap = Collections.unmodifiableMap(new EnumMap<_Fields, FieldMetaData>(_Fields.class) {{
      put(_Fields.SUCCESS, new FieldMetaData("success", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.I32)));
      put(_Fields.USER_EXCEPTION, new FieldMetaData("userException", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.STRUCT)));
      put(_Fields.SYSTEM_EXCEPTION, new FieldMetaData("systemException", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.STRUCT)));
      put(_Fields.NOT_FOUND_EXCEPTION, new FieldMetaData("notFoundException", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.STRUCT)));
    }});

    static {
      FieldMetaData.addStructMetaDataMap(deleteNote_result.class, metaDataMap);
    }

    public deleteNote_result() {
    }

    public deleteNote_result(
      int success,
      com.evernote.edam.error.EDAMUserException userException,
      com.evernote.edam.error.EDAMSystemException systemException,
      com.evernote.edam.error.EDAMNotFoundException notFoundException)
    {
      this();
      this.success = success;
      setSuccessIsSet(true);
      this.userException = userException;
      this.systemException = systemException;
      this.notFoundException = notFoundException;
    }

    /**
     * Performs a deep copy on <i>other</i>.
     */
    public deleteNote_result(deleteNote_result other) {
      __isset_bit_vector.clear();
      __isset_bit_vector.or(other.__isset_bit_vector);
      this.success = other.success;
      if (other.isSetUserException()) {
        this.userException = new com.evernote.edam.error.EDAMUserException(other.userException);
      }
      if (other.isSetSystemException()) {
        this.systemException = new com.evernote.edam.error.EDAMSystemException(other.systemException);
      }
      if (other.isSetNotFoundException()) {
        this.notFoundException = new com.evernote.edam.error.EDAMNotFoundException(other.notFoundException);
      }
    }

    public deleteNote_result deepCopy() {
      return new deleteNote_result(this);
    }

    @Deprecated
    public deleteNote_result clone() {
      return new deleteNote_result(this);
    }

    public int getSuccess() {
      return this.success;
    }

    public void setSuccess(int success) {
      this.success = success;
      setSuccessIsSet(true);
    }

    public void unsetSuccess() {
      __isset_bit_vector.clear(__SUCCESS_ISSET_ID);
    }

    /** Returns true if field success is set (has been asigned a value) and false otherwise */
    public boolean isSetSuccess() {
      return __isset_bit_vector.get(__SUCCESS_ISSET_ID);
    }

    public void setSuccessIsSet(boolean value) {
      __isset_bit_vector.set(__SUCCESS_ISSET_ID, value);
    }

    public com.evernote.edam.error.EDAMUserException getUserException() {
      return this.userException;
    }

    public void setUserException(com.evernote.edam.error.EDAMUserException userException) {
      this.userException = userException;
    }

    public void unsetUserException() {
      this.userException = null;
    }

    /** Returns true if field userException is set (has been asigned a value) and false otherwise */
    public boolean isSetUserException() {
      return this.userException != null;
    }

    public void setUserExceptionIsSet(boolean value) {
      if (!value) {
        this.userException = null;
      }
    }

    public com.evernote.edam.error.EDAMSystemException getSystemException() {
      return this.systemException;
    }

    public void setSystemException(com.evernote.edam.error.EDAMSystemException systemException) {
      this.systemException = systemException;
    }

    public void unsetSystemException() {
      this.systemException = null;
    }

    /** Returns true if field systemException is set (has been asigned a value) and false otherwise */
    public boolean isSetSystemException() {
      return this.systemException != null;
    }

    public void setSystemExceptionIsSet(boolean value) {
      if (!value) {
        this.systemException = null;
      }
    }

    public com.evernote.edam.error.EDAMNotFoundException getNotFoundException() {
      return this.notFoundException;
    }

    public void setNotFoundException(com.evernote.edam.error.EDAMNotFoundException notFoundException) {
      this.notFoundException = notFoundException;
    }

    public void unsetNotFoundException() {
      this.notFoundException = null;
    }

    /** Returns true if field notFoundException is set (has been asigned a value) and false otherwise */
    public boolean isSetNotFoundException() {
      return this.notFoundException != null;
    }

    public void setNotFoundExceptionIsSet(boolean value) {
      if (!value) {
        this.notFoundException = null;
      }
    }

    public void setFieldValue(_Fields field, Object value) {
      switch (field) {
      case SUCCESS:
        if (value == null) {
          unsetSuccess();
        } else {
          setSuccess((Integer)value);
        }
        break;

      case USER_EXCEPTION:
        if (value == null) {
          unsetUserException();
        } else {
          setUserException((com.evernote.edam.error.EDAMUserException)value);
        }
        break;

      case SYSTEM_EXCEPTION:
        if (value == null) {
          unsetSystemException();
        } else {
          setSystemException((com.evernote.edam.error.EDAMSystemException)value);
        }
        break;

      case NOT_FOUND_EXCEPTION:
        if (value == null) {
          unsetNotFoundException();
        } else {
          setNotFoundException((com.evernote.edam.error.EDAMNotFoundException)value);
        }
        break;

      }
    }

    public void setFieldValue(int fieldID, Object value) {
      setFieldValue(_Fields.findByThriftIdOrThrow(fieldID), value);
    }

    public Object getFieldValue(_Fields field) {
      switch (field) {
      case SUCCESS:
        return new Integer(getSuccess());

      case USER_EXCEPTION:
        return getUserException();

      case SYSTEM_EXCEPTION:
        return getSystemException();

      case NOT_FOUND_EXCEPTION:
        return getNotFoundException();

      }
      throw new IllegalStateException();
    }

    public Object getFieldValue(int fieldId) {
      return getFieldValue(_Fields.findByThriftIdOrThrow(fieldId));
    }

    /** Returns true if field corresponding to fieldID is set (has been asigned a value) and false otherwise */
    public boolean isSet(_Fields field) {
      switch (field) {
      case SUCCESS:
        return isSetSuccess();
      case USER_EXCEPTION:
        return isSetUserException();
      case SYSTEM_EXCEPTION:
        return isSetSystemException();
      case NOT_FOUND_EXCEPTION:
        return isSetNotFoundException();
      }
      throw new IllegalStateException();
    }

    public boolean isSet(int fieldID) {
      return isSet(_Fields.findByThriftIdOrThrow(fieldID));
    }

    public boolean equals(Object that) {
      if (that == null)
        return false;
      if (that instanceof deleteNote_result)
        return this.equals((deleteNote_result)that);
      return false;
    }

    public boolean equals(deleteNote_result that) {
      if (that == null)
        return false;

      boolean this_present_success = true;
      boolean that_present_success = true;
      if (this_present_success || that_present_success) {
        if (!(this_present_success && that_present_success))
          return false;
        if (this.success != that.success)
          return false;
      }

      boolean this_present_userException = true && this.isSetUserException();
      boolean that_present_userException = true && that.isSetUserException();
      if (this_present_userException || that_present_userException) {
        if (!(this_present_userException && that_present_userException))
          return false;
        if (!this.userException.equals(that.userException))
          return false;
      }

      boolean this_present_systemException = true && this.isSetSystemException();
      boolean that_present_systemException = true && that.isSetSystemException();
      if (this_present_systemException || that_present_systemException) {
        if (!(this_present_systemException && that_present_systemException))
          return false;
        if (!this.systemException.equals(that.systemException))
          return false;
      }

      boolean this_present_notFoundException = true && this.isSetNotFoundException();
      boolean that_present_notFoundException = true && that.isSetNotFoundException();
      if (this_present_notFoundException || that_present_notFoundException) {
        if (!(this_present_notFoundException && that_present_notFoundException))
          return false;
        if (!this.notFoundException.equals(that.notFoundException))
          return false;
      }

      return true;
    }

    public int hashCode() {
      return 0;
    }

    public int compareTo(deleteNote_result other) {
      if (!getClass().equals(other.getClass())) {
        return getClass().getName().compareTo(other.getClass().getName());
      }

      int lastComparison = 0;
      deleteNote_result typedOther = (deleteNote_result)other;

      lastComparison = Boolean.valueOf(isSetSuccess()).compareTo(isSetSuccess());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(success, typedOther.success);
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = Boolean.valueOf(isSetUserException()).compareTo(isSetUserException());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(userException, typedOther.userException);
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = Boolean.valueOf(isSetSystemException()).compareTo(isSetSystemException());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(systemException, typedOther.systemException);
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = Boolean.valueOf(isSetNotFoundException()).compareTo(isSetNotFoundException());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(notFoundException, typedOther.notFoundException);
      if (lastComparison != 0) {
        return lastComparison;
      }
      return 0;
    }

    public void read(TProtocol iprot) throws TException {
      TField field;
      iprot.readStructBegin();
      while (true)
      {
        field = iprot.readFieldBegin();
        if (field.type == TType.STOP) { 
          break;
        }
        _Fields fieldId = _Fields.findByThriftId(field.id);
        if (fieldId == null) {
          TProtocolUtil.skip(iprot, field.type);
        } else {
          switch (fieldId) {
            case SUCCESS:
              if (field.type == TType.I32) {
                this.success = iprot.readI32();
                setSuccessIsSet(true);
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
            case USER_EXCEPTION:
              if (field.type == TType.STRUCT) {
                this.userException = new com.evernote.edam.error.EDAMUserException();
                this.userException.read(iprot);
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
            case SYSTEM_EXCEPTION:
              if (field.type == TType.STRUCT) {
                this.systemException = new com.evernote.edam.error.EDAMSystemException();
                this.systemException.read(iprot);
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
            case NOT_FOUND_EXCEPTION:
              if (field.type == TType.STRUCT) {
                this.notFoundException = new com.evernote.edam.error.EDAMNotFoundException();
                this.notFoundException.read(iprot);
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
          }
          iprot.readFieldEnd();
        }
      }
      iprot.readStructEnd();
      validate();
    }

    public void write(TProtocol oprot) throws TException {
      oprot.writeStructBegin(STRUCT_DESC);

      if (this.isSetSuccess()) {
        oprot.writeFieldBegin(SUCCESS_FIELD_DESC);
        oprot.writeI32(this.success);
        oprot.writeFieldEnd();
      } else if (this.isSetUserException()) {
        oprot.writeFieldBegin(USER_EXCEPTION_FIELD_DESC);
        this.userException.write(oprot);
        oprot.writeFieldEnd();
      } else if (this.isSetSystemException()) {
        oprot.writeFieldBegin(SYSTEM_EXCEPTION_FIELD_DESC);
        this.systemException.write(oprot);
        oprot.writeFieldEnd();
      } else if (this.isSetNotFoundException()) {
        oprot.writeFieldBegin(NOT_FOUND_EXCEPTION_FIELD_DESC);
        this.notFoundException.write(oprot);
        oprot.writeFieldEnd();
      }
      oprot.writeFieldStop();
      oprot.writeStructEnd();
    }

    public String toString() {
      StringBuilder sb = new StringBuilder("deleteNote_result(");
      boolean first = true;

      sb.append("success:");
      sb.append(this.success);
      first = false;
      if (!first) sb.append(", ");
      sb.append("userException:");
      if (this.userException == null) {
        sb.append("null");
      } else {
        sb.append(this.userException);
      }
      first = false;
      if (!first) sb.append(", ");
      sb.append("systemException:");
      if (this.systemException == null) {
        sb.append("null");
      } else {
        sb.append(this.systemException);
      }
      first = false;
      if (!first) sb.append(", ");
      sb.append("notFoundException:");
      if (this.notFoundException == null) {
        sb.append("null");
      } else {
        sb.append(this.notFoundException);
      }
      first = false;
      sb.append(")");
      return sb.toString();
    }

    public void validate() throws TException {
      // check for required fields
    }

  }

  public static class expungeNote_args implements TBase<expungeNote_args._Fields>, java.io.Serializable, Cloneable, Comparable<expungeNote_args>   {
    private static final TStruct STRUCT_DESC = new TStruct("expungeNote_args");

    private static final TField AUTHENTICATION_TOKEN_FIELD_DESC = new TField("authenticationToken", TType.STRING, (short)1);
    private static final TField GUID_FIELD_DESC = new TField("guid", TType.STRING, (short)2);

    private String authenticationToken;
    private String guid;

    /** The set of fields this struct contains, along with convenience methods for finding and manipulating them. */
    public enum _Fields implements TFieldIdEnum {
      AUTHENTICATION_TOKEN((short)1, "authenticationToken"),
      GUID((short)2, "guid");

      private static final Map<Integer, _Fields> byId = new HashMap<Integer, _Fields>();
      private static final Map<String, _Fields> byName = new HashMap<String, _Fields>();

      static {
        for (_Fields field : EnumSet.allOf(_Fields.class)) {
          byId.put((int)field._thriftId, field);
          byName.put(field.getFieldName(), field);
        }
      }

      /**
       * Find the _Fields constant that matches fieldId, or null if its not found.
       */
      public static _Fields findByThriftId(int fieldId) {
        return byId.get(fieldId);
      }

      /**
       * Find the _Fields constant that matches fieldId, throwing an exception
       * if it is not found.
       */
      public static _Fields findByThriftIdOrThrow(int fieldId) {
        _Fields fields = findByThriftId(fieldId);
        if (fields == null) throw new IllegalArgumentException("Field " + fieldId + " doesn't exist!");
        return fields;
      }

      /**
       * Find the _Fields constant that matches name, or null if its not found.
       */
      public static _Fields findByName(String name) {
        return byName.get(name);
      }

      private final short _thriftId;
      private final String _fieldName;

      _Fields(short thriftId, String fieldName) {
        _thriftId = thriftId;
        _fieldName = fieldName;
      }

      public short getThriftFieldId() {
        return _thriftId;
      }

      public String getFieldName() {
        return _fieldName;
      }
    }

    // isset id assignments

    public static final Map<_Fields, FieldMetaData> metaDataMap = Collections.unmodifiableMap(new EnumMap<_Fields, FieldMetaData>(_Fields.class) {{
      put(_Fields.AUTHENTICATION_TOKEN, new FieldMetaData("authenticationToken", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.STRING)));
      put(_Fields.GUID, new FieldMetaData("guid", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.STRING)));
    }});

    static {
      FieldMetaData.addStructMetaDataMap(expungeNote_args.class, metaDataMap);
    }

    public expungeNote_args() {
    }

    public expungeNote_args(
      String authenticationToken,
      String guid)
    {
      this();
      this.authenticationToken = authenticationToken;
      this.guid = guid;
    }

    /**
     * Performs a deep copy on <i>other</i>.
     */
    public expungeNote_args(expungeNote_args other) {
      if (other.isSetAuthenticationToken()) {
        this.authenticationToken = other.authenticationToken;
      }
      if (other.isSetGuid()) {
        this.guid = other.guid;
      }
    }

    public expungeNote_args deepCopy() {
      return new expungeNote_args(this);
    }

    @Deprecated
    public expungeNote_args clone() {
      return new expungeNote_args(this);
    }

    public String getAuthenticationToken() {
      return this.authenticationToken;
    }

    public void setAuthenticationToken(String authenticationToken) {
      this.authenticationToken = authenticationToken;
    }

    public void unsetAuthenticationToken() {
      this.authenticationToken = null;
    }

    /** Returns true if field authenticationToken is set (has been asigned a value) and false otherwise */
    public boolean isSetAuthenticationToken() {
      return this.authenticationToken != null;
    }

    public void setAuthenticationTokenIsSet(boolean value) {
      if (!value) {
        this.authenticationToken = null;
      }
    }

    public String getGuid() {
      return this.guid;
    }

    public void setGuid(String guid) {
      this.guid = guid;
    }

    public void unsetGuid() {
      this.guid = null;
    }

    /** Returns true if field guid is set (has been asigned a value) and false otherwise */
    public boolean isSetGuid() {
      return this.guid != null;
    }

    public void setGuidIsSet(boolean value) {
      if (!value) {
        this.guid = null;
      }
    }

    public void setFieldValue(_Fields field, Object value) {
      switch (field) {
      case AUTHENTICATION_TOKEN:
        if (value == null) {
          unsetAuthenticationToken();
        } else {
          setAuthenticationToken((String)value);
        }
        break;

      case GUID:
        if (value == null) {
          unsetGuid();
        } else {
          setGuid((String)value);
        }
        break;

      }
    }

    public void setFieldValue(int fieldID, Object value) {
      setFieldValue(_Fields.findByThriftIdOrThrow(fieldID), value);
    }

    public Object getFieldValue(_Fields field) {
      switch (field) {
      case AUTHENTICATION_TOKEN:
        return getAuthenticationToken();

      case GUID:
        return getGuid();

      }
      throw new IllegalStateException();
    }

    public Object getFieldValue(int fieldId) {
      return getFieldValue(_Fields.findByThriftIdOrThrow(fieldId));
    }

    /** Returns true if field corresponding to fieldID is set (has been asigned a value) and false otherwise */
    public boolean isSet(_Fields field) {
      switch (field) {
      case AUTHENTICATION_TOKEN:
        return isSetAuthenticationToken();
      case GUID:
        return isSetGuid();
      }
      throw new IllegalStateException();
    }

    public boolean isSet(int fieldID) {
      return isSet(_Fields.findByThriftIdOrThrow(fieldID));
    }

    public boolean equals(Object that) {
      if (that == null)
        return false;
      if (that instanceof expungeNote_args)
        return this.equals((expungeNote_args)that);
      return false;
    }

    public boolean equals(expungeNote_args that) {
      if (that == null)
        return false;

      boolean this_present_authenticationToken = true && this.isSetAuthenticationToken();
      boolean that_present_authenticationToken = true && that.isSetAuthenticationToken();
      if (this_present_authenticationToken || that_present_authenticationToken) {
        if (!(this_present_authenticationToken && that_present_authenticationToken))
          return false;
        if (!this.authenticationToken.equals(that.authenticationToken))
          return false;
      }

      boolean this_present_guid = true && this.isSetGuid();
      boolean that_present_guid = true && that.isSetGuid();
      if (this_present_guid || that_present_guid) {
        if (!(this_present_guid && that_present_guid))
          return false;
        if (!this.guid.equals(that.guid))
          return false;
      }

      return true;
    }

    public int hashCode() {
      return 0;
    }

    public int compareTo(expungeNote_args other) {
      if (!getClass().equals(other.getClass())) {
        return getClass().getName().compareTo(other.getClass().getName());
      }

      int lastComparison = 0;
      expungeNote_args typedOther = (expungeNote_args)other;

      lastComparison = Boolean.valueOf(isSetAuthenticationToken()).compareTo(isSetAuthenticationToken());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(authenticationToken, typedOther.authenticationToken);
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = Boolean.valueOf(isSetGuid()).compareTo(isSetGuid());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(guid, typedOther.guid);
      if (lastComparison != 0) {
        return lastComparison;
      }
      return 0;
    }

    public void read(TProtocol iprot) throws TException {
      TField field;
      iprot.readStructBegin();
      while (true)
      {
        field = iprot.readFieldBegin();
        if (field.type == TType.STOP) { 
          break;
        }
        _Fields fieldId = _Fields.findByThriftId(field.id);
        if (fieldId == null) {
          TProtocolUtil.skip(iprot, field.type);
        } else {
          switch (fieldId) {
            case AUTHENTICATION_TOKEN:
              if (field.type == TType.STRING) {
                this.authenticationToken = iprot.readString();
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
            case GUID:
              if (field.type == TType.STRING) {
                this.guid = iprot.readString();
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
          }
          iprot.readFieldEnd();
        }
      }
      iprot.readStructEnd();
      validate();
    }

    public void write(TProtocol oprot) throws TException {
      validate();

      oprot.writeStructBegin(STRUCT_DESC);
      if (this.authenticationToken != null) {
        oprot.writeFieldBegin(AUTHENTICATION_TOKEN_FIELD_DESC);
        oprot.writeString(this.authenticationToken);
        oprot.writeFieldEnd();
      }
      if (this.guid != null) {
        oprot.writeFieldBegin(GUID_FIELD_DESC);
        oprot.writeString(this.guid);
        oprot.writeFieldEnd();
      }
      oprot.writeFieldStop();
      oprot.writeStructEnd();
    }

    public String toString() {
      StringBuilder sb = new StringBuilder("expungeNote_args(");
      boolean first = true;

      sb.append("authenticationToken:");
      if (this.authenticationToken == null) {
        sb.append("null");
      } else {
        sb.append(this.authenticationToken);
      }
      first = false;
      if (!first) sb.append(", ");
      sb.append("guid:");
      if (this.guid == null) {
        sb.append("null");
      } else {
        sb.append(this.guid);
      }
      first = false;
      sb.append(")");
      return sb.toString();
    }

    public void validate() throws TException {
      // check for required fields
    }

  }

  public static class expungeNote_result implements TBase<expungeNote_result._Fields>, java.io.Serializable, Cloneable, Comparable<expungeNote_result>   {
    private static final TStruct STRUCT_DESC = new TStruct("expungeNote_result");

    private static final TField SUCCESS_FIELD_DESC = new TField("success", TType.I32, (short)0);
    private static final TField USER_EXCEPTION_FIELD_DESC = new TField("userException", TType.STRUCT, (short)1);
    private static final TField SYSTEM_EXCEPTION_FIELD_DESC = new TField("systemException", TType.STRUCT, (short)2);
    private static final TField NOT_FOUND_EXCEPTION_FIELD_DESC = new TField("notFoundException", TType.STRUCT, (short)3);

    private int success;
    private com.evernote.edam.error.EDAMUserException userException;
    private com.evernote.edam.error.EDAMSystemException systemException;
    private com.evernote.edam.error.EDAMNotFoundException notFoundException;

    /** The set of fields this struct contains, along with convenience methods for finding and manipulating them. */
    public enum _Fields implements TFieldIdEnum {
      SUCCESS((short)0, "success"),
      USER_EXCEPTION((short)1, "userException"),
      SYSTEM_EXCEPTION((short)2, "systemException"),
      NOT_FOUND_EXCEPTION((short)3, "notFoundException");

      private static final Map<Integer, _Fields> byId = new HashMap<Integer, _Fields>();
      private static final Map<String, _Fields> byName = new HashMap<String, _Fields>();

      static {
        for (_Fields field : EnumSet.allOf(_Fields.class)) {
          byId.put((int)field._thriftId, field);
          byName.put(field.getFieldName(), field);
        }
      }

      /**
       * Find the _Fields constant that matches fieldId, or null if its not found.
       */
      public static _Fields findByThriftId(int fieldId) {
        return byId.get(fieldId);
      }

      /**
       * Find the _Fields constant that matches fieldId, throwing an exception
       * if it is not found.
       */
      public static _Fields findByThriftIdOrThrow(int fieldId) {
        _Fields fields = findByThriftId(fieldId);
        if (fields == null) throw new IllegalArgumentException("Field " + fieldId + " doesn't exist!");
        return fields;
      }

      /**
       * Find the _Fields constant that matches name, or null if its not found.
       */
      public static _Fields findByName(String name) {
        return byName.get(name);
      }

      private final short _thriftId;
      private final String _fieldName;

      _Fields(short thriftId, String fieldName) {
        _thriftId = thriftId;
        _fieldName = fieldName;
      }

      public short getThriftFieldId() {
        return _thriftId;
      }

      public String getFieldName() {
        return _fieldName;
      }
    }

    // isset id assignments
    private static final int __SUCCESS_ISSET_ID = 0;
    private BitSet __isset_bit_vector = new BitSet(1);

    public static final Map<_Fields, FieldMetaData> metaDataMap = Collections.unmodifiableMap(new EnumMap<_Fields, FieldMetaData>(_Fields.class) {{
      put(_Fields.SUCCESS, new FieldMetaData("success", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.I32)));
      put(_Fields.USER_EXCEPTION, new FieldMetaData("userException", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.STRUCT)));
      put(_Fields.SYSTEM_EXCEPTION, new FieldMetaData("systemException", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.STRUCT)));
      put(_Fields.NOT_FOUND_EXCEPTION, new FieldMetaData("notFoundException", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.STRUCT)));
    }});

    static {
      FieldMetaData.addStructMetaDataMap(expungeNote_result.class, metaDataMap);
    }

    public expungeNote_result() {
    }

    public expungeNote_result(
      int success,
      com.evernote.edam.error.EDAMUserException userException,
      com.evernote.edam.error.EDAMSystemException systemException,
      com.evernote.edam.error.EDAMNotFoundException notFoundException)
    {
      this();
      this.success = success;
      setSuccessIsSet(true);
      this.userException = userException;
      this.systemException = systemException;
      this.notFoundException = notFoundException;
    }

    /**
     * Performs a deep copy on <i>other</i>.
     */
    public expungeNote_result(expungeNote_result other) {
      __isset_bit_vector.clear();
      __isset_bit_vector.or(other.__isset_bit_vector);
      this.success = other.success;
      if (other.isSetUserException()) {
        this.userException = new com.evernote.edam.error.EDAMUserException(other.userException);
      }
      if (other.isSetSystemException()) {
        this.systemException = new com.evernote.edam.error.EDAMSystemException(other.systemException);
      }
      if (other.isSetNotFoundException()) {
        this.notFoundException = new com.evernote.edam.error.EDAMNotFoundException(other.notFoundException);
      }
    }

    public expungeNote_result deepCopy() {
      return new expungeNote_result(this);
    }

    @Deprecated
    public expungeNote_result clone() {
      return new expungeNote_result(this);
    }

    public int getSuccess() {
      return this.success;
    }

    public void setSuccess(int success) {
      this.success = success;
      setSuccessIsSet(true);
    }

    public void unsetSuccess() {
      __isset_bit_vector.clear(__SUCCESS_ISSET_ID);
    }

    /** Returns true if field success is set (has been asigned a value) and false otherwise */
    public boolean isSetSuccess() {
      return __isset_bit_vector.get(__SUCCESS_ISSET_ID);
    }

    public void setSuccessIsSet(boolean value) {
      __isset_bit_vector.set(__SUCCESS_ISSET_ID, value);
    }

    public com.evernote.edam.error.EDAMUserException getUserException() {
      return this.userException;
    }

    public void setUserException(com.evernote.edam.error.EDAMUserException userException) {
      this.userException = userException;
    }

    public void unsetUserException() {
      this.userException = null;
    }

    /** Returns true if field userException is set (has been asigned a value) and false otherwise */
    public boolean isSetUserException() {
      return this.userException != null;
    }

    public void setUserExceptionIsSet(boolean value) {
      if (!value) {
        this.userException = null;
      }
    }

    public com.evernote.edam.error.EDAMSystemException getSystemException() {
      return this.systemException;
    }

    public void setSystemException(com.evernote.edam.error.EDAMSystemException systemException) {
      this.systemException = systemException;
    }

    public void unsetSystemException() {
      this.systemException = null;
    }

    /** Returns true if field systemException is set (has been asigned a value) and false otherwise */
    public boolean isSetSystemException() {
      return this.systemException != null;
    }

    public void setSystemExceptionIsSet(boolean value) {
      if (!value) {
        this.systemException = null;
      }
    }

    public com.evernote.edam.error.EDAMNotFoundException getNotFoundException() {
      return this.notFoundException;
    }

    public void setNotFoundException(com.evernote.edam.error.EDAMNotFoundException notFoundException) {
      this.notFoundException = notFoundException;
    }

    public void unsetNotFoundException() {
      this.notFoundException = null;
    }

    /** Returns true if field notFoundException is set (has been asigned a value) and false otherwise */
    public boolean isSetNotFoundException() {
      return this.notFoundException != null;
    }

    public void setNotFoundExceptionIsSet(boolean value) {
      if (!value) {
        this.notFoundException = null;
      }
    }

    public void setFieldValue(_Fields field, Object value) {
      switch (field) {
      case SUCCESS:
        if (value == null) {
          unsetSuccess();
        } else {
          setSuccess((Integer)value);
        }
        break;

      case USER_EXCEPTION:
        if (value == null) {
          unsetUserException();
        } else {
          setUserException((com.evernote.edam.error.EDAMUserException)value);
        }
        break;

      case SYSTEM_EXCEPTION:
        if (value == null) {
          unsetSystemException();
        } else {
          setSystemException((com.evernote.edam.error.EDAMSystemException)value);
        }
        break;

      case NOT_FOUND_EXCEPTION:
        if (value == null) {
          unsetNotFoundException();
        } else {
          setNotFoundException((com.evernote.edam.error.EDAMNotFoundException)value);
        }
        break;

      }
    }

    public void setFieldValue(int fieldID, Object value) {
      setFieldValue(_Fields.findByThriftIdOrThrow(fieldID), value);
    }

    public Object getFieldValue(_Fields field) {
      switch (field) {
      case SUCCESS:
        return new Integer(getSuccess());

      case USER_EXCEPTION:
        return getUserException();

      case SYSTEM_EXCEPTION:
        return getSystemException();

      case NOT_FOUND_EXCEPTION:
        return getNotFoundException();

      }
      throw new IllegalStateException();
    }

    public Object getFieldValue(int fieldId) {
      return getFieldValue(_Fields.findByThriftIdOrThrow(fieldId));
    }

    /** Returns true if field corresponding to fieldID is set (has been asigned a value) and false otherwise */
    public boolean isSet(_Fields field) {
      switch (field) {
      case SUCCESS:
        return isSetSuccess();
      case USER_EXCEPTION:
        return isSetUserException();
      case SYSTEM_EXCEPTION:
        return isSetSystemException();
      case NOT_FOUND_EXCEPTION:
        return isSetNotFoundException();
      }
      throw new IllegalStateException();
    }

    public boolean isSet(int fieldID) {
      return isSet(_Fields.findByThriftIdOrThrow(fieldID));
    }

    public boolean equals(Object that) {
      if (that == null)
        return false;
      if (that instanceof expungeNote_result)
        return this.equals((expungeNote_result)that);
      return false;
    }

    public boolean equals(expungeNote_result that) {
      if (that == null)
        return false;

      boolean this_present_success = true;
      boolean that_present_success = true;
      if (this_present_success || that_present_success) {
        if (!(this_present_success && that_present_success))
          return false;
        if (this.success != that.success)
          return false;
      }

      boolean this_present_userException = true && this.isSetUserException();
      boolean that_present_userException = true && that.isSetUserException();
      if (this_present_userException || that_present_userException) {
        if (!(this_present_userException && that_present_userException))
          return false;
        if (!this.userException.equals(that.userException))
          return false;
      }

      boolean this_present_systemException = true && this.isSetSystemException();
      boolean that_present_systemException = true && that.isSetSystemException();
      if (this_present_systemException || that_present_systemException) {
        if (!(this_present_systemException && that_present_systemException))
          return false;
        if (!this.systemException.equals(that.systemException))
          return false;
      }

      boolean this_present_notFoundException = true && this.isSetNotFoundException();
      boolean that_present_notFoundException = true && that.isSetNotFoundException();
      if (this_present_notFoundException || that_present_notFoundException) {
        if (!(this_present_notFoundException && that_present_notFoundException))
          return false;
        if (!this.notFoundException.equals(that.notFoundException))
          return false;
      }

      return true;
    }

    public int hashCode() {
      return 0;
    }

    public int compareTo(expungeNote_result other) {
      if (!getClass().equals(other.getClass())) {
        return getClass().getName().compareTo(other.getClass().getName());
      }

      int lastComparison = 0;
      expungeNote_result typedOther = (expungeNote_result)other;

      lastComparison = Boolean.valueOf(isSetSuccess()).compareTo(isSetSuccess());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(success, typedOther.success);
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = Boolean.valueOf(isSetUserException()).compareTo(isSetUserException());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(userException, typedOther.userException);
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = Boolean.valueOf(isSetSystemException()).compareTo(isSetSystemException());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(systemException, typedOther.systemException);
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = Boolean.valueOf(isSetNotFoundException()).compareTo(isSetNotFoundException());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(notFoundException, typedOther.notFoundException);
      if (lastComparison != 0) {
        return lastComparison;
      }
      return 0;
    }

    public void read(TProtocol iprot) throws TException {
      TField field;
      iprot.readStructBegin();
      while (true)
      {
        field = iprot.readFieldBegin();
        if (field.type == TType.STOP) { 
          break;
        }
        _Fields fieldId = _Fields.findByThriftId(field.id);
        if (fieldId == null) {
          TProtocolUtil.skip(iprot, field.type);
        } else {
          switch (fieldId) {
            case SUCCESS:
              if (field.type == TType.I32) {
                this.success = iprot.readI32();
                setSuccessIsSet(true);
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
            case USER_EXCEPTION:
              if (field.type == TType.STRUCT) {
                this.userException = new com.evernote.edam.error.EDAMUserException();
                this.userException.read(iprot);
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
            case SYSTEM_EXCEPTION:
              if (field.type == TType.STRUCT) {
                this.systemException = new com.evernote.edam.error.EDAMSystemException();
                this.systemException.read(iprot);
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
            case NOT_FOUND_EXCEPTION:
              if (field.type == TType.STRUCT) {
                this.notFoundException = new com.evernote.edam.error.EDAMNotFoundException();
                this.notFoundException.read(iprot);
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
          }
          iprot.readFieldEnd();
        }
      }
      iprot.readStructEnd();
      validate();
    }

    public void write(TProtocol oprot) throws TException {
      oprot.writeStructBegin(STRUCT_DESC);

      if (this.isSetSuccess()) {
        oprot.writeFieldBegin(SUCCESS_FIELD_DESC);
        oprot.writeI32(this.success);
        oprot.writeFieldEnd();
      } else if (this.isSetUserException()) {
        oprot.writeFieldBegin(USER_EXCEPTION_FIELD_DESC);
        this.userException.write(oprot);
        oprot.writeFieldEnd();
      } else if (this.isSetSystemException()) {
        oprot.writeFieldBegin(SYSTEM_EXCEPTION_FIELD_DESC);
        this.systemException.write(oprot);
        oprot.writeFieldEnd();
      } else if (this.isSetNotFoundException()) {
        oprot.writeFieldBegin(NOT_FOUND_EXCEPTION_FIELD_DESC);
        this.notFoundException.write(oprot);
        oprot.writeFieldEnd();
      }
      oprot.writeFieldStop();
      oprot.writeStructEnd();
    }

    public String toString() {
      StringBuilder sb = new StringBuilder("expungeNote_result(");
      boolean first = true;

      sb.append("success:");
      sb.append(this.success);
      first = false;
      if (!first) sb.append(", ");
      sb.append("userException:");
      if (this.userException == null) {
        sb.append("null");
      } else {
        sb.append(this.userException);
      }
      first = false;
      if (!first) sb.append(", ");
      sb.append("systemException:");
      if (this.systemException == null) {
        sb.append("null");
      } else {
        sb.append(this.systemException);
      }
      first = false;
      if (!first) sb.append(", ");
      sb.append("notFoundException:");
      if (this.notFoundException == null) {
        sb.append("null");
      } else {
        sb.append(this.notFoundException);
      }
      first = false;
      sb.append(")");
      return sb.toString();
    }

    public void validate() throws TException {
      // check for required fields
    }

  }

  public static class expungeNotes_args implements TBase<expungeNotes_args._Fields>, java.io.Serializable, Cloneable, Comparable<expungeNotes_args>   {
    private static final TStruct STRUCT_DESC = new TStruct("expungeNotes_args");

    private static final TField AUTHENTICATION_TOKEN_FIELD_DESC = new TField("authenticationToken", TType.STRING, (short)1);
    private static final TField NOTE_GUIDS_FIELD_DESC = new TField("noteGuids", TType.LIST, (short)2);

    private String authenticationToken;
    private List<String> noteGuids;

    /** The set of fields this struct contains, along with convenience methods for finding and manipulating them. */
    public enum _Fields implements TFieldIdEnum {
      AUTHENTICATION_TOKEN((short)1, "authenticationToken"),
      NOTE_GUIDS((short)2, "noteGuids");

      private static final Map<Integer, _Fields> byId = new HashMap<Integer, _Fields>();
      private static final Map<String, _Fields> byName = new HashMap<String, _Fields>();

      static {
        for (_Fields field : EnumSet.allOf(_Fields.class)) {
          byId.put((int)field._thriftId, field);
          byName.put(field.getFieldName(), field);
        }
      }

      /**
       * Find the _Fields constant that matches fieldId, or null if its not found.
       */
      public static _Fields findByThriftId(int fieldId) {
        return byId.get(fieldId);
      }

      /**
       * Find the _Fields constant that matches fieldId, throwing an exception
       * if it is not found.
       */
      public static _Fields findByThriftIdOrThrow(int fieldId) {
        _Fields fields = findByThriftId(fieldId);
        if (fields == null) throw new IllegalArgumentException("Field " + fieldId + " doesn't exist!");
        return fields;
      }

      /**
       * Find the _Fields constant that matches name, or null if its not found.
       */
      public static _Fields findByName(String name) {
        return byName.get(name);
      }

      private final short _thriftId;
      private final String _fieldName;

      _Fields(short thriftId, String fieldName) {
        _thriftId = thriftId;
        _fieldName = fieldName;
      }

      public short getThriftFieldId() {
        return _thriftId;
      }

      public String getFieldName() {
        return _fieldName;
      }
    }

    // isset id assignments

    public static final Map<_Fields, FieldMetaData> metaDataMap = Collections.unmodifiableMap(new EnumMap<_Fields, FieldMetaData>(_Fields.class) {{
      put(_Fields.AUTHENTICATION_TOKEN, new FieldMetaData("authenticationToken", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.STRING)));
      put(_Fields.NOTE_GUIDS, new FieldMetaData("noteGuids", TFieldRequirementType.DEFAULT, 
          new ListMetaData(TType.LIST, 
              new FieldValueMetaData(TType.STRING))));
    }});

    static {
      FieldMetaData.addStructMetaDataMap(expungeNotes_args.class, metaDataMap);
    }

    public expungeNotes_args() {
    }

    public expungeNotes_args(
      String authenticationToken,
      List<String> noteGuids)
    {
      this();
      this.authenticationToken = authenticationToken;
      this.noteGuids = noteGuids;
    }

    /**
     * Performs a deep copy on <i>other</i>.
     */
    public expungeNotes_args(expungeNotes_args other) {
      if (other.isSetAuthenticationToken()) {
        this.authenticationToken = other.authenticationToken;
      }
      if (other.isSetNoteGuids()) {
        List<String> __this__noteGuids = new ArrayList<String>();
        for (String other_element : other.noteGuids) {
          __this__noteGuids.add(other_element);
        }
        this.noteGuids = __this__noteGuids;
      }
    }

    public expungeNotes_args deepCopy() {
      return new expungeNotes_args(this);
    }

    @Deprecated
    public expungeNotes_args clone() {
      return new expungeNotes_args(this);
    }

    public String getAuthenticationToken() {
      return this.authenticationToken;
    }

    public void setAuthenticationToken(String authenticationToken) {
      this.authenticationToken = authenticationToken;
    }

    public void unsetAuthenticationToken() {
      this.authenticationToken = null;
    }

    /** Returns true if field authenticationToken is set (has been asigned a value) and false otherwise */
    public boolean isSetAuthenticationToken() {
      return this.authenticationToken != null;
    }

    public void setAuthenticationTokenIsSet(boolean value) {
      if (!value) {
        this.authenticationToken = null;
      }
    }

    public int getNoteGuidsSize() {
      return (this.noteGuids == null) ? 0 : this.noteGuids.size();
    }

    public java.util.Iterator<String> getNoteGuidsIterator() {
      return (this.noteGuids == null) ? null : this.noteGuids.iterator();
    }

    public void addToNoteGuids(String elem) {
      if (this.noteGuids == null) {
        this.noteGuids = new ArrayList<String>();
      }
      this.noteGuids.add(elem);
    }

    public List<String> getNoteGuids() {
      return this.noteGuids;
    }

    public void setNoteGuids(List<String> noteGuids) {
      this.noteGuids = noteGuids;
    }

    public void unsetNoteGuids() {
      this.noteGuids = null;
    }

    /** Returns true if field noteGuids is set (has been asigned a value) and false otherwise */
    public boolean isSetNoteGuids() {
      return this.noteGuids != null;
    }

    public void setNoteGuidsIsSet(boolean value) {
      if (!value) {
        this.noteGuids = null;
      }
    }

    public void setFieldValue(_Fields field, Object value) {
      switch (field) {
      case AUTHENTICATION_TOKEN:
        if (value == null) {
          unsetAuthenticationToken();
        } else {
          setAuthenticationToken((String)value);
        }
        break;

      case NOTE_GUIDS:
        if (value == null) {
          unsetNoteGuids();
        } else {
          setNoteGuids((List<String>)value);
        }
        break;

      }
    }

    public void setFieldValue(int fieldID, Object value) {
      setFieldValue(_Fields.findByThriftIdOrThrow(fieldID), value);
    }

    public Object getFieldValue(_Fields field) {
      switch (field) {
      case AUTHENTICATION_TOKEN:
        return getAuthenticationToken();

      case NOTE_GUIDS:
        return getNoteGuids();

      }
      throw new IllegalStateException();
    }

    public Object getFieldValue(int fieldId) {
      return getFieldValue(_Fields.findByThriftIdOrThrow(fieldId));
    }

    /** Returns true if field corresponding to fieldID is set (has been asigned a value) and false otherwise */
    public boolean isSet(_Fields field) {
      switch (field) {
      case AUTHENTICATION_TOKEN:
        return isSetAuthenticationToken();
      case NOTE_GUIDS:
        return isSetNoteGuids();
      }
      throw new IllegalStateException();
    }

    public boolean isSet(int fieldID) {
      return isSet(_Fields.findByThriftIdOrThrow(fieldID));
    }

    public boolean equals(Object that) {
      if (that == null)
        return false;
      if (that instanceof expungeNotes_args)
        return this.equals((expungeNotes_args)that);
      return false;
    }

    public boolean equals(expungeNotes_args that) {
      if (that == null)
        return false;

      boolean this_present_authenticationToken = true && this.isSetAuthenticationToken();
      boolean that_present_authenticationToken = true && that.isSetAuthenticationToken();
      if (this_present_authenticationToken || that_present_authenticationToken) {
        if (!(this_present_authenticationToken && that_present_authenticationToken))
          return false;
        if (!this.authenticationToken.equals(that.authenticationToken))
          return false;
      }

      boolean this_present_noteGuids = true && this.isSetNoteGuids();
      boolean that_present_noteGuids = true && that.isSetNoteGuids();
      if (this_present_noteGuids || that_present_noteGuids) {
        if (!(this_present_noteGuids && that_present_noteGuids))
          return false;
        if (!this.noteGuids.equals(that.noteGuids))
          return false;
      }

      return true;
    }

    public int hashCode() {
      return 0;
    }

    public int compareTo(expungeNotes_args other) {
      if (!getClass().equals(other.getClass())) {
        return getClass().getName().compareTo(other.getClass().getName());
      }

      int lastComparison = 0;
      expungeNotes_args typedOther = (expungeNotes_args)other;

      lastComparison = Boolean.valueOf(isSetAuthenticationToken()).compareTo(isSetAuthenticationToken());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(authenticationToken, typedOther.authenticationToken);
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = Boolean.valueOf(isSetNoteGuids()).compareTo(isSetNoteGuids());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(noteGuids, typedOther.noteGuids);
      if (lastComparison != 0) {
        return lastComparison;
      }
      return 0;
    }

    public void read(TProtocol iprot) throws TException {
      TField field;
      iprot.readStructBegin();
      while (true)
      {
        field = iprot.readFieldBegin();
        if (field.type == TType.STOP) { 
          break;
        }
        _Fields fieldId = _Fields.findByThriftId(field.id);
        if (fieldId == null) {
          TProtocolUtil.skip(iprot, field.type);
        } else {
          switch (fieldId) {
            case AUTHENTICATION_TOKEN:
              if (field.type == TType.STRING) {
                this.authenticationToken = iprot.readString();
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
            case NOTE_GUIDS:
              if (field.type == TType.LIST) {
                {
                  TList _list99 = iprot.readListBegin();
                  this.noteGuids = new ArrayList<String>(_list99.size);
                  for (int _i100 = 0; _i100 < _list99.size; ++_i100)
                  {
                    String _elem101;
                    _elem101 = iprot.readString();
                    this.noteGuids.add(_elem101);
                  }
                  iprot.readListEnd();
                }
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
          }
          iprot.readFieldEnd();
        }
      }
      iprot.readStructEnd();
      validate();
    }

    public void write(TProtocol oprot) throws TException {
      validate();

      oprot.writeStructBegin(STRUCT_DESC);
      if (this.authenticationToken != null) {
        oprot.writeFieldBegin(AUTHENTICATION_TOKEN_FIELD_DESC);
        oprot.writeString(this.authenticationToken);
        oprot.writeFieldEnd();
      }
      if (this.noteGuids != null) {
        oprot.writeFieldBegin(NOTE_GUIDS_FIELD_DESC);
        {
          oprot.writeListBegin(new TList(TType.STRING, this.noteGuids.size()));
          for (String _iter102 : this.noteGuids)
          {
            oprot.writeString(_iter102);
          }
          oprot.writeListEnd();
        }
        oprot.writeFieldEnd();
      }
      oprot.writeFieldStop();
      oprot.writeStructEnd();
    }

    public String toString() {
      StringBuilder sb = new StringBuilder("expungeNotes_args(");
      boolean first = true;

      sb.append("authenticationToken:");
      if (this.authenticationToken == null) {
        sb.append("null");
      } else {
        sb.append(this.authenticationToken);
      }
      first = false;
      if (!first) sb.append(", ");
      sb.append("noteGuids:");
      if (this.noteGuids == null) {
        sb.append("null");
      } else {
        sb.append(this.noteGuids);
      }
      first = false;
      sb.append(")");
      return sb.toString();
    }

    public void validate() throws TException {
      // check for required fields
    }

  }

  public static class expungeNotes_result implements TBase<expungeNotes_result._Fields>, java.io.Serializable, Cloneable, Comparable<expungeNotes_result>   {
    private static final TStruct STRUCT_DESC = new TStruct("expungeNotes_result");

    private static final TField SUCCESS_FIELD_DESC = new TField("success", TType.I32, (short)0);
    private static final TField USER_EXCEPTION_FIELD_DESC = new TField("userException", TType.STRUCT, (short)1);
    private static final TField SYSTEM_EXCEPTION_FIELD_DESC = new TField("systemException", TType.STRUCT, (short)2);
    private static final TField NOT_FOUND_EXCEPTION_FIELD_DESC = new TField("notFoundException", TType.STRUCT, (short)3);

    private int success;
    private com.evernote.edam.error.EDAMUserException userException;
    private com.evernote.edam.error.EDAMSystemException systemException;
    private com.evernote.edam.error.EDAMNotFoundException notFoundException;

    /** The set of fields this struct contains, along with convenience methods for finding and manipulating them. */
    public enum _Fields implements TFieldIdEnum {
      SUCCESS((short)0, "success"),
      USER_EXCEPTION((short)1, "userException"),
      SYSTEM_EXCEPTION((short)2, "systemException"),
      NOT_FOUND_EXCEPTION((short)3, "notFoundException");

      private static final Map<Integer, _Fields> byId = new HashMap<Integer, _Fields>();
      private static final Map<String, _Fields> byName = new HashMap<String, _Fields>();

      static {
        for (_Fields field : EnumSet.allOf(_Fields.class)) {
          byId.put((int)field._thriftId, field);
          byName.put(field.getFieldName(), field);
        }
      }

      /**
       * Find the _Fields constant that matches fieldId, or null if its not found.
       */
      public static _Fields findByThriftId(int fieldId) {
        return byId.get(fieldId);
      }

      /**
       * Find the _Fields constant that matches fieldId, throwing an exception
       * if it is not found.
       */
      public static _Fields findByThriftIdOrThrow(int fieldId) {
        _Fields fields = findByThriftId(fieldId);
        if (fields == null) throw new IllegalArgumentException("Field " + fieldId + " doesn't exist!");
        return fields;
      }

      /**
       * Find the _Fields constant that matches name, or null if its not found.
       */
      public static _Fields findByName(String name) {
        return byName.get(name);
      }

      private final short _thriftId;
      private final String _fieldName;

      _Fields(short thriftId, String fieldName) {
        _thriftId = thriftId;
        _fieldName = fieldName;
      }

      public short getThriftFieldId() {
        return _thriftId;
      }

      public String getFieldName() {
        return _fieldName;
      }
    }

    // isset id assignments
    private static final int __SUCCESS_ISSET_ID = 0;
    private BitSet __isset_bit_vector = new BitSet(1);

    public static final Map<_Fields, FieldMetaData> metaDataMap = Collections.unmodifiableMap(new EnumMap<_Fields, FieldMetaData>(_Fields.class) {{
      put(_Fields.SUCCESS, new FieldMetaData("success", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.I32)));
      put(_Fields.USER_EXCEPTION, new FieldMetaData("userException", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.STRUCT)));
      put(_Fields.SYSTEM_EXCEPTION, new FieldMetaData("systemException", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.STRUCT)));
      put(_Fields.NOT_FOUND_EXCEPTION, new FieldMetaData("notFoundException", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.STRUCT)));
    }});

    static {
      FieldMetaData.addStructMetaDataMap(expungeNotes_result.class, metaDataMap);
    }

    public expungeNotes_result() {
    }

    public expungeNotes_result(
      int success,
      com.evernote.edam.error.EDAMUserException userException,
      com.evernote.edam.error.EDAMSystemException systemException,
      com.evernote.edam.error.EDAMNotFoundException notFoundException)
    {
      this();
      this.success = success;
      setSuccessIsSet(true);
      this.userException = userException;
      this.systemException = systemException;
      this.notFoundException = notFoundException;
    }

    /**
     * Performs a deep copy on <i>other</i>.
     */
    public expungeNotes_result(expungeNotes_result other) {
      __isset_bit_vector.clear();
      __isset_bit_vector.or(other.__isset_bit_vector);
      this.success = other.success;
      if (other.isSetUserException()) {
        this.userException = new com.evernote.edam.error.EDAMUserException(other.userException);
      }
      if (other.isSetSystemException()) {
        this.systemException = new com.evernote.edam.error.EDAMSystemException(other.systemException);
      }
      if (other.isSetNotFoundException()) {
        this.notFoundException = new com.evernote.edam.error.EDAMNotFoundException(other.notFoundException);
      }
    }

    public expungeNotes_result deepCopy() {
      return new expungeNotes_result(this);
    }

    @Deprecated
    public expungeNotes_result clone() {
      return new expungeNotes_result(this);
    }

    public int getSuccess() {
      return this.success;
    }

    public void setSuccess(int success) {
      this.success = success;
      setSuccessIsSet(true);
    }

    public void unsetSuccess() {
      __isset_bit_vector.clear(__SUCCESS_ISSET_ID);
    }

    /** Returns true if field success is set (has been asigned a value) and false otherwise */
    public boolean isSetSuccess() {
      return __isset_bit_vector.get(__SUCCESS_ISSET_ID);
    }

    public void setSuccessIsSet(boolean value) {
      __isset_bit_vector.set(__SUCCESS_ISSET_ID, value);
    }

    public com.evernote.edam.error.EDAMUserException getUserException() {
      return this.userException;
    }

    public void setUserException(com.evernote.edam.error.EDAMUserException userException) {
      this.userException = userException;
    }

    public void unsetUserException() {
      this.userException = null;
    }

    /** Returns true if field userException is set (has been asigned a value) and false otherwise */
    public boolean isSetUserException() {
      return this.userException != null;
    }

    public void setUserExceptionIsSet(boolean value) {
      if (!value) {
        this.userException = null;
      }
    }

    public com.evernote.edam.error.EDAMSystemException getSystemException() {
      return this.systemException;
    }

    public void setSystemException(com.evernote.edam.error.EDAMSystemException systemException) {
      this.systemException = systemException;
    }

    public void unsetSystemException() {
      this.systemException = null;
    }

    /** Returns true if field systemException is set (has been asigned a value) and false otherwise */
    public boolean isSetSystemException() {
      return this.systemException != null;
    }

    public void setSystemExceptionIsSet(boolean value) {
      if (!value) {
        this.systemException = null;
      }
    }

    public com.evernote.edam.error.EDAMNotFoundException getNotFoundException() {
      return this.notFoundException;
    }

    public void setNotFoundException(com.evernote.edam.error.EDAMNotFoundException notFoundException) {
      this.notFoundException = notFoundException;
    }

    public void unsetNotFoundException() {
      this.notFoundException = null;
    }

    /** Returns true if field notFoundException is set (has been asigned a value) and false otherwise */
    public boolean isSetNotFoundException() {
      return this.notFoundException != null;
    }

    public void setNotFoundExceptionIsSet(boolean value) {
      if (!value) {
        this.notFoundException = null;
      }
    }

    public void setFieldValue(_Fields field, Object value) {
      switch (field) {
      case SUCCESS:
        if (value == null) {
          unsetSuccess();
        } else {
          setSuccess((Integer)value);
        }
        break;

      case USER_EXCEPTION:
        if (value == null) {
          unsetUserException();
        } else {
          setUserException((com.evernote.edam.error.EDAMUserException)value);
        }
        break;

      case SYSTEM_EXCEPTION:
        if (value == null) {
          unsetSystemException();
        } else {
          setSystemException((com.evernote.edam.error.EDAMSystemException)value);
        }
        break;

      case NOT_FOUND_EXCEPTION:
        if (value == null) {
          unsetNotFoundException();
        } else {
          setNotFoundException((com.evernote.edam.error.EDAMNotFoundException)value);
        }
        break;

      }
    }

    public void setFieldValue(int fieldID, Object value) {
      setFieldValue(_Fields.findByThriftIdOrThrow(fieldID), value);
    }

    public Object getFieldValue(_Fields field) {
      switch (field) {
      case SUCCESS:
        return new Integer(getSuccess());

      case USER_EXCEPTION:
        return getUserException();

      case SYSTEM_EXCEPTION:
        return getSystemException();

      case NOT_FOUND_EXCEPTION:
        return getNotFoundException();

      }
      throw new IllegalStateException();
    }

    public Object getFieldValue(int fieldId) {
      return getFieldValue(_Fields.findByThriftIdOrThrow(fieldId));
    }

    /** Returns true if field corresponding to fieldID is set (has been asigned a value) and false otherwise */
    public boolean isSet(_Fields field) {
      switch (field) {
      case SUCCESS:
        return isSetSuccess();
      case USER_EXCEPTION:
        return isSetUserException();
      case SYSTEM_EXCEPTION:
        return isSetSystemException();
      case NOT_FOUND_EXCEPTION:
        return isSetNotFoundException();
      }
      throw new IllegalStateException();
    }

    public boolean isSet(int fieldID) {
      return isSet(_Fields.findByThriftIdOrThrow(fieldID));
    }

    public boolean equals(Object that) {
      if (that == null)
        return false;
      if (that instanceof expungeNotes_result)
        return this.equals((expungeNotes_result)that);
      return false;
    }

    public boolean equals(expungeNotes_result that) {
      if (that == null)
        return false;

      boolean this_present_success = true;
      boolean that_present_success = true;
      if (this_present_success || that_present_success) {
        if (!(this_present_success && that_present_success))
          return false;
        if (this.success != that.success)
          return false;
      }

      boolean this_present_userException = true && this.isSetUserException();
      boolean that_present_userException = true && that.isSetUserException();
      if (this_present_userException || that_present_userException) {
        if (!(this_present_userException && that_present_userException))
          return false;
        if (!this.userException.equals(that.userException))
          return false;
      }

      boolean this_present_systemException = true && this.isSetSystemException();
      boolean that_present_systemException = true && that.isSetSystemException();
      if (this_present_systemException || that_present_systemException) {
        if (!(this_present_systemException && that_present_systemException))
          return false;
        if (!this.systemException.equals(that.systemException))
          return false;
      }

      boolean this_present_notFoundException = true && this.isSetNotFoundException();
      boolean that_present_notFoundException = true && that.isSetNotFoundException();
      if (this_present_notFoundException || that_present_notFoundException) {
        if (!(this_present_notFoundException && that_present_notFoundException))
          return false;
        if (!this.notFoundException.equals(that.notFoundException))
          return false;
      }

      return true;
    }

    public int hashCode() {
      return 0;
    }

    public int compareTo(expungeNotes_result other) {
      if (!getClass().equals(other.getClass())) {
        return getClass().getName().compareTo(other.getClass().getName());
      }

      int lastComparison = 0;
      expungeNotes_result typedOther = (expungeNotes_result)other;

      lastComparison = Boolean.valueOf(isSetSuccess()).compareTo(isSetSuccess());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(success, typedOther.success);
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = Boolean.valueOf(isSetUserException()).compareTo(isSetUserException());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(userException, typedOther.userException);
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = Boolean.valueOf(isSetSystemException()).compareTo(isSetSystemException());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(systemException, typedOther.systemException);
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = Boolean.valueOf(isSetNotFoundException()).compareTo(isSetNotFoundException());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(notFoundException, typedOther.notFoundException);
      if (lastComparison != 0) {
        return lastComparison;
      }
      return 0;
    }

    public void read(TProtocol iprot) throws TException {
      TField field;
      iprot.readStructBegin();
      while (true)
      {
        field = iprot.readFieldBegin();
        if (field.type == TType.STOP) { 
          break;
        }
        _Fields fieldId = _Fields.findByThriftId(field.id);
        if (fieldId == null) {
          TProtocolUtil.skip(iprot, field.type);
        } else {
          switch (fieldId) {
            case SUCCESS:
              if (field.type == TType.I32) {
                this.success = iprot.readI32();
                setSuccessIsSet(true);
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
            case USER_EXCEPTION:
              if (field.type == TType.STRUCT) {
                this.userException = new com.evernote.edam.error.EDAMUserException();
                this.userException.read(iprot);
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
            case SYSTEM_EXCEPTION:
              if (field.type == TType.STRUCT) {
                this.systemException = new com.evernote.edam.error.EDAMSystemException();
                this.systemException.read(iprot);
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
            case NOT_FOUND_EXCEPTION:
              if (field.type == TType.STRUCT) {
                this.notFoundException = new com.evernote.edam.error.EDAMNotFoundException();
                this.notFoundException.read(iprot);
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
          }
          iprot.readFieldEnd();
        }
      }
      iprot.readStructEnd();
      validate();
    }

    public void write(TProtocol oprot) throws TException {
      oprot.writeStructBegin(STRUCT_DESC);

      if (this.isSetSuccess()) {
        oprot.writeFieldBegin(SUCCESS_FIELD_DESC);
        oprot.writeI32(this.success);
        oprot.writeFieldEnd();
      } else if (this.isSetUserException()) {
        oprot.writeFieldBegin(USER_EXCEPTION_FIELD_DESC);
        this.userException.write(oprot);
        oprot.writeFieldEnd();
      } else if (this.isSetSystemException()) {
        oprot.writeFieldBegin(SYSTEM_EXCEPTION_FIELD_DESC);
        this.systemException.write(oprot);
        oprot.writeFieldEnd();
      } else if (this.isSetNotFoundException()) {
        oprot.writeFieldBegin(NOT_FOUND_EXCEPTION_FIELD_DESC);
        this.notFoundException.write(oprot);
        oprot.writeFieldEnd();
      }
      oprot.writeFieldStop();
      oprot.writeStructEnd();
    }

    public String toString() {
      StringBuilder sb = new StringBuilder("expungeNotes_result(");
      boolean first = true;

      sb.append("success:");
      sb.append(this.success);
      first = false;
      if (!first) sb.append(", ");
      sb.append("userException:");
      if (this.userException == null) {
        sb.append("null");
      } else {
        sb.append(this.userException);
      }
      first = false;
      if (!first) sb.append(", ");
      sb.append("systemException:");
      if (this.systemException == null) {
        sb.append("null");
      } else {
        sb.append(this.systemException);
      }
      first = false;
      if (!first) sb.append(", ");
      sb.append("notFoundException:");
      if (this.notFoundException == null) {
        sb.append("null");
      } else {
        sb.append(this.notFoundException);
      }
      first = false;
      sb.append(")");
      return sb.toString();
    }

    public void validate() throws TException {
      // check for required fields
    }

  }

  public static class expungeInactiveNotes_args implements TBase<expungeInactiveNotes_args._Fields>, java.io.Serializable, Cloneable, Comparable<expungeInactiveNotes_args>   {
    private static final TStruct STRUCT_DESC = new TStruct("expungeInactiveNotes_args");

    private static final TField AUTHENTICATION_TOKEN_FIELD_DESC = new TField("authenticationToken", TType.STRING, (short)1);

    private String authenticationToken;

    /** The set of fields this struct contains, along with convenience methods for finding and manipulating them. */
    public enum _Fields implements TFieldIdEnum {
      AUTHENTICATION_TOKEN((short)1, "authenticationToken");

      private static final Map<Integer, _Fields> byId = new HashMap<Integer, _Fields>();
      private static final Map<String, _Fields> byName = new HashMap<String, _Fields>();

      static {
        for (_Fields field : EnumSet.allOf(_Fields.class)) {
          byId.put((int)field._thriftId, field);
          byName.put(field.getFieldName(), field);
        }
      }

      /**
       * Find the _Fields constant that matches fieldId, or null if its not found.
       */
      public static _Fields findByThriftId(int fieldId) {
        return byId.get(fieldId);
      }

      /**
       * Find the _Fields constant that matches fieldId, throwing an exception
       * if it is not found.
       */
      public static _Fields findByThriftIdOrThrow(int fieldId) {
        _Fields fields = findByThriftId(fieldId);
        if (fields == null) throw new IllegalArgumentException("Field " + fieldId + " doesn't exist!");
        return fields;
      }

      /**
       * Find the _Fields constant that matches name, or null if its not found.
       */
      public static _Fields findByName(String name) {
        return byName.get(name);
      }

      private final short _thriftId;
      private final String _fieldName;

      _Fields(short thriftId, String fieldName) {
        _thriftId = thriftId;
        _fieldName = fieldName;
      }

      public short getThriftFieldId() {
        return _thriftId;
      }

      public String getFieldName() {
        return _fieldName;
      }
    }

    // isset id assignments

    public static final Map<_Fields, FieldMetaData> metaDataMap = Collections.unmodifiableMap(new EnumMap<_Fields, FieldMetaData>(_Fields.class) {{
      put(_Fields.AUTHENTICATION_TOKEN, new FieldMetaData("authenticationToken", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.STRING)));
    }});

    static {
      FieldMetaData.addStructMetaDataMap(expungeInactiveNotes_args.class, metaDataMap);
    }

    public expungeInactiveNotes_args() {
    }

    public expungeInactiveNotes_args(
      String authenticationToken)
    {
      this();
      this.authenticationToken = authenticationToken;
    }

    /**
     * Performs a deep copy on <i>other</i>.
     */
    public expungeInactiveNotes_args(expungeInactiveNotes_args other) {
      if (other.isSetAuthenticationToken()) {
        this.authenticationToken = other.authenticationToken;
      }
    }

    public expungeInactiveNotes_args deepCopy() {
      return new expungeInactiveNotes_args(this);
    }

    @Deprecated
    public expungeInactiveNotes_args clone() {
      return new expungeInactiveNotes_args(this);
    }

    public String getAuthenticationToken() {
      return this.authenticationToken;
    }

    public void setAuthenticationToken(String authenticationToken) {
      this.authenticationToken = authenticationToken;
    }

    public void unsetAuthenticationToken() {
      this.authenticationToken = null;
    }

    /** Returns true if field authenticationToken is set (has been asigned a value) and false otherwise */
    public boolean isSetAuthenticationToken() {
      return this.authenticationToken != null;
    }

    public void setAuthenticationTokenIsSet(boolean value) {
      if (!value) {
        this.authenticationToken = null;
      }
    }

    public void setFieldValue(_Fields field, Object value) {
      switch (field) {
      case AUTHENTICATION_TOKEN:
        if (value == null) {
          unsetAuthenticationToken();
        } else {
          setAuthenticationToken((String)value);
        }
        break;

      }
    }

    public void setFieldValue(int fieldID, Object value) {
      setFieldValue(_Fields.findByThriftIdOrThrow(fieldID), value);
    }

    public Object getFieldValue(_Fields field) {
      switch (field) {
      case AUTHENTICATION_TOKEN:
        return getAuthenticationToken();

      }
      throw new IllegalStateException();
    }

    public Object getFieldValue(int fieldId) {
      return getFieldValue(_Fields.findByThriftIdOrThrow(fieldId));
    }

    /** Returns true if field corresponding to fieldID is set (has been asigned a value) and false otherwise */
    public boolean isSet(_Fields field) {
      switch (field) {
      case AUTHENTICATION_TOKEN:
        return isSetAuthenticationToken();
      }
      throw new IllegalStateException();
    }

    public boolean isSet(int fieldID) {
      return isSet(_Fields.findByThriftIdOrThrow(fieldID));
    }

    public boolean equals(Object that) {
      if (that == null)
        return false;
      if (that instanceof expungeInactiveNotes_args)
        return this.equals((expungeInactiveNotes_args)that);
      return false;
    }

    public boolean equals(expungeInactiveNotes_args that) {
      if (that == null)
        return false;

      boolean this_present_authenticationToken = true && this.isSetAuthenticationToken();
      boolean that_present_authenticationToken = true && that.isSetAuthenticationToken();
      if (this_present_authenticationToken || that_present_authenticationToken) {
        if (!(this_present_authenticationToken && that_present_authenticationToken))
          return false;
        if (!this.authenticationToken.equals(that.authenticationToken))
          return false;
      }

      return true;
    }

    public int hashCode() {
      return 0;
    }

    public int compareTo(expungeInactiveNotes_args other) {
      if (!getClass().equals(other.getClass())) {
        return getClass().getName().compareTo(other.getClass().getName());
      }

      int lastComparison = 0;
      expungeInactiveNotes_args typedOther = (expungeInactiveNotes_args)other;

      lastComparison = Boolean.valueOf(isSetAuthenticationToken()).compareTo(isSetAuthenticationToken());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(authenticationToken, typedOther.authenticationToken);
      if (lastComparison != 0) {
        return lastComparison;
      }
      return 0;
    }

    public void read(TProtocol iprot) throws TException {
      TField field;
      iprot.readStructBegin();
      while (true)
      {
        field = iprot.readFieldBegin();
        if (field.type == TType.STOP) { 
          break;
        }
        _Fields fieldId = _Fields.findByThriftId(field.id);
        if (fieldId == null) {
          TProtocolUtil.skip(iprot, field.type);
        } else {
          switch (fieldId) {
            case AUTHENTICATION_TOKEN:
              if (field.type == TType.STRING) {
                this.authenticationToken = iprot.readString();
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
          }
          iprot.readFieldEnd();
        }
      }
      iprot.readStructEnd();
      validate();
    }

    public void write(TProtocol oprot) throws TException {
      validate();

      oprot.writeStructBegin(STRUCT_DESC);
      if (this.authenticationToken != null) {
        oprot.writeFieldBegin(AUTHENTICATION_TOKEN_FIELD_DESC);
        oprot.writeString(this.authenticationToken);
        oprot.writeFieldEnd();
      }
      oprot.writeFieldStop();
      oprot.writeStructEnd();
    }

    public String toString() {
      StringBuilder sb = new StringBuilder("expungeInactiveNotes_args(");
      boolean first = true;

      sb.append("authenticationToken:");
      if (this.authenticationToken == null) {
        sb.append("null");
      } else {
        sb.append(this.authenticationToken);
      }
      first = false;
      sb.append(")");
      return sb.toString();
    }

    public void validate() throws TException {
      // check for required fields
    }

  }

  public static class expungeInactiveNotes_result implements TBase<expungeInactiveNotes_result._Fields>, java.io.Serializable, Cloneable, Comparable<expungeInactiveNotes_result>   {
    private static final TStruct STRUCT_DESC = new TStruct("expungeInactiveNotes_result");

    private static final TField SUCCESS_FIELD_DESC = new TField("success", TType.I32, (short)0);
    private static final TField USER_EXCEPTION_FIELD_DESC = new TField("userException", TType.STRUCT, (short)1);
    private static final TField SYSTEM_EXCEPTION_FIELD_DESC = new TField("systemException", TType.STRUCT, (short)2);

    private int success;
    private com.evernote.edam.error.EDAMUserException userException;
    private com.evernote.edam.error.EDAMSystemException systemException;

    /** The set of fields this struct contains, along with convenience methods for finding and manipulating them. */
    public enum _Fields implements TFieldIdEnum {
      SUCCESS((short)0, "success"),
      USER_EXCEPTION((short)1, "userException"),
      SYSTEM_EXCEPTION((short)2, "systemException");

      private static final Map<Integer, _Fields> byId = new HashMap<Integer, _Fields>();
      private static final Map<String, _Fields> byName = new HashMap<String, _Fields>();

      static {
        for (_Fields field : EnumSet.allOf(_Fields.class)) {
          byId.put((int)field._thriftId, field);
          byName.put(field.getFieldName(), field);
        }
      }

      /**
       * Find the _Fields constant that matches fieldId, or null if its not found.
       */
      public static _Fields findByThriftId(int fieldId) {
        return byId.get(fieldId);
      }

      /**
       * Find the _Fields constant that matches fieldId, throwing an exception
       * if it is not found.
       */
      public static _Fields findByThriftIdOrThrow(int fieldId) {
        _Fields fields = findByThriftId(fieldId);
        if (fields == null) throw new IllegalArgumentException("Field " + fieldId + " doesn't exist!");
        return fields;
      }

      /**
       * Find the _Fields constant that matches name, or null if its not found.
       */
      public static _Fields findByName(String name) {
        return byName.get(name);
      }

      private final short _thriftId;
      private final String _fieldName;

      _Fields(short thriftId, String fieldName) {
        _thriftId = thriftId;
        _fieldName = fieldName;
      }

      public short getThriftFieldId() {
        return _thriftId;
      }

      public String getFieldName() {
        return _fieldName;
      }
    }

    // isset id assignments
    private static final int __SUCCESS_ISSET_ID = 0;
    private BitSet __isset_bit_vector = new BitSet(1);

    public static final Map<_Fields, FieldMetaData> metaDataMap = Collections.unmodifiableMap(new EnumMap<_Fields, FieldMetaData>(_Fields.class) {{
      put(_Fields.SUCCESS, new FieldMetaData("success", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.I32)));
      put(_Fields.USER_EXCEPTION, new FieldMetaData("userException", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.STRUCT)));
      put(_Fields.SYSTEM_EXCEPTION, new FieldMetaData("systemException", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.STRUCT)));
    }});

    static {
      FieldMetaData.addStructMetaDataMap(expungeInactiveNotes_result.class, metaDataMap);
    }

    public expungeInactiveNotes_result() {
    }

    public expungeInactiveNotes_result(
      int success,
      com.evernote.edam.error.EDAMUserException userException,
      com.evernote.edam.error.EDAMSystemException systemException)
    {
      this();
      this.success = success;
      setSuccessIsSet(true);
      this.userException = userException;
      this.systemException = systemException;
    }

    /**
     * Performs a deep copy on <i>other</i>.
     */
    public expungeInactiveNotes_result(expungeInactiveNotes_result other) {
      __isset_bit_vector.clear();
      __isset_bit_vector.or(other.__isset_bit_vector);
      this.success = other.success;
      if (other.isSetUserException()) {
        this.userException = new com.evernote.edam.error.EDAMUserException(other.userException);
      }
      if (other.isSetSystemException()) {
        this.systemException = new com.evernote.edam.error.EDAMSystemException(other.systemException);
      }
    }

    public expungeInactiveNotes_result deepCopy() {
      return new expungeInactiveNotes_result(this);
    }

    @Deprecated
    public expungeInactiveNotes_result clone() {
      return new expungeInactiveNotes_result(this);
    }

    public int getSuccess() {
      return this.success;
    }

    public void setSuccess(int success) {
      this.success = success;
      setSuccessIsSet(true);
    }

    public void unsetSuccess() {
      __isset_bit_vector.clear(__SUCCESS_ISSET_ID);
    }

    /** Returns true if field success is set (has been asigned a value) and false otherwise */
    public boolean isSetSuccess() {
      return __isset_bit_vector.get(__SUCCESS_ISSET_ID);
    }

    public void setSuccessIsSet(boolean value) {
      __isset_bit_vector.set(__SUCCESS_ISSET_ID, value);
    }

    public com.evernote.edam.error.EDAMUserException getUserException() {
      return this.userException;
    }

    public void setUserException(com.evernote.edam.error.EDAMUserException userException) {
      this.userException = userException;
    }

    public void unsetUserException() {
      this.userException = null;
    }

    /** Returns true if field userException is set (has been asigned a value) and false otherwise */
    public boolean isSetUserException() {
      return this.userException != null;
    }

    public void setUserExceptionIsSet(boolean value) {
      if (!value) {
        this.userException = null;
      }
    }

    public com.evernote.edam.error.EDAMSystemException getSystemException() {
      return this.systemException;
    }

    public void setSystemException(com.evernote.edam.error.EDAMSystemException systemException) {
      this.systemException = systemException;
    }

    public void unsetSystemException() {
      this.systemException = null;
    }

    /** Returns true if field systemException is set (has been asigned a value) and false otherwise */
    public boolean isSetSystemException() {
      return this.systemException != null;
    }

    public void setSystemExceptionIsSet(boolean value) {
      if (!value) {
        this.systemException = null;
      }
    }

    public void setFieldValue(_Fields field, Object value) {
      switch (field) {
      case SUCCESS:
        if (value == null) {
          unsetSuccess();
        } else {
          setSuccess((Integer)value);
        }
        break;

      case USER_EXCEPTION:
        if (value == null) {
          unsetUserException();
        } else {
          setUserException((com.evernote.edam.error.EDAMUserException)value);
        }
        break;

      case SYSTEM_EXCEPTION:
        if (value == null) {
          unsetSystemException();
        } else {
          setSystemException((com.evernote.edam.error.EDAMSystemException)value);
        }
        break;

      }
    }

    public void setFieldValue(int fieldID, Object value) {
      setFieldValue(_Fields.findByThriftIdOrThrow(fieldID), value);
    }

    public Object getFieldValue(_Fields field) {
      switch (field) {
      case SUCCESS:
        return new Integer(getSuccess());

      case USER_EXCEPTION:
        return getUserException();

      case SYSTEM_EXCEPTION:
        return getSystemException();

      }
      throw new IllegalStateException();
    }

    public Object getFieldValue(int fieldId) {
      return getFieldValue(_Fields.findByThriftIdOrThrow(fieldId));
    }

    /** Returns true if field corresponding to fieldID is set (has been asigned a value) and false otherwise */
    public boolean isSet(_Fields field) {
      switch (field) {
      case SUCCESS:
        return isSetSuccess();
      case USER_EXCEPTION:
        return isSetUserException();
      case SYSTEM_EXCEPTION:
        return isSetSystemException();
      }
      throw new IllegalStateException();
    }

    public boolean isSet(int fieldID) {
      return isSet(_Fields.findByThriftIdOrThrow(fieldID));
    }

    public boolean equals(Object that) {
      if (that == null)
        return false;
      if (that instanceof expungeInactiveNotes_result)
        return this.equals((expungeInactiveNotes_result)that);
      return false;
    }

    public boolean equals(expungeInactiveNotes_result that) {
      if (that == null)
        return false;

      boolean this_present_success = true;
      boolean that_present_success = true;
      if (this_present_success || that_present_success) {
        if (!(this_present_success && that_present_success))
          return false;
        if (this.success != that.success)
          return false;
      }

      boolean this_present_userException = true && this.isSetUserException();
      boolean that_present_userException = true && that.isSetUserException();
      if (this_present_userException || that_present_userException) {
        if (!(this_present_userException && that_present_userException))
          return false;
        if (!this.userException.equals(that.userException))
          return false;
      }

      boolean this_present_systemException = true && this.isSetSystemException();
      boolean that_present_systemException = true && that.isSetSystemException();
      if (this_present_systemException || that_present_systemException) {
        if (!(this_present_systemException && that_present_systemException))
          return false;
        if (!this.systemException.equals(that.systemException))
          return false;
      }

      return true;
    }

    public int hashCode() {
      return 0;
    }

    public int compareTo(expungeInactiveNotes_result other) {
      if (!getClass().equals(other.getClass())) {
        return getClass().getName().compareTo(other.getClass().getName());
      }

      int lastComparison = 0;
      expungeInactiveNotes_result typedOther = (expungeInactiveNotes_result)other;

      lastComparison = Boolean.valueOf(isSetSuccess()).compareTo(isSetSuccess());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(success, typedOther.success);
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = Boolean.valueOf(isSetUserException()).compareTo(isSetUserException());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(userException, typedOther.userException);
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = Boolean.valueOf(isSetSystemException()).compareTo(isSetSystemException());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(systemException, typedOther.systemException);
      if (lastComparison != 0) {
        return lastComparison;
      }
      return 0;
    }

    public void read(TProtocol iprot) throws TException {
      TField field;
      iprot.readStructBegin();
      while (true)
      {
        field = iprot.readFieldBegin();
        if (field.type == TType.STOP) { 
          break;
        }
        _Fields fieldId = _Fields.findByThriftId(field.id);
        if (fieldId == null) {
          TProtocolUtil.skip(iprot, field.type);
        } else {
          switch (fieldId) {
            case SUCCESS:
              if (field.type == TType.I32) {
                this.success = iprot.readI32();
                setSuccessIsSet(true);
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
            case USER_EXCEPTION:
              if (field.type == TType.STRUCT) {
                this.userException = new com.evernote.edam.error.EDAMUserException();
                this.userException.read(iprot);
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
            case SYSTEM_EXCEPTION:
              if (field.type == TType.STRUCT) {
                this.systemException = new com.evernote.edam.error.EDAMSystemException();
                this.systemException.read(iprot);
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
          }
          iprot.readFieldEnd();
        }
      }
      iprot.readStructEnd();
      validate();
    }

    public void write(TProtocol oprot) throws TException {
      oprot.writeStructBegin(STRUCT_DESC);

      if (this.isSetSuccess()) {
        oprot.writeFieldBegin(SUCCESS_FIELD_DESC);
        oprot.writeI32(this.success);
        oprot.writeFieldEnd();
      } else if (this.isSetUserException()) {
        oprot.writeFieldBegin(USER_EXCEPTION_FIELD_DESC);
        this.userException.write(oprot);
        oprot.writeFieldEnd();
      } else if (this.isSetSystemException()) {
        oprot.writeFieldBegin(SYSTEM_EXCEPTION_FIELD_DESC);
        this.systemException.write(oprot);
        oprot.writeFieldEnd();
      }
      oprot.writeFieldStop();
      oprot.writeStructEnd();
    }

    public String toString() {
      StringBuilder sb = new StringBuilder("expungeInactiveNotes_result(");
      boolean first = true;

      sb.append("success:");
      sb.append(this.success);
      first = false;
      if (!first) sb.append(", ");
      sb.append("userException:");
      if (this.userException == null) {
        sb.append("null");
      } else {
        sb.append(this.userException);
      }
      first = false;
      if (!first) sb.append(", ");
      sb.append("systemException:");
      if (this.systemException == null) {
        sb.append("null");
      } else {
        sb.append(this.systemException);
      }
      first = false;
      sb.append(")");
      return sb.toString();
    }

    public void validate() throws TException {
      // check for required fields
    }

  }

  public static class copyNote_args implements TBase<copyNote_args._Fields>, java.io.Serializable, Cloneable, Comparable<copyNote_args>   {
    private static final TStruct STRUCT_DESC = new TStruct("copyNote_args");

    private static final TField AUTHENTICATION_TOKEN_FIELD_DESC = new TField("authenticationToken", TType.STRING, (short)1);
    private static final TField NOTE_GUID_FIELD_DESC = new TField("noteGuid", TType.STRING, (short)2);
    private static final TField TO_NOTEBOOK_GUID_FIELD_DESC = new TField("toNotebookGuid", TType.STRING, (short)3);

    private String authenticationToken;
    private String noteGuid;
    private String toNotebookGuid;

    /** The set of fields this struct contains, along with convenience methods for finding and manipulating them. */
    public enum _Fields implements TFieldIdEnum {
      AUTHENTICATION_TOKEN((short)1, "authenticationToken"),
      NOTE_GUID((short)2, "noteGuid"),
      TO_NOTEBOOK_GUID((short)3, "toNotebookGuid");

      private static final Map<Integer, _Fields> byId = new HashMap<Integer, _Fields>();
      private static final Map<String, _Fields> byName = new HashMap<String, _Fields>();

      static {
        for (_Fields field : EnumSet.allOf(_Fields.class)) {
          byId.put((int)field._thriftId, field);
          byName.put(field.getFieldName(), field);
        }
      }

      /**
       * Find the _Fields constant that matches fieldId, or null if its not found.
       */
      public static _Fields findByThriftId(int fieldId) {
        return byId.get(fieldId);
      }

      /**
       * Find the _Fields constant that matches fieldId, throwing an exception
       * if it is not found.
       */
      public static _Fields findByThriftIdOrThrow(int fieldId) {
        _Fields fields = findByThriftId(fieldId);
        if (fields == null) throw new IllegalArgumentException("Field " + fieldId + " doesn't exist!");
        return fields;
      }

      /**
       * Find the _Fields constant that matches name, or null if its not found.
       */
      public static _Fields findByName(String name) {
        return byName.get(name);
      }

      private final short _thriftId;
      private final String _fieldName;

      _Fields(short thriftId, String fieldName) {
        _thriftId = thriftId;
        _fieldName = fieldName;
      }

      public short getThriftFieldId() {
        return _thriftId;
      }

      public String getFieldName() {
        return _fieldName;
      }
    }

    // isset id assignments

    public static final Map<_Fields, FieldMetaData> metaDataMap = Collections.unmodifiableMap(new EnumMap<_Fields, FieldMetaData>(_Fields.class) {{
      put(_Fields.AUTHENTICATION_TOKEN, new FieldMetaData("authenticationToken", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.STRING)));
      put(_Fields.NOTE_GUID, new FieldMetaData("noteGuid", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.STRING)));
      put(_Fields.TO_NOTEBOOK_GUID, new FieldMetaData("toNotebookGuid", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.STRING)));
    }});

    static {
      FieldMetaData.addStructMetaDataMap(copyNote_args.class, metaDataMap);
    }

    public copyNote_args() {
    }

    public copyNote_args(
      String authenticationToken,
      String noteGuid,
      String toNotebookGuid)
    {
      this();
      this.authenticationToken = authenticationToken;
      this.noteGuid = noteGuid;
      this.toNotebookGuid = toNotebookGuid;
    }

    /**
     * Performs a deep copy on <i>other</i>.
     */
    public copyNote_args(copyNote_args other) {
      if (other.isSetAuthenticationToken()) {
        this.authenticationToken = other.authenticationToken;
      }
      if (other.isSetNoteGuid()) {
        this.noteGuid = other.noteGuid;
      }
      if (other.isSetToNotebookGuid()) {
        this.toNotebookGuid = other.toNotebookGuid;
      }
    }

    public copyNote_args deepCopy() {
      return new copyNote_args(this);
    }

    @Deprecated
    public copyNote_args clone() {
      return new copyNote_args(this);
    }

    public String getAuthenticationToken() {
      return this.authenticationToken;
    }

    public void setAuthenticationToken(String authenticationToken) {
      this.authenticationToken = authenticationToken;
    }

    public void unsetAuthenticationToken() {
      this.authenticationToken = null;
    }

    /** Returns true if field authenticationToken is set (has been asigned a value) and false otherwise */
    public boolean isSetAuthenticationToken() {
      return this.authenticationToken != null;
    }

    public void setAuthenticationTokenIsSet(boolean value) {
      if (!value) {
        this.authenticationToken = null;
      }
    }

    public String getNoteGuid() {
      return this.noteGuid;
    }

    public void setNoteGuid(String noteGuid) {
      this.noteGuid = noteGuid;
    }

    public void unsetNoteGuid() {
      this.noteGuid = null;
    }

    /** Returns true if field noteGuid is set (has been asigned a value) and false otherwise */
    public boolean isSetNoteGuid() {
      return this.noteGuid != null;
    }

    public void setNoteGuidIsSet(boolean value) {
      if (!value) {
        this.noteGuid = null;
      }
    }

    public String getToNotebookGuid() {
      return this.toNotebookGuid;
    }

    public void setToNotebookGuid(String toNotebookGuid) {
      this.toNotebookGuid = toNotebookGuid;
    }

    public void unsetToNotebookGuid() {
      this.toNotebookGuid = null;
    }

    /** Returns true if field toNotebookGuid is set (has been asigned a value) and false otherwise */
    public boolean isSetToNotebookGuid() {
      return this.toNotebookGuid != null;
    }

    public void setToNotebookGuidIsSet(boolean value) {
      if (!value) {
        this.toNotebookGuid = null;
      }
    }

    public void setFieldValue(_Fields field, Object value) {
      switch (field) {
      case AUTHENTICATION_TOKEN:
        if (value == null) {
          unsetAuthenticationToken();
        } else {
          setAuthenticationToken((String)value);
        }
        break;

      case NOTE_GUID:
        if (value == null) {
          unsetNoteGuid();
        } else {
          setNoteGuid((String)value);
        }
        break;

      case TO_NOTEBOOK_GUID:
        if (value == null) {
          unsetToNotebookGuid();
        } else {
          setToNotebookGuid((String)value);
        }
        break;

      }
    }

    public void setFieldValue(int fieldID, Object value) {
      setFieldValue(_Fields.findByThriftIdOrThrow(fieldID), value);
    }

    public Object getFieldValue(_Fields field) {
      switch (field) {
      case AUTHENTICATION_TOKEN:
        return getAuthenticationToken();

      case NOTE_GUID:
        return getNoteGuid();

      case TO_NOTEBOOK_GUID:
        return getToNotebookGuid();

      }
      throw new IllegalStateException();
    }

    public Object getFieldValue(int fieldId) {
      return getFieldValue(_Fields.findByThriftIdOrThrow(fieldId));
    }

    /** Returns true if field corresponding to fieldID is set (has been asigned a value) and false otherwise */
    public boolean isSet(_Fields field) {
      switch (field) {
      case AUTHENTICATION_TOKEN:
        return isSetAuthenticationToken();
      case NOTE_GUID:
        return isSetNoteGuid();
      case TO_NOTEBOOK_GUID:
        return isSetToNotebookGuid();
      }
      throw new IllegalStateException();
    }

    public boolean isSet(int fieldID) {
      return isSet(_Fields.findByThriftIdOrThrow(fieldID));
    }

    public boolean equals(Object that) {
      if (that == null)
        return false;
      if (that instanceof copyNote_args)
        return this.equals((copyNote_args)that);
      return false;
    }

    public boolean equals(copyNote_args that) {
      if (that == null)
        return false;

      boolean this_present_authenticationToken = true && this.isSetAuthenticationToken();
      boolean that_present_authenticationToken = true && that.isSetAuthenticationToken();
      if (this_present_authenticationToken || that_present_authenticationToken) {
        if (!(this_present_authenticationToken && that_present_authenticationToken))
          return false;
        if (!this.authenticationToken.equals(that.authenticationToken))
          return false;
      }

      boolean this_present_noteGuid = true && this.isSetNoteGuid();
      boolean that_present_noteGuid = true && that.isSetNoteGuid();
      if (this_present_noteGuid || that_present_noteGuid) {
        if (!(this_present_noteGuid && that_present_noteGuid))
          return false;
        if (!this.noteGuid.equals(that.noteGuid))
          return false;
      }

      boolean this_present_toNotebookGuid = true && this.isSetToNotebookGuid();
      boolean that_present_toNotebookGuid = true && that.isSetToNotebookGuid();
      if (this_present_toNotebookGuid || that_present_toNotebookGuid) {
        if (!(this_present_toNotebookGuid && that_present_toNotebookGuid))
          return false;
        if (!this.toNotebookGuid.equals(that.toNotebookGuid))
          return false;
      }

      return true;
    }

    public int hashCode() {
      return 0;
    }

    public int compareTo(copyNote_args other) {
      if (!getClass().equals(other.getClass())) {
        return getClass().getName().compareTo(other.getClass().getName());
      }

      int lastComparison = 0;
      copyNote_args typedOther = (copyNote_args)other;

      lastComparison = Boolean.valueOf(isSetAuthenticationToken()).compareTo(isSetAuthenticationToken());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(authenticationToken, typedOther.authenticationToken);
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = Boolean.valueOf(isSetNoteGuid()).compareTo(isSetNoteGuid());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(noteGuid, typedOther.noteGuid);
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = Boolean.valueOf(isSetToNotebookGuid()).compareTo(isSetToNotebookGuid());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(toNotebookGuid, typedOther.toNotebookGuid);
      if (lastComparison != 0) {
        return lastComparison;
      }
      return 0;
    }

    public void read(TProtocol iprot) throws TException {
      TField field;
      iprot.readStructBegin();
      while (true)
      {
        field = iprot.readFieldBegin();
        if (field.type == TType.STOP) { 
          break;
        }
        _Fields fieldId = _Fields.findByThriftId(field.id);
        if (fieldId == null) {
          TProtocolUtil.skip(iprot, field.type);
        } else {
          switch (fieldId) {
            case AUTHENTICATION_TOKEN:
              if (field.type == TType.STRING) {
                this.authenticationToken = iprot.readString();
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
            case NOTE_GUID:
              if (field.type == TType.STRING) {
                this.noteGuid = iprot.readString();
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
            case TO_NOTEBOOK_GUID:
              if (field.type == TType.STRING) {
                this.toNotebookGuid = iprot.readString();
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
          }
          iprot.readFieldEnd();
        }
      }
      iprot.readStructEnd();
      validate();
    }

    public void write(TProtocol oprot) throws TException {
      validate();

      oprot.writeStructBegin(STRUCT_DESC);
      if (this.authenticationToken != null) {
        oprot.writeFieldBegin(AUTHENTICATION_TOKEN_FIELD_DESC);
        oprot.writeString(this.authenticationToken);
        oprot.writeFieldEnd();
      }
      if (this.noteGuid != null) {
        oprot.writeFieldBegin(NOTE_GUID_FIELD_DESC);
        oprot.writeString(this.noteGuid);
        oprot.writeFieldEnd();
      }
      if (this.toNotebookGuid != null) {
        oprot.writeFieldBegin(TO_NOTEBOOK_GUID_FIELD_DESC);
        oprot.writeString(this.toNotebookGuid);
        oprot.writeFieldEnd();
      }
      oprot.writeFieldStop();
      oprot.writeStructEnd();
    }

    public String toString() {
      StringBuilder sb = new StringBuilder("copyNote_args(");
      boolean first = true;

      sb.append("authenticationToken:");
      if (this.authenticationToken == null) {
        sb.append("null");
      } else {
        sb.append(this.authenticationToken);
      }
      first = false;
      if (!first) sb.append(", ");
      sb.append("noteGuid:");
      if (this.noteGuid == null) {
        sb.append("null");
      } else {
        sb.append(this.noteGuid);
      }
      first = false;
      if (!first) sb.append(", ");
      sb.append("toNotebookGuid:");
      if (this.toNotebookGuid == null) {
        sb.append("null");
      } else {
        sb.append(this.toNotebookGuid);
      }
      first = false;
      sb.append(")");
      return sb.toString();
    }

    public void validate() throws TException {
      // check for required fields
    }

  }

  public static class copyNote_result implements TBase<copyNote_result._Fields>, java.io.Serializable, Cloneable, Comparable<copyNote_result>   {
    private static final TStruct STRUCT_DESC = new TStruct("copyNote_result");

    private static final TField SUCCESS_FIELD_DESC = new TField("success", TType.STRUCT, (short)0);
    private static final TField USER_EXCEPTION_FIELD_DESC = new TField("userException", TType.STRUCT, (short)1);
    private static final TField SYSTEM_EXCEPTION_FIELD_DESC = new TField("systemException", TType.STRUCT, (short)2);
    private static final TField NOT_FOUND_EXCEPTION_FIELD_DESC = new TField("notFoundException", TType.STRUCT, (short)3);

    private com.evernote.edam.type.Note success;
    private com.evernote.edam.error.EDAMUserException userException;
    private com.evernote.edam.error.EDAMSystemException systemException;
    private com.evernote.edam.error.EDAMNotFoundException notFoundException;

    /** The set of fields this struct contains, along with convenience methods for finding and manipulating them. */
    public enum _Fields implements TFieldIdEnum {
      SUCCESS((short)0, "success"),
      USER_EXCEPTION((short)1, "userException"),
      SYSTEM_EXCEPTION((short)2, "systemException"),
      NOT_FOUND_EXCEPTION((short)3, "notFoundException");

      private static final Map<Integer, _Fields> byId = new HashMap<Integer, _Fields>();
      private static final Map<String, _Fields> byName = new HashMap<String, _Fields>();

      static {
        for (_Fields field : EnumSet.allOf(_Fields.class)) {
          byId.put((int)field._thriftId, field);
          byName.put(field.getFieldName(), field);
        }
      }

      /**
       * Find the _Fields constant that matches fieldId, or null if its not found.
       */
      public static _Fields findByThriftId(int fieldId) {
        return byId.get(fieldId);
      }

      /**
       * Find the _Fields constant that matches fieldId, throwing an exception
       * if it is not found.
       */
      public static _Fields findByThriftIdOrThrow(int fieldId) {
        _Fields fields = findByThriftId(fieldId);
        if (fields == null) throw new IllegalArgumentException("Field " + fieldId + " doesn't exist!");
        return fields;
      }

      /**
       * Find the _Fields constant that matches name, or null if its not found.
       */
      public static _Fields findByName(String name) {
        return byName.get(name);
      }

      private final short _thriftId;
      private final String _fieldName;

      _Fields(short thriftId, String fieldName) {
        _thriftId = thriftId;
        _fieldName = fieldName;
      }

      public short getThriftFieldId() {
        return _thriftId;
      }

      public String getFieldName() {
        return _fieldName;
      }
    }

    // isset id assignments

    public static final Map<_Fields, FieldMetaData> metaDataMap = Collections.unmodifiableMap(new EnumMap<_Fields, FieldMetaData>(_Fields.class) {{
      put(_Fields.SUCCESS, new FieldMetaData("success", TFieldRequirementType.DEFAULT, 
          new StructMetaData(TType.STRUCT, com.evernote.edam.type.Note.class)));
      put(_Fields.USER_EXCEPTION, new FieldMetaData("userException", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.STRUCT)));
      put(_Fields.SYSTEM_EXCEPTION, new FieldMetaData("systemException", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.STRUCT)));
      put(_Fields.NOT_FOUND_EXCEPTION, new FieldMetaData("notFoundException", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.STRUCT)));
    }});

    static {
      FieldMetaData.addStructMetaDataMap(copyNote_result.class, metaDataMap);
    }

    public copyNote_result() {
    }

    public copyNote_result(
      com.evernote.edam.type.Note success,
      com.evernote.edam.error.EDAMUserException userException,
      com.evernote.edam.error.EDAMSystemException systemException,
      com.evernote.edam.error.EDAMNotFoundException notFoundException)
    {
      this();
      this.success = success;
      this.userException = userException;
      this.systemException = systemException;
      this.notFoundException = notFoundException;
    }

    /**
     * Performs a deep copy on <i>other</i>.
     */
    public copyNote_result(copyNote_result other) {
      if (other.isSetSuccess()) {
        this.success = new com.evernote.edam.type.Note(other.success);
      }
      if (other.isSetUserException()) {
        this.userException = new com.evernote.edam.error.EDAMUserException(other.userException);
      }
      if (other.isSetSystemException()) {
        this.systemException = new com.evernote.edam.error.EDAMSystemException(other.systemException);
      }
      if (other.isSetNotFoundException()) {
        this.notFoundException = new com.evernote.edam.error.EDAMNotFoundException(other.notFoundException);
      }
    }

    public copyNote_result deepCopy() {
      return new copyNote_result(this);
    }

    @Deprecated
    public copyNote_result clone() {
      return new copyNote_result(this);
    }

    public com.evernote.edam.type.Note getSuccess() {
      return this.success;
    }

    public void setSuccess(com.evernote.edam.type.Note success) {
      this.success = success;
    }

    public void unsetSuccess() {
      this.success = null;
    }

    /** Returns true if field success is set (has been asigned a value) and false otherwise */
    public boolean isSetSuccess() {
      return this.success != null;
    }

    public void setSuccessIsSet(boolean value) {
      if (!value) {
        this.success = null;
      }
    }

    public com.evernote.edam.error.EDAMUserException getUserException() {
      return this.userException;
    }

    public void setUserException(com.evernote.edam.error.EDAMUserException userException) {
      this.userException = userException;
    }

    public void unsetUserException() {
      this.userException = null;
    }

    /** Returns true if field userException is set (has been asigned a value) and false otherwise */
    public boolean isSetUserException() {
      return this.userException != null;
    }

    public void setUserExceptionIsSet(boolean value) {
      if (!value) {
        this.userException = null;
      }
    }

    public com.evernote.edam.error.EDAMSystemException getSystemException() {
      return this.systemException;
    }

    public void setSystemException(com.evernote.edam.error.EDAMSystemException systemException) {
      this.systemException = systemException;
    }

    public void unsetSystemException() {
      this.systemException = null;
    }

    /** Returns true if field systemException is set (has been asigned a value) and false otherwise */
    public boolean isSetSystemException() {
      return this.systemException != null;
    }

    public void setSystemExceptionIsSet(boolean value) {
      if (!value) {
        this.systemException = null;
      }
    }

    public com.evernote.edam.error.EDAMNotFoundException getNotFoundException() {
      return this.notFoundException;
    }

    public void setNotFoundException(com.evernote.edam.error.EDAMNotFoundException notFoundException) {
      this.notFoundException = notFoundException;
    }

    public void unsetNotFoundException() {
      this.notFoundException = null;
    }

    /** Returns true if field notFoundException is set (has been asigned a value) and false otherwise */
    public boolean isSetNotFoundException() {
      return this.notFoundException != null;
    }

    public void setNotFoundExceptionIsSet(boolean value) {
      if (!value) {
        this.notFoundException = null;
      }
    }

    public void setFieldValue(_Fields field, Object value) {
      switch (field) {
      case SUCCESS:
        if (value == null) {
          unsetSuccess();
        } else {
          setSuccess((com.evernote.edam.type.Note)value);
        }
        break;

      case USER_EXCEPTION:
        if (value == null) {
          unsetUserException();
        } else {
          setUserException((com.evernote.edam.error.EDAMUserException)value);
        }
        break;

      case SYSTEM_EXCEPTION:
        if (value == null) {
          unsetSystemException();
        } else {
          setSystemException((com.evernote.edam.error.EDAMSystemException)value);
        }
        break;

      case NOT_FOUND_EXCEPTION:
        if (value == null) {
          unsetNotFoundException();
        } else {
          setNotFoundException((com.evernote.edam.error.EDAMNotFoundException)value);
        }
        break;

      }
    }

    public void setFieldValue(int fieldID, Object value) {
      setFieldValue(_Fields.findByThriftIdOrThrow(fieldID), value);
    }

    public Object getFieldValue(_Fields field) {
      switch (field) {
      case SUCCESS:
        return getSuccess();

      case USER_EXCEPTION:
        return getUserException();

      case SYSTEM_EXCEPTION:
        return getSystemException();

      case NOT_FOUND_EXCEPTION:
        return getNotFoundException();

      }
      throw new IllegalStateException();
    }

    public Object getFieldValue(int fieldId) {
      return getFieldValue(_Fields.findByThriftIdOrThrow(fieldId));
    }

    /** Returns true if field corresponding to fieldID is set (has been asigned a value) and false otherwise */
    public boolean isSet(_Fields field) {
      switch (field) {
      case SUCCESS:
        return isSetSuccess();
      case USER_EXCEPTION:
        return isSetUserException();
      case SYSTEM_EXCEPTION:
        return isSetSystemException();
      case NOT_FOUND_EXCEPTION:
        return isSetNotFoundException();
      }
      throw new IllegalStateException();
    }

    public boolean isSet(int fieldID) {
      return isSet(_Fields.findByThriftIdOrThrow(fieldID));
    }

    public boolean equals(Object that) {
      if (that == null)
        return false;
      if (that instanceof copyNote_result)
        return this.equals((copyNote_result)that);
      return false;
    }

    public boolean equals(copyNote_result that) {
      if (that == null)
        return false;

      boolean this_present_success = true && this.isSetSuccess();
      boolean that_present_success = true && that.isSetSuccess();
      if (this_present_success || that_present_success) {
        if (!(this_present_success && that_present_success))
          return false;
        if (!this.success.equals(that.success))
          return false;
      }

      boolean this_present_userException = true && this.isSetUserException();
      boolean that_present_userException = true && that.isSetUserException();
      if (this_present_userException || that_present_userException) {
        if (!(this_present_userException && that_present_userException))
          return false;
        if (!this.userException.equals(that.userException))
          return false;
      }

      boolean this_present_systemException = true && this.isSetSystemException();
      boolean that_present_systemException = true && that.isSetSystemException();
      if (this_present_systemException || that_present_systemException) {
        if (!(this_present_systemException && that_present_systemException))
          return false;
        if (!this.systemException.equals(that.systemException))
          return false;
      }

      boolean this_present_notFoundException = true && this.isSetNotFoundException();
      boolean that_present_notFoundException = true && that.isSetNotFoundException();
      if (this_present_notFoundException || that_present_notFoundException) {
        if (!(this_present_notFoundException && that_present_notFoundException))
          return false;
        if (!this.notFoundException.equals(that.notFoundException))
          return false;
      }

      return true;
    }

    public int hashCode() {
      return 0;
    }

    public int compareTo(copyNote_result other) {
      if (!getClass().equals(other.getClass())) {
        return getClass().getName().compareTo(other.getClass().getName());
      }

      int lastComparison = 0;
      copyNote_result typedOther = (copyNote_result)other;

      lastComparison = Boolean.valueOf(isSetSuccess()).compareTo(isSetSuccess());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(success, typedOther.success);
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = Boolean.valueOf(isSetUserException()).compareTo(isSetUserException());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(userException, typedOther.userException);
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = Boolean.valueOf(isSetSystemException()).compareTo(isSetSystemException());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(systemException, typedOther.systemException);
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = Boolean.valueOf(isSetNotFoundException()).compareTo(isSetNotFoundException());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(notFoundException, typedOther.notFoundException);
      if (lastComparison != 0) {
        return lastComparison;
      }
      return 0;
    }

    public void read(TProtocol iprot) throws TException {
      TField field;
      iprot.readStructBegin();
      while (true)
      {
        field = iprot.readFieldBegin();
        if (field.type == TType.STOP) { 
          break;
        }
        _Fields fieldId = _Fields.findByThriftId(field.id);
        if (fieldId == null) {
          TProtocolUtil.skip(iprot, field.type);
        } else {
          switch (fieldId) {
            case SUCCESS:
              if (field.type == TType.STRUCT) {
                this.success = new com.evernote.edam.type.Note();
                this.success.read(iprot);
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
            case USER_EXCEPTION:
              if (field.type == TType.STRUCT) {
                this.userException = new com.evernote.edam.error.EDAMUserException();
                this.userException.read(iprot);
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
            case SYSTEM_EXCEPTION:
              if (field.type == TType.STRUCT) {
                this.systemException = new com.evernote.edam.error.EDAMSystemException();
                this.systemException.read(iprot);
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
            case NOT_FOUND_EXCEPTION:
              if (field.type == TType.STRUCT) {
                this.notFoundException = new com.evernote.edam.error.EDAMNotFoundException();
                this.notFoundException.read(iprot);
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
          }
          iprot.readFieldEnd();
        }
      }
      iprot.readStructEnd();
      validate();
    }

    public void write(TProtocol oprot) throws TException {
      oprot.writeStructBegin(STRUCT_DESC);

      if (this.isSetSuccess()) {
        oprot.writeFieldBegin(SUCCESS_FIELD_DESC);
        this.success.write(oprot);
        oprot.writeFieldEnd();
      } else if (this.isSetUserException()) {
        oprot.writeFieldBegin(USER_EXCEPTION_FIELD_DESC);
        this.userException.write(oprot);
        oprot.writeFieldEnd();
      } else if (this.isSetSystemException()) {
        oprot.writeFieldBegin(SYSTEM_EXCEPTION_FIELD_DESC);
        this.systemException.write(oprot);
        oprot.writeFieldEnd();
      } else if (this.isSetNotFoundException()) {
        oprot.writeFieldBegin(NOT_FOUND_EXCEPTION_FIELD_DESC);
        this.notFoundException.write(oprot);
        oprot.writeFieldEnd();
      }
      oprot.writeFieldStop();
      oprot.writeStructEnd();
    }

    public String toString() {
      StringBuilder sb = new StringBuilder("copyNote_result(");
      boolean first = true;

      sb.append("success:");
      if (this.success == null) {
        sb.append("null");
      } else {
        sb.append(this.success);
      }
      first = false;
      if (!first) sb.append(", ");
      sb.append("userException:");
      if (this.userException == null) {
        sb.append("null");
      } else {
        sb.append(this.userException);
      }
      first = false;
      if (!first) sb.append(", ");
      sb.append("systemException:");
      if (this.systemException == null) {
        sb.append("null");
      } else {
        sb.append(this.systemException);
      }
      first = false;
      if (!first) sb.append(", ");
      sb.append("notFoundException:");
      if (this.notFoundException == null) {
        sb.append("null");
      } else {
        sb.append(this.notFoundException);
      }
      first = false;
      sb.append(")");
      return sb.toString();
    }

    public void validate() throws TException {
      // check for required fields
    }

  }

  public static class listNoteVersions_args implements TBase<listNoteVersions_args._Fields>, java.io.Serializable, Cloneable, Comparable<listNoteVersions_args>   {
    private static final TStruct STRUCT_DESC = new TStruct("listNoteVersions_args");

    private static final TField AUTHENTICATION_TOKEN_FIELD_DESC = new TField("authenticationToken", TType.STRING, (short)1);
    private static final TField NOTE_GUID_FIELD_DESC = new TField("noteGuid", TType.STRING, (short)2);

    private String authenticationToken;
    private String noteGuid;

    /** The set of fields this struct contains, along with convenience methods for finding and manipulating them. */
    public enum _Fields implements TFieldIdEnum {
      AUTHENTICATION_TOKEN((short)1, "authenticationToken"),
      NOTE_GUID((short)2, "noteGuid");

      private static final Map<Integer, _Fields> byId = new HashMap<Integer, _Fields>();
      private static final Map<String, _Fields> byName = new HashMap<String, _Fields>();

      static {
        for (_Fields field : EnumSet.allOf(_Fields.class)) {
          byId.put((int)field._thriftId, field);
          byName.put(field.getFieldName(), field);
        }
      }

      /**
       * Find the _Fields constant that matches fieldId, or null if its not found.
       */
      public static _Fields findByThriftId(int fieldId) {
        return byId.get(fieldId);
      }

      /**
       * Find the _Fields constant that matches fieldId, throwing an exception
       * if it is not found.
       */
      public static _Fields findByThriftIdOrThrow(int fieldId) {
        _Fields fields = findByThriftId(fieldId);
        if (fields == null) throw new IllegalArgumentException("Field " + fieldId + " doesn't exist!");
        return fields;
      }

      /**
       * Find the _Fields constant that matches name, or null if its not found.
       */
      public static _Fields findByName(String name) {
        return byName.get(name);
      }

      private final short _thriftId;
      private final String _fieldName;

      _Fields(short thriftId, String fieldName) {
        _thriftId = thriftId;
        _fieldName = fieldName;
      }

      public short getThriftFieldId() {
        return _thriftId;
      }

      public String getFieldName() {
        return _fieldName;
      }
    }

    // isset id assignments

    public static final Map<_Fields, FieldMetaData> metaDataMap = Collections.unmodifiableMap(new EnumMap<_Fields, FieldMetaData>(_Fields.class) {{
      put(_Fields.AUTHENTICATION_TOKEN, new FieldMetaData("authenticationToken", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.STRING)));
      put(_Fields.NOTE_GUID, new FieldMetaData("noteGuid", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.STRING)));
    }});

    static {
      FieldMetaData.addStructMetaDataMap(listNoteVersions_args.class, metaDataMap);
    }

    public listNoteVersions_args() {
    }

    public listNoteVersions_args(
      String authenticationToken,
      String noteGuid)
    {
      this();
      this.authenticationToken = authenticationToken;
      this.noteGuid = noteGuid;
    }

    /**
     * Performs a deep copy on <i>other</i>.
     */
    public listNoteVersions_args(listNoteVersions_args other) {
      if (other.isSetAuthenticationToken()) {
        this.authenticationToken = other.authenticationToken;
      }
      if (other.isSetNoteGuid()) {
        this.noteGuid = other.noteGuid;
      }
    }

    public listNoteVersions_args deepCopy() {
      return new listNoteVersions_args(this);
    }

    @Deprecated
    public listNoteVersions_args clone() {
      return new listNoteVersions_args(this);
    }

    public String getAuthenticationToken() {
      return this.authenticationToken;
    }

    public void setAuthenticationToken(String authenticationToken) {
      this.authenticationToken = authenticationToken;
    }

    public void unsetAuthenticationToken() {
      this.authenticationToken = null;
    }

    /** Returns true if field authenticationToken is set (has been asigned a value) and false otherwise */
    public boolean isSetAuthenticationToken() {
      return this.authenticationToken != null;
    }

    public void setAuthenticationTokenIsSet(boolean value) {
      if (!value) {
        this.authenticationToken = null;
      }
    }

    public String getNoteGuid() {
      return this.noteGuid;
    }

    public void setNoteGuid(String noteGuid) {
      this.noteGuid = noteGuid;
    }

    public void unsetNoteGuid() {
      this.noteGuid = null;
    }

    /** Returns true if field noteGuid is set (has been asigned a value) and false otherwise */
    public boolean isSetNoteGuid() {
      return this.noteGuid != null;
    }

    public void setNoteGuidIsSet(boolean value) {
      if (!value) {
        this.noteGuid = null;
      }
    }

    public void setFieldValue(_Fields field, Object value) {
      switch (field) {
      case AUTHENTICATION_TOKEN:
        if (value == null) {
          unsetAuthenticationToken();
        } else {
          setAuthenticationToken((String)value);
        }
        break;

      case NOTE_GUID:
        if (value == null) {
          unsetNoteGuid();
        } else {
          setNoteGuid((String)value);
        }
        break;

      }
    }

    public void setFieldValue(int fieldID, Object value) {
      setFieldValue(_Fields.findByThriftIdOrThrow(fieldID), value);
    }

    public Object getFieldValue(_Fields field) {
      switch (field) {
      case AUTHENTICATION_TOKEN:
        return getAuthenticationToken();

      case NOTE_GUID:
        return getNoteGuid();

      }
      throw new IllegalStateException();
    }

    public Object getFieldValue(int fieldId) {
      return getFieldValue(_Fields.findByThriftIdOrThrow(fieldId));
    }

    /** Returns true if field corresponding to fieldID is set (has been asigned a value) and false otherwise */
    public boolean isSet(_Fields field) {
      switch (field) {
      case AUTHENTICATION_TOKEN:
        return isSetAuthenticationToken();
      case NOTE_GUID:
        return isSetNoteGuid();
      }
      throw new IllegalStateException();
    }

    public boolean isSet(int fieldID) {
      return isSet(_Fields.findByThriftIdOrThrow(fieldID));
    }

    public boolean equals(Object that) {
      if (that == null)
        return false;
      if (that instanceof listNoteVersions_args)
        return this.equals((listNoteVersions_args)that);
      return false;
    }

    public boolean equals(listNoteVersions_args that) {
      if (that == null)
        return false;

      boolean this_present_authenticationToken = true && this.isSetAuthenticationToken();
      boolean that_present_authenticationToken = true && that.isSetAuthenticationToken();
      if (this_present_authenticationToken || that_present_authenticationToken) {
        if (!(this_present_authenticationToken && that_present_authenticationToken))
          return false;
        if (!this.authenticationToken.equals(that.authenticationToken))
          return false;
      }

      boolean this_present_noteGuid = true && this.isSetNoteGuid();
      boolean that_present_noteGuid = true && that.isSetNoteGuid();
      if (this_present_noteGuid || that_present_noteGuid) {
        if (!(this_present_noteGuid && that_present_noteGuid))
          return false;
        if (!this.noteGuid.equals(that.noteGuid))
          return false;
      }

      return true;
    }

    public int hashCode() {
      return 0;
    }

    public int compareTo(listNoteVersions_args other) {
      if (!getClass().equals(other.getClass())) {
        return getClass().getName().compareTo(other.getClass().getName());
      }

      int lastComparison = 0;
      listNoteVersions_args typedOther = (listNoteVersions_args)other;

      lastComparison = Boolean.valueOf(isSetAuthenticationToken()).compareTo(isSetAuthenticationToken());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(authenticationToken, typedOther.authenticationToken);
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = Boolean.valueOf(isSetNoteGuid()).compareTo(isSetNoteGuid());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(noteGuid, typedOther.noteGuid);
      if (lastComparison != 0) {
        return lastComparison;
      }
      return 0;
    }

    public void read(TProtocol iprot) throws TException {
      TField field;
      iprot.readStructBegin();
      while (true)
      {
        field = iprot.readFieldBegin();
        if (field.type == TType.STOP) { 
          break;
        }
        _Fields fieldId = _Fields.findByThriftId(field.id);
        if (fieldId == null) {
          TProtocolUtil.skip(iprot, field.type);
        } else {
          switch (fieldId) {
            case AUTHENTICATION_TOKEN:
              if (field.type == TType.STRING) {
                this.authenticationToken = iprot.readString();
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
            case NOTE_GUID:
              if (field.type == TType.STRING) {
                this.noteGuid = iprot.readString();
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
          }
          iprot.readFieldEnd();
        }
      }
      iprot.readStructEnd();
      validate();
    }

    public void write(TProtocol oprot) throws TException {
      validate();

      oprot.writeStructBegin(STRUCT_DESC);
      if (this.authenticationToken != null) {
        oprot.writeFieldBegin(AUTHENTICATION_TOKEN_FIELD_DESC);
        oprot.writeString(this.authenticationToken);
        oprot.writeFieldEnd();
      }
      if (this.noteGuid != null) {
        oprot.writeFieldBegin(NOTE_GUID_FIELD_DESC);
        oprot.writeString(this.noteGuid);
        oprot.writeFieldEnd();
      }
      oprot.writeFieldStop();
      oprot.writeStructEnd();
    }

    public String toString() {
      StringBuilder sb = new StringBuilder("listNoteVersions_args(");
      boolean first = true;

      sb.append("authenticationToken:");
      if (this.authenticationToken == null) {
        sb.append("null");
      } else {
        sb.append(this.authenticationToken);
      }
      first = false;
      if (!first) sb.append(", ");
      sb.append("noteGuid:");
      if (this.noteGuid == null) {
        sb.append("null");
      } else {
        sb.append(this.noteGuid);
      }
      first = false;
      sb.append(")");
      return sb.toString();
    }

    public void validate() throws TException {
      // check for required fields
    }

  }

  public static class listNoteVersions_result implements TBase<listNoteVersions_result._Fields>, java.io.Serializable, Cloneable, Comparable<listNoteVersions_result>   {
    private static final TStruct STRUCT_DESC = new TStruct("listNoteVersions_result");

    private static final TField SUCCESS_FIELD_DESC = new TField("success", TType.LIST, (short)0);
    private static final TField USER_EXCEPTION_FIELD_DESC = new TField("userException", TType.STRUCT, (short)1);
    private static final TField SYSTEM_EXCEPTION_FIELD_DESC = new TField("systemException", TType.STRUCT, (short)2);
    private static final TField NOT_FOUND_EXCEPTION_FIELD_DESC = new TField("notFoundException", TType.STRUCT, (short)3);

    private List<NoteVersionId> success;
    private com.evernote.edam.error.EDAMUserException userException;
    private com.evernote.edam.error.EDAMSystemException systemException;
    private com.evernote.edam.error.EDAMNotFoundException notFoundException;

    /** The set of fields this struct contains, along with convenience methods for finding and manipulating them. */
    public enum _Fields implements TFieldIdEnum {
      SUCCESS((short)0, "success"),
      USER_EXCEPTION((short)1, "userException"),
      SYSTEM_EXCEPTION((short)2, "systemException"),
      NOT_FOUND_EXCEPTION((short)3, "notFoundException");

      private static final Map<Integer, _Fields> byId = new HashMap<Integer, _Fields>();
      private static final Map<String, _Fields> byName = new HashMap<String, _Fields>();

      static {
        for (_Fields field : EnumSet.allOf(_Fields.class)) {
          byId.put((int)field._thriftId, field);
          byName.put(field.getFieldName(), field);
        }
      }

      /**
       * Find the _Fields constant that matches fieldId, or null if its not found.
       */
      public static _Fields findByThriftId(int fieldId) {
        return byId.get(fieldId);
      }

      /**
       * Find the _Fields constant that matches fieldId, throwing an exception
       * if it is not found.
       */
      public static _Fields findByThriftIdOrThrow(int fieldId) {
        _Fields fields = findByThriftId(fieldId);
        if (fields == null) throw new IllegalArgumentException("Field " + fieldId + " doesn't exist!");
        return fields;
      }

      /**
       * Find the _Fields constant that matches name, or null if its not found.
       */
      public static _Fields findByName(String name) {
        return byName.get(name);
      }

      private final short _thriftId;
      private final String _fieldName;

      _Fields(short thriftId, String fieldName) {
        _thriftId = thriftId;
        _fieldName = fieldName;
      }

      public short getThriftFieldId() {
        return _thriftId;
      }

      public String getFieldName() {
        return _fieldName;
      }
    }

    // isset id assignments

    public static final Map<_Fields, FieldMetaData> metaDataMap = Collections.unmodifiableMap(new EnumMap<_Fields, FieldMetaData>(_Fields.class) {{
      put(_Fields.SUCCESS, new FieldMetaData("success", TFieldRequirementType.DEFAULT, 
          new ListMetaData(TType.LIST, 
              new StructMetaData(TType.STRUCT, NoteVersionId.class))));
      put(_Fields.USER_EXCEPTION, new FieldMetaData("userException", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.STRUCT)));
      put(_Fields.SYSTEM_EXCEPTION, new FieldMetaData("systemException", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.STRUCT)));
      put(_Fields.NOT_FOUND_EXCEPTION, new FieldMetaData("notFoundException", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.STRUCT)));
    }});

    static {
      FieldMetaData.addStructMetaDataMap(listNoteVersions_result.class, metaDataMap);
    }

    public listNoteVersions_result() {
    }

    public listNoteVersions_result(
      List<NoteVersionId> success,
      com.evernote.edam.error.EDAMUserException userException,
      com.evernote.edam.error.EDAMSystemException systemException,
      com.evernote.edam.error.EDAMNotFoundException notFoundException)
    {
      this();
      this.success = success;
      this.userException = userException;
      this.systemException = systemException;
      this.notFoundException = notFoundException;
    }

    /**
     * Performs a deep copy on <i>other</i>.
     */
    public listNoteVersions_result(listNoteVersions_result other) {
      if (other.isSetSuccess()) {
        List<NoteVersionId> __this__success = new ArrayList<NoteVersionId>();
        for (NoteVersionId other_element : other.success) {
          __this__success.add(new NoteVersionId(other_element));
        }
        this.success = __this__success;
      }
      if (other.isSetUserException()) {
        this.userException = new com.evernote.edam.error.EDAMUserException(other.userException);
      }
      if (other.isSetSystemException()) {
        this.systemException = new com.evernote.edam.error.EDAMSystemException(other.systemException);
      }
      if (other.isSetNotFoundException()) {
        this.notFoundException = new com.evernote.edam.error.EDAMNotFoundException(other.notFoundException);
      }
    }

    public listNoteVersions_result deepCopy() {
      return new listNoteVersions_result(this);
    }

    @Deprecated
    public listNoteVersions_result clone() {
      return new listNoteVersions_result(this);
    }

    public int getSuccessSize() {
      return (this.success == null) ? 0 : this.success.size();
    }

    public java.util.Iterator<NoteVersionId> getSuccessIterator() {
      return (this.success == null) ? null : this.success.iterator();
    }

    public void addToSuccess(NoteVersionId elem) {
      if (this.success == null) {
        this.success = new ArrayList<NoteVersionId>();
      }
      this.success.add(elem);
    }

    public List<NoteVersionId> getSuccess() {
      return this.success;
    }

    public void setSuccess(List<NoteVersionId> success) {
      this.success = success;
    }

    public void unsetSuccess() {
      this.success = null;
    }

    /** Returns true if field success is set (has been asigned a value) and false otherwise */
    public boolean isSetSuccess() {
      return this.success != null;
    }

    public void setSuccessIsSet(boolean value) {
      if (!value) {
        this.success = null;
      }
    }

    public com.evernote.edam.error.EDAMUserException getUserException() {
      return this.userException;
    }

    public void setUserException(com.evernote.edam.error.EDAMUserException userException) {
      this.userException = userException;
    }

    public void unsetUserException() {
      this.userException = null;
    }

    /** Returns true if field userException is set (has been asigned a value) and false otherwise */
    public boolean isSetUserException() {
      return this.userException != null;
    }

    public void setUserExceptionIsSet(boolean value) {
      if (!value) {
        this.userException = null;
      }
    }

    public com.evernote.edam.error.EDAMSystemException getSystemException() {
      return this.systemException;
    }

    public void setSystemException(com.evernote.edam.error.EDAMSystemException systemException) {
      this.systemException = systemException;
    }

    public void unsetSystemException() {
      this.systemException = null;
    }

    /** Returns true if field systemException is set (has been asigned a value) and false otherwise */
    public boolean isSetSystemException() {
      return this.systemException != null;
    }

    public void setSystemExceptionIsSet(boolean value) {
      if (!value) {
        this.systemException = null;
      }
    }

    public com.evernote.edam.error.EDAMNotFoundException getNotFoundException() {
      return this.notFoundException;
    }

    public void setNotFoundException(com.evernote.edam.error.EDAMNotFoundException notFoundException) {
      this.notFoundException = notFoundException;
    }

    public void unsetNotFoundException() {
      this.notFoundException = null;
    }

    /** Returns true if field notFoundException is set (has been asigned a value) and false otherwise */
    public boolean isSetNotFoundException() {
      return this.notFoundException != null;
    }

    public void setNotFoundExceptionIsSet(boolean value) {
      if (!value) {
        this.notFoundException = null;
      }
    }

    public void setFieldValue(_Fields field, Object value) {
      switch (field) {
      case SUCCESS:
        if (value == null) {
          unsetSuccess();
        } else {
          setSuccess((List<NoteVersionId>)value);
        }
        break;

      case USER_EXCEPTION:
        if (value == null) {
          unsetUserException();
        } else {
          setUserException((com.evernote.edam.error.EDAMUserException)value);
        }
        break;

      case SYSTEM_EXCEPTION:
        if (value == null) {
          unsetSystemException();
        } else {
          setSystemException((com.evernote.edam.error.EDAMSystemException)value);
        }
        break;

      case NOT_FOUND_EXCEPTION:
        if (value == null) {
          unsetNotFoundException();
        } else {
          setNotFoundException((com.evernote.edam.error.EDAMNotFoundException)value);
        }
        break;

      }
    }

    public void setFieldValue(int fieldID, Object value) {
      setFieldValue(_Fields.findByThriftIdOrThrow(fieldID), value);
    }

    public Object getFieldValue(_Fields field) {
      switch (field) {
      case SUCCESS:
        return getSuccess();

      case USER_EXCEPTION:
        return getUserException();

      case SYSTEM_EXCEPTION:
        return getSystemException();

      case NOT_FOUND_EXCEPTION:
        return getNotFoundException();

      }
      throw new IllegalStateException();
    }

    public Object getFieldValue(int fieldId) {
      return getFieldValue(_Fields.findByThriftIdOrThrow(fieldId));
    }

    /** Returns true if field corresponding to fieldID is set (has been asigned a value) and false otherwise */
    public boolean isSet(_Fields field) {
      switch (field) {
      case SUCCESS:
        return isSetSuccess();
      case USER_EXCEPTION:
        return isSetUserException();
      case SYSTEM_EXCEPTION:
        return isSetSystemException();
      case NOT_FOUND_EXCEPTION:
        return isSetNotFoundException();
      }
      throw new IllegalStateException();
    }

    public boolean isSet(int fieldID) {
      return isSet(_Fields.findByThriftIdOrThrow(fieldID));
    }

    public boolean equals(Object that) {
      if (that == null)
        return false;
      if (that instanceof listNoteVersions_result)
        return this.equals((listNoteVersions_result)that);
      return false;
    }

    public boolean equals(listNoteVersions_result that) {
      if (that == null)
        return false;

      boolean this_present_success = true && this.isSetSuccess();
      boolean that_present_success = true && that.isSetSuccess();
      if (this_present_success || that_present_success) {
        if (!(this_present_success && that_present_success))
          return false;
        if (!this.success.equals(that.success))
          return false;
      }

      boolean this_present_userException = true && this.isSetUserException();
      boolean that_present_userException = true && that.isSetUserException();
      if (this_present_userException || that_present_userException) {
        if (!(this_present_userException && that_present_userException))
          return false;
        if (!this.userException.equals(that.userException))
          return false;
      }

      boolean this_present_systemException = true && this.isSetSystemException();
      boolean that_present_systemException = true && that.isSetSystemException();
      if (this_present_systemException || that_present_systemException) {
        if (!(this_present_systemException && that_present_systemException))
          return false;
        if (!this.systemException.equals(that.systemException))
          return false;
      }

      boolean this_present_notFoundException = true && this.isSetNotFoundException();
      boolean that_present_notFoundException = true && that.isSetNotFoundException();
      if (this_present_notFoundException || that_present_notFoundException) {
        if (!(this_present_notFoundException && that_present_notFoundException))
          return false;
        if (!this.notFoundException.equals(that.notFoundException))
          return false;
      }

      return true;
    }

    public int hashCode() {
      return 0;
    }

    public int compareTo(listNoteVersions_result other) {
      if (!getClass().equals(other.getClass())) {
        return getClass().getName().compareTo(other.getClass().getName());
      }

      int lastComparison = 0;
      listNoteVersions_result typedOther = (listNoteVersions_result)other;

      lastComparison = Boolean.valueOf(isSetSuccess()).compareTo(isSetSuccess());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(success, typedOther.success);
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = Boolean.valueOf(isSetUserException()).compareTo(isSetUserException());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(userException, typedOther.userException);
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = Boolean.valueOf(isSetSystemException()).compareTo(isSetSystemException());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(systemException, typedOther.systemException);
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = Boolean.valueOf(isSetNotFoundException()).compareTo(isSetNotFoundException());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(notFoundException, typedOther.notFoundException);
      if (lastComparison != 0) {
        return lastComparison;
      }
      return 0;
    }

    public void read(TProtocol iprot) throws TException {
      TField field;
      iprot.readStructBegin();
      while (true)
      {
        field = iprot.readFieldBegin();
        if (field.type == TType.STOP) { 
          break;
        }
        _Fields fieldId = _Fields.findByThriftId(field.id);
        if (fieldId == null) {
          TProtocolUtil.skip(iprot, field.type);
        } else {
          switch (fieldId) {
            case SUCCESS:
              if (field.type == TType.LIST) {
                {
                  TList _list103 = iprot.readListBegin();
                  this.success = new ArrayList<NoteVersionId>(_list103.size);
                  for (int _i104 = 0; _i104 < _list103.size; ++_i104)
                  {
                    NoteVersionId _elem105;
                    _elem105 = new NoteVersionId();
                    _elem105.read(iprot);
                    this.success.add(_elem105);
                  }
                  iprot.readListEnd();
                }
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
            case USER_EXCEPTION:
              if (field.type == TType.STRUCT) {
                this.userException = new com.evernote.edam.error.EDAMUserException();
                this.userException.read(iprot);
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
            case SYSTEM_EXCEPTION:
              if (field.type == TType.STRUCT) {
                this.systemException = new com.evernote.edam.error.EDAMSystemException();
                this.systemException.read(iprot);
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
            case NOT_FOUND_EXCEPTION:
              if (field.type == TType.STRUCT) {
                this.notFoundException = new com.evernote.edam.error.EDAMNotFoundException();
                this.notFoundException.read(iprot);
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
          }
          iprot.readFieldEnd();
        }
      }
      iprot.readStructEnd();
      validate();
    }

    public void write(TProtocol oprot) throws TException {
      oprot.writeStructBegin(STRUCT_DESC);

      if (this.isSetSuccess()) {
        oprot.writeFieldBegin(SUCCESS_FIELD_DESC);
        {
          oprot.writeListBegin(new TList(TType.STRUCT, this.success.size()));
          for (NoteVersionId _iter106 : this.success)
          {
            _iter106.write(oprot);
          }
          oprot.writeListEnd();
        }
        oprot.writeFieldEnd();
      } else if (this.isSetUserException()) {
        oprot.writeFieldBegin(USER_EXCEPTION_FIELD_DESC);
        this.userException.write(oprot);
        oprot.writeFieldEnd();
      } else if (this.isSetSystemException()) {
        oprot.writeFieldBegin(SYSTEM_EXCEPTION_FIELD_DESC);
        this.systemException.write(oprot);
        oprot.writeFieldEnd();
      } else if (this.isSetNotFoundException()) {
        oprot.writeFieldBegin(NOT_FOUND_EXCEPTION_FIELD_DESC);
        this.notFoundException.write(oprot);
        oprot.writeFieldEnd();
      }
      oprot.writeFieldStop();
      oprot.writeStructEnd();
    }

    public String toString() {
      StringBuilder sb = new StringBuilder("listNoteVersions_result(");
      boolean first = true;

      sb.append("success:");
      if (this.success == null) {
        sb.append("null");
      } else {
        sb.append(this.success);
      }
      first = false;
      if (!first) sb.append(", ");
      sb.append("userException:");
      if (this.userException == null) {
        sb.append("null");
      } else {
        sb.append(this.userException);
      }
      first = false;
      if (!first) sb.append(", ");
      sb.append("systemException:");
      if (this.systemException == null) {
        sb.append("null");
      } else {
        sb.append(this.systemException);
      }
      first = false;
      if (!first) sb.append(", ");
      sb.append("notFoundException:");
      if (this.notFoundException == null) {
        sb.append("null");
      } else {
        sb.append(this.notFoundException);
      }
      first = false;
      sb.append(")");
      return sb.toString();
    }

    public void validate() throws TException {
      // check for required fields
    }

  }

  public static class getNoteVersion_args implements TBase<getNoteVersion_args._Fields>, java.io.Serializable, Cloneable, Comparable<getNoteVersion_args>   {
    private static final TStruct STRUCT_DESC = new TStruct("getNoteVersion_args");

    private static final TField AUTHENTICATION_TOKEN_FIELD_DESC = new TField("authenticationToken", TType.STRING, (short)1);
    private static final TField NOTE_GUID_FIELD_DESC = new TField("noteGuid", TType.STRING, (short)2);
    private static final TField UPDATE_SEQUENCE_NUM_FIELD_DESC = new TField("updateSequenceNum", TType.I32, (short)3);
    private static final TField WITH_RESOURCES_DATA_FIELD_DESC = new TField("withResourcesData", TType.BOOL, (short)4);
    private static final TField WITH_RESOURCES_RECOGNITION_FIELD_DESC = new TField("withResourcesRecognition", TType.BOOL, (short)5);
    private static final TField WITH_RESOURCES_ALTERNATE_DATA_FIELD_DESC = new TField("withResourcesAlternateData", TType.BOOL, (short)6);

    private String authenticationToken;
    private String noteGuid;
    private int updateSequenceNum;
    private boolean withResourcesData;
    private boolean withResourcesRecognition;
    private boolean withResourcesAlternateData;

    /** The set of fields this struct contains, along with convenience methods for finding and manipulating them. */
    public enum _Fields implements TFieldIdEnum {
      AUTHENTICATION_TOKEN((short)1, "authenticationToken"),
      NOTE_GUID((short)2, "noteGuid"),
      UPDATE_SEQUENCE_NUM((short)3, "updateSequenceNum"),
      WITH_RESOURCES_DATA((short)4, "withResourcesData"),
      WITH_RESOURCES_RECOGNITION((short)5, "withResourcesRecognition"),
      WITH_RESOURCES_ALTERNATE_DATA((short)6, "withResourcesAlternateData");

      private static final Map<Integer, _Fields> byId = new HashMap<Integer, _Fields>();
      private static final Map<String, _Fields> byName = new HashMap<String, _Fields>();

      static {
        for (_Fields field : EnumSet.allOf(_Fields.class)) {
          byId.put((int)field._thriftId, field);
          byName.put(field.getFieldName(), field);
        }
      }

      /**
       * Find the _Fields constant that matches fieldId, or null if its not found.
       */
      public static _Fields findByThriftId(int fieldId) {
        return byId.get(fieldId);
      }

      /**
       * Find the _Fields constant that matches fieldId, throwing an exception
       * if it is not found.
       */
      public static _Fields findByThriftIdOrThrow(int fieldId) {
        _Fields fields = findByThriftId(fieldId);
        if (fields == null) throw new IllegalArgumentException("Field " + fieldId + " doesn't exist!");
        return fields;
      }

      /**
       * Find the _Fields constant that matches name, or null if its not found.
       */
      public static _Fields findByName(String name) {
        return byName.get(name);
      }

      private final short _thriftId;
      private final String _fieldName;

      _Fields(short thriftId, String fieldName) {
        _thriftId = thriftId;
        _fieldName = fieldName;
      }

      public short getThriftFieldId() {
        return _thriftId;
      }

      public String getFieldName() {
        return _fieldName;
      }
    }

    // isset id assignments
    private static final int __UPDATESEQUENCENUM_ISSET_ID = 0;
    private static final int __WITHRESOURCESDATA_ISSET_ID = 1;
    private static final int __WITHRESOURCESRECOGNITION_ISSET_ID = 2;
    private static final int __WITHRESOURCESALTERNATEDATA_ISSET_ID = 3;
    private BitSet __isset_bit_vector = new BitSet(4);

    public static final Map<_Fields, FieldMetaData> metaDataMap = Collections.unmodifiableMap(new EnumMap<_Fields, FieldMetaData>(_Fields.class) {{
      put(_Fields.AUTHENTICATION_TOKEN, new FieldMetaData("authenticationToken", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.STRING)));
      put(_Fields.NOTE_GUID, new FieldMetaData("noteGuid", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.STRING)));
      put(_Fields.UPDATE_SEQUENCE_NUM, new FieldMetaData("updateSequenceNum", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.I32)));
      put(_Fields.WITH_RESOURCES_DATA, new FieldMetaData("withResourcesData", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.BOOL)));
      put(_Fields.WITH_RESOURCES_RECOGNITION, new FieldMetaData("withResourcesRecognition", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.BOOL)));
      put(_Fields.WITH_RESOURCES_ALTERNATE_DATA, new FieldMetaData("withResourcesAlternateData", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.BOOL)));
    }});

    static {
      FieldMetaData.addStructMetaDataMap(getNoteVersion_args.class, metaDataMap);
    }

    public getNoteVersion_args() {
    }

    public getNoteVersion_args(
      String authenticationToken,
      String noteGuid,
      int updateSequenceNum,
      boolean withResourcesData,
      boolean withResourcesRecognition,
      boolean withResourcesAlternateData)
    {
      this();
      this.authenticationToken = authenticationToken;
      this.noteGuid = noteGuid;
      this.updateSequenceNum = updateSequenceNum;
      setUpdateSequenceNumIsSet(true);
      this.withResourcesData = withResourcesData;
      setWithResourcesDataIsSet(true);
      this.withResourcesRecognition = withResourcesRecognition;
      setWithResourcesRecognitionIsSet(true);
      this.withResourcesAlternateData = withResourcesAlternateData;
      setWithResourcesAlternateDataIsSet(true);
    }

    /**
     * Performs a deep copy on <i>other</i>.
     */
    public getNoteVersion_args(getNoteVersion_args other) {
      __isset_bit_vector.clear();
      __isset_bit_vector.or(other.__isset_bit_vector);
      if (other.isSetAuthenticationToken()) {
        this.authenticationToken = other.authenticationToken;
      }
      if (other.isSetNoteGuid()) {
        this.noteGuid = other.noteGuid;
      }
      this.updateSequenceNum = other.updateSequenceNum;
      this.withResourcesData = other.withResourcesData;
      this.withResourcesRecognition = other.withResourcesRecognition;
      this.withResourcesAlternateData = other.withResourcesAlternateData;
    }

    public getNoteVersion_args deepCopy() {
      return new getNoteVersion_args(this);
    }

    @Deprecated
    public getNoteVersion_args clone() {
      return new getNoteVersion_args(this);
    }

    public String getAuthenticationToken() {
      return this.authenticationToken;
    }

    public void setAuthenticationToken(String authenticationToken) {
      this.authenticationToken = authenticationToken;
    }

    public void unsetAuthenticationToken() {
      this.authenticationToken = null;
    }

    /** Returns true if field authenticationToken is set (has been asigned a value) and false otherwise */
    public boolean isSetAuthenticationToken() {
      return this.authenticationToken != null;
    }

    public void setAuthenticationTokenIsSet(boolean value) {
      if (!value) {
        this.authenticationToken = null;
      }
    }

    public String getNoteGuid() {
      return this.noteGuid;
    }

    public void setNoteGuid(String noteGuid) {
      this.noteGuid = noteGuid;
    }

    public void unsetNoteGuid() {
      this.noteGuid = null;
    }

    /** Returns true if field noteGuid is set (has been asigned a value) and false otherwise */
    public boolean isSetNoteGuid() {
      return this.noteGuid != null;
    }

    public void setNoteGuidIsSet(boolean value) {
      if (!value) {
        this.noteGuid = null;
      }
    }

    public int getUpdateSequenceNum() {
      return this.updateSequenceNum;
    }

    public void setUpdateSequenceNum(int updateSequenceNum) {
      this.updateSequenceNum = updateSequenceNum;
      setUpdateSequenceNumIsSet(true);
    }

    public void unsetUpdateSequenceNum() {
      __isset_bit_vector.clear(__UPDATESEQUENCENUM_ISSET_ID);
    }

    /** Returns true if field updateSequenceNum is set (has been asigned a value) and false otherwise */
    public boolean isSetUpdateSequenceNum() {
      return __isset_bit_vector.get(__UPDATESEQUENCENUM_ISSET_ID);
    }

    public void setUpdateSequenceNumIsSet(boolean value) {
      __isset_bit_vector.set(__UPDATESEQUENCENUM_ISSET_ID, value);
    }

    public boolean isWithResourcesData() {
      return this.withResourcesData;
    }

    public void setWithResourcesData(boolean withResourcesData) {
      this.withResourcesData = withResourcesData;
      setWithResourcesDataIsSet(true);
    }

    public void unsetWithResourcesData() {
      __isset_bit_vector.clear(__WITHRESOURCESDATA_ISSET_ID);
    }

    /** Returns true if field withResourcesData is set (has been asigned a value) and false otherwise */
    public boolean isSetWithResourcesData() {
      return __isset_bit_vector.get(__WITHRESOURCESDATA_ISSET_ID);
    }

    public void setWithResourcesDataIsSet(boolean value) {
      __isset_bit_vector.set(__WITHRESOURCESDATA_ISSET_ID, value);
    }

    public boolean isWithResourcesRecognition() {
      return this.withResourcesRecognition;
    }

    public void setWithResourcesRecognition(boolean withResourcesRecognition) {
      this.withResourcesRecognition = withResourcesRecognition;
      setWithResourcesRecognitionIsSet(true);
    }

    public void unsetWithResourcesRecognition() {
      __isset_bit_vector.clear(__WITHRESOURCESRECOGNITION_ISSET_ID);
    }

    /** Returns true if field withResourcesRecognition is set (has been asigned a value) and false otherwise */
    public boolean isSetWithResourcesRecognition() {
      return __isset_bit_vector.get(__WITHRESOURCESRECOGNITION_ISSET_ID);
    }

    public void setWithResourcesRecognitionIsSet(boolean value) {
      __isset_bit_vector.set(__WITHRESOURCESRECOGNITION_ISSET_ID, value);
    }

    public boolean isWithResourcesAlternateData() {
      return this.withResourcesAlternateData;
    }

    public void setWithResourcesAlternateData(boolean withResourcesAlternateData) {
      this.withResourcesAlternateData = withResourcesAlternateData;
      setWithResourcesAlternateDataIsSet(true);
    }

    public void unsetWithResourcesAlternateData() {
      __isset_bit_vector.clear(__WITHRESOURCESALTERNATEDATA_ISSET_ID);
    }

    /** Returns true if field withResourcesAlternateData is set (has been asigned a value) and false otherwise */
    public boolean isSetWithResourcesAlternateData() {
      return __isset_bit_vector.get(__WITHRESOURCESALTERNATEDATA_ISSET_ID);
    }

    public void setWithResourcesAlternateDataIsSet(boolean value) {
      __isset_bit_vector.set(__WITHRESOURCESALTERNATEDATA_ISSET_ID, value);
    }

    public void setFieldValue(_Fields field, Object value) {
      switch (field) {
      case AUTHENTICATION_TOKEN:
        if (value == null) {
          unsetAuthenticationToken();
        } else {
          setAuthenticationToken((String)value);
        }
        break;

      case NOTE_GUID:
        if (value == null) {
          unsetNoteGuid();
        } else {
          setNoteGuid((String)value);
        }
        break;

      case UPDATE_SEQUENCE_NUM:
        if (value == null) {
          unsetUpdateSequenceNum();
        } else {
          setUpdateSequenceNum((Integer)value);
        }
        break;

      case WITH_RESOURCES_DATA:
        if (value == null) {
          unsetWithResourcesData();
        } else {
          setWithResourcesData((Boolean)value);
        }
        break;

      case WITH_RESOURCES_RECOGNITION:
        if (value == null) {
          unsetWithResourcesRecognition();
        } else {
          setWithResourcesRecognition((Boolean)value);
        }
        break;

      case WITH_RESOURCES_ALTERNATE_DATA:
        if (value == null) {
          unsetWithResourcesAlternateData();
        } else {
          setWithResourcesAlternateData((Boolean)value);
        }
        break;

      }
    }

    public void setFieldValue(int fieldID, Object value) {
      setFieldValue(_Fields.findByThriftIdOrThrow(fieldID), value);
    }

    public Object getFieldValue(_Fields field) {
      switch (field) {
      case AUTHENTICATION_TOKEN:
        return getAuthenticationToken();

      case NOTE_GUID:
        return getNoteGuid();

      case UPDATE_SEQUENCE_NUM:
        return new Integer(getUpdateSequenceNum());

      case WITH_RESOURCES_DATA:
        return new Boolean(isWithResourcesData());

      case WITH_RESOURCES_RECOGNITION:
        return new Boolean(isWithResourcesRecognition());

      case WITH_RESOURCES_ALTERNATE_DATA:
        return new Boolean(isWithResourcesAlternateData());

      }
      throw new IllegalStateException();
    }

    public Object getFieldValue(int fieldId) {
      return getFieldValue(_Fields.findByThriftIdOrThrow(fieldId));
    }

    /** Returns true if field corresponding to fieldID is set (has been asigned a value) and false otherwise */
    public boolean isSet(_Fields field) {
      switch (field) {
      case AUTHENTICATION_TOKEN:
        return isSetAuthenticationToken();
      case NOTE_GUID:
        return isSetNoteGuid();
      case UPDATE_SEQUENCE_NUM:
        return isSetUpdateSequenceNum();
      case WITH_RESOURCES_DATA:
        return isSetWithResourcesData();
      case WITH_RESOURCES_RECOGNITION:
        return isSetWithResourcesRecognition();
      case WITH_RESOURCES_ALTERNATE_DATA:
        return isSetWithResourcesAlternateData();
      }
      throw new IllegalStateException();
    }

    public boolean isSet(int fieldID) {
      return isSet(_Fields.findByThriftIdOrThrow(fieldID));
    }

    public boolean equals(Object that) {
      if (that == null)
        return false;
      if (that instanceof getNoteVersion_args)
        return this.equals((getNoteVersion_args)that);
      return false;
    }

    public boolean equals(getNoteVersion_args that) {
      if (that == null)
        return false;

      boolean this_present_authenticationToken = true && this.isSetAuthenticationToken();
      boolean that_present_authenticationToken = true && that.isSetAuthenticationToken();
      if (this_present_authenticationToken || that_present_authenticationToken) {
        if (!(this_present_authenticationToken && that_present_authenticationToken))
          return false;
        if (!this.authenticationToken.equals(that.authenticationToken))
          return false;
      }

      boolean this_present_noteGuid = true && this.isSetNoteGuid();
      boolean that_present_noteGuid = true && that.isSetNoteGuid();
      if (this_present_noteGuid || that_present_noteGuid) {
        if (!(this_present_noteGuid && that_present_noteGuid))
          return false;
        if (!this.noteGuid.equals(that.noteGuid))
          return false;
      }

      boolean this_present_updateSequenceNum = true;
      boolean that_present_updateSequenceNum = true;
      if (this_present_updateSequenceNum || that_present_updateSequenceNum) {
        if (!(this_present_updateSequenceNum && that_present_updateSequenceNum))
          return false;
        if (this.updateSequenceNum != that.updateSequenceNum)
          return false;
      }

      boolean this_present_withResourcesData = true;
      boolean that_present_withResourcesData = true;
      if (this_present_withResourcesData || that_present_withResourcesData) {
        if (!(this_present_withResourcesData && that_present_withResourcesData))
          return false;
        if (this.withResourcesData != that.withResourcesData)
          return false;
      }

      boolean this_present_withResourcesRecognition = true;
      boolean that_present_withResourcesRecognition = true;
      if (this_present_withResourcesRecognition || that_present_withResourcesRecognition) {
        if (!(this_present_withResourcesRecognition && that_present_withResourcesRecognition))
          return false;
        if (this.withResourcesRecognition != that.withResourcesRecognition)
          return false;
      }

      boolean this_present_withResourcesAlternateData = true;
      boolean that_present_withResourcesAlternateData = true;
      if (this_present_withResourcesAlternateData || that_present_withResourcesAlternateData) {
        if (!(this_present_withResourcesAlternateData && that_present_withResourcesAlternateData))
          return false;
        if (this.withResourcesAlternateData != that.withResourcesAlternateData)
          return false;
      }

      return true;
    }

    public int hashCode() {
      return 0;
    }

    public int compareTo(getNoteVersion_args other) {
      if (!getClass().equals(other.getClass())) {
        return getClass().getName().compareTo(other.getClass().getName());
      }

      int lastComparison = 0;
      getNoteVersion_args typedOther = (getNoteVersion_args)other;

      lastComparison = Boolean.valueOf(isSetAuthenticationToken()).compareTo(isSetAuthenticationToken());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(authenticationToken, typedOther.authenticationToken);
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = Boolean.valueOf(isSetNoteGuid()).compareTo(isSetNoteGuid());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(noteGuid, typedOther.noteGuid);
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = Boolean.valueOf(isSetUpdateSequenceNum()).compareTo(isSetUpdateSequenceNum());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(updateSequenceNum, typedOther.updateSequenceNum);
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = Boolean.valueOf(isSetWithResourcesData()).compareTo(isSetWithResourcesData());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(withResourcesData, typedOther.withResourcesData);
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = Boolean.valueOf(isSetWithResourcesRecognition()).compareTo(isSetWithResourcesRecognition());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(withResourcesRecognition, typedOther.withResourcesRecognition);
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = Boolean.valueOf(isSetWithResourcesAlternateData()).compareTo(isSetWithResourcesAlternateData());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(withResourcesAlternateData, typedOther.withResourcesAlternateData);
      if (lastComparison != 0) {
        return lastComparison;
      }
      return 0;
    }

    public void read(TProtocol iprot) throws TException {
      TField field;
      iprot.readStructBegin();
      while (true)
      {
        field = iprot.readFieldBegin();
        if (field.type == TType.STOP) { 
          break;
        }
        _Fields fieldId = _Fields.findByThriftId(field.id);
        if (fieldId == null) {
          TProtocolUtil.skip(iprot, field.type);
        } else {
          switch (fieldId) {
            case AUTHENTICATION_TOKEN:
              if (field.type == TType.STRING) {
                this.authenticationToken = iprot.readString();
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
            case NOTE_GUID:
              if (field.type == TType.STRING) {
                this.noteGuid = iprot.readString();
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
            case UPDATE_SEQUENCE_NUM:
              if (field.type == TType.I32) {
                this.updateSequenceNum = iprot.readI32();
                setUpdateSequenceNumIsSet(true);
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
            case WITH_RESOURCES_DATA:
              if (field.type == TType.BOOL) {
                this.withResourcesData = iprot.readBool();
                setWithResourcesDataIsSet(true);
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
            case WITH_RESOURCES_RECOGNITION:
              if (field.type == TType.BOOL) {
                this.withResourcesRecognition = iprot.readBool();
                setWithResourcesRecognitionIsSet(true);
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
            case WITH_RESOURCES_ALTERNATE_DATA:
              if (field.type == TType.BOOL) {
                this.withResourcesAlternateData = iprot.readBool();
                setWithResourcesAlternateDataIsSet(true);
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
          }
          iprot.readFieldEnd();
        }
      }
      iprot.readStructEnd();
      validate();
    }

    public void write(TProtocol oprot) throws TException {
      validate();

      oprot.writeStructBegin(STRUCT_DESC);
      if (this.authenticationToken != null) {
        oprot.writeFieldBegin(AUTHENTICATION_TOKEN_FIELD_DESC);
        oprot.writeString(this.authenticationToken);
        oprot.writeFieldEnd();
      }
      if (this.noteGuid != null) {
        oprot.writeFieldBegin(NOTE_GUID_FIELD_DESC);
        oprot.writeString(this.noteGuid);
        oprot.writeFieldEnd();
      }
      oprot.writeFieldBegin(UPDATE_SEQUENCE_NUM_FIELD_DESC);
      oprot.writeI32(this.updateSequenceNum);
      oprot.writeFieldEnd();
      oprot.writeFieldBegin(WITH_RESOURCES_DATA_FIELD_DESC);
      oprot.writeBool(this.withResourcesData);
      oprot.writeFieldEnd();
      oprot.writeFieldBegin(WITH_RESOURCES_RECOGNITION_FIELD_DESC);
      oprot.writeBool(this.withResourcesRecognition);
      oprot.writeFieldEnd();
      oprot.writeFieldBegin(WITH_RESOURCES_ALTERNATE_DATA_FIELD_DESC);
      oprot.writeBool(this.withResourcesAlternateData);
      oprot.writeFieldEnd();
      oprot.writeFieldStop();
      oprot.writeStructEnd();
    }

    public String toString() {
      StringBuilder sb = new StringBuilder("getNoteVersion_args(");
      boolean first = true;

      sb.append("authenticationToken:");
      if (this.authenticationToken == null) {
        sb.append("null");
      } else {
        sb.append(this.authenticationToken);
      }
      first = false;
      if (!first) sb.append(", ");
      sb.append("noteGuid:");
      if (this.noteGuid == null) {
        sb.append("null");
      } else {
        sb.append(this.noteGuid);
      }
      first = false;
      if (!first) sb.append(", ");
      sb.append("updateSequenceNum:");
      sb.append(this.updateSequenceNum);
      first = false;
      if (!first) sb.append(", ");
      sb.append("withResourcesData:");
      sb.append(this.withResourcesData);
      first = false;
      if (!first) sb.append(", ");
      sb.append("withResourcesRecognition:");
      sb.append(this.withResourcesRecognition);
      first = false;
      if (!first) sb.append(", ");
      sb.append("withResourcesAlternateData:");
      sb.append(this.withResourcesAlternateData);
      first = false;
      sb.append(")");
      return sb.toString();
    }

    public void validate() throws TException {
      // check for required fields
    }

  }

  public static class getNoteVersion_result implements TBase<getNoteVersion_result._Fields>, java.io.Serializable, Cloneable, Comparable<getNoteVersion_result>   {
    private static final TStruct STRUCT_DESC = new TStruct("getNoteVersion_result");

    private static final TField SUCCESS_FIELD_DESC = new TField("success", TType.STRUCT, (short)0);
    private static final TField USER_EXCEPTION_FIELD_DESC = new TField("userException", TType.STRUCT, (short)1);
    private static final TField SYSTEM_EXCEPTION_FIELD_DESC = new TField("systemException", TType.STRUCT, (short)2);
    private static final TField NOT_FOUND_EXCEPTION_FIELD_DESC = new TField("notFoundException", TType.STRUCT, (short)3);

    private com.evernote.edam.type.Note success;
    private com.evernote.edam.error.EDAMUserException userException;
    private com.evernote.edam.error.EDAMSystemException systemException;
    private com.evernote.edam.error.EDAMNotFoundException notFoundException;

    /** The set of fields this struct contains, along with convenience methods for finding and manipulating them. */
    public enum _Fields implements TFieldIdEnum {
      SUCCESS((short)0, "success"),
      USER_EXCEPTION((short)1, "userException"),
      SYSTEM_EXCEPTION((short)2, "systemException"),
      NOT_FOUND_EXCEPTION((short)3, "notFoundException");

      private static final Map<Integer, _Fields> byId = new HashMap<Integer, _Fields>();
      private static final Map<String, _Fields> byName = new HashMap<String, _Fields>();

      static {
        for (_Fields field : EnumSet.allOf(_Fields.class)) {
          byId.put((int)field._thriftId, field);
          byName.put(field.getFieldName(), field);
        }
      }

      /**
       * Find the _Fields constant that matches fieldId, or null if its not found.
       */
      public static _Fields findByThriftId(int fieldId) {
        return byId.get(fieldId);
      }

      /**
       * Find the _Fields constant that matches fieldId, throwing an exception
       * if it is not found.
       */
      public static _Fields findByThriftIdOrThrow(int fieldId) {
        _Fields fields = findByThriftId(fieldId);
        if (fields == null) throw new IllegalArgumentException("Field " + fieldId + " doesn't exist!");
        return fields;
      }

      /**
       * Find the _Fields constant that matches name, or null if its not found.
       */
      public static _Fields findByName(String name) {
        return byName.get(name);
      }

      private final short _thriftId;
      private final String _fieldName;

      _Fields(short thriftId, String fieldName) {
        _thriftId = thriftId;
        _fieldName = fieldName;
      }

      public short getThriftFieldId() {
        return _thriftId;
      }

      public String getFieldName() {
        return _fieldName;
      }
    }

    // isset id assignments

    public static final Map<_Fields, FieldMetaData> metaDataMap = Collections.unmodifiableMap(new EnumMap<_Fields, FieldMetaData>(_Fields.class) {{
      put(_Fields.SUCCESS, new FieldMetaData("success", TFieldRequirementType.DEFAULT, 
          new StructMetaData(TType.STRUCT, com.evernote.edam.type.Note.class)));
      put(_Fields.USER_EXCEPTION, new FieldMetaData("userException", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.STRUCT)));
      put(_Fields.SYSTEM_EXCEPTION, new FieldMetaData("systemException", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.STRUCT)));
      put(_Fields.NOT_FOUND_EXCEPTION, new FieldMetaData("notFoundException", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.STRUCT)));
    }});

    static {
      FieldMetaData.addStructMetaDataMap(getNoteVersion_result.class, metaDataMap);
    }

    public getNoteVersion_result() {
    }

    public getNoteVersion_result(
      com.evernote.edam.type.Note success,
      com.evernote.edam.error.EDAMUserException userException,
      com.evernote.edam.error.EDAMSystemException systemException,
      com.evernote.edam.error.EDAMNotFoundException notFoundException)
    {
      this();
      this.success = success;
      this.userException = userException;
      this.systemException = systemException;
      this.notFoundException = notFoundException;
    }

    /**
     * Performs a deep copy on <i>other</i>.
     */
    public getNoteVersion_result(getNoteVersion_result other) {
      if (other.isSetSuccess()) {
        this.success = new com.evernote.edam.type.Note(other.success);
      }
      if (other.isSetUserException()) {
        this.userException = new com.evernote.edam.error.EDAMUserException(other.userException);
      }
      if (other.isSetSystemException()) {
        this.systemException = new com.evernote.edam.error.EDAMSystemException(other.systemException);
      }
      if (other.isSetNotFoundException()) {
        this.notFoundException = new com.evernote.edam.error.EDAMNotFoundException(other.notFoundException);
      }
    }

    public getNoteVersion_result deepCopy() {
      return new getNoteVersion_result(this);
    }

    @Deprecated
    public getNoteVersion_result clone() {
      return new getNoteVersion_result(this);
    }

    public com.evernote.edam.type.Note getSuccess() {
      return this.success;
    }

    public void setSuccess(com.evernote.edam.type.Note success) {
      this.success = success;
    }

    public void unsetSuccess() {
      this.success = null;
    }

    /** Returns true if field success is set (has been asigned a value) and false otherwise */
    public boolean isSetSuccess() {
      return this.success != null;
    }

    public void setSuccessIsSet(boolean value) {
      if (!value) {
        this.success = null;
      }
    }

    public com.evernote.edam.error.EDAMUserException getUserException() {
      return this.userException;
    }

    public void setUserException(com.evernote.edam.error.EDAMUserException userException) {
      this.userException = userException;
    }

    public void unsetUserException() {
      this.userException = null;
    }

    /** Returns true if field userException is set (has been asigned a value) and false otherwise */
    public boolean isSetUserException() {
      return this.userException != null;
    }

    public void setUserExceptionIsSet(boolean value) {
      if (!value) {
        this.userException = null;
      }
    }

    public com.evernote.edam.error.EDAMSystemException getSystemException() {
      return this.systemException;
    }

    public void setSystemException(com.evernote.edam.error.EDAMSystemException systemException) {
      this.systemException = systemException;
    }

    public void unsetSystemException() {
      this.systemException = null;
    }

    /** Returns true if field systemException is set (has been asigned a value) and false otherwise */
    public boolean isSetSystemException() {
      return this.systemException != null;
    }

    public void setSystemExceptionIsSet(boolean value) {
      if (!value) {
        this.systemException = null;
      }
    }

    public com.evernote.edam.error.EDAMNotFoundException getNotFoundException() {
      return this.notFoundException;
    }

    public void setNotFoundException(com.evernote.edam.error.EDAMNotFoundException notFoundException) {
      this.notFoundException = notFoundException;
    }

    public void unsetNotFoundException() {
      this.notFoundException = null;
    }

    /** Returns true if field notFoundException is set (has been asigned a value) and false otherwise */
    public boolean isSetNotFoundException() {
      return this.notFoundException != null;
    }

    public void setNotFoundExceptionIsSet(boolean value) {
      if (!value) {
        this.notFoundException = null;
      }
    }

    public void setFieldValue(_Fields field, Object value) {
      switch (field) {
      case SUCCESS:
        if (value == null) {
          unsetSuccess();
        } else {
          setSuccess((com.evernote.edam.type.Note)value);
        }
        break;

      case USER_EXCEPTION:
        if (value == null) {
          unsetUserException();
        } else {
          setUserException((com.evernote.edam.error.EDAMUserException)value);
        }
        break;

      case SYSTEM_EXCEPTION:
        if (value == null) {
          unsetSystemException();
        } else {
          setSystemException((com.evernote.edam.error.EDAMSystemException)value);
        }
        break;

      case NOT_FOUND_EXCEPTION:
        if (value == null) {
          unsetNotFoundException();
        } else {
          setNotFoundException((com.evernote.edam.error.EDAMNotFoundException)value);
        }
        break;

      }
    }

    public void setFieldValue(int fieldID, Object value) {
      setFieldValue(_Fields.findByThriftIdOrThrow(fieldID), value);
    }

    public Object getFieldValue(_Fields field) {
      switch (field) {
      case SUCCESS:
        return getSuccess();

      case USER_EXCEPTION:
        return getUserException();

      case SYSTEM_EXCEPTION:
        return getSystemException();

      case NOT_FOUND_EXCEPTION:
        return getNotFoundException();

      }
      throw new IllegalStateException();
    }

    public Object getFieldValue(int fieldId) {
      return getFieldValue(_Fields.findByThriftIdOrThrow(fieldId));
    }

    /** Returns true if field corresponding to fieldID is set (has been asigned a value) and false otherwise */
    public boolean isSet(_Fields field) {
      switch (field) {
      case SUCCESS:
        return isSetSuccess();
      case USER_EXCEPTION:
        return isSetUserException();
      case SYSTEM_EXCEPTION:
        return isSetSystemException();
      case NOT_FOUND_EXCEPTION:
        return isSetNotFoundException();
      }
      throw new IllegalStateException();
    }

    public boolean isSet(int fieldID) {
      return isSet(_Fields.findByThriftIdOrThrow(fieldID));
    }

    public boolean equals(Object that) {
      if (that == null)
        return false;
      if (that instanceof getNoteVersion_result)
        return this.equals((getNoteVersion_result)that);
      return false;
    }

    public boolean equals(getNoteVersion_result that) {
      if (that == null)
        return false;

      boolean this_present_success = true && this.isSetSuccess();
      boolean that_present_success = true && that.isSetSuccess();
      if (this_present_success || that_present_success) {
        if (!(this_present_success && that_present_success))
          return false;
        if (!this.success.equals(that.success))
          return false;
      }

      boolean this_present_userException = true && this.isSetUserException();
      boolean that_present_userException = true && that.isSetUserException();
      if (this_present_userException || that_present_userException) {
        if (!(this_present_userException && that_present_userException))
          return false;
        if (!this.userException.equals(that.userException))
          return false;
      }

      boolean this_present_systemException = true && this.isSetSystemException();
      boolean that_present_systemException = true && that.isSetSystemException();
      if (this_present_systemException || that_present_systemException) {
        if (!(this_present_systemException && that_present_systemException))
          return false;
        if (!this.systemException.equals(that.systemException))
          return false;
      }

      boolean this_present_notFoundException = true && this.isSetNotFoundException();
      boolean that_present_notFoundException = true && that.isSetNotFoundException();
      if (this_present_notFoundException || that_present_notFoundException) {
        if (!(this_present_notFoundException && that_present_notFoundException))
          return false;
        if (!this.notFoundException.equals(that.notFoundException))
          return false;
      }

      return true;
    }

    public int hashCode() {
      return 0;
    }

    public int compareTo(getNoteVersion_result other) {
      if (!getClass().equals(other.getClass())) {
        return getClass().getName().compareTo(other.getClass().getName());
      }

      int lastComparison = 0;
      getNoteVersion_result typedOther = (getNoteVersion_result)other;

      lastComparison = Boolean.valueOf(isSetSuccess()).compareTo(isSetSuccess());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(success, typedOther.success);
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = Boolean.valueOf(isSetUserException()).compareTo(isSetUserException());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(userException, typedOther.userException);
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = Boolean.valueOf(isSetSystemException()).compareTo(isSetSystemException());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(systemException, typedOther.systemException);
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = Boolean.valueOf(isSetNotFoundException()).compareTo(isSetNotFoundException());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(notFoundException, typedOther.notFoundException);
      if (lastComparison != 0) {
        return lastComparison;
      }
      return 0;
    }

    public void read(TProtocol iprot) throws TException {
      TField field;
      iprot.readStructBegin();
      while (true)
      {
        field = iprot.readFieldBegin();
        if (field.type == TType.STOP) { 
          break;
        }
        _Fields fieldId = _Fields.findByThriftId(field.id);
        if (fieldId == null) {
          TProtocolUtil.skip(iprot, field.type);
        } else {
          switch (fieldId) {
            case SUCCESS:
              if (field.type == TType.STRUCT) {
                this.success = new com.evernote.edam.type.Note();
                this.success.read(iprot);
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
            case USER_EXCEPTION:
              if (field.type == TType.STRUCT) {
                this.userException = new com.evernote.edam.error.EDAMUserException();
                this.userException.read(iprot);
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
            case SYSTEM_EXCEPTION:
              if (field.type == TType.STRUCT) {
                this.systemException = new com.evernote.edam.error.EDAMSystemException();
                this.systemException.read(iprot);
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
            case NOT_FOUND_EXCEPTION:
              if (field.type == TType.STRUCT) {
                this.notFoundException = new com.evernote.edam.error.EDAMNotFoundException();
                this.notFoundException.read(iprot);
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
          }
          iprot.readFieldEnd();
        }
      }
      iprot.readStructEnd();
      validate();
    }

    public void write(TProtocol oprot) throws TException {
      oprot.writeStructBegin(STRUCT_DESC);

      if (this.isSetSuccess()) {
        oprot.writeFieldBegin(SUCCESS_FIELD_DESC);
        this.success.write(oprot);
        oprot.writeFieldEnd();
      } else if (this.isSetUserException()) {
        oprot.writeFieldBegin(USER_EXCEPTION_FIELD_DESC);
        this.userException.write(oprot);
        oprot.writeFieldEnd();
      } else if (this.isSetSystemException()) {
        oprot.writeFieldBegin(SYSTEM_EXCEPTION_FIELD_DESC);
        this.systemException.write(oprot);
        oprot.writeFieldEnd();
      } else if (this.isSetNotFoundException()) {
        oprot.writeFieldBegin(NOT_FOUND_EXCEPTION_FIELD_DESC);
        this.notFoundException.write(oprot);
        oprot.writeFieldEnd();
      }
      oprot.writeFieldStop();
      oprot.writeStructEnd();
    }

    public String toString() {
      StringBuilder sb = new StringBuilder("getNoteVersion_result(");
      boolean first = true;

      sb.append("success:");
      if (this.success == null) {
        sb.append("null");
      } else {
        sb.append(this.success);
      }
      first = false;
      if (!first) sb.append(", ");
      sb.append("userException:");
      if (this.userException == null) {
        sb.append("null");
      } else {
        sb.append(this.userException);
      }
      first = false;
      if (!first) sb.append(", ");
      sb.append("systemException:");
      if (this.systemException == null) {
        sb.append("null");
      } else {
        sb.append(this.systemException);
      }
      first = false;
      if (!first) sb.append(", ");
      sb.append("notFoundException:");
      if (this.notFoundException == null) {
        sb.append("null");
      } else {
        sb.append(this.notFoundException);
      }
      first = false;
      sb.append(")");
      return sb.toString();
    }

    public void validate() throws TException {
      // check for required fields
    }

  }

  public static class getResource_args implements TBase<getResource_args._Fields>, java.io.Serializable, Cloneable, Comparable<getResource_args>   {
    private static final TStruct STRUCT_DESC = new TStruct("getResource_args");

    private static final TField AUTHENTICATION_TOKEN_FIELD_DESC = new TField("authenticationToken", TType.STRING, (short)1);
    private static final TField GUID_FIELD_DESC = new TField("guid", TType.STRING, (short)2);
    private static final TField WITH_DATA_FIELD_DESC = new TField("withData", TType.BOOL, (short)3);
    private static final TField WITH_RECOGNITION_FIELD_DESC = new TField("withRecognition", TType.BOOL, (short)4);
    private static final TField WITH_ATTRIBUTES_FIELD_DESC = new TField("withAttributes", TType.BOOL, (short)5);
    private static final TField WITH_ALTERNATE_DATA_FIELD_DESC = new TField("withAlternateData", TType.BOOL, (short)6);

    private String authenticationToken;
    private String guid;
    private boolean withData;
    private boolean withRecognition;
    private boolean withAttributes;
    private boolean withAlternateData;

    /** The set of fields this struct contains, along with convenience methods for finding and manipulating them. */
    public enum _Fields implements TFieldIdEnum {
      AUTHENTICATION_TOKEN((short)1, "authenticationToken"),
      GUID((short)2, "guid"),
      WITH_DATA((short)3, "withData"),
      WITH_RECOGNITION((short)4, "withRecognition"),
      WITH_ATTRIBUTES((short)5, "withAttributes"),
      WITH_ALTERNATE_DATA((short)6, "withAlternateData");

      private static final Map<Integer, _Fields> byId = new HashMap<Integer, _Fields>();
      private static final Map<String, _Fields> byName = new HashMap<String, _Fields>();

      static {
        for (_Fields field : EnumSet.allOf(_Fields.class)) {
          byId.put((int)field._thriftId, field);
          byName.put(field.getFieldName(), field);
        }
      }

      /**
       * Find the _Fields constant that matches fieldId, or null if its not found.
       */
      public static _Fields findByThriftId(int fieldId) {
        return byId.get(fieldId);
      }

      /**
       * Find the _Fields constant that matches fieldId, throwing an exception
       * if it is not found.
       */
      public static _Fields findByThriftIdOrThrow(int fieldId) {
        _Fields fields = findByThriftId(fieldId);
        if (fields == null) throw new IllegalArgumentException("Field " + fieldId + " doesn't exist!");
        return fields;
      }

      /**
       * Find the _Fields constant that matches name, or null if its not found.
       */
      public static _Fields findByName(String name) {
        return byName.get(name);
      }

      private final short _thriftId;
      private final String _fieldName;

      _Fields(short thriftId, String fieldName) {
        _thriftId = thriftId;
        _fieldName = fieldName;
      }

      public short getThriftFieldId() {
        return _thriftId;
      }

      public String getFieldName() {
        return _fieldName;
      }
    }

    // isset id assignments
    private static final int __WITHDATA_ISSET_ID = 0;
    private static final int __WITHRECOGNITION_ISSET_ID = 1;
    private static final int __WITHATTRIBUTES_ISSET_ID = 2;
    private static final int __WITHALTERNATEDATA_ISSET_ID = 3;
    private BitSet __isset_bit_vector = new BitSet(4);

    public static final Map<_Fields, FieldMetaData> metaDataMap = Collections.unmodifiableMap(new EnumMap<_Fields, FieldMetaData>(_Fields.class) {{
      put(_Fields.AUTHENTICATION_TOKEN, new FieldMetaData("authenticationToken", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.STRING)));
      put(_Fields.GUID, new FieldMetaData("guid", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.STRING)));
      put(_Fields.WITH_DATA, new FieldMetaData("withData", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.BOOL)));
      put(_Fields.WITH_RECOGNITION, new FieldMetaData("withRecognition", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.BOOL)));
      put(_Fields.WITH_ATTRIBUTES, new FieldMetaData("withAttributes", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.BOOL)));
      put(_Fields.WITH_ALTERNATE_DATA, new FieldMetaData("withAlternateData", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.BOOL)));
    }});

    static {
      FieldMetaData.addStructMetaDataMap(getResource_args.class, metaDataMap);
    }

    public getResource_args() {
    }

    public getResource_args(
      String authenticationToken,
      String guid,
      boolean withData,
      boolean withRecognition,
      boolean withAttributes,
      boolean withAlternateData)
    {
      this();
      this.authenticationToken = authenticationToken;
      this.guid = guid;
      this.withData = withData;
      setWithDataIsSet(true);
      this.withRecognition = withRecognition;
      setWithRecognitionIsSet(true);
      this.withAttributes = withAttributes;
      setWithAttributesIsSet(true);
      this.withAlternateData = withAlternateData;
      setWithAlternateDataIsSet(true);
    }

    /**
     * Performs a deep copy on <i>other</i>.
     */
    public getResource_args(getResource_args other) {
      __isset_bit_vector.clear();
      __isset_bit_vector.or(other.__isset_bit_vector);
      if (other.isSetAuthenticationToken()) {
        this.authenticationToken = other.authenticationToken;
      }
      if (other.isSetGuid()) {
        this.guid = other.guid;
      }
      this.withData = other.withData;
      this.withRecognition = other.withRecognition;
      this.withAttributes = other.withAttributes;
      this.withAlternateData = other.withAlternateData;
    }

    public getResource_args deepCopy() {
      return new getResource_args(this);
    }

    @Deprecated
    public getResource_args clone() {
      return new getResource_args(this);
    }

    public String getAuthenticationToken() {
      return this.authenticationToken;
    }

    public void setAuthenticationToken(String authenticationToken) {
      this.authenticationToken = authenticationToken;
    }

    public void unsetAuthenticationToken() {
      this.authenticationToken = null;
    }

    /** Returns true if field authenticationToken is set (has been asigned a value) and false otherwise */
    public boolean isSetAuthenticationToken() {
      return this.authenticationToken != null;
    }

    public void setAuthenticationTokenIsSet(boolean value) {
      if (!value) {
        this.authenticationToken = null;
      }
    }

    public String getGuid() {
      return this.guid;
    }

    public void setGuid(String guid) {
      this.guid = guid;
    }

    public void unsetGuid() {
      this.guid = null;
    }

    /** Returns true if field guid is set (has been asigned a value) and false otherwise */
    public boolean isSetGuid() {
      return this.guid != null;
    }

    public void setGuidIsSet(boolean value) {
      if (!value) {
        this.guid = null;
      }
    }

    public boolean isWithData() {
      return this.withData;
    }

    public void setWithData(boolean withData) {
      this.withData = withData;
      setWithDataIsSet(true);
    }

    public void unsetWithData() {
      __isset_bit_vector.clear(__WITHDATA_ISSET_ID);
    }

    /** Returns true if field withData is set (has been asigned a value) and false otherwise */
    public boolean isSetWithData() {
      return __isset_bit_vector.get(__WITHDATA_ISSET_ID);
    }

    public void setWithDataIsSet(boolean value) {
      __isset_bit_vector.set(__WITHDATA_ISSET_ID, value);
    }

    public boolean isWithRecognition() {
      return this.withRecognition;
    }

    public void setWithRecognition(boolean withRecognition) {
      this.withRecognition = withRecognition;
      setWithRecognitionIsSet(true);
    }

    public void unsetWithRecognition() {
      __isset_bit_vector.clear(__WITHRECOGNITION_ISSET_ID);
    }

    /** Returns true if field withRecognition is set (has been asigned a value) and false otherwise */
    public boolean isSetWithRecognition() {
      return __isset_bit_vector.get(__WITHRECOGNITION_ISSET_ID);
    }

    public void setWithRecognitionIsSet(boolean value) {
      __isset_bit_vector.set(__WITHRECOGNITION_ISSET_ID, value);
    }

    public boolean isWithAttributes() {
      return this.withAttributes;
    }

    public void setWithAttributes(boolean withAttributes) {
      this.withAttributes = withAttributes;
      setWithAttributesIsSet(true);
    }

    public void unsetWithAttributes() {
      __isset_bit_vector.clear(__WITHATTRIBUTES_ISSET_ID);
    }

    /** Returns true if field withAttributes is set (has been asigned a value) and false otherwise */
    public boolean isSetWithAttributes() {
      return __isset_bit_vector.get(__WITHATTRIBUTES_ISSET_ID);
    }

    public void setWithAttributesIsSet(boolean value) {
      __isset_bit_vector.set(__WITHATTRIBUTES_ISSET_ID, value);
    }

    public boolean isWithAlternateData() {
      return this.withAlternateData;
    }

    public void setWithAlternateData(boolean withAlternateData) {
      this.withAlternateData = withAlternateData;
      setWithAlternateDataIsSet(true);
    }

    public void unsetWithAlternateData() {
      __isset_bit_vector.clear(__WITHALTERNATEDATA_ISSET_ID);
    }

    /** Returns true if field withAlternateData is set (has been asigned a value) and false otherwise */
    public boolean isSetWithAlternateData() {
      return __isset_bit_vector.get(__WITHALTERNATEDATA_ISSET_ID);
    }

    public void setWithAlternateDataIsSet(boolean value) {
      __isset_bit_vector.set(__WITHALTERNATEDATA_ISSET_ID, value);
    }

    public void setFieldValue(_Fields field, Object value) {
      switch (field) {
      case AUTHENTICATION_TOKEN:
        if (value == null) {
          unsetAuthenticationToken();
        } else {
          setAuthenticationToken((String)value);
        }
        break;

      case GUID:
        if (value == null) {
          unsetGuid();
        } else {
          setGuid((String)value);
        }
        break;

      case WITH_DATA:
        if (value == null) {
          unsetWithData();
        } else {
          setWithData((Boolean)value);
        }
        break;

      case WITH_RECOGNITION:
        if (value == null) {
          unsetWithRecognition();
        } else {
          setWithRecognition((Boolean)value);
        }
        break;

      case WITH_ATTRIBUTES:
        if (value == null) {
          unsetWithAttributes();
        } else {
          setWithAttributes((Boolean)value);
        }
        break;

      case WITH_ALTERNATE_DATA:
        if (value == null) {
          unsetWithAlternateData();
        } else {
          setWithAlternateData((Boolean)value);
        }
        break;

      }
    }

    public void setFieldValue(int fieldID, Object value) {
      setFieldValue(_Fields.findByThriftIdOrThrow(fieldID), value);
    }

    public Object getFieldValue(_Fields field) {
      switch (field) {
      case AUTHENTICATION_TOKEN:
        return getAuthenticationToken();

      case GUID:
        return getGuid();

      case WITH_DATA:
        return new Boolean(isWithData());

      case WITH_RECOGNITION:
        return new Boolean(isWithRecognition());

      case WITH_ATTRIBUTES:
        return new Boolean(isWithAttributes());

      case WITH_ALTERNATE_DATA:
        return new Boolean(isWithAlternateData());

      }
      throw new IllegalStateException();
    }

    public Object getFieldValue(int fieldId) {
      return getFieldValue(_Fields.findByThriftIdOrThrow(fieldId));
    }

    /** Returns true if field corresponding to fieldID is set (has been asigned a value) and false otherwise */
    public boolean isSet(_Fields field) {
      switch (field) {
      case AUTHENTICATION_TOKEN:
        return isSetAuthenticationToken();
      case GUID:
        return isSetGuid();
      case WITH_DATA:
        return isSetWithData();
      case WITH_RECOGNITION:
        return isSetWithRecognition();
      case WITH_ATTRIBUTES:
        return isSetWithAttributes();
      case WITH_ALTERNATE_DATA:
        return isSetWithAlternateData();
      }
      throw new IllegalStateException();
    }

    public boolean isSet(int fieldID) {
      return isSet(_Fields.findByThriftIdOrThrow(fieldID));
    }

    public boolean equals(Object that) {
      if (that == null)
        return false;
      if (that instanceof getResource_args)
        return this.equals((getResource_args)that);
      return false;
    }

    public boolean equals(getResource_args that) {
      if (that == null)
        return false;

      boolean this_present_authenticationToken = true && this.isSetAuthenticationToken();
      boolean that_present_authenticationToken = true && that.isSetAuthenticationToken();
      if (this_present_authenticationToken || that_present_authenticationToken) {
        if (!(this_present_authenticationToken && that_present_authenticationToken))
          return false;
        if (!this.authenticationToken.equals(that.authenticationToken))
          return false;
      }

      boolean this_present_guid = true && this.isSetGuid();
      boolean that_present_guid = true && that.isSetGuid();
      if (this_present_guid || that_present_guid) {
        if (!(this_present_guid && that_present_guid))
          return false;
        if (!this.guid.equals(that.guid))
          return false;
      }

      boolean this_present_withData = true;
      boolean that_present_withData = true;
      if (this_present_withData || that_present_withData) {
        if (!(this_present_withData && that_present_withData))
          return false;
        if (this.withData != that.withData)
          return false;
      }

      boolean this_present_withRecognition = true;
      boolean that_present_withRecognition = true;
      if (this_present_withRecognition || that_present_withRecognition) {
        if (!(this_present_withRecognition && that_present_withRecognition))
          return false;
        if (this.withRecognition != that.withRecognition)
          return false;
      }

      boolean this_present_withAttributes = true;
      boolean that_present_withAttributes = true;
      if (this_present_withAttributes || that_present_withAttributes) {
        if (!(this_present_withAttributes && that_present_withAttributes))
          return false;
        if (this.withAttributes != that.withAttributes)
          return false;
      }

      boolean this_present_withAlternateData = true;
      boolean that_present_withAlternateData = true;
      if (this_present_withAlternateData || that_present_withAlternateData) {
        if (!(this_present_withAlternateData && that_present_withAlternateData))
          return false;
        if (this.withAlternateData != that.withAlternateData)
          return false;
      }

      return true;
    }

    public int hashCode() {
      return 0;
    }

    public int compareTo(getResource_args other) {
      if (!getClass().equals(other.getClass())) {
        return getClass().getName().compareTo(other.getClass().getName());
      }

      int lastComparison = 0;
      getResource_args typedOther = (getResource_args)other;

      lastComparison = Boolean.valueOf(isSetAuthenticationToken()).compareTo(isSetAuthenticationToken());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(authenticationToken, typedOther.authenticationToken);
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = Boolean.valueOf(isSetGuid()).compareTo(isSetGuid());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(guid, typedOther.guid);
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = Boolean.valueOf(isSetWithData()).compareTo(isSetWithData());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(withData, typedOther.withData);
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = Boolean.valueOf(isSetWithRecognition()).compareTo(isSetWithRecognition());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(withRecognition, typedOther.withRecognition);
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = Boolean.valueOf(isSetWithAttributes()).compareTo(isSetWithAttributes());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(withAttributes, typedOther.withAttributes);
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = Boolean.valueOf(isSetWithAlternateData()).compareTo(isSetWithAlternateData());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(withAlternateData, typedOther.withAlternateData);
      if (lastComparison != 0) {
        return lastComparison;
      }
      return 0;
    }

    public void read(TProtocol iprot) throws TException {
      TField field;
      iprot.readStructBegin();
      while (true)
      {
        field = iprot.readFieldBegin();
        if (field.type == TType.STOP) { 
          break;
        }
        _Fields fieldId = _Fields.findByThriftId(field.id);
        if (fieldId == null) {
          TProtocolUtil.skip(iprot, field.type);
        } else {
          switch (fieldId) {
            case AUTHENTICATION_TOKEN:
              if (field.type == TType.STRING) {
                this.authenticationToken = iprot.readString();
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
            case GUID:
              if (field.type == TType.STRING) {
                this.guid = iprot.readString();
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
            case WITH_DATA:
              if (field.type == TType.BOOL) {
                this.withData = iprot.readBool();
                setWithDataIsSet(true);
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
            case WITH_RECOGNITION:
              if (field.type == TType.BOOL) {
                this.withRecognition = iprot.readBool();
                setWithRecognitionIsSet(true);
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
            case WITH_ATTRIBUTES:
              if (field.type == TType.BOOL) {
                this.withAttributes = iprot.readBool();
                setWithAttributesIsSet(true);
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
            case WITH_ALTERNATE_DATA:
              if (field.type == TType.BOOL) {
                this.withAlternateData = iprot.readBool();
                setWithAlternateDataIsSet(true);
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
          }
          iprot.readFieldEnd();
        }
      }
      iprot.readStructEnd();
      validate();
    }

    public void write(TProtocol oprot) throws TException {
      validate();

      oprot.writeStructBegin(STRUCT_DESC);
      if (this.authenticationToken != null) {
        oprot.writeFieldBegin(AUTHENTICATION_TOKEN_FIELD_DESC);
        oprot.writeString(this.authenticationToken);
        oprot.writeFieldEnd();
      }
      if (this.guid != null) {
        oprot.writeFieldBegin(GUID_FIELD_DESC);
        oprot.writeString(this.guid);
        oprot.writeFieldEnd();
      }
      oprot.writeFieldBegin(WITH_DATA_FIELD_DESC);
      oprot.writeBool(this.withData);
      oprot.writeFieldEnd();
      oprot.writeFieldBegin(WITH_RECOGNITION_FIELD_DESC);
      oprot.writeBool(this.withRecognition);
      oprot.writeFieldEnd();
      oprot.writeFieldBegin(WITH_ATTRIBUTES_FIELD_DESC);
      oprot.writeBool(this.withAttributes);
      oprot.writeFieldEnd();
      oprot.writeFieldBegin(WITH_ALTERNATE_DATA_FIELD_DESC);
      oprot.writeBool(this.withAlternateData);
      oprot.writeFieldEnd();
      oprot.writeFieldStop();
      oprot.writeStructEnd();
    }

    public String toString() {
      StringBuilder sb = new StringBuilder("getResource_args(");
      boolean first = true;

      sb.append("authenticationToken:");
      if (this.authenticationToken == null) {
        sb.append("null");
      } else {
        sb.append(this.authenticationToken);
      }
      first = false;
      if (!first) sb.append(", ");
      sb.append("guid:");
      if (this.guid == null) {
        sb.append("null");
      } else {
        sb.append(this.guid);
      }
      first = false;
      if (!first) sb.append(", ");
      sb.append("withData:");
      sb.append(this.withData);
      first = false;
      if (!first) sb.append(", ");
      sb.append("withRecognition:");
      sb.append(this.withRecognition);
      first = false;
      if (!first) sb.append(", ");
      sb.append("withAttributes:");
      sb.append(this.withAttributes);
      first = false;
      if (!first) sb.append(", ");
      sb.append("withAlternateData:");
      sb.append(this.withAlternateData);
      first = false;
      sb.append(")");
      return sb.toString();
    }

    public void validate() throws TException {
      // check for required fields
    }

  }

  public static class getResource_result implements TBase<getResource_result._Fields>, java.io.Serializable, Cloneable, Comparable<getResource_result>   {
    private static final TStruct STRUCT_DESC = new TStruct("getResource_result");

    private static final TField SUCCESS_FIELD_DESC = new TField("success", TType.STRUCT, (short)0);
    private static final TField USER_EXCEPTION_FIELD_DESC = new TField("userException", TType.STRUCT, (short)1);
    private static final TField SYSTEM_EXCEPTION_FIELD_DESC = new TField("systemException", TType.STRUCT, (short)2);
    private static final TField NOT_FOUND_EXCEPTION_FIELD_DESC = new TField("notFoundException", TType.STRUCT, (short)3);

    private com.evernote.edam.type.Resource success;
    private com.evernote.edam.error.EDAMUserException userException;
    private com.evernote.edam.error.EDAMSystemException systemException;
    private com.evernote.edam.error.EDAMNotFoundException notFoundException;

    /** The set of fields this struct contains, along with convenience methods for finding and manipulating them. */
    public enum _Fields implements TFieldIdEnum {
      SUCCESS((short)0, "success"),
      USER_EXCEPTION((short)1, "userException"),
      SYSTEM_EXCEPTION((short)2, "systemException"),
      NOT_FOUND_EXCEPTION((short)3, "notFoundException");

      private static final Map<Integer, _Fields> byId = new HashMap<Integer, _Fields>();
      private static final Map<String, _Fields> byName = new HashMap<String, _Fields>();

      static {
        for (_Fields field : EnumSet.allOf(_Fields.class)) {
          byId.put((int)field._thriftId, field);
          byName.put(field.getFieldName(), field);
        }
      }

      /**
       * Find the _Fields constant that matches fieldId, or null if its not found.
       */
      public static _Fields findByThriftId(int fieldId) {
        return byId.get(fieldId);
      }

      /**
       * Find the _Fields constant that matches fieldId, throwing an exception
       * if it is not found.
       */
      public static _Fields findByThriftIdOrThrow(int fieldId) {
        _Fields fields = findByThriftId(fieldId);
        if (fields == null) throw new IllegalArgumentException("Field " + fieldId + " doesn't exist!");
        return fields;
      }

      /**
       * Find the _Fields constant that matches name, or null if its not found.
       */
      public static _Fields findByName(String name) {
        return byName.get(name);
      }

      private final short _thriftId;
      private final String _fieldName;

      _Fields(short thriftId, String fieldName) {
        _thriftId = thriftId;
        _fieldName = fieldName;
      }

      public short getThriftFieldId() {
        return _thriftId;
      }

      public String getFieldName() {
        return _fieldName;
      }
    }

    // isset id assignments

    public static final Map<_Fields, FieldMetaData> metaDataMap = Collections.unmodifiableMap(new EnumMap<_Fields, FieldMetaData>(_Fields.class) {{
      put(_Fields.SUCCESS, new FieldMetaData("success", TFieldRequirementType.DEFAULT, 
          new StructMetaData(TType.STRUCT, com.evernote.edam.type.Resource.class)));
      put(_Fields.USER_EXCEPTION, new FieldMetaData("userException", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.STRUCT)));
      put(_Fields.SYSTEM_EXCEPTION, new FieldMetaData("systemException", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.STRUCT)));
      put(_Fields.NOT_FOUND_EXCEPTION, new FieldMetaData("notFoundException", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.STRUCT)));
    }});

    static {
      FieldMetaData.addStructMetaDataMap(getResource_result.class, metaDataMap);
    }

    public getResource_result() {
    }

    public getResource_result(
      com.evernote.edam.type.Resource success,
      com.evernote.edam.error.EDAMUserException userException,
      com.evernote.edam.error.EDAMSystemException systemException,
      com.evernote.edam.error.EDAMNotFoundException notFoundException)
    {
      this();
      this.success = success;
      this.userException = userException;
      this.systemException = systemException;
      this.notFoundException = notFoundException;
    }

    /**
     * Performs a deep copy on <i>other</i>.
     */
    public getResource_result(getResource_result other) {
      if (other.isSetSuccess()) {
        this.success = new com.evernote.edam.type.Resource(other.success);
      }
      if (other.isSetUserException()) {
        this.userException = new com.evernote.edam.error.EDAMUserException(other.userException);
      }
      if (other.isSetSystemException()) {
        this.systemException = new com.evernote.edam.error.EDAMSystemException(other.systemException);
      }
      if (other.isSetNotFoundException()) {
        this.notFoundException = new com.evernote.edam.error.EDAMNotFoundException(other.notFoundException);
      }
    }

    public getResource_result deepCopy() {
      return new getResource_result(this);
    }

    @Deprecated
    public getResource_result clone() {
      return new getResource_result(this);
    }

    public com.evernote.edam.type.Resource getSuccess() {
      return this.success;
    }

    public void setSuccess(com.evernote.edam.type.Resource success) {
      this.success = success;
    }

    public void unsetSuccess() {
      this.success = null;
    }

    /** Returns true if field success is set (has been asigned a value) and false otherwise */
    public boolean isSetSuccess() {
      return this.success != null;
    }

    public void setSuccessIsSet(boolean value) {
      if (!value) {
        this.success = null;
      }
    }

    public com.evernote.edam.error.EDAMUserException getUserException() {
      return this.userException;
    }

    public void setUserException(com.evernote.edam.error.EDAMUserException userException) {
      this.userException = userException;
    }

    public void unsetUserException() {
      this.userException = null;
    }

    /** Returns true if field userException is set (has been asigned a value) and false otherwise */
    public boolean isSetUserException() {
      return this.userException != null;
    }

    public void setUserExceptionIsSet(boolean value) {
      if (!value) {
        this.userException = null;
      }
    }

    public com.evernote.edam.error.EDAMSystemException getSystemException() {
      return this.systemException;
    }

    public void setSystemException(com.evernote.edam.error.EDAMSystemException systemException) {
      this.systemException = systemException;
    }

    public void unsetSystemException() {
      this.systemException = null;
    }

    /** Returns true if field systemException is set (has been asigned a value) and false otherwise */
    public boolean isSetSystemException() {
      return this.systemException != null;
    }

    public void setSystemExceptionIsSet(boolean value) {
      if (!value) {
        this.systemException = null;
      }
    }

    public com.evernote.edam.error.EDAMNotFoundException getNotFoundException() {
      return this.notFoundException;
    }

    public void setNotFoundException(com.evernote.edam.error.EDAMNotFoundException notFoundException) {
      this.notFoundException = notFoundException;
    }

    public void unsetNotFoundException() {
      this.notFoundException = null;
    }

    /** Returns true if field notFoundException is set (has been asigned a value) and false otherwise */
    public boolean isSetNotFoundException() {
      return this.notFoundException != null;
    }

    public void setNotFoundExceptionIsSet(boolean value) {
      if (!value) {
        this.notFoundException = null;
      }
    }

    public void setFieldValue(_Fields field, Object value) {
      switch (field) {
      case SUCCESS:
        if (value == null) {
          unsetSuccess();
        } else {
          setSuccess((com.evernote.edam.type.Resource)value);
        }
        break;

      case USER_EXCEPTION:
        if (value == null) {
          unsetUserException();
        } else {
          setUserException((com.evernote.edam.error.EDAMUserException)value);
        }
        break;

      case SYSTEM_EXCEPTION:
        if (value == null) {
          unsetSystemException();
        } else {
          setSystemException((com.evernote.edam.error.EDAMSystemException)value);
        }
        break;

      case NOT_FOUND_EXCEPTION:
        if (value == null) {
          unsetNotFoundException();
        } else {
          setNotFoundException((com.evernote.edam.error.EDAMNotFoundException)value);
        }
        break;

      }
    }

    public void setFieldValue(int fieldID, Object value) {
      setFieldValue(_Fields.findByThriftIdOrThrow(fieldID), value);
    }

    public Object getFieldValue(_Fields field) {
      switch (field) {
      case SUCCESS:
        return getSuccess();

      case USER_EXCEPTION:
        return getUserException();

      case SYSTEM_EXCEPTION:
        return getSystemException();

      case NOT_FOUND_EXCEPTION:
        return getNotFoundException();

      }
      throw new IllegalStateException();
    }

    public Object getFieldValue(int fieldId) {
      return getFieldValue(_Fields.findByThriftIdOrThrow(fieldId));
    }

    /** Returns true if field corresponding to fieldID is set (has been asigned a value) and false otherwise */
    public boolean isSet(_Fields field) {
      switch (field) {
      case SUCCESS:
        return isSetSuccess();
      case USER_EXCEPTION:
        return isSetUserException();
      case SYSTEM_EXCEPTION:
        return isSetSystemException();
      case NOT_FOUND_EXCEPTION:
        return isSetNotFoundException();
      }
      throw new IllegalStateException();
    }

    public boolean isSet(int fieldID) {
      return isSet(_Fields.findByThriftIdOrThrow(fieldID));
    }

    public boolean equals(Object that) {
      if (that == null)
        return false;
      if (that instanceof getResource_result)
        return this.equals((getResource_result)that);
      return false;
    }

    public boolean equals(getResource_result that) {
      if (that == null)
        return false;

      boolean this_present_success = true && this.isSetSuccess();
      boolean that_present_success = true && that.isSetSuccess();
      if (this_present_success || that_present_success) {
        if (!(this_present_success && that_present_success))
          return false;
        if (!this.success.equals(that.success))
          return false;
      }

      boolean this_present_userException = true && this.isSetUserException();
      boolean that_present_userException = true && that.isSetUserException();
      if (this_present_userException || that_present_userException) {
        if (!(this_present_userException && that_present_userException))
          return false;
        if (!this.userException.equals(that.userException))
          return false;
      }

      boolean this_present_systemException = true && this.isSetSystemException();
      boolean that_present_systemException = true && that.isSetSystemException();
      if (this_present_systemException || that_present_systemException) {
        if (!(this_present_systemException && that_present_systemException))
          return false;
        if (!this.systemException.equals(that.systemException))
          return false;
      }

      boolean this_present_notFoundException = true && this.isSetNotFoundException();
      boolean that_present_notFoundException = true && that.isSetNotFoundException();
      if (this_present_notFoundException || that_present_notFoundException) {
        if (!(this_present_notFoundException && that_present_notFoundException))
          return false;
        if (!this.notFoundException.equals(that.notFoundException))
          return false;
      }

      return true;
    }

    public int hashCode() {
      return 0;
    }

    public int compareTo(getResource_result other) {
      if (!getClass().equals(other.getClass())) {
        return getClass().getName().compareTo(other.getClass().getName());
      }

      int lastComparison = 0;
      getResource_result typedOther = (getResource_result)other;

      lastComparison = Boolean.valueOf(isSetSuccess()).compareTo(isSetSuccess());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(success, typedOther.success);
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = Boolean.valueOf(isSetUserException()).compareTo(isSetUserException());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(userException, typedOther.userException);
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = Boolean.valueOf(isSetSystemException()).compareTo(isSetSystemException());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(systemException, typedOther.systemException);
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = Boolean.valueOf(isSetNotFoundException()).compareTo(isSetNotFoundException());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(notFoundException, typedOther.notFoundException);
      if (lastComparison != 0) {
        return lastComparison;
      }
      return 0;
    }

    public void read(TProtocol iprot) throws TException {
      TField field;
      iprot.readStructBegin();
      while (true)
      {
        field = iprot.readFieldBegin();
        if (field.type == TType.STOP) { 
          break;
        }
        _Fields fieldId = _Fields.findByThriftId(field.id);
        if (fieldId == null) {
          TProtocolUtil.skip(iprot, field.type);
        } else {
          switch (fieldId) {
            case SUCCESS:
              if (field.type == TType.STRUCT) {
                this.success = new com.evernote.edam.type.Resource();
                this.success.read(iprot);
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
            case USER_EXCEPTION:
              if (field.type == TType.STRUCT) {
                this.userException = new com.evernote.edam.error.EDAMUserException();
                this.userException.read(iprot);
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
            case SYSTEM_EXCEPTION:
              if (field.type == TType.STRUCT) {
                this.systemException = new com.evernote.edam.error.EDAMSystemException();
                this.systemException.read(iprot);
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
            case NOT_FOUND_EXCEPTION:
              if (field.type == TType.STRUCT) {
                this.notFoundException = new com.evernote.edam.error.EDAMNotFoundException();
                this.notFoundException.read(iprot);
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
          }
          iprot.readFieldEnd();
        }
      }
      iprot.readStructEnd();
      validate();
    }

    public void write(TProtocol oprot) throws TException {
      oprot.writeStructBegin(STRUCT_DESC);

      if (this.isSetSuccess()) {
        oprot.writeFieldBegin(SUCCESS_FIELD_DESC);
        this.success.write(oprot);
        oprot.writeFieldEnd();
      } else if (this.isSetUserException()) {
        oprot.writeFieldBegin(USER_EXCEPTION_FIELD_DESC);
        this.userException.write(oprot);
        oprot.writeFieldEnd();
      } else if (this.isSetSystemException()) {
        oprot.writeFieldBegin(SYSTEM_EXCEPTION_FIELD_DESC);
        this.systemException.write(oprot);
        oprot.writeFieldEnd();
      } else if (this.isSetNotFoundException()) {
        oprot.writeFieldBegin(NOT_FOUND_EXCEPTION_FIELD_DESC);
        this.notFoundException.write(oprot);
        oprot.writeFieldEnd();
      }
      oprot.writeFieldStop();
      oprot.writeStructEnd();
    }

    public String toString() {
      StringBuilder sb = new StringBuilder("getResource_result(");
      boolean first = true;

      sb.append("success:");
      if (this.success == null) {
        sb.append("null");
      } else {
        sb.append(this.success);
      }
      first = false;
      if (!first) sb.append(", ");
      sb.append("userException:");
      if (this.userException == null) {
        sb.append("null");
      } else {
        sb.append(this.userException);
      }
      first = false;
      if (!first) sb.append(", ");
      sb.append("systemException:");
      if (this.systemException == null) {
        sb.append("null");
      } else {
        sb.append(this.systemException);
      }
      first = false;
      if (!first) sb.append(", ");
      sb.append("notFoundException:");
      if (this.notFoundException == null) {
        sb.append("null");
      } else {
        sb.append(this.notFoundException);
      }
      first = false;
      sb.append(")");
      return sb.toString();
    }

    public void validate() throws TException {
      // check for required fields
    }

  }

  public static class updateResource_args implements TBase<updateResource_args._Fields>, java.io.Serializable, Cloneable, Comparable<updateResource_args>   {
    private static final TStruct STRUCT_DESC = new TStruct("updateResource_args");

    private static final TField AUTHENTICATION_TOKEN_FIELD_DESC = new TField("authenticationToken", TType.STRING, (short)1);
    private static final TField RESOURCE_FIELD_DESC = new TField("resource", TType.STRUCT, (short)2);

    private String authenticationToken;
    private com.evernote.edam.type.Resource resource;

    /** The set of fields this struct contains, along with convenience methods for finding and manipulating them. */
    public enum _Fields implements TFieldIdEnum {
      AUTHENTICATION_TOKEN((short)1, "authenticationToken"),
      RESOURCE((short)2, "resource");

      private static final Map<Integer, _Fields> byId = new HashMap<Integer, _Fields>();
      private static final Map<String, _Fields> byName = new HashMap<String, _Fields>();

      static {
        for (_Fields field : EnumSet.allOf(_Fields.class)) {
          byId.put((int)field._thriftId, field);
          byName.put(field.getFieldName(), field);
        }
      }

      /**
       * Find the _Fields constant that matches fieldId, or null if its not found.
       */
      public static _Fields findByThriftId(int fieldId) {
        return byId.get(fieldId);
      }

      /**
       * Find the _Fields constant that matches fieldId, throwing an exception
       * if it is not found.
       */
      public static _Fields findByThriftIdOrThrow(int fieldId) {
        _Fields fields = findByThriftId(fieldId);
        if (fields == null) throw new IllegalArgumentException("Field " + fieldId + " doesn't exist!");
        return fields;
      }

      /**
       * Find the _Fields constant that matches name, or null if its not found.
       */
      public static _Fields findByName(String name) {
        return byName.get(name);
      }

      private final short _thriftId;
      private final String _fieldName;

      _Fields(short thriftId, String fieldName) {
        _thriftId = thriftId;
        _fieldName = fieldName;
      }

      public short getThriftFieldId() {
        return _thriftId;
      }

      public String getFieldName() {
        return _fieldName;
      }
    }

    // isset id assignments

    public static final Map<_Fields, FieldMetaData> metaDataMap = Collections.unmodifiableMap(new EnumMap<_Fields, FieldMetaData>(_Fields.class) {{
      put(_Fields.AUTHENTICATION_TOKEN, new FieldMetaData("authenticationToken", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.STRING)));
      put(_Fields.RESOURCE, new FieldMetaData("resource", TFieldRequirementType.DEFAULT, 
          new StructMetaData(TType.STRUCT, com.evernote.edam.type.Resource.class)));
    }});

    static {
      FieldMetaData.addStructMetaDataMap(updateResource_args.class, metaDataMap);
    }

    public updateResource_args() {
    }

    public updateResource_args(
      String authenticationToken,
      com.evernote.edam.type.Resource resource)
    {
      this();
      this.authenticationToken = authenticationToken;
      this.resource = resource;
    }

    /**
     * Performs a deep copy on <i>other</i>.
     */
    public updateResource_args(updateResource_args other) {
      if (other.isSetAuthenticationToken()) {
        this.authenticationToken = other.authenticationToken;
      }
      if (other.isSetResource()) {
        this.resource = new com.evernote.edam.type.Resource(other.resource);
      }
    }

    public updateResource_args deepCopy() {
      return new updateResource_args(this);
    }

    @Deprecated
    public updateResource_args clone() {
      return new updateResource_args(this);
    }

    public String getAuthenticationToken() {
      return this.authenticationToken;
    }

    public void setAuthenticationToken(String authenticationToken) {
      this.authenticationToken = authenticationToken;
    }

    public void unsetAuthenticationToken() {
      this.authenticationToken = null;
    }

    /** Returns true if field authenticationToken is set (has been asigned a value) and false otherwise */
    public boolean isSetAuthenticationToken() {
      return this.authenticationToken != null;
    }

    public void setAuthenticationTokenIsSet(boolean value) {
      if (!value) {
        this.authenticationToken = null;
      }
    }

    public com.evernote.edam.type.Resource getResource() {
      return this.resource;
    }

    public void setResource(com.evernote.edam.type.Resource resource) {
      this.resource = resource;
    }

    public void unsetResource() {
      this.resource = null;
    }

    /** Returns true if field resource is set (has been asigned a value) and false otherwise */
    public boolean isSetResource() {
      return this.resource != null;
    }

    public void setResourceIsSet(boolean value) {
      if (!value) {
        this.resource = null;
      }
    }

    public void setFieldValue(_Fields field, Object value) {
      switch (field) {
      case AUTHENTICATION_TOKEN:
        if (value == null) {
          unsetAuthenticationToken();
        } else {
          setAuthenticationToken((String)value);
        }
        break;

      case RESOURCE:
        if (value == null) {
          unsetResource();
        } else {
          setResource((com.evernote.edam.type.Resource)value);
        }
        break;

      }
    }

    public void setFieldValue(int fieldID, Object value) {
      setFieldValue(_Fields.findByThriftIdOrThrow(fieldID), value);
    }

    public Object getFieldValue(_Fields field) {
      switch (field) {
      case AUTHENTICATION_TOKEN:
        return getAuthenticationToken();

      case RESOURCE:
        return getResource();

      }
      throw new IllegalStateException();
    }

    public Object getFieldValue(int fieldId) {
      return getFieldValue(_Fields.findByThriftIdOrThrow(fieldId));
    }

    /** Returns true if field corresponding to fieldID is set (has been asigned a value) and false otherwise */
    public boolean isSet(_Fields field) {
      switch (field) {
      case AUTHENTICATION_TOKEN:
        return isSetAuthenticationToken();
      case RESOURCE:
        return isSetResource();
      }
      throw new IllegalStateException();
    }

    public boolean isSet(int fieldID) {
      return isSet(_Fields.findByThriftIdOrThrow(fieldID));
    }

    public boolean equals(Object that) {
      if (that == null)
        return false;
      if (that instanceof updateResource_args)
        return this.equals((updateResource_args)that);
      return false;
    }

    public boolean equals(updateResource_args that) {
      if (that == null)
        return false;

      boolean this_present_authenticationToken = true && this.isSetAuthenticationToken();
      boolean that_present_authenticationToken = true && that.isSetAuthenticationToken();
      if (this_present_authenticationToken || that_present_authenticationToken) {
        if (!(this_present_authenticationToken && that_present_authenticationToken))
          return false;
        if (!this.authenticationToken.equals(that.authenticationToken))
          return false;
      }

      boolean this_present_resource = true && this.isSetResource();
      boolean that_present_resource = true && that.isSetResource();
      if (this_present_resource || that_present_resource) {
        if (!(this_present_resource && that_present_resource))
          return false;
        if (!this.resource.equals(that.resource))
          return false;
      }

      return true;
    }

    public int hashCode() {
      return 0;
    }

    public int compareTo(updateResource_args other) {
      if (!getClass().equals(other.getClass())) {
        return getClass().getName().compareTo(other.getClass().getName());
      }

      int lastComparison = 0;
      updateResource_args typedOther = (updateResource_args)other;

      lastComparison = Boolean.valueOf(isSetAuthenticationToken()).compareTo(isSetAuthenticationToken());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(authenticationToken, typedOther.authenticationToken);
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = Boolean.valueOf(isSetResource()).compareTo(isSetResource());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(resource, typedOther.resource);
      if (lastComparison != 0) {
        return lastComparison;
      }
      return 0;
    }

    public void read(TProtocol iprot) throws TException {
      TField field;
      iprot.readStructBegin();
      while (true)
      {
        field = iprot.readFieldBegin();
        if (field.type == TType.STOP) { 
          break;
        }
        _Fields fieldId = _Fields.findByThriftId(field.id);
        if (fieldId == null) {
          TProtocolUtil.skip(iprot, field.type);
        } else {
          switch (fieldId) {
            case AUTHENTICATION_TOKEN:
              if (field.type == TType.STRING) {
                this.authenticationToken = iprot.readString();
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
            case RESOURCE:
              if (field.type == TType.STRUCT) {
                this.resource = new com.evernote.edam.type.Resource();
                this.resource.read(iprot);
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
          }
          iprot.readFieldEnd();
        }
      }
      iprot.readStructEnd();
      validate();
    }

    public void write(TProtocol oprot) throws TException {
      validate();

      oprot.writeStructBegin(STRUCT_DESC);
      if (this.authenticationToken != null) {
        oprot.writeFieldBegin(AUTHENTICATION_TOKEN_FIELD_DESC);
        oprot.writeString(this.authenticationToken);
        oprot.writeFieldEnd();
      }
      if (this.resource != null) {
        oprot.writeFieldBegin(RESOURCE_FIELD_DESC);
        this.resource.write(oprot);
        oprot.writeFieldEnd();
      }
      oprot.writeFieldStop();
      oprot.writeStructEnd();
    }

    public String toString() {
      StringBuilder sb = new StringBuilder("updateResource_args(");
      boolean first = true;

      sb.append("authenticationToken:");
      if (this.authenticationToken == null) {
        sb.append("null");
      } else {
        sb.append(this.authenticationToken);
      }
      first = false;
      if (!first) sb.append(", ");
      sb.append("resource:");
      if (this.resource == null) {
        sb.append("null");
      } else {
        sb.append(this.resource);
      }
      first = false;
      sb.append(")");
      return sb.toString();
    }

    public void validate() throws TException {
      // check for required fields
    }

  }

  public static class updateResource_result implements TBase<updateResource_result._Fields>, java.io.Serializable, Cloneable, Comparable<updateResource_result>   {
    private static final TStruct STRUCT_DESC = new TStruct("updateResource_result");

    private static final TField SUCCESS_FIELD_DESC = new TField("success", TType.I32, (short)0);
    private static final TField USER_EXCEPTION_FIELD_DESC = new TField("userException", TType.STRUCT, (short)1);
    private static final TField SYSTEM_EXCEPTION_FIELD_DESC = new TField("systemException", TType.STRUCT, (short)2);
    private static final TField NOT_FOUND_EXCEPTION_FIELD_DESC = new TField("notFoundException", TType.STRUCT, (short)3);

    private int success;
    private com.evernote.edam.error.EDAMUserException userException;
    private com.evernote.edam.error.EDAMSystemException systemException;
    private com.evernote.edam.error.EDAMNotFoundException notFoundException;

    /** The set of fields this struct contains, along with convenience methods for finding and manipulating them. */
    public enum _Fields implements TFieldIdEnum {
      SUCCESS((short)0, "success"),
      USER_EXCEPTION((short)1, "userException"),
      SYSTEM_EXCEPTION((short)2, "systemException"),
      NOT_FOUND_EXCEPTION((short)3, "notFoundException");

      private static final Map<Integer, _Fields> byId = new HashMap<Integer, _Fields>();
      private static final Map<String, _Fields> byName = new HashMap<String, _Fields>();

      static {
        for (_Fields field : EnumSet.allOf(_Fields.class)) {
          byId.put((int)field._thriftId, field);
          byName.put(field.getFieldName(), field);
        }
      }

      /**
       * Find the _Fields constant that matches fieldId, or null if its not found.
       */
      public static _Fields findByThriftId(int fieldId) {
        return byId.get(fieldId);
      }

      /**
       * Find the _Fields constant that matches fieldId, throwing an exception
       * if it is not found.
       */
      public static _Fields findByThriftIdOrThrow(int fieldId) {
        _Fields fields = findByThriftId(fieldId);
        if (fields == null) throw new IllegalArgumentException("Field " + fieldId + " doesn't exist!");
        return fields;
      }

      /**
       * Find the _Fields constant that matches name, or null if its not found.
       */
      public static _Fields findByName(String name) {
        return byName.get(name);
      }

      private final short _thriftId;
      private final String _fieldName;

      _Fields(short thriftId, String fieldName) {
        _thriftId = thriftId;
        _fieldName = fieldName;
      }

      public short getThriftFieldId() {
        return _thriftId;
      }

      public String getFieldName() {
        return _fieldName;
      }
    }

    // isset id assignments
    private static final int __SUCCESS_ISSET_ID = 0;
    private BitSet __isset_bit_vector = new BitSet(1);

    public static final Map<_Fields, FieldMetaData> metaDataMap = Collections.unmodifiableMap(new EnumMap<_Fields, FieldMetaData>(_Fields.class) {{
      put(_Fields.SUCCESS, new FieldMetaData("success", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.I32)));
      put(_Fields.USER_EXCEPTION, new FieldMetaData("userException", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.STRUCT)));
      put(_Fields.SYSTEM_EXCEPTION, new FieldMetaData("systemException", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.STRUCT)));
      put(_Fields.NOT_FOUND_EXCEPTION, new FieldMetaData("notFoundException", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.STRUCT)));
    }});

    static {
      FieldMetaData.addStructMetaDataMap(updateResource_result.class, metaDataMap);
    }

    public updateResource_result() {
    }

    public updateResource_result(
      int success,
      com.evernote.edam.error.EDAMUserException userException,
      com.evernote.edam.error.EDAMSystemException systemException,
      com.evernote.edam.error.EDAMNotFoundException notFoundException)
    {
      this();
      this.success = success;
      setSuccessIsSet(true);
      this.userException = userException;
      this.systemException = systemException;
      this.notFoundException = notFoundException;
    }

    /**
     * Performs a deep copy on <i>other</i>.
     */
    public updateResource_result(updateResource_result other) {
      __isset_bit_vector.clear();
      __isset_bit_vector.or(other.__isset_bit_vector);
      this.success = other.success;
      if (other.isSetUserException()) {
        this.userException = new com.evernote.edam.error.EDAMUserException(other.userException);
      }
      if (other.isSetSystemException()) {
        this.systemException = new com.evernote.edam.error.EDAMSystemException(other.systemException);
      }
      if (other.isSetNotFoundException()) {
        this.notFoundException = new com.evernote.edam.error.EDAMNotFoundException(other.notFoundException);
      }
    }

    public updateResource_result deepCopy() {
      return new updateResource_result(this);
    }

    @Deprecated
    public updateResource_result clone() {
      return new updateResource_result(this);
    }

    public int getSuccess() {
      return this.success;
    }

    public void setSuccess(int success) {
      this.success = success;
      setSuccessIsSet(true);
    }

    public void unsetSuccess() {
      __isset_bit_vector.clear(__SUCCESS_ISSET_ID);
    }

    /** Returns true if field success is set (has been asigned a value) and false otherwise */
    public boolean isSetSuccess() {
      return __isset_bit_vector.get(__SUCCESS_ISSET_ID);
    }

    public void setSuccessIsSet(boolean value) {
      __isset_bit_vector.set(__SUCCESS_ISSET_ID, value);
    }

    public com.evernote.edam.error.EDAMUserException getUserException() {
      return this.userException;
    }

    public void setUserException(com.evernote.edam.error.EDAMUserException userException) {
      this.userException = userException;
    }

    public void unsetUserException() {
      this.userException = null;
    }

    /** Returns true if field userException is set (has been asigned a value) and false otherwise */
    public boolean isSetUserException() {
      return this.userException != null;
    }

    public void setUserExceptionIsSet(boolean value) {
      if (!value) {
        this.userException = null;
      }
    }

    public com.evernote.edam.error.EDAMSystemException getSystemException() {
      return this.systemException;
    }

    public void setSystemException(com.evernote.edam.error.EDAMSystemException systemException) {
      this.systemException = systemException;
    }

    public void unsetSystemException() {
      this.systemException = null;
    }

    /** Returns true if field systemException is set (has been asigned a value) and false otherwise */
    public boolean isSetSystemException() {
      return this.systemException != null;
    }

    public void setSystemExceptionIsSet(boolean value) {
      if (!value) {
        this.systemException = null;
      }
    }

    public com.evernote.edam.error.EDAMNotFoundException getNotFoundException() {
      return this.notFoundException;
    }

    public void setNotFoundException(com.evernote.edam.error.EDAMNotFoundException notFoundException) {
      this.notFoundException = notFoundException;
    }

    public void unsetNotFoundException() {
      this.notFoundException = null;
    }

    /** Returns true if field notFoundException is set (has been asigned a value) and false otherwise */
    public boolean isSetNotFoundException() {
      return this.notFoundException != null;
    }

    public void setNotFoundExceptionIsSet(boolean value) {
      if (!value) {
        this.notFoundException = null;
      }
    }

    public void setFieldValue(_Fields field, Object value) {
      switch (field) {
      case SUCCESS:
        if (value == null) {
          unsetSuccess();
        } else {
          setSuccess((Integer)value);
        }
        break;

      case USER_EXCEPTION:
        if (value == null) {
          unsetUserException();
        } else {
          setUserException((com.evernote.edam.error.EDAMUserException)value);
        }
        break;

      case SYSTEM_EXCEPTION:
        if (value == null) {
          unsetSystemException();
        } else {
          setSystemException((com.evernote.edam.error.EDAMSystemException)value);
        }
        break;

      case NOT_FOUND_EXCEPTION:
        if (value == null) {
          unsetNotFoundException();
        } else {
          setNotFoundException((com.evernote.edam.error.EDAMNotFoundException)value);
        }
        break;

      }
    }

    public void setFieldValue(int fieldID, Object value) {
      setFieldValue(_Fields.findByThriftIdOrThrow(fieldID), value);
    }

    public Object getFieldValue(_Fields field) {
      switch (field) {
      case SUCCESS:
        return new Integer(getSuccess());

      case USER_EXCEPTION:
        return getUserException();

      case SYSTEM_EXCEPTION:
        return getSystemException();

      case NOT_FOUND_EXCEPTION:
        return getNotFoundException();

      }
      throw new IllegalStateException();
    }

    public Object getFieldValue(int fieldId) {
      return getFieldValue(_Fields.findByThriftIdOrThrow(fieldId));
    }

    /** Returns true if field corresponding to fieldID is set (has been asigned a value) and false otherwise */
    public boolean isSet(_Fields field) {
      switch (field) {
      case SUCCESS:
        return isSetSuccess();
      case USER_EXCEPTION:
        return isSetUserException();
      case SYSTEM_EXCEPTION:
        return isSetSystemException();
      case NOT_FOUND_EXCEPTION:
        return isSetNotFoundException();
      }
      throw new IllegalStateException();
    }

    public boolean isSet(int fieldID) {
      return isSet(_Fields.findByThriftIdOrThrow(fieldID));
    }

    public boolean equals(Object that) {
      if (that == null)
        return false;
      if (that instanceof updateResource_result)
        return this.equals((updateResource_result)that);
      return false;
    }

    public boolean equals(updateResource_result that) {
      if (that == null)
        return false;

      boolean this_present_success = true;
      boolean that_present_success = true;
      if (this_present_success || that_present_success) {
        if (!(this_present_success && that_present_success))
          return false;
        if (this.success != that.success)
          return false;
      }

      boolean this_present_userException = true && this.isSetUserException();
      boolean that_present_userException = true && that.isSetUserException();
      if (this_present_userException || that_present_userException) {
        if (!(this_present_userException && that_present_userException))
          return false;
        if (!this.userException.equals(that.userException))
          return false;
      }

      boolean this_present_systemException = true && this.isSetSystemException();
      boolean that_present_systemException = true && that.isSetSystemException();
      if (this_present_systemException || that_present_systemException) {
        if (!(this_present_systemException && that_present_systemException))
          return false;
        if (!this.systemException.equals(that.systemException))
          return false;
      }

      boolean this_present_notFoundException = true && this.isSetNotFoundException();
      boolean that_present_notFoundException = true && that.isSetNotFoundException();
      if (this_present_notFoundException || that_present_notFoundException) {
        if (!(this_present_notFoundException && that_present_notFoundException))
          return false;
        if (!this.notFoundException.equals(that.notFoundException))
          return false;
      }

      return true;
    }

    public int hashCode() {
      return 0;
    }

    public int compareTo(updateResource_result other) {
      if (!getClass().equals(other.getClass())) {
        return getClass().getName().compareTo(other.getClass().getName());
      }

      int lastComparison = 0;
      updateResource_result typedOther = (updateResource_result)other;

      lastComparison = Boolean.valueOf(isSetSuccess()).compareTo(isSetSuccess());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(success, typedOther.success);
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = Boolean.valueOf(isSetUserException()).compareTo(isSetUserException());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(userException, typedOther.userException);
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = Boolean.valueOf(isSetSystemException()).compareTo(isSetSystemException());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(systemException, typedOther.systemException);
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = Boolean.valueOf(isSetNotFoundException()).compareTo(isSetNotFoundException());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(notFoundException, typedOther.notFoundException);
      if (lastComparison != 0) {
        return lastComparison;
      }
      return 0;
    }

    public void read(TProtocol iprot) throws TException {
      TField field;
      iprot.readStructBegin();
      while (true)
      {
        field = iprot.readFieldBegin();
        if (field.type == TType.STOP) { 
          break;
        }
        _Fields fieldId = _Fields.findByThriftId(field.id);
        if (fieldId == null) {
          TProtocolUtil.skip(iprot, field.type);
        } else {
          switch (fieldId) {
            case SUCCESS:
              if (field.type == TType.I32) {
                this.success = iprot.readI32();
                setSuccessIsSet(true);
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
            case USER_EXCEPTION:
              if (field.type == TType.STRUCT) {
                this.userException = new com.evernote.edam.error.EDAMUserException();
                this.userException.read(iprot);
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
            case SYSTEM_EXCEPTION:
              if (field.type == TType.STRUCT) {
                this.systemException = new com.evernote.edam.error.EDAMSystemException();
                this.systemException.read(iprot);
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
            case NOT_FOUND_EXCEPTION:
              if (field.type == TType.STRUCT) {
                this.notFoundException = new com.evernote.edam.error.EDAMNotFoundException();
                this.notFoundException.read(iprot);
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
          }
          iprot.readFieldEnd();
        }
      }
      iprot.readStructEnd();
      validate();
    }

    public void write(TProtocol oprot) throws TException {
      oprot.writeStructBegin(STRUCT_DESC);

      if (this.isSetSuccess()) {
        oprot.writeFieldBegin(SUCCESS_FIELD_DESC);
        oprot.writeI32(this.success);
        oprot.writeFieldEnd();
      } else if (this.isSetUserException()) {
        oprot.writeFieldBegin(USER_EXCEPTION_FIELD_DESC);
        this.userException.write(oprot);
        oprot.writeFieldEnd();
      } else if (this.isSetSystemException()) {
        oprot.writeFieldBegin(SYSTEM_EXCEPTION_FIELD_DESC);
        this.systemException.write(oprot);
        oprot.writeFieldEnd();
      } else if (this.isSetNotFoundException()) {
        oprot.writeFieldBegin(NOT_FOUND_EXCEPTION_FIELD_DESC);
        this.notFoundException.write(oprot);
        oprot.writeFieldEnd();
      }
      oprot.writeFieldStop();
      oprot.writeStructEnd();
    }

    public String toString() {
      StringBuilder sb = new StringBuilder("updateResource_result(");
      boolean first = true;

      sb.append("success:");
      sb.append(this.success);
      first = false;
      if (!first) sb.append(", ");
      sb.append("userException:");
      if (this.userException == null) {
        sb.append("null");
      } else {
        sb.append(this.userException);
      }
      first = false;
      if (!first) sb.append(", ");
      sb.append("systemException:");
      if (this.systemException == null) {
        sb.append("null");
      } else {
        sb.append(this.systemException);
      }
      first = false;
      if (!first) sb.append(", ");
      sb.append("notFoundException:");
      if (this.notFoundException == null) {
        sb.append("null");
      } else {
        sb.append(this.notFoundException);
      }
      first = false;
      sb.append(")");
      return sb.toString();
    }

    public void validate() throws TException {
      // check for required fields
    }

  }

  public static class getResourceData_args implements TBase<getResourceData_args._Fields>, java.io.Serializable, Cloneable, Comparable<getResourceData_args>   {
    private static final TStruct STRUCT_DESC = new TStruct("getResourceData_args");

    private static final TField AUTHENTICATION_TOKEN_FIELD_DESC = new TField("authenticationToken", TType.STRING, (short)1);
    private static final TField GUID_FIELD_DESC = new TField("guid", TType.STRING, (short)2);

    private String authenticationToken;
    private String guid;

    /** The set of fields this struct contains, along with convenience methods for finding and manipulating them. */
    public enum _Fields implements TFieldIdEnum {
      AUTHENTICATION_TOKEN((short)1, "authenticationToken"),
      GUID((short)2, "guid");

      private static final Map<Integer, _Fields> byId = new HashMap<Integer, _Fields>();
      private static final Map<String, _Fields> byName = new HashMap<String, _Fields>();

      static {
        for (_Fields field : EnumSet.allOf(_Fields.class)) {
          byId.put((int)field._thriftId, field);
          byName.put(field.getFieldName(), field);
        }
      }

      /**
       * Find the _Fields constant that matches fieldId, or null if its not found.
       */
      public static _Fields findByThriftId(int fieldId) {
        return byId.get(fieldId);
      }

      /**
       * Find the _Fields constant that matches fieldId, throwing an exception
       * if it is not found.
       */
      public static _Fields findByThriftIdOrThrow(int fieldId) {
        _Fields fields = findByThriftId(fieldId);
        if (fields == null) throw new IllegalArgumentException("Field " + fieldId + " doesn't exist!");
        return fields;
      }

      /**
       * Find the _Fields constant that matches name, or null if its not found.
       */
      public static _Fields findByName(String name) {
        return byName.get(name);
      }

      private final short _thriftId;
      private final String _fieldName;

      _Fields(short thriftId, String fieldName) {
        _thriftId = thriftId;
        _fieldName = fieldName;
      }

      public short getThriftFieldId() {
        return _thriftId;
      }

      public String getFieldName() {
        return _fieldName;
      }
    }

    // isset id assignments

    public static final Map<_Fields, FieldMetaData> metaDataMap = Collections.unmodifiableMap(new EnumMap<_Fields, FieldMetaData>(_Fields.class) {{
      put(_Fields.AUTHENTICATION_TOKEN, new FieldMetaData("authenticationToken", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.STRING)));
      put(_Fields.GUID, new FieldMetaData("guid", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.STRING)));
    }});

    static {
      FieldMetaData.addStructMetaDataMap(getResourceData_args.class, metaDataMap);
    }

    public getResourceData_args() {
    }

    public getResourceData_args(
      String authenticationToken,
      String guid)
    {
      this();
      this.authenticationToken = authenticationToken;
      this.guid = guid;
    }

    /**
     * Performs a deep copy on <i>other</i>.
     */
    public getResourceData_args(getResourceData_args other) {
      if (other.isSetAuthenticationToken()) {
        this.authenticationToken = other.authenticationToken;
      }
      if (other.isSetGuid()) {
        this.guid = other.guid;
      }
    }

    public getResourceData_args deepCopy() {
      return new getResourceData_args(this);
    }

    @Deprecated
    public getResourceData_args clone() {
      return new getResourceData_args(this);
    }

    public String getAuthenticationToken() {
      return this.authenticationToken;
    }

    public void setAuthenticationToken(String authenticationToken) {
      this.authenticationToken = authenticationToken;
    }

    public void unsetAuthenticationToken() {
      this.authenticationToken = null;
    }

    /** Returns true if field authenticationToken is set (has been asigned a value) and false otherwise */
    public boolean isSetAuthenticationToken() {
      return this.authenticationToken != null;
    }

    public void setAuthenticationTokenIsSet(boolean value) {
      if (!value) {
        this.authenticationToken = null;
      }
    }

    public String getGuid() {
      return this.guid;
    }

    public void setGuid(String guid) {
      this.guid = guid;
    }

    public void unsetGuid() {
      this.guid = null;
    }

    /** Returns true if field guid is set (has been asigned a value) and false otherwise */
    public boolean isSetGuid() {
      return this.guid != null;
    }

    public void setGuidIsSet(boolean value) {
      if (!value) {
        this.guid = null;
      }
    }

    public void setFieldValue(_Fields field, Object value) {
      switch (field) {
      case AUTHENTICATION_TOKEN:
        if (value == null) {
          unsetAuthenticationToken();
        } else {
          setAuthenticationToken((String)value);
        }
        break;

      case GUID:
        if (value == null) {
          unsetGuid();
        } else {
          setGuid((String)value);
        }
        break;

      }
    }

    public void setFieldValue(int fieldID, Object value) {
      setFieldValue(_Fields.findByThriftIdOrThrow(fieldID), value);
    }

    public Object getFieldValue(_Fields field) {
      switch (field) {
      case AUTHENTICATION_TOKEN:
        return getAuthenticationToken();

      case GUID:
        return getGuid();

      }
      throw new IllegalStateException();
    }

    public Object getFieldValue(int fieldId) {
      return getFieldValue(_Fields.findByThriftIdOrThrow(fieldId));
    }

    /** Returns true if field corresponding to fieldID is set (has been asigned a value) and false otherwise */
    public boolean isSet(_Fields field) {
      switch (field) {
      case AUTHENTICATION_TOKEN:
        return isSetAuthenticationToken();
      case GUID:
        return isSetGuid();
      }
      throw new IllegalStateException();
    }

    public boolean isSet(int fieldID) {
      return isSet(_Fields.findByThriftIdOrThrow(fieldID));
    }

    public boolean equals(Object that) {
      if (that == null)
        return false;
      if (that instanceof getResourceData_args)
        return this.equals((getResourceData_args)that);
      return false;
    }

    public boolean equals(getResourceData_args that) {
      if (that == null)
        return false;

      boolean this_present_authenticationToken = true && this.isSetAuthenticationToken();
      boolean that_present_authenticationToken = true && that.isSetAuthenticationToken();
      if (this_present_authenticationToken || that_present_authenticationToken) {
        if (!(this_present_authenticationToken && that_present_authenticationToken))
          return false;
        if (!this.authenticationToken.equals(that.authenticationToken))
          return false;
      }

      boolean this_present_guid = true && this.isSetGuid();
      boolean that_present_guid = true && that.isSetGuid();
      if (this_present_guid || that_present_guid) {
        if (!(this_present_guid && that_present_guid))
          return false;
        if (!this.guid.equals(that.guid))
          return false;
      }

      return true;
    }

    public int hashCode() {
      return 0;
    }

    public int compareTo(getResourceData_args other) {
      if (!getClass().equals(other.getClass())) {
        return getClass().getName().compareTo(other.getClass().getName());
      }

      int lastComparison = 0;
      getResourceData_args typedOther = (getResourceData_args)other;

      lastComparison = Boolean.valueOf(isSetAuthenticationToken()).compareTo(isSetAuthenticationToken());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(authenticationToken, typedOther.authenticationToken);
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = Boolean.valueOf(isSetGuid()).compareTo(isSetGuid());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(guid, typedOther.guid);
      if (lastComparison != 0) {
        return lastComparison;
      }
      return 0;
    }

    public void read(TProtocol iprot) throws TException {
      TField field;
      iprot.readStructBegin();
      while (true)
      {
        field = iprot.readFieldBegin();
        if (field.type == TType.STOP) { 
          break;
        }
        _Fields fieldId = _Fields.findByThriftId(field.id);
        if (fieldId == null) {
          TProtocolUtil.skip(iprot, field.type);
        } else {
          switch (fieldId) {
            case AUTHENTICATION_TOKEN:
              if (field.type == TType.STRING) {
                this.authenticationToken = iprot.readString();
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
            case GUID:
              if (field.type == TType.STRING) {
                this.guid = iprot.readString();
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
          }
          iprot.readFieldEnd();
        }
      }
      iprot.readStructEnd();
      validate();
    }

    public void write(TProtocol oprot) throws TException {
      validate();

      oprot.writeStructBegin(STRUCT_DESC);
      if (this.authenticationToken != null) {
        oprot.writeFieldBegin(AUTHENTICATION_TOKEN_FIELD_DESC);
        oprot.writeString(this.authenticationToken);
        oprot.writeFieldEnd();
      }
      if (this.guid != null) {
        oprot.writeFieldBegin(GUID_FIELD_DESC);
        oprot.writeString(this.guid);
        oprot.writeFieldEnd();
      }
      oprot.writeFieldStop();
      oprot.writeStructEnd();
    }

    public String toString() {
      StringBuilder sb = new StringBuilder("getResourceData_args(");
      boolean first = true;

      sb.append("authenticationToken:");
      if (this.authenticationToken == null) {
        sb.append("null");
      } else {
        sb.append(this.authenticationToken);
      }
      first = false;
      if (!first) sb.append(", ");
      sb.append("guid:");
      if (this.guid == null) {
        sb.append("null");
      } else {
        sb.append(this.guid);
      }
      first = false;
      sb.append(")");
      return sb.toString();
    }

    public void validate() throws TException {
      // check for required fields
    }

  }

  public static class getResourceData_result implements TBase<getResourceData_result._Fields>, java.io.Serializable, Cloneable, Comparable<getResourceData_result>   {
    private static final TStruct STRUCT_DESC = new TStruct("getResourceData_result");

    private static final TField SUCCESS_FIELD_DESC = new TField("success", TType.STRING, (short)0);
    private static final TField USER_EXCEPTION_FIELD_DESC = new TField("userException", TType.STRUCT, (short)1);
    private static final TField SYSTEM_EXCEPTION_FIELD_DESC = new TField("systemException", TType.STRUCT, (short)2);
    private static final TField NOT_FOUND_EXCEPTION_FIELD_DESC = new TField("notFoundException", TType.STRUCT, (short)3);

    private byte[] success;
    private com.evernote.edam.error.EDAMUserException userException;
    private com.evernote.edam.error.EDAMSystemException systemException;
    private com.evernote.edam.error.EDAMNotFoundException notFoundException;

    /** The set of fields this struct contains, along with convenience methods for finding and manipulating them. */
    public enum _Fields implements TFieldIdEnum {
      SUCCESS((short)0, "success"),
      USER_EXCEPTION((short)1, "userException"),
      SYSTEM_EXCEPTION((short)2, "systemException"),
      NOT_FOUND_EXCEPTION((short)3, "notFoundException");

      private static final Map<Integer, _Fields> byId = new HashMap<Integer, _Fields>();
      private static final Map<String, _Fields> byName = new HashMap<String, _Fields>();

      static {
        for (_Fields field : EnumSet.allOf(_Fields.class)) {
          byId.put((int)field._thriftId, field);
          byName.put(field.getFieldName(), field);
        }
      }

      /**
       * Find the _Fields constant that matches fieldId, or null if its not found.
       */
      public static _Fields findByThriftId(int fieldId) {
        return byId.get(fieldId);
      }

      /**
       * Find the _Fields constant that matches fieldId, throwing an exception
       * if it is not found.
       */
      public static _Fields findByThriftIdOrThrow(int fieldId) {
        _Fields fields = findByThriftId(fieldId);
        if (fields == null) throw new IllegalArgumentException("Field " + fieldId + " doesn't exist!");
        return fields;
      }

      /**
       * Find the _Fields constant that matches name, or null if its not found.
       */
      public static _Fields findByName(String name) {
        return byName.get(name);
      }

      private final short _thriftId;
      private final String _fieldName;

      _Fields(short thriftId, String fieldName) {
        _thriftId = thriftId;
        _fieldName = fieldName;
      }

      public short getThriftFieldId() {
        return _thriftId;
      }

      public String getFieldName() {
        return _fieldName;
      }
    }

    // isset id assignments

    public static final Map<_Fields, FieldMetaData> metaDataMap = Collections.unmodifiableMap(new EnumMap<_Fields, FieldMetaData>(_Fields.class) {{
      put(_Fields.SUCCESS, new FieldMetaData("success", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.STRING)));
      put(_Fields.USER_EXCEPTION, new FieldMetaData("userException", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.STRUCT)));
      put(_Fields.SYSTEM_EXCEPTION, new FieldMetaData("systemException", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.STRUCT)));
      put(_Fields.NOT_FOUND_EXCEPTION, new FieldMetaData("notFoundException", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.STRUCT)));
    }});

    static {
      FieldMetaData.addStructMetaDataMap(getResourceData_result.class, metaDataMap);
    }

    public getResourceData_result() {
    }

    public getResourceData_result(
      byte[] success,
      com.evernote.edam.error.EDAMUserException userException,
      com.evernote.edam.error.EDAMSystemException systemException,
      com.evernote.edam.error.EDAMNotFoundException notFoundException)
    {
      this();
      this.success = success;
      this.userException = userException;
      this.systemException = systemException;
      this.notFoundException = notFoundException;
    }

    /**
     * Performs a deep copy on <i>other</i>.
     */
    public getResourceData_result(getResourceData_result other) {
      if (other.isSetSuccess()) {
        this.success = new byte[other.success.length];
        System.arraycopy(other.success, 0, success, 0, other.success.length);
      }
      if (other.isSetUserException()) {
        this.userException = new com.evernote.edam.error.EDAMUserException(other.userException);
      }
      if (other.isSetSystemException()) {
        this.systemException = new com.evernote.edam.error.EDAMSystemException(other.systemException);
      }
      if (other.isSetNotFoundException()) {
        this.notFoundException = new com.evernote.edam.error.EDAMNotFoundException(other.notFoundException);
      }
    }

    public getResourceData_result deepCopy() {
      return new getResourceData_result(this);
    }

    @Deprecated
    public getResourceData_result clone() {
      return new getResourceData_result(this);
    }

    public byte[] getSuccess() {
      return this.success;
    }

    public void setSuccess(byte[] success) {
      this.success = success;
    }

    public void unsetSuccess() {
      this.success = null;
    }

    /** Returns true if field success is set (has been asigned a value) and false otherwise */
    public boolean isSetSuccess() {
      return this.success != null;
    }

    public void setSuccessIsSet(boolean value) {
      if (!value) {
        this.success = null;
      }
    }

    public com.evernote.edam.error.EDAMUserException getUserException() {
      return this.userException;
    }

    public void setUserException(com.evernote.edam.error.EDAMUserException userException) {
      this.userException = userException;
    }

    public void unsetUserException() {
      this.userException = null;
    }

    /** Returns true if field userException is set (has been asigned a value) and false otherwise */
    public boolean isSetUserException() {
      return this.userException != null;
    }

    public void setUserExceptionIsSet(boolean value) {
      if (!value) {
        this.userException = null;
      }
    }

    public com.evernote.edam.error.EDAMSystemException getSystemException() {
      return this.systemException;
    }

    public void setSystemException(com.evernote.edam.error.EDAMSystemException systemException) {
      this.systemException = systemException;
    }

    public void unsetSystemException() {
      this.systemException = null;
    }

    /** Returns true if field systemException is set (has been asigned a value) and false otherwise */
    public boolean isSetSystemException() {
      return this.systemException != null;
    }

    public void setSystemExceptionIsSet(boolean value) {
      if (!value) {
        this.systemException = null;
      }
    }

    public com.evernote.edam.error.EDAMNotFoundException getNotFoundException() {
      return this.notFoundException;
    }

    public void setNotFoundException(com.evernote.edam.error.EDAMNotFoundException notFoundException) {
      this.notFoundException = notFoundException;
    }

    public void unsetNotFoundException() {
      this.notFoundException = null;
    }

    /** Returns true if field notFoundException is set (has been asigned a value) and false otherwise */
    public boolean isSetNotFoundException() {
      return this.notFoundException != null;
    }

    public void setNotFoundExceptionIsSet(boolean value) {
      if (!value) {
        this.notFoundException = null;
      }
    }

    public void setFieldValue(_Fields field, Object value) {
      switch (field) {
      case SUCCESS:
        if (value == null) {
          unsetSuccess();
        } else {
          setSuccess((byte[])value);
        }
        break;

      case USER_EXCEPTION:
        if (value == null) {
          unsetUserException();
        } else {
          setUserException((com.evernote.edam.error.EDAMUserException)value);
        }
        break;

      case SYSTEM_EXCEPTION:
        if (value == null) {
          unsetSystemException();
        } else {
          setSystemException((com.evernote.edam.error.EDAMSystemException)value);
        }
        break;

      case NOT_FOUND_EXCEPTION:
        if (value == null) {
          unsetNotFoundException();
        } else {
          setNotFoundException((com.evernote.edam.error.EDAMNotFoundException)value);
        }
        break;

      }
    }

    public void setFieldValue(int fieldID, Object value) {
      setFieldValue(_Fields.findByThriftIdOrThrow(fieldID), value);
    }

    public Object getFieldValue(_Fields field) {
      switch (field) {
      case SUCCESS:
        return getSuccess();

      case USER_EXCEPTION:
        return getUserException();

      case SYSTEM_EXCEPTION:
        return getSystemException();

      case NOT_FOUND_EXCEPTION:
        return getNotFoundException();

      }
      throw new IllegalStateException();
    }

    public Object getFieldValue(int fieldId) {
      return getFieldValue(_Fields.findByThriftIdOrThrow(fieldId));
    }

    /** Returns true if field corresponding to fieldID is set (has been asigned a value) and false otherwise */
    public boolean isSet(_Fields field) {
      switch (field) {
      case SUCCESS:
        return isSetSuccess();
      case USER_EXCEPTION:
        return isSetUserException();
      case SYSTEM_EXCEPTION:
        return isSetSystemException();
      case NOT_FOUND_EXCEPTION:
        return isSetNotFoundException();
      }
      throw new IllegalStateException();
    }

    public boolean isSet(int fieldID) {
      return isSet(_Fields.findByThriftIdOrThrow(fieldID));
    }

    public boolean equals(Object that) {
      if (that == null)
        return false;
      if (that instanceof getResourceData_result)
        return this.equals((getResourceData_result)that);
      return false;
    }

    public boolean equals(getResourceData_result that) {
      if (that == null)
        return false;

      boolean this_present_success = true && this.isSetSuccess();
      boolean that_present_success = true && that.isSetSuccess();
      if (this_present_success || that_present_success) {
        if (!(this_present_success && that_present_success))
          return false;
        if (!java.util.Arrays.equals(this.success, that.success))
          return false;
      }

      boolean this_present_userException = true && this.isSetUserException();
      boolean that_present_userException = true && that.isSetUserException();
      if (this_present_userException || that_present_userException) {
        if (!(this_present_userException && that_present_userException))
          return false;
        if (!this.userException.equals(that.userException))
          return false;
      }

      boolean this_present_systemException = true && this.isSetSystemException();
      boolean that_present_systemException = true && that.isSetSystemException();
      if (this_present_systemException || that_present_systemException) {
        if (!(this_present_systemException && that_present_systemException))
          return false;
        if (!this.systemException.equals(that.systemException))
          return false;
      }

      boolean this_present_notFoundException = true && this.isSetNotFoundException();
      boolean that_present_notFoundException = true && that.isSetNotFoundException();
      if (this_present_notFoundException || that_present_notFoundException) {
        if (!(this_present_notFoundException && that_present_notFoundException))
          return false;
        if (!this.notFoundException.equals(that.notFoundException))
          return false;
      }

      return true;
    }

    public int hashCode() {
      return 0;
    }

    public int compareTo(getResourceData_result other) {
      if (!getClass().equals(other.getClass())) {
        return getClass().getName().compareTo(other.getClass().getName());
      }

      int lastComparison = 0;
      getResourceData_result typedOther = (getResourceData_result)other;

      lastComparison = Boolean.valueOf(isSetSuccess()).compareTo(isSetSuccess());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(success, typedOther.success);
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = Boolean.valueOf(isSetUserException()).compareTo(isSetUserException());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(userException, typedOther.userException);
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = Boolean.valueOf(isSetSystemException()).compareTo(isSetSystemException());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(systemException, typedOther.systemException);
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = Boolean.valueOf(isSetNotFoundException()).compareTo(isSetNotFoundException());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(notFoundException, typedOther.notFoundException);
      if (lastComparison != 0) {
        return lastComparison;
      }
      return 0;
    }

    public void read(TProtocol iprot) throws TException {
      TField field;
      iprot.readStructBegin();
      while (true)
      {
        field = iprot.readFieldBegin();
        if (field.type == TType.STOP) { 
          break;
        }
        _Fields fieldId = _Fields.findByThriftId(field.id);
        if (fieldId == null) {
          TProtocolUtil.skip(iprot, field.type);
        } else {
          switch (fieldId) {
            case SUCCESS:
              if (field.type == TType.STRING) {
                this.success = iprot.readBinary();
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
            case USER_EXCEPTION:
              if (field.type == TType.STRUCT) {
                this.userException = new com.evernote.edam.error.EDAMUserException();
                this.userException.read(iprot);
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
            case SYSTEM_EXCEPTION:
              if (field.type == TType.STRUCT) {
                this.systemException = new com.evernote.edam.error.EDAMSystemException();
                this.systemException.read(iprot);
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
            case NOT_FOUND_EXCEPTION:
              if (field.type == TType.STRUCT) {
                this.notFoundException = new com.evernote.edam.error.EDAMNotFoundException();
                this.notFoundException.read(iprot);
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
          }
          iprot.readFieldEnd();
        }
      }
      iprot.readStructEnd();
      validate();
    }

    public void write(TProtocol oprot) throws TException {
      oprot.writeStructBegin(STRUCT_DESC);

      if (this.isSetSuccess()) {
        oprot.writeFieldBegin(SUCCESS_FIELD_DESC);
        oprot.writeBinary(this.success);
        oprot.writeFieldEnd();
      } else if (this.isSetUserException()) {
        oprot.writeFieldBegin(USER_EXCEPTION_FIELD_DESC);
        this.userException.write(oprot);
        oprot.writeFieldEnd();
      } else if (this.isSetSystemException()) {
        oprot.writeFieldBegin(SYSTEM_EXCEPTION_FIELD_DESC);
        this.systemException.write(oprot);
        oprot.writeFieldEnd();
      } else if (this.isSetNotFoundException()) {
        oprot.writeFieldBegin(NOT_FOUND_EXCEPTION_FIELD_DESC);
        this.notFoundException.write(oprot);
        oprot.writeFieldEnd();
      }
      oprot.writeFieldStop();
      oprot.writeStructEnd();
    }

    public String toString() {
      StringBuilder sb = new StringBuilder("getResourceData_result(");
      boolean first = true;

      sb.append("success:");
      if (this.success == null) {
        sb.append("null");
      } else {
          int __success_size = Math.min(this.success.length, 128);
          for (int i = 0; i < __success_size; i++) {
            if (i != 0) sb.append(" ");
            sb.append(Integer.toHexString(this.success[i]).length() > 1 ? Integer.toHexString(this.success[i]).substring(Integer.toHexString(this.success[i]).length() - 2).toUpperCase() : "0" + Integer.toHexString(this.success[i]).toUpperCase());
          }
          if (this.success.length > 128) sb.append(" ...");
      }
      first = false;
      if (!first) sb.append(", ");
      sb.append("userException:");
      if (this.userException == null) {
        sb.append("null");
      } else {
        sb.append(this.userException);
      }
      first = false;
      if (!first) sb.append(", ");
      sb.append("systemException:");
      if (this.systemException == null) {
        sb.append("null");
      } else {
        sb.append(this.systemException);
      }
      first = false;
      if (!first) sb.append(", ");
      sb.append("notFoundException:");
      if (this.notFoundException == null) {
        sb.append("null");
      } else {
        sb.append(this.notFoundException);
      }
      first = false;
      sb.append(")");
      return sb.toString();
    }

    public void validate() throws TException {
      // check for required fields
    }

  }

  public static class getResourceByHash_args implements TBase<getResourceByHash_args._Fields>, java.io.Serializable, Cloneable, Comparable<getResourceByHash_args>   {
    private static final TStruct STRUCT_DESC = new TStruct("getResourceByHash_args");

    private static final TField AUTHENTICATION_TOKEN_FIELD_DESC = new TField("authenticationToken", TType.STRING, (short)1);
    private static final TField NOTE_GUID_FIELD_DESC = new TField("noteGuid", TType.STRING, (short)2);
    private static final TField CONTENT_HASH_FIELD_DESC = new TField("contentHash", TType.STRING, (short)3);
    private static final TField WITH_DATA_FIELD_DESC = new TField("withData", TType.BOOL, (short)4);
    private static final TField WITH_RECOGNITION_FIELD_DESC = new TField("withRecognition", TType.BOOL, (short)5);
    private static final TField WITH_ALTERNATE_DATA_FIELD_DESC = new TField("withAlternateData", TType.BOOL, (short)6);

    private String authenticationToken;
    private String noteGuid;
    private byte[] contentHash;
    private boolean withData;
    private boolean withRecognition;
    private boolean withAlternateData;

    /** The set of fields this struct contains, along with convenience methods for finding and manipulating them. */
    public enum _Fields implements TFieldIdEnum {
      AUTHENTICATION_TOKEN((short)1, "authenticationToken"),
      NOTE_GUID((short)2, "noteGuid"),
      CONTENT_HASH((short)3, "contentHash"),
      WITH_DATA((short)4, "withData"),
      WITH_RECOGNITION((short)5, "withRecognition"),
      WITH_ALTERNATE_DATA((short)6, "withAlternateData");

      private static final Map<Integer, _Fields> byId = new HashMap<Integer, _Fields>();
      private static final Map<String, _Fields> byName = new HashMap<String, _Fields>();

      static {
        for (_Fields field : EnumSet.allOf(_Fields.class)) {
          byId.put((int)field._thriftId, field);
          byName.put(field.getFieldName(), field);
        }
      }

      /**
       * Find the _Fields constant that matches fieldId, or null if its not found.
       */
      public static _Fields findByThriftId(int fieldId) {
        return byId.get(fieldId);
      }

      /**
       * Find the _Fields constant that matches fieldId, throwing an exception
       * if it is not found.
       */
      public static _Fields findByThriftIdOrThrow(int fieldId) {
        _Fields fields = findByThriftId(fieldId);
        if (fields == null) throw new IllegalArgumentException("Field " + fieldId + " doesn't exist!");
        return fields;
      }

      /**
       * Find the _Fields constant that matches name, or null if its not found.
       */
      public static _Fields findByName(String name) {
        return byName.get(name);
      }

      private final short _thriftId;
      private final String _fieldName;

      _Fields(short thriftId, String fieldName) {
        _thriftId = thriftId;
        _fieldName = fieldName;
      }

      public short getThriftFieldId() {
        return _thriftId;
      }

      public String getFieldName() {
        return _fieldName;
      }
    }

    // isset id assignments
    private static final int __WITHDATA_ISSET_ID = 0;
    private static final int __WITHRECOGNITION_ISSET_ID = 1;
    private static final int __WITHALTERNATEDATA_ISSET_ID = 2;
    private BitSet __isset_bit_vector = new BitSet(3);

    public static final Map<_Fields, FieldMetaData> metaDataMap = Collections.unmodifiableMap(new EnumMap<_Fields, FieldMetaData>(_Fields.class) {{
      put(_Fields.AUTHENTICATION_TOKEN, new FieldMetaData("authenticationToken", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.STRING)));
      put(_Fields.NOTE_GUID, new FieldMetaData("noteGuid", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.STRING)));
      put(_Fields.CONTENT_HASH, new FieldMetaData("contentHash", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.STRING)));
      put(_Fields.WITH_DATA, new FieldMetaData("withData", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.BOOL)));
      put(_Fields.WITH_RECOGNITION, new FieldMetaData("withRecognition", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.BOOL)));
      put(_Fields.WITH_ALTERNATE_DATA, new FieldMetaData("withAlternateData", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.BOOL)));
    }});

    static {
      FieldMetaData.addStructMetaDataMap(getResourceByHash_args.class, metaDataMap);
    }

    public getResourceByHash_args() {
    }

    public getResourceByHash_args(
      String authenticationToken,
      String noteGuid,
      byte[] contentHash,
      boolean withData,
      boolean withRecognition,
      boolean withAlternateData)
    {
      this();
      this.authenticationToken = authenticationToken;
      this.noteGuid = noteGuid;
      this.contentHash = contentHash;
      this.withData = withData;
      setWithDataIsSet(true);
      this.withRecognition = withRecognition;
      setWithRecognitionIsSet(true);
      this.withAlternateData = withAlternateData;
      setWithAlternateDataIsSet(true);
    }

    /**
     * Performs a deep copy on <i>other</i>.
     */
    public getResourceByHash_args(getResourceByHash_args other) {
      __isset_bit_vector.clear();
      __isset_bit_vector.or(other.__isset_bit_vector);
      if (other.isSetAuthenticationToken()) {
        this.authenticationToken = other.authenticationToken;
      }
      if (other.isSetNoteGuid()) {
        this.noteGuid = other.noteGuid;
      }
      if (other.isSetContentHash()) {
        this.contentHash = new byte[other.contentHash.length];
        System.arraycopy(other.contentHash, 0, contentHash, 0, other.contentHash.length);
      }
      this.withData = other.withData;
      this.withRecognition = other.withRecognition;
      this.withAlternateData = other.withAlternateData;
    }

    public getResourceByHash_args deepCopy() {
      return new getResourceByHash_args(this);
    }

    @Deprecated
    public getResourceByHash_args clone() {
      return new getResourceByHash_args(this);
    }

    public String getAuthenticationToken() {
      return this.authenticationToken;
    }

    public void setAuthenticationToken(String authenticationToken) {
      this.authenticationToken = authenticationToken;
    }

    public void unsetAuthenticationToken() {
      this.authenticationToken = null;
    }

    /** Returns true if field authenticationToken is set (has been asigned a value) and false otherwise */
    public boolean isSetAuthenticationToken() {
      return this.authenticationToken != null;
    }

    public void setAuthenticationTokenIsSet(boolean value) {
      if (!value) {
        this.authenticationToken = null;
      }
    }

    public String getNoteGuid() {
      return this.noteGuid;
    }

    public void setNoteGuid(String noteGuid) {
      this.noteGuid = noteGuid;
    }

    public void unsetNoteGuid() {
      this.noteGuid = null;
    }

    /** Returns true if field noteGuid is set (has been asigned a value) and false otherwise */
    public boolean isSetNoteGuid() {
      return this.noteGuid != null;
    }

    public void setNoteGuidIsSet(boolean value) {
      if (!value) {
        this.noteGuid = null;
      }
    }

    public byte[] getContentHash() {
      return this.contentHash;
    }

    public void setContentHash(byte[] contentHash) {
      this.contentHash = contentHash;
    }

    public void unsetContentHash() {
      this.contentHash = null;
    }

    /** Returns true if field contentHash is set (has been asigned a value) and false otherwise */
    public boolean isSetContentHash() {
      return this.contentHash != null;
    }

    public void setContentHashIsSet(boolean value) {
      if (!value) {
        this.contentHash = null;
      }
    }

    public boolean isWithData() {
      return this.withData;
    }

    public void setWithData(boolean withData) {
      this.withData = withData;
      setWithDataIsSet(true);
    }

    public void unsetWithData() {
      __isset_bit_vector.clear(__WITHDATA_ISSET_ID);
    }

    /** Returns true if field withData is set (has been asigned a value) and false otherwise */
    public boolean isSetWithData() {
      return __isset_bit_vector.get(__WITHDATA_ISSET_ID);
    }

    public void setWithDataIsSet(boolean value) {
      __isset_bit_vector.set(__WITHDATA_ISSET_ID, value);
    }

    public boolean isWithRecognition() {
      return this.withRecognition;
    }

    public void setWithRecognition(boolean withRecognition) {
      this.withRecognition = withRecognition;
      setWithRecognitionIsSet(true);
    }

    public void unsetWithRecognition() {
      __isset_bit_vector.clear(__WITHRECOGNITION_ISSET_ID);
    }

    /** Returns true if field withRecognition is set (has been asigned a value) and false otherwise */
    public boolean isSetWithRecognition() {
      return __isset_bit_vector.get(__WITHRECOGNITION_ISSET_ID);
    }

    public void setWithRecognitionIsSet(boolean value) {
      __isset_bit_vector.set(__WITHRECOGNITION_ISSET_ID, value);
    }

    public boolean isWithAlternateData() {
      return this.withAlternateData;
    }

    public void setWithAlternateData(boolean withAlternateData) {
      this.withAlternateData = withAlternateData;
      setWithAlternateDataIsSet(true);
    }

    public void unsetWithAlternateData() {
      __isset_bit_vector.clear(__WITHALTERNATEDATA_ISSET_ID);
    }

    /** Returns true if field withAlternateData is set (has been asigned a value) and false otherwise */
    public boolean isSetWithAlternateData() {
      return __isset_bit_vector.get(__WITHALTERNATEDATA_ISSET_ID);
    }

    public void setWithAlternateDataIsSet(boolean value) {
      __isset_bit_vector.set(__WITHALTERNATEDATA_ISSET_ID, value);
    }

    public void setFieldValue(_Fields field, Object value) {
      switch (field) {
      case AUTHENTICATION_TOKEN:
        if (value == null) {
          unsetAuthenticationToken();
        } else {
          setAuthenticationToken((String)value);
        }
        break;

      case NOTE_GUID:
        if (value == null) {
          unsetNoteGuid();
        } else {
          setNoteGuid((String)value);
        }
        break;

      case CONTENT_HASH:
        if (value == null) {
          unsetContentHash();
        } else {
          setContentHash((byte[])value);
        }
        break;

      case WITH_DATA:
        if (value == null) {
          unsetWithData();
        } else {
          setWithData((Boolean)value);
        }
        break;

      case WITH_RECOGNITION:
        if (value == null) {
          unsetWithRecognition();
        } else {
          setWithRecognition((Boolean)value);
        }
        break;

      case WITH_ALTERNATE_DATA:
        if (value == null) {
          unsetWithAlternateData();
        } else {
          setWithAlternateData((Boolean)value);
        }
        break;

      }
    }

    public void setFieldValue(int fieldID, Object value) {
      setFieldValue(_Fields.findByThriftIdOrThrow(fieldID), value);
    }

    public Object getFieldValue(_Fields field) {
      switch (field) {
      case AUTHENTICATION_TOKEN:
        return getAuthenticationToken();

      case NOTE_GUID:
        return getNoteGuid();

      case CONTENT_HASH:
        return getContentHash();

      case WITH_DATA:
        return new Boolean(isWithData());

      case WITH_RECOGNITION:
        return new Boolean(isWithRecognition());

      case WITH_ALTERNATE_DATA:
        return new Boolean(isWithAlternateData());

      }
      throw new IllegalStateException();
    }

    public Object getFieldValue(int fieldId) {
      return getFieldValue(_Fields.findByThriftIdOrThrow(fieldId));
    }

    /** Returns true if field corresponding to fieldID is set (has been asigned a value) and false otherwise */
    public boolean isSet(_Fields field) {
      switch (field) {
      case AUTHENTICATION_TOKEN:
        return isSetAuthenticationToken();
      case NOTE_GUID:
        return isSetNoteGuid();
      case CONTENT_HASH:
        return isSetContentHash();
      case WITH_DATA:
        return isSetWithData();
      case WITH_RECOGNITION:
        return isSetWithRecognition();
      case WITH_ALTERNATE_DATA:
        return isSetWithAlternateData();
      }
      throw new IllegalStateException();
    }

    public boolean isSet(int fieldID) {
      return isSet(_Fields.findByThriftIdOrThrow(fieldID));
    }

    public boolean equals(Object that) {
      if (that == null)
        return false;
      if (that instanceof getResourceByHash_args)
        return this.equals((getResourceByHash_args)that);
      return false;
    }

    public boolean equals(getResourceByHash_args that) {
      if (that == null)
        return false;

      boolean this_present_authenticationToken = true && this.isSetAuthenticationToken();
      boolean that_present_authenticationToken = true && that.isSetAuthenticationToken();
      if (this_present_authenticationToken || that_present_authenticationToken) {
        if (!(this_present_authenticationToken && that_present_authenticationToken))
          return false;
        if (!this.authenticationToken.equals(that.authenticationToken))
          return false;
      }

      boolean this_present_noteGuid = true && this.isSetNoteGuid();
      boolean that_present_noteGuid = true && that.isSetNoteGuid();
      if (this_present_noteGuid || that_present_noteGuid) {
        if (!(this_present_noteGuid && that_present_noteGuid))
          return false;
        if (!this.noteGuid.equals(that.noteGuid))
          return false;
      }

      boolean this_present_contentHash = true && this.isSetContentHash();
      boolean that_present_contentHash = true && that.isSetContentHash();
      if (this_present_contentHash || that_present_contentHash) {
        if (!(this_present_contentHash && that_present_contentHash))
          return false;
        if (!java.util.Arrays.equals(this.contentHash, that.contentHash))
          return false;
      }

      boolean this_present_withData = true;
      boolean that_present_withData = true;
      if (this_present_withData || that_present_withData) {
        if (!(this_present_withData && that_present_withData))
          return false;
        if (this.withData != that.withData)
          return false;
      }

      boolean this_present_withRecognition = true;
      boolean that_present_withRecognition = true;
      if (this_present_withRecognition || that_present_withRecognition) {
        if (!(this_present_withRecognition && that_present_withRecognition))
          return false;
        if (this.withRecognition != that.withRecognition)
          return false;
      }

      boolean this_present_withAlternateData = true;
      boolean that_present_withAlternateData = true;
      if (this_present_withAlternateData || that_present_withAlternateData) {
        if (!(this_present_withAlternateData && that_present_withAlternateData))
          return false;
        if (this.withAlternateData != that.withAlternateData)
          return false;
      }

      return true;
    }

    public int hashCode() {
      return 0;
    }

    public int compareTo(getResourceByHash_args other) {
      if (!getClass().equals(other.getClass())) {
        return getClass().getName().compareTo(other.getClass().getName());
      }

      int lastComparison = 0;
      getResourceByHash_args typedOther = (getResourceByHash_args)other;

      lastComparison = Boolean.valueOf(isSetAuthenticationToken()).compareTo(isSetAuthenticationToken());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(authenticationToken, typedOther.authenticationToken);
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = Boolean.valueOf(isSetNoteGuid()).compareTo(isSetNoteGuid());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(noteGuid, typedOther.noteGuid);
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = Boolean.valueOf(isSetContentHash()).compareTo(isSetContentHash());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(contentHash, typedOther.contentHash);
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = Boolean.valueOf(isSetWithData()).compareTo(isSetWithData());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(withData, typedOther.withData);
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = Boolean.valueOf(isSetWithRecognition()).compareTo(isSetWithRecognition());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(withRecognition, typedOther.withRecognition);
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = Boolean.valueOf(isSetWithAlternateData()).compareTo(isSetWithAlternateData());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(withAlternateData, typedOther.withAlternateData);
      if (lastComparison != 0) {
        return lastComparison;
      }
      return 0;
    }

    public void read(TProtocol iprot) throws TException {
      TField field;
      iprot.readStructBegin();
      while (true)
      {
        field = iprot.readFieldBegin();
        if (field.type == TType.STOP) { 
          break;
        }
        _Fields fieldId = _Fields.findByThriftId(field.id);
        if (fieldId == null) {
          TProtocolUtil.skip(iprot, field.type);
        } else {
          switch (fieldId) {
            case AUTHENTICATION_TOKEN:
              if (field.type == TType.STRING) {
                this.authenticationToken = iprot.readString();
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
            case NOTE_GUID:
              if (field.type == TType.STRING) {
                this.noteGuid = iprot.readString();
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
            case CONTENT_HASH:
              if (field.type == TType.STRING) {
                this.contentHash = iprot.readBinary();
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
            case WITH_DATA:
              if (field.type == TType.BOOL) {
                this.withData = iprot.readBool();
                setWithDataIsSet(true);
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
            case WITH_RECOGNITION:
              if (field.type == TType.BOOL) {
                this.withRecognition = iprot.readBool();
                setWithRecognitionIsSet(true);
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
            case WITH_ALTERNATE_DATA:
              if (field.type == TType.BOOL) {
                this.withAlternateData = iprot.readBool();
                setWithAlternateDataIsSet(true);
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
          }
          iprot.readFieldEnd();
        }
      }
      iprot.readStructEnd();
      validate();
    }

    public void write(TProtocol oprot) throws TException {
      validate();

      oprot.writeStructBegin(STRUCT_DESC);
      if (this.authenticationToken != null) {
        oprot.writeFieldBegin(AUTHENTICATION_TOKEN_FIELD_DESC);
        oprot.writeString(this.authenticationToken);
        oprot.writeFieldEnd();
      }
      if (this.noteGuid != null) {
        oprot.writeFieldBegin(NOTE_GUID_FIELD_DESC);
        oprot.writeString(this.noteGuid);
        oprot.writeFieldEnd();
      }
      if (this.contentHash != null) {
        oprot.writeFieldBegin(CONTENT_HASH_FIELD_DESC);
        oprot.writeBinary(this.contentHash);
        oprot.writeFieldEnd();
      }
      oprot.writeFieldBegin(WITH_DATA_FIELD_DESC);
      oprot.writeBool(this.withData);
      oprot.writeFieldEnd();
      oprot.writeFieldBegin(WITH_RECOGNITION_FIELD_DESC);
      oprot.writeBool(this.withRecognition);
      oprot.writeFieldEnd();
      oprot.writeFieldBegin(WITH_ALTERNATE_DATA_FIELD_DESC);
      oprot.writeBool(this.withAlternateData);
      oprot.writeFieldEnd();
      oprot.writeFieldStop();
      oprot.writeStructEnd();
    }

    public String toString() {
      StringBuilder sb = new StringBuilder("getResourceByHash_args(");
      boolean first = true;

      sb.append("authenticationToken:");
      if (this.authenticationToken == null) {
        sb.append("null");
      } else {
        sb.append(this.authenticationToken);
      }
      first = false;
      if (!first) sb.append(", ");
      sb.append("noteGuid:");
      if (this.noteGuid == null) {
        sb.append("null");
      } else {
        sb.append(this.noteGuid);
      }
      first = false;
      if (!first) sb.append(", ");
      sb.append("contentHash:");
      if (this.contentHash == null) {
        sb.append("null");
      } else {
          int __contentHash_size = Math.min(this.contentHash.length, 128);
          for (int i = 0; i < __contentHash_size; i++) {
            if (i != 0) sb.append(" ");
            sb.append(Integer.toHexString(this.contentHash[i]).length() > 1 ? Integer.toHexString(this.contentHash[i]).substring(Integer.toHexString(this.contentHash[i]).length() - 2).toUpperCase() : "0" + Integer.toHexString(this.contentHash[i]).toUpperCase());
          }
          if (this.contentHash.length > 128) sb.append(" ...");
      }
      first = false;
      if (!first) sb.append(", ");
      sb.append("withData:");
      sb.append(this.withData);
      first = false;
      if (!first) sb.append(", ");
      sb.append("withRecognition:");
      sb.append(this.withRecognition);
      first = false;
      if (!first) sb.append(", ");
      sb.append("withAlternateData:");
      sb.append(this.withAlternateData);
      first = false;
      sb.append(")");
      return sb.toString();
    }

    public void validate() throws TException {
      // check for required fields
    }

  }

  public static class getResourceByHash_result implements TBase<getResourceByHash_result._Fields>, java.io.Serializable, Cloneable, Comparable<getResourceByHash_result>   {
    private static final TStruct STRUCT_DESC = new TStruct("getResourceByHash_result");

    private static final TField SUCCESS_FIELD_DESC = new TField("success", TType.STRUCT, (short)0);
    private static final TField USER_EXCEPTION_FIELD_DESC = new TField("userException", TType.STRUCT, (short)1);
    private static final TField SYSTEM_EXCEPTION_FIELD_DESC = new TField("systemException", TType.STRUCT, (short)2);
    private static final TField NOT_FOUND_EXCEPTION_FIELD_DESC = new TField("notFoundException", TType.STRUCT, (short)3);

    private com.evernote.edam.type.Resource success;
    private com.evernote.edam.error.EDAMUserException userException;
    private com.evernote.edam.error.EDAMSystemException systemException;
    private com.evernote.edam.error.EDAMNotFoundException notFoundException;

    /** The set of fields this struct contains, along with convenience methods for finding and manipulating them. */
    public enum _Fields implements TFieldIdEnum {
      SUCCESS((short)0, "success"),
      USER_EXCEPTION((short)1, "userException"),
      SYSTEM_EXCEPTION((short)2, "systemException"),
      NOT_FOUND_EXCEPTION((short)3, "notFoundException");

      private static final Map<Integer, _Fields> byId = new HashMap<Integer, _Fields>();
      private static final Map<String, _Fields> byName = new HashMap<String, _Fields>();

      static {
        for (_Fields field : EnumSet.allOf(_Fields.class)) {
          byId.put((int)field._thriftId, field);
          byName.put(field.getFieldName(), field);
        }
      }

      /**
       * Find the _Fields constant that matches fieldId, or null if its not found.
       */
      public static _Fields findByThriftId(int fieldId) {
        return byId.get(fieldId);
      }

      /**
       * Find the _Fields constant that matches fieldId, throwing an exception
       * if it is not found.
       */
      public static _Fields findByThriftIdOrThrow(int fieldId) {
        _Fields fields = findByThriftId(fieldId);
        if (fields == null) throw new IllegalArgumentException("Field " + fieldId + " doesn't exist!");
        return fields;
      }

      /**
       * Find the _Fields constant that matches name, or null if its not found.
       */
      public static _Fields findByName(String name) {
        return byName.get(name);
      }

      private final short _thriftId;
      private final String _fieldName;

      _Fields(short thriftId, String fieldName) {
        _thriftId = thriftId;
        _fieldName = fieldName;
      }

      public short getThriftFieldId() {
        return _thriftId;
      }

      public String getFieldName() {
        return _fieldName;
      }
    }

    // isset id assignments

    public static final Map<_Fields, FieldMetaData> metaDataMap = Collections.unmodifiableMap(new EnumMap<_Fields, FieldMetaData>(_Fields.class) {{
      put(_Fields.SUCCESS, new FieldMetaData("success", TFieldRequirementType.DEFAULT, 
          new StructMetaData(TType.STRUCT, com.evernote.edam.type.Resource.class)));
      put(_Fields.USER_EXCEPTION, new FieldMetaData("userException", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.STRUCT)));
      put(_Fields.SYSTEM_EXCEPTION, new FieldMetaData("systemException", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.STRUCT)));
      put(_Fields.NOT_FOUND_EXCEPTION, new FieldMetaData("notFoundException", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.STRUCT)));
    }});

    static {
      FieldMetaData.addStructMetaDataMap(getResourceByHash_result.class, metaDataMap);
    }

    public getResourceByHash_result() {
    }

    public getResourceByHash_result(
      com.evernote.edam.type.Resource success,
      com.evernote.edam.error.EDAMUserException userException,
      com.evernote.edam.error.EDAMSystemException systemException,
      com.evernote.edam.error.EDAMNotFoundException notFoundException)
    {
      this();
      this.success = success;
      this.userException = userException;
      this.systemException = systemException;
      this.notFoundException = notFoundException;
    }

    /**
     * Performs a deep copy on <i>other</i>.
     */
    public getResourceByHash_result(getResourceByHash_result other) {
      if (other.isSetSuccess()) {
        this.success = new com.evernote.edam.type.Resource(other.success);
      }
      if (other.isSetUserException()) {
        this.userException = new com.evernote.edam.error.EDAMUserException(other.userException);
      }
      if (other.isSetSystemException()) {
        this.systemException = new com.evernote.edam.error.EDAMSystemException(other.systemException);
      }
      if (other.isSetNotFoundException()) {
        this.notFoundException = new com.evernote.edam.error.EDAMNotFoundException(other.notFoundException);
      }
    }

    public getResourceByHash_result deepCopy() {
      return new getResourceByHash_result(this);
    }

    @Deprecated
    public getResourceByHash_result clone() {
      return new getResourceByHash_result(this);
    }

    public com.evernote.edam.type.Resource getSuccess() {
      return this.success;
    }

    public void setSuccess(com.evernote.edam.type.Resource success) {
      this.success = success;
    }

    public void unsetSuccess() {
      this.success = null;
    }

    /** Returns true if field success is set (has been asigned a value) and false otherwise */
    public boolean isSetSuccess() {
      return this.success != null;
    }

    public void setSuccessIsSet(boolean value) {
      if (!value) {
        this.success = null;
      }
    }

    public com.evernote.edam.error.EDAMUserException getUserException() {
      return this.userException;
    }

    public void setUserException(com.evernote.edam.error.EDAMUserException userException) {
      this.userException = userException;
    }

    public void unsetUserException() {
      this.userException = null;
    }

    /** Returns true if field userException is set (has been asigned a value) and false otherwise */
    public boolean isSetUserException() {
      return this.userException != null;
    }

    public void setUserExceptionIsSet(boolean value) {
      if (!value) {
        this.userException = null;
      }
    }

    public com.evernote.edam.error.EDAMSystemException getSystemException() {
      return this.systemException;
    }

    public void setSystemException(com.evernote.edam.error.EDAMSystemException systemException) {
      this.systemException = systemException;
    }

    public void unsetSystemException() {
      this.systemException = null;
    }

    /** Returns true if field systemException is set (has been asigned a value) and false otherwise */
    public boolean isSetSystemException() {
      return this.systemException != null;
    }

    public void setSystemExceptionIsSet(boolean value) {
      if (!value) {
        this.systemException = null;
      }
    }

    public com.evernote.edam.error.EDAMNotFoundException getNotFoundException() {
      return this.notFoundException;
    }

    public void setNotFoundException(com.evernote.edam.error.EDAMNotFoundException notFoundException) {
      this.notFoundException = notFoundException;
    }

    public void unsetNotFoundException() {
      this.notFoundException = null;
    }

    /** Returns true if field notFoundException is set (has been asigned a value) and false otherwise */
    public boolean isSetNotFoundException() {
      return this.notFoundException != null;
    }

    public void setNotFoundExceptionIsSet(boolean value) {
      if (!value) {
        this.notFoundException = null;
      }
    }

    public void setFieldValue(_Fields field, Object value) {
      switch (field) {
      case SUCCESS:
        if (value == null) {
          unsetSuccess();
        } else {
          setSuccess((com.evernote.edam.type.Resource)value);
        }
        break;

      case USER_EXCEPTION:
        if (value == null) {
          unsetUserException();
        } else {
          setUserException((com.evernote.edam.error.EDAMUserException)value);
        }
        break;

      case SYSTEM_EXCEPTION:
        if (value == null) {
          unsetSystemException();
        } else {
          setSystemException((com.evernote.edam.error.EDAMSystemException)value);
        }
        break;

      case NOT_FOUND_EXCEPTION:
        if (value == null) {
          unsetNotFoundException();
        } else {
          setNotFoundException((com.evernote.edam.error.EDAMNotFoundException)value);
        }
        break;

      }
    }

    public void setFieldValue(int fieldID, Object value) {
      setFieldValue(_Fields.findByThriftIdOrThrow(fieldID), value);
    }

    public Object getFieldValue(_Fields field) {
      switch (field) {
      case SUCCESS:
        return getSuccess();

      case USER_EXCEPTION:
        return getUserException();

      case SYSTEM_EXCEPTION:
        return getSystemException();

      case NOT_FOUND_EXCEPTION:
        return getNotFoundException();

      }
      throw new IllegalStateException();
    }

    public Object getFieldValue(int fieldId) {
      return getFieldValue(_Fields.findByThriftIdOrThrow(fieldId));
    }

    /** Returns true if field corresponding to fieldID is set (has been asigned a value) and false otherwise */
    public boolean isSet(_Fields field) {
      switch (field) {
      case SUCCESS:
        return isSetSuccess();
      case USER_EXCEPTION:
        return isSetUserException();
      case SYSTEM_EXCEPTION:
        return isSetSystemException();
      case NOT_FOUND_EXCEPTION:
        return isSetNotFoundException();
      }
      throw new IllegalStateException();
    }

    public boolean isSet(int fieldID) {
      return isSet(_Fields.findByThriftIdOrThrow(fieldID));
    }

    public boolean equals(Object that) {
      if (that == null)
        return false;
      if (that instanceof getResourceByHash_result)
        return this.equals((getResourceByHash_result)that);
      return false;
    }

    public boolean equals(getResourceByHash_result that) {
      if (that == null)
        return false;

      boolean this_present_success = true && this.isSetSuccess();
      boolean that_present_success = true && that.isSetSuccess();
      if (this_present_success || that_present_success) {
        if (!(this_present_success && that_present_success))
          return false;
        if (!this.success.equals(that.success))
          return false;
      }

      boolean this_present_userException = true && this.isSetUserException();
      boolean that_present_userException = true && that.isSetUserException();
      if (this_present_userException || that_present_userException) {
        if (!(this_present_userException && that_present_userException))
          return false;
        if (!this.userException.equals(that.userException))
          return false;
      }

      boolean this_present_systemException = true && this.isSetSystemException();
      boolean that_present_systemException = true && that.isSetSystemException();
      if (this_present_systemException || that_present_systemException) {
        if (!(this_present_systemException && that_present_systemException))
          return false;
        if (!this.systemException.equals(that.systemException))
          return false;
      }

      boolean this_present_notFoundException = true && this.isSetNotFoundException();
      boolean that_present_notFoundException = true && that.isSetNotFoundException();
      if (this_present_notFoundException || that_present_notFoundException) {
        if (!(this_present_notFoundException && that_present_notFoundException))
          return false;
        if (!this.notFoundException.equals(that.notFoundException))
          return false;
      }

      return true;
    }

    public int hashCode() {
      return 0;
    }

    public int compareTo(getResourceByHash_result other) {
      if (!getClass().equals(other.getClass())) {
        return getClass().getName().compareTo(other.getClass().getName());
      }

      int lastComparison = 0;
      getResourceByHash_result typedOther = (getResourceByHash_result)other;

      lastComparison = Boolean.valueOf(isSetSuccess()).compareTo(isSetSuccess());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(success, typedOther.success);
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = Boolean.valueOf(isSetUserException()).compareTo(isSetUserException());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(userException, typedOther.userException);
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = Boolean.valueOf(isSetSystemException()).compareTo(isSetSystemException());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(systemException, typedOther.systemException);
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = Boolean.valueOf(isSetNotFoundException()).compareTo(isSetNotFoundException());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(notFoundException, typedOther.notFoundException);
      if (lastComparison != 0) {
        return lastComparison;
      }
      return 0;
    }

    public void read(TProtocol iprot) throws TException {
      TField field;
      iprot.readStructBegin();
      while (true)
      {
        field = iprot.readFieldBegin();
        if (field.type == TType.STOP) { 
          break;
        }
        _Fields fieldId = _Fields.findByThriftId(field.id);
        if (fieldId == null) {
          TProtocolUtil.skip(iprot, field.type);
        } else {
          switch (fieldId) {
            case SUCCESS:
              if (field.type == TType.STRUCT) {
                this.success = new com.evernote.edam.type.Resource();
                this.success.read(iprot);
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
            case USER_EXCEPTION:
              if (field.type == TType.STRUCT) {
                this.userException = new com.evernote.edam.error.EDAMUserException();
                this.userException.read(iprot);
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
            case SYSTEM_EXCEPTION:
              if (field.type == TType.STRUCT) {
                this.systemException = new com.evernote.edam.error.EDAMSystemException();
                this.systemException.read(iprot);
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
            case NOT_FOUND_EXCEPTION:
              if (field.type == TType.STRUCT) {
                this.notFoundException = new com.evernote.edam.error.EDAMNotFoundException();
                this.notFoundException.read(iprot);
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
          }
          iprot.readFieldEnd();
        }
      }
      iprot.readStructEnd();
      validate();
    }

    public void write(TProtocol oprot) throws TException {
      oprot.writeStructBegin(STRUCT_DESC);

      if (this.isSetSuccess()) {
        oprot.writeFieldBegin(SUCCESS_FIELD_DESC);
        this.success.write(oprot);
        oprot.writeFieldEnd();
      } else if (this.isSetUserException()) {
        oprot.writeFieldBegin(USER_EXCEPTION_FIELD_DESC);
        this.userException.write(oprot);
        oprot.writeFieldEnd();
      } else if (this.isSetSystemException()) {
        oprot.writeFieldBegin(SYSTEM_EXCEPTION_FIELD_DESC);
        this.systemException.write(oprot);
        oprot.writeFieldEnd();
      } else if (this.isSetNotFoundException()) {
        oprot.writeFieldBegin(NOT_FOUND_EXCEPTION_FIELD_DESC);
        this.notFoundException.write(oprot);
        oprot.writeFieldEnd();
      }
      oprot.writeFieldStop();
      oprot.writeStructEnd();
    }

    public String toString() {
      StringBuilder sb = new StringBuilder("getResourceByHash_result(");
      boolean first = true;

      sb.append("success:");
      if (this.success == null) {
        sb.append("null");
      } else {
        sb.append(this.success);
      }
      first = false;
      if (!first) sb.append(", ");
      sb.append("userException:");
      if (this.userException == null) {
        sb.append("null");
      } else {
        sb.append(this.userException);
      }
      first = false;
      if (!first) sb.append(", ");
      sb.append("systemException:");
      if (this.systemException == null) {
        sb.append("null");
      } else {
        sb.append(this.systemException);
      }
      first = false;
      if (!first) sb.append(", ");
      sb.append("notFoundException:");
      if (this.notFoundException == null) {
        sb.append("null");
      } else {
        sb.append(this.notFoundException);
      }
      first = false;
      sb.append(")");
      return sb.toString();
    }

    public void validate() throws TException {
      // check for required fields
    }

  }

  public static class getResourceRecognition_args implements TBase<getResourceRecognition_args._Fields>, java.io.Serializable, Cloneable, Comparable<getResourceRecognition_args>   {
    private static final TStruct STRUCT_DESC = new TStruct("getResourceRecognition_args");

    private static final TField AUTHENTICATION_TOKEN_FIELD_DESC = new TField("authenticationToken", TType.STRING, (short)1);
    private static final TField GUID_FIELD_DESC = new TField("guid", TType.STRING, (short)2);

    private String authenticationToken;
    private String guid;

    /** The set of fields this struct contains, along with convenience methods for finding and manipulating them. */
    public enum _Fields implements TFieldIdEnum {
      AUTHENTICATION_TOKEN((short)1, "authenticationToken"),
      GUID((short)2, "guid");

      private static final Map<Integer, _Fields> byId = new HashMap<Integer, _Fields>();
      private static final Map<String, _Fields> byName = new HashMap<String, _Fields>();

      static {
        for (_Fields field : EnumSet.allOf(_Fields.class)) {
          byId.put((int)field._thriftId, field);
          byName.put(field.getFieldName(), field);
        }
      }

      /**
       * Find the _Fields constant that matches fieldId, or null if its not found.
       */
      public static _Fields findByThriftId(int fieldId) {
        return byId.get(fieldId);
      }

      /**
       * Find the _Fields constant that matches fieldId, throwing an exception
       * if it is not found.
       */
      public static _Fields findByThriftIdOrThrow(int fieldId) {
        _Fields fields = findByThriftId(fieldId);
        if (fields == null) throw new IllegalArgumentException("Field " + fieldId + " doesn't exist!");
        return fields;
      }

      /**
       * Find the _Fields constant that matches name, or null if its not found.
       */
      public static _Fields findByName(String name) {
        return byName.get(name);
      }

      private final short _thriftId;
      private final String _fieldName;

      _Fields(short thriftId, String fieldName) {
        _thriftId = thriftId;
        _fieldName = fieldName;
      }

      public short getThriftFieldId() {
        return _thriftId;
      }

      public String getFieldName() {
        return _fieldName;
      }
    }

    // isset id assignments

    public static final Map<_Fields, FieldMetaData> metaDataMap = Collections.unmodifiableMap(new EnumMap<_Fields, FieldMetaData>(_Fields.class) {{
      put(_Fields.AUTHENTICATION_TOKEN, new FieldMetaData("authenticationToken", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.STRING)));
      put(_Fields.GUID, new FieldMetaData("guid", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.STRING)));
    }});

    static {
      FieldMetaData.addStructMetaDataMap(getResourceRecognition_args.class, metaDataMap);
    }

    public getResourceRecognition_args() {
    }

    public getResourceRecognition_args(
      String authenticationToken,
      String guid)
    {
      this();
      this.authenticationToken = authenticationToken;
      this.guid = guid;
    }

    /**
     * Performs a deep copy on <i>other</i>.
     */
    public getResourceRecognition_args(getResourceRecognition_args other) {
      if (other.isSetAuthenticationToken()) {
        this.authenticationToken = other.authenticationToken;
      }
      if (other.isSetGuid()) {
        this.guid = other.guid;
      }
    }

    public getResourceRecognition_args deepCopy() {
      return new getResourceRecognition_args(this);
    }

    @Deprecated
    public getResourceRecognition_args clone() {
      return new getResourceRecognition_args(this);
    }

    public String getAuthenticationToken() {
      return this.authenticationToken;
    }

    public void setAuthenticationToken(String authenticationToken) {
      this.authenticationToken = authenticationToken;
    }

    public void unsetAuthenticationToken() {
      this.authenticationToken = null;
    }

    /** Returns true if field authenticationToken is set (has been asigned a value) and false otherwise */
    public boolean isSetAuthenticationToken() {
      return this.authenticationToken != null;
    }

    public void setAuthenticationTokenIsSet(boolean value) {
      if (!value) {
        this.authenticationToken = null;
      }
    }

    public String getGuid() {
      return this.guid;
    }

    public void setGuid(String guid) {
      this.guid = guid;
    }

    public void unsetGuid() {
      this.guid = null;
    }

    /** Returns true if field guid is set (has been asigned a value) and false otherwise */
    public boolean isSetGuid() {
      return this.guid != null;
    }

    public void setGuidIsSet(boolean value) {
      if (!value) {
        this.guid = null;
      }
    }

    public void setFieldValue(_Fields field, Object value) {
      switch (field) {
      case AUTHENTICATION_TOKEN:
        if (value == null) {
          unsetAuthenticationToken();
        } else {
          setAuthenticationToken((String)value);
        }
        break;

      case GUID:
        if (value == null) {
          unsetGuid();
        } else {
          setGuid((String)value);
        }
        break;

      }
    }

    public void setFieldValue(int fieldID, Object value) {
      setFieldValue(_Fields.findByThriftIdOrThrow(fieldID), value);
    }

    public Object getFieldValue(_Fields field) {
      switch (field) {
      case AUTHENTICATION_TOKEN:
        return getAuthenticationToken();

      case GUID:
        return getGuid();

      }
      throw new IllegalStateException();
    }

    public Object getFieldValue(int fieldId) {
      return getFieldValue(_Fields.findByThriftIdOrThrow(fieldId));
    }

    /** Returns true if field corresponding to fieldID is set (has been asigned a value) and false otherwise */
    public boolean isSet(_Fields field) {
      switch (field) {
      case AUTHENTICATION_TOKEN:
        return isSetAuthenticationToken();
      case GUID:
        return isSetGuid();
      }
      throw new IllegalStateException();
    }

    public boolean isSet(int fieldID) {
      return isSet(_Fields.findByThriftIdOrThrow(fieldID));
    }

    public boolean equals(Object that) {
      if (that == null)
        return false;
      if (that instanceof getResourceRecognition_args)
        return this.equals((getResourceRecognition_args)that);
      return false;
    }

    public boolean equals(getResourceRecognition_args that) {
      if (that == null)
        return false;

      boolean this_present_authenticationToken = true && this.isSetAuthenticationToken();
      boolean that_present_authenticationToken = true && that.isSetAuthenticationToken();
      if (this_present_authenticationToken || that_present_authenticationToken) {
        if (!(this_present_authenticationToken && that_present_authenticationToken))
          return false;
        if (!this.authenticationToken.equals(that.authenticationToken))
          return false;
      }

      boolean this_present_guid = true && this.isSetGuid();
      boolean that_present_guid = true && that.isSetGuid();
      if (this_present_guid || that_present_guid) {
        if (!(this_present_guid && that_present_guid))
          return false;
        if (!this.guid.equals(that.guid))
          return false;
      }

      return true;
    }

    public int hashCode() {
      return 0;
    }

    public int compareTo(getResourceRecognition_args other) {
      if (!getClass().equals(other.getClass())) {
        return getClass().getName().compareTo(other.getClass().getName());
      }

      int lastComparison = 0;
      getResourceRecognition_args typedOther = (getResourceRecognition_args)other;

      lastComparison = Boolean.valueOf(isSetAuthenticationToken()).compareTo(isSetAuthenticationToken());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(authenticationToken, typedOther.authenticationToken);
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = Boolean.valueOf(isSetGuid()).compareTo(isSetGuid());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(guid, typedOther.guid);
      if (lastComparison != 0) {
        return lastComparison;
      }
      return 0;
    }

    public void read(TProtocol iprot) throws TException {
      TField field;
      iprot.readStructBegin();
      while (true)
      {
        field = iprot.readFieldBegin();
        if (field.type == TType.STOP) { 
          break;
        }
        _Fields fieldId = _Fields.findByThriftId(field.id);
        if (fieldId == null) {
          TProtocolUtil.skip(iprot, field.type);
        } else {
          switch (fieldId) {
            case AUTHENTICATION_TOKEN:
              if (field.type == TType.STRING) {
                this.authenticationToken = iprot.readString();
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
            case GUID:
              if (field.type == TType.STRING) {
                this.guid = iprot.readString();
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
          }
          iprot.readFieldEnd();
        }
      }
      iprot.readStructEnd();
      validate();
    }

    public void write(TProtocol oprot) throws TException {
      validate();

      oprot.writeStructBegin(STRUCT_DESC);
      if (this.authenticationToken != null) {
        oprot.writeFieldBegin(AUTHENTICATION_TOKEN_FIELD_DESC);
        oprot.writeString(this.authenticationToken);
        oprot.writeFieldEnd();
      }
      if (this.guid != null) {
        oprot.writeFieldBegin(GUID_FIELD_DESC);
        oprot.writeString(this.guid);
        oprot.writeFieldEnd();
      }
      oprot.writeFieldStop();
      oprot.writeStructEnd();
    }

    public String toString() {
      StringBuilder sb = new StringBuilder("getResourceRecognition_args(");
      boolean first = true;

      sb.append("authenticationToken:");
      if (this.authenticationToken == null) {
        sb.append("null");
      } else {
        sb.append(this.authenticationToken);
      }
      first = false;
      if (!first) sb.append(", ");
      sb.append("guid:");
      if (this.guid == null) {
        sb.append("null");
      } else {
        sb.append(this.guid);
      }
      first = false;
      sb.append(")");
      return sb.toString();
    }

    public void validate() throws TException {
      // check for required fields
    }

  }

  public static class getResourceRecognition_result implements TBase<getResourceRecognition_result._Fields>, java.io.Serializable, Cloneable, Comparable<getResourceRecognition_result>   {
    private static final TStruct STRUCT_DESC = new TStruct("getResourceRecognition_result");

    private static final TField SUCCESS_FIELD_DESC = new TField("success", TType.STRING, (short)0);
    private static final TField USER_EXCEPTION_FIELD_DESC = new TField("userException", TType.STRUCT, (short)1);
    private static final TField SYSTEM_EXCEPTION_FIELD_DESC = new TField("systemException", TType.STRUCT, (short)2);
    private static final TField NOT_FOUND_EXCEPTION_FIELD_DESC = new TField("notFoundException", TType.STRUCT, (short)3);

    private byte[] success;
    private com.evernote.edam.error.EDAMUserException userException;
    private com.evernote.edam.error.EDAMSystemException systemException;
    private com.evernote.edam.error.EDAMNotFoundException notFoundException;

    /** The set of fields this struct contains, along with convenience methods for finding and manipulating them. */
    public enum _Fields implements TFieldIdEnum {
      SUCCESS((short)0, "success"),
      USER_EXCEPTION((short)1, "userException"),
      SYSTEM_EXCEPTION((short)2, "systemException"),
      NOT_FOUND_EXCEPTION((short)3, "notFoundException");

      private static final Map<Integer, _Fields> byId = new HashMap<Integer, _Fields>();
      private static final Map<String, _Fields> byName = new HashMap<String, _Fields>();

      static {
        for (_Fields field : EnumSet.allOf(_Fields.class)) {
          byId.put((int)field._thriftId, field);
          byName.put(field.getFieldName(), field);
        }
      }

      /**
       * Find the _Fields constant that matches fieldId, or null if its not found.
       */
      public static _Fields findByThriftId(int fieldId) {
        return byId.get(fieldId);
      }

      /**
       * Find the _Fields constant that matches fieldId, throwing an exception
       * if it is not found.
       */
      public static _Fields findByThriftIdOrThrow(int fieldId) {
        _Fields fields = findByThriftId(fieldId);
        if (fields == null) throw new IllegalArgumentException("Field " + fieldId + " doesn't exist!");
        return fields;
      }

      /**
       * Find the _Fields constant that matches name, or null if its not found.
       */
      public static _Fields findByName(String name) {
        return byName.get(name);
      }

      private final short _thriftId;
      private final String _fieldName;

      _Fields(short thriftId, String fieldName) {
        _thriftId = thriftId;
        _fieldName = fieldName;
      }

      public short getThriftFieldId() {
        return _thriftId;
      }

      public String getFieldName() {
        return _fieldName;
      }
    }

    // isset id assignments

    public static final Map<_Fields, FieldMetaData> metaDataMap = Collections.unmodifiableMap(new EnumMap<_Fields, FieldMetaData>(_Fields.class) {{
      put(_Fields.SUCCESS, new FieldMetaData("success", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.STRING)));
      put(_Fields.USER_EXCEPTION, new FieldMetaData("userException", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.STRUCT)));
      put(_Fields.SYSTEM_EXCEPTION, new FieldMetaData("systemException", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.STRUCT)));
      put(_Fields.NOT_FOUND_EXCEPTION, new FieldMetaData("notFoundException", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.STRUCT)));
    }});

    static {
      FieldMetaData.addStructMetaDataMap(getResourceRecognition_result.class, metaDataMap);
    }

    public getResourceRecognition_result() {
    }

    public getResourceRecognition_result(
      byte[] success,
      com.evernote.edam.error.EDAMUserException userException,
      com.evernote.edam.error.EDAMSystemException systemException,
      com.evernote.edam.error.EDAMNotFoundException notFoundException)
    {
      this();
      this.success = success;
      this.userException = userException;
      this.systemException = systemException;
      this.notFoundException = notFoundException;
    }

    /**
     * Performs a deep copy on <i>other</i>.
     */
    public getResourceRecognition_result(getResourceRecognition_result other) {
      if (other.isSetSuccess()) {
        this.success = new byte[other.success.length];
        System.arraycopy(other.success, 0, success, 0, other.success.length);
      }
      if (other.isSetUserException()) {
        this.userException = new com.evernote.edam.error.EDAMUserException(other.userException);
      }
      if (other.isSetSystemException()) {
        this.systemException = new com.evernote.edam.error.EDAMSystemException(other.systemException);
      }
      if (other.isSetNotFoundException()) {
        this.notFoundException = new com.evernote.edam.error.EDAMNotFoundException(other.notFoundException);
      }
    }

    public getResourceRecognition_result deepCopy() {
      return new getResourceRecognition_result(this);
    }

    @Deprecated
    public getResourceRecognition_result clone() {
      return new getResourceRecognition_result(this);
    }

    public byte[] getSuccess() {
      return this.success;
    }

    public void setSuccess(byte[] success) {
      this.success = success;
    }

    public void unsetSuccess() {
      this.success = null;
    }

    /** Returns true if field success is set (has been asigned a value) and false otherwise */
    public boolean isSetSuccess() {
      return this.success != null;
    }

    public void setSuccessIsSet(boolean value) {
      if (!value) {
        this.success = null;
      }
    }

    public com.evernote.edam.error.EDAMUserException getUserException() {
      return this.userException;
    }

    public void setUserException(com.evernote.edam.error.EDAMUserException userException) {
      this.userException = userException;
    }

    public void unsetUserException() {
      this.userException = null;
    }

    /** Returns true if field userException is set (has been asigned a value) and false otherwise */
    public boolean isSetUserException() {
      return this.userException != null;
    }

    public void setUserExceptionIsSet(boolean value) {
      if (!value) {
        this.userException = null;
      }
    }

    public com.evernote.edam.error.EDAMSystemException getSystemException() {
      return this.systemException;
    }

    public void setSystemException(com.evernote.edam.error.EDAMSystemException systemException) {
      this.systemException = systemException;
    }

    public void unsetSystemException() {
      this.systemException = null;
    }

    /** Returns true if field systemException is set (has been asigned a value) and false otherwise */
    public boolean isSetSystemException() {
      return this.systemException != null;
    }

    public void setSystemExceptionIsSet(boolean value) {
      if (!value) {
        this.systemException = null;
      }
    }

    public com.evernote.edam.error.EDAMNotFoundException getNotFoundException() {
      return this.notFoundException;
    }

    public void setNotFoundException(com.evernote.edam.error.EDAMNotFoundException notFoundException) {
      this.notFoundException = notFoundException;
    }

    public void unsetNotFoundException() {
      this.notFoundException = null;
    }

    /** Returns true if field notFoundException is set (has been asigned a value) and false otherwise */
    public boolean isSetNotFoundException() {
      return this.notFoundException != null;
    }

    public void setNotFoundExceptionIsSet(boolean value) {
      if (!value) {
        this.notFoundException = null;
      }
    }

    public void setFieldValue(_Fields field, Object value) {
      switch (field) {
      case SUCCESS:
        if (value == null) {
          unsetSuccess();
        } else {
          setSuccess((byte[])value);
        }
        break;

      case USER_EXCEPTION:
        if (value == null) {
          unsetUserException();
        } else {
          setUserException((com.evernote.edam.error.EDAMUserException)value);
        }
        break;

      case SYSTEM_EXCEPTION:
        if (value == null) {
          unsetSystemException();
        } else {
          setSystemException((com.evernote.edam.error.EDAMSystemException)value);
        }
        break;

      case NOT_FOUND_EXCEPTION:
        if (value == null) {
          unsetNotFoundException();
        } else {
          setNotFoundException((com.evernote.edam.error.EDAMNotFoundException)value);
        }
        break;

      }
    }

    public void setFieldValue(int fieldID, Object value) {
      setFieldValue(_Fields.findByThriftIdOrThrow(fieldID), value);
    }

    public Object getFieldValue(_Fields field) {
      switch (field) {
      case SUCCESS:
        return getSuccess();

      case USER_EXCEPTION:
        return getUserException();

      case SYSTEM_EXCEPTION:
        return getSystemException();

      case NOT_FOUND_EXCEPTION:
        return getNotFoundException();

      }
      throw new IllegalStateException();
    }

    public Object getFieldValue(int fieldId) {
      return getFieldValue(_Fields.findByThriftIdOrThrow(fieldId));
    }

    /** Returns true if field corresponding to fieldID is set (has been asigned a value) and false otherwise */
    public boolean isSet(_Fields field) {
      switch (field) {
      case SUCCESS:
        return isSetSuccess();
      case USER_EXCEPTION:
        return isSetUserException();
      case SYSTEM_EXCEPTION:
        return isSetSystemException();
      case NOT_FOUND_EXCEPTION:
        return isSetNotFoundException();
      }
      throw new IllegalStateException();
    }

    public boolean isSet(int fieldID) {
      return isSet(_Fields.findByThriftIdOrThrow(fieldID));
    }

    public boolean equals(Object that) {
      if (that == null)
        return false;
      if (that instanceof getResourceRecognition_result)
        return this.equals((getResourceRecognition_result)that);
      return false;
    }

    public boolean equals(getResourceRecognition_result that) {
      if (that == null)
        return false;

      boolean this_present_success = true && this.isSetSuccess();
      boolean that_present_success = true && that.isSetSuccess();
      if (this_present_success || that_present_success) {
        if (!(this_present_success && that_present_success))
          return false;
        if (!java.util.Arrays.equals(this.success, that.success))
          return false;
      }

      boolean this_present_userException = true && this.isSetUserException();
      boolean that_present_userException = true && that.isSetUserException();
      if (this_present_userException || that_present_userException) {
        if (!(this_present_userException && that_present_userException))
          return false;
        if (!this.userException.equals(that.userException))
          return false;
      }

      boolean this_present_systemException = true && this.isSetSystemException();
      boolean that_present_systemException = true && that.isSetSystemException();
      if (this_present_systemException || that_present_systemException) {
        if (!(this_present_systemException && that_present_systemException))
          return false;
        if (!this.systemException.equals(that.systemException))
          return false;
      }

      boolean this_present_notFoundException = true && this.isSetNotFoundException();
      boolean that_present_notFoundException = true && that.isSetNotFoundException();
      if (this_present_notFoundException || that_present_notFoundException) {
        if (!(this_present_notFoundException && that_present_notFoundException))
          return false;
        if (!this.notFoundException.equals(that.notFoundException))
          return false;
      }

      return true;
    }

    public int hashCode() {
      return 0;
    }

    public int compareTo(getResourceRecognition_result other) {
      if (!getClass().equals(other.getClass())) {
        return getClass().getName().compareTo(other.getClass().getName());
      }

      int lastComparison = 0;
      getResourceRecognition_result typedOther = (getResourceRecognition_result)other;

      lastComparison = Boolean.valueOf(isSetSuccess()).compareTo(isSetSuccess());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(success, typedOther.success);
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = Boolean.valueOf(isSetUserException()).compareTo(isSetUserException());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(userException, typedOther.userException);
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = Boolean.valueOf(isSetSystemException()).compareTo(isSetSystemException());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(systemException, typedOther.systemException);
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = Boolean.valueOf(isSetNotFoundException()).compareTo(isSetNotFoundException());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(notFoundException, typedOther.notFoundException);
      if (lastComparison != 0) {
        return lastComparison;
      }
      return 0;
    }

    public void read(TProtocol iprot) throws TException {
      TField field;
      iprot.readStructBegin();
      while (true)
      {
        field = iprot.readFieldBegin();
        if (field.type == TType.STOP) { 
          break;
        }
        _Fields fieldId = _Fields.findByThriftId(field.id);
        if (fieldId == null) {
          TProtocolUtil.skip(iprot, field.type);
        } else {
          switch (fieldId) {
            case SUCCESS:
              if (field.type == TType.STRING) {
                this.success = iprot.readBinary();
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
            case USER_EXCEPTION:
              if (field.type == TType.STRUCT) {
                this.userException = new com.evernote.edam.error.EDAMUserException();
                this.userException.read(iprot);
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
            case SYSTEM_EXCEPTION:
              if (field.type == TType.STRUCT) {
                this.systemException = new com.evernote.edam.error.EDAMSystemException();
                this.systemException.read(iprot);
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
            case NOT_FOUND_EXCEPTION:
              if (field.type == TType.STRUCT) {
                this.notFoundException = new com.evernote.edam.error.EDAMNotFoundException();
                this.notFoundException.read(iprot);
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
          }
          iprot.readFieldEnd();
        }
      }
      iprot.readStructEnd();
      validate();
    }

    public void write(TProtocol oprot) throws TException {
      oprot.writeStructBegin(STRUCT_DESC);

      if (this.isSetSuccess()) {
        oprot.writeFieldBegin(SUCCESS_FIELD_DESC);
        oprot.writeBinary(this.success);
        oprot.writeFieldEnd();
      } else if (this.isSetUserException()) {
        oprot.writeFieldBegin(USER_EXCEPTION_FIELD_DESC);
        this.userException.write(oprot);
        oprot.writeFieldEnd();
      } else if (this.isSetSystemException()) {
        oprot.writeFieldBegin(SYSTEM_EXCEPTION_FIELD_DESC);
        this.systemException.write(oprot);
        oprot.writeFieldEnd();
      } else if (this.isSetNotFoundException()) {
        oprot.writeFieldBegin(NOT_FOUND_EXCEPTION_FIELD_DESC);
        this.notFoundException.write(oprot);
        oprot.writeFieldEnd();
      }
      oprot.writeFieldStop();
      oprot.writeStructEnd();
    }

    public String toString() {
      StringBuilder sb = new StringBuilder("getResourceRecognition_result(");
      boolean first = true;

      sb.append("success:");
      if (this.success == null) {
        sb.append("null");
      } else {
          int __success_size = Math.min(this.success.length, 128);
          for (int i = 0; i < __success_size; i++) {
            if (i != 0) sb.append(" ");
            sb.append(Integer.toHexString(this.success[i]).length() > 1 ? Integer.toHexString(this.success[i]).substring(Integer.toHexString(this.success[i]).length() - 2).toUpperCase() : "0" + Integer.toHexString(this.success[i]).toUpperCase());
          }
          if (this.success.length > 128) sb.append(" ...");
      }
      first = false;
      if (!first) sb.append(", ");
      sb.append("userException:");
      if (this.userException == null) {
        sb.append("null");
      } else {
        sb.append(this.userException);
      }
      first = false;
      if (!first) sb.append(", ");
      sb.append("systemException:");
      if (this.systemException == null) {
        sb.append("null");
      } else {
        sb.append(this.systemException);
      }
      first = false;
      if (!first) sb.append(", ");
      sb.append("notFoundException:");
      if (this.notFoundException == null) {
        sb.append("null");
      } else {
        sb.append(this.notFoundException);
      }
      first = false;
      sb.append(")");
      return sb.toString();
    }

    public void validate() throws TException {
      // check for required fields
    }

  }

  public static class getResourceAlternateData_args implements TBase<getResourceAlternateData_args._Fields>, java.io.Serializable, Cloneable, Comparable<getResourceAlternateData_args>   {
    private static final TStruct STRUCT_DESC = new TStruct("getResourceAlternateData_args");

    private static final TField AUTHENTICATION_TOKEN_FIELD_DESC = new TField("authenticationToken", TType.STRING, (short)1);
    private static final TField GUID_FIELD_DESC = new TField("guid", TType.STRING, (short)2);

    private String authenticationToken;
    private String guid;

    /** The set of fields this struct contains, along with convenience methods for finding and manipulating them. */
    public enum _Fields implements TFieldIdEnum {
      AUTHENTICATION_TOKEN((short)1, "authenticationToken"),
      GUID((short)2, "guid");

      private static final Map<Integer, _Fields> byId = new HashMap<Integer, _Fields>();
      private static final Map<String, _Fields> byName = new HashMap<String, _Fields>();

      static {
        for (_Fields field : EnumSet.allOf(_Fields.class)) {
          byId.put((int)field._thriftId, field);
          byName.put(field.getFieldName(), field);
        }
      }

      /**
       * Find the _Fields constant that matches fieldId, or null if its not found.
       */
      public static _Fields findByThriftId(int fieldId) {
        return byId.get(fieldId);
      }

      /**
       * Find the _Fields constant that matches fieldId, throwing an exception
       * if it is not found.
       */
      public static _Fields findByThriftIdOrThrow(int fieldId) {
        _Fields fields = findByThriftId(fieldId);
        if (fields == null) throw new IllegalArgumentException("Field " + fieldId + " doesn't exist!");
        return fields;
      }

      /**
       * Find the _Fields constant that matches name, or null if its not found.
       */
      public static _Fields findByName(String name) {
        return byName.get(name);
      }

      private final short _thriftId;
      private final String _fieldName;

      _Fields(short thriftId, String fieldName) {
        _thriftId = thriftId;
        _fieldName = fieldName;
      }

      public short getThriftFieldId() {
        return _thriftId;
      }

      public String getFieldName() {
        return _fieldName;
      }
    }

    // isset id assignments

    public static final Map<_Fields, FieldMetaData> metaDataMap = Collections.unmodifiableMap(new EnumMap<_Fields, FieldMetaData>(_Fields.class) {{
      put(_Fields.AUTHENTICATION_TOKEN, new FieldMetaData("authenticationToken", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.STRING)));
      put(_Fields.GUID, new FieldMetaData("guid", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.STRING)));
    }});

    static {
      FieldMetaData.addStructMetaDataMap(getResourceAlternateData_args.class, metaDataMap);
    }

    public getResourceAlternateData_args() {
    }

    public getResourceAlternateData_args(
      String authenticationToken,
      String guid)
    {
      this();
      this.authenticationToken = authenticationToken;
      this.guid = guid;
    }

    /**
     * Performs a deep copy on <i>other</i>.
     */
    public getResourceAlternateData_args(getResourceAlternateData_args other) {
      if (other.isSetAuthenticationToken()) {
        this.authenticationToken = other.authenticationToken;
      }
      if (other.isSetGuid()) {
        this.guid = other.guid;
      }
    }

    public getResourceAlternateData_args deepCopy() {
      return new getResourceAlternateData_args(this);
    }

    @Deprecated
    public getResourceAlternateData_args clone() {
      return new getResourceAlternateData_args(this);
    }

    public String getAuthenticationToken() {
      return this.authenticationToken;
    }

    public void setAuthenticationToken(String authenticationToken) {
      this.authenticationToken = authenticationToken;
    }

    public void unsetAuthenticationToken() {
      this.authenticationToken = null;
    }

    /** Returns true if field authenticationToken is set (has been asigned a value) and false otherwise */
    public boolean isSetAuthenticationToken() {
      return this.authenticationToken != null;
    }

    public void setAuthenticationTokenIsSet(boolean value) {
      if (!value) {
        this.authenticationToken = null;
      }
    }

    public String getGuid() {
      return this.guid;
    }

    public void setGuid(String guid) {
      this.guid = guid;
    }

    public void unsetGuid() {
      this.guid = null;
    }

    /** Returns true if field guid is set (has been asigned a value) and false otherwise */
    public boolean isSetGuid() {
      return this.guid != null;
    }

    public void setGuidIsSet(boolean value) {
      if (!value) {
        this.guid = null;
      }
    }

    public void setFieldValue(_Fields field, Object value) {
      switch (field) {
      case AUTHENTICATION_TOKEN:
        if (value == null) {
          unsetAuthenticationToken();
        } else {
          setAuthenticationToken((String)value);
        }
        break;

      case GUID:
        if (value == null) {
          unsetGuid();
        } else {
          setGuid((String)value);
        }
        break;

      }
    }

    public void setFieldValue(int fieldID, Object value) {
      setFieldValue(_Fields.findByThriftIdOrThrow(fieldID), value);
    }

    public Object getFieldValue(_Fields field) {
      switch (field) {
      case AUTHENTICATION_TOKEN:
        return getAuthenticationToken();

      case GUID:
        return getGuid();

      }
      throw new IllegalStateException();
    }

    public Object getFieldValue(int fieldId) {
      return getFieldValue(_Fields.findByThriftIdOrThrow(fieldId));
    }

    /** Returns true if field corresponding to fieldID is set (has been asigned a value) and false otherwise */
    public boolean isSet(_Fields field) {
      switch (field) {
      case AUTHENTICATION_TOKEN:
        return isSetAuthenticationToken();
      case GUID:
        return isSetGuid();
      }
      throw new IllegalStateException();
    }

    public boolean isSet(int fieldID) {
      return isSet(_Fields.findByThriftIdOrThrow(fieldID));
    }

    public boolean equals(Object that) {
      if (that == null)
        return false;
      if (that instanceof getResourceAlternateData_args)
        return this.equals((getResourceAlternateData_args)that);
      return false;
    }

    public boolean equals(getResourceAlternateData_args that) {
      if (that == null)
        return false;

      boolean this_present_authenticationToken = true && this.isSetAuthenticationToken();
      boolean that_present_authenticationToken = true && that.isSetAuthenticationToken();
      if (this_present_authenticationToken || that_present_authenticationToken) {
        if (!(this_present_authenticationToken && that_present_authenticationToken))
          return false;
        if (!this.authenticationToken.equals(that.authenticationToken))
          return false;
      }

      boolean this_present_guid = true && this.isSetGuid();
      boolean that_present_guid = true && that.isSetGuid();
      if (this_present_guid || that_present_guid) {
        if (!(this_present_guid && that_present_guid))
          return false;
        if (!this.guid.equals(that.guid))
          return false;
      }

      return true;
    }

    public int hashCode() {
      return 0;
    }

    public int compareTo(getResourceAlternateData_args other) {
      if (!getClass().equals(other.getClass())) {
        return getClass().getName().compareTo(other.getClass().getName());
      }

      int lastComparison = 0;
      getResourceAlternateData_args typedOther = (getResourceAlternateData_args)other;

      lastComparison = Boolean.valueOf(isSetAuthenticationToken()).compareTo(isSetAuthenticationToken());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(authenticationToken, typedOther.authenticationToken);
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = Boolean.valueOf(isSetGuid()).compareTo(isSetGuid());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(guid, typedOther.guid);
      if (lastComparison != 0) {
        return lastComparison;
      }
      return 0;
    }

    public void read(TProtocol iprot) throws TException {
      TField field;
      iprot.readStructBegin();
      while (true)
      {
        field = iprot.readFieldBegin();
        if (field.type == TType.STOP) { 
          break;
        }
        _Fields fieldId = _Fields.findByThriftId(field.id);
        if (fieldId == null) {
          TProtocolUtil.skip(iprot, field.type);
        } else {
          switch (fieldId) {
            case AUTHENTICATION_TOKEN:
              if (field.type == TType.STRING) {
                this.authenticationToken = iprot.readString();
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
            case GUID:
              if (field.type == TType.STRING) {
                this.guid = iprot.readString();
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
          }
          iprot.readFieldEnd();
        }
      }
      iprot.readStructEnd();
      validate();
    }

    public void write(TProtocol oprot) throws TException {
      validate();

      oprot.writeStructBegin(STRUCT_DESC);
      if (this.authenticationToken != null) {
        oprot.writeFieldBegin(AUTHENTICATION_TOKEN_FIELD_DESC);
        oprot.writeString(this.authenticationToken);
        oprot.writeFieldEnd();
      }
      if (this.guid != null) {
        oprot.writeFieldBegin(GUID_FIELD_DESC);
        oprot.writeString(this.guid);
        oprot.writeFieldEnd();
      }
      oprot.writeFieldStop();
      oprot.writeStructEnd();
    }

    public String toString() {
      StringBuilder sb = new StringBuilder("getResourceAlternateData_args(");
      boolean first = true;

      sb.append("authenticationToken:");
      if (this.authenticationToken == null) {
        sb.append("null");
      } else {
        sb.append(this.authenticationToken);
      }
      first = false;
      if (!first) sb.append(", ");
      sb.append("guid:");
      if (this.guid == null) {
        sb.append("null");
      } else {
        sb.append(this.guid);
      }
      first = false;
      sb.append(")");
      return sb.toString();
    }

    public void validate() throws TException {
      // check for required fields
    }

  }

  public static class getResourceAlternateData_result implements TBase<getResourceAlternateData_result._Fields>, java.io.Serializable, Cloneable, Comparable<getResourceAlternateData_result>   {
    private static final TStruct STRUCT_DESC = new TStruct("getResourceAlternateData_result");

    private static final TField SUCCESS_FIELD_DESC = new TField("success", TType.STRING, (short)0);
    private static final TField USER_EXCEPTION_FIELD_DESC = new TField("userException", TType.STRUCT, (short)1);
    private static final TField SYSTEM_EXCEPTION_FIELD_DESC = new TField("systemException", TType.STRUCT, (short)2);
    private static final TField NOT_FOUND_EXCEPTION_FIELD_DESC = new TField("notFoundException", TType.STRUCT, (short)3);

    private byte[] success;
    private com.evernote.edam.error.EDAMUserException userException;
    private com.evernote.edam.error.EDAMSystemException systemException;
    private com.evernote.edam.error.EDAMNotFoundException notFoundException;

    /** The set of fields this struct contains, along with convenience methods for finding and manipulating them. */
    public enum _Fields implements TFieldIdEnum {
      SUCCESS((short)0, "success"),
      USER_EXCEPTION((short)1, "userException"),
      SYSTEM_EXCEPTION((short)2, "systemException"),
      NOT_FOUND_EXCEPTION((short)3, "notFoundException");

      private static final Map<Integer, _Fields> byId = new HashMap<Integer, _Fields>();
      private static final Map<String, _Fields> byName = new HashMap<String, _Fields>();

      static {
        for (_Fields field : EnumSet.allOf(_Fields.class)) {
          byId.put((int)field._thriftId, field);
          byName.put(field.getFieldName(), field);
        }
      }

      /**
       * Find the _Fields constant that matches fieldId, or null if its not found.
       */
      public static _Fields findByThriftId(int fieldId) {
        return byId.get(fieldId);
      }

      /**
       * Find the _Fields constant that matches fieldId, throwing an exception
       * if it is not found.
       */
      public static _Fields findByThriftIdOrThrow(int fieldId) {
        _Fields fields = findByThriftId(fieldId);
        if (fields == null) throw new IllegalArgumentException("Field " + fieldId + " doesn't exist!");
        return fields;
      }

      /**
       * Find the _Fields constant that matches name, or null if its not found.
       */
      public static _Fields findByName(String name) {
        return byName.get(name);
      }

      private final short _thriftId;
      private final String _fieldName;

      _Fields(short thriftId, String fieldName) {
        _thriftId = thriftId;
        _fieldName = fieldName;
      }

      public short getThriftFieldId() {
        return _thriftId;
      }

      public String getFieldName() {
        return _fieldName;
      }
    }

    // isset id assignments

    public static final Map<_Fields, FieldMetaData> metaDataMap = Collections.unmodifiableMap(new EnumMap<_Fields, FieldMetaData>(_Fields.class) {{
      put(_Fields.SUCCESS, new FieldMetaData("success", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.STRING)));
      put(_Fields.USER_EXCEPTION, new FieldMetaData("userException", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.STRUCT)));
      put(_Fields.SYSTEM_EXCEPTION, new FieldMetaData("systemException", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.STRUCT)));
      put(_Fields.NOT_FOUND_EXCEPTION, new FieldMetaData("notFoundException", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.STRUCT)));
    }});

    static {
      FieldMetaData.addStructMetaDataMap(getResourceAlternateData_result.class, metaDataMap);
    }

    public getResourceAlternateData_result() {
    }

    public getResourceAlternateData_result(
      byte[] success,
      com.evernote.edam.error.EDAMUserException userException,
      com.evernote.edam.error.EDAMSystemException systemException,
      com.evernote.edam.error.EDAMNotFoundException notFoundException)
    {
      this();
      this.success = success;
      this.userException = userException;
      this.systemException = systemException;
      this.notFoundException = notFoundException;
    }

    /**
     * Performs a deep copy on <i>other</i>.
     */
    public getResourceAlternateData_result(getResourceAlternateData_result other) {
      if (other.isSetSuccess()) {
        this.success = new byte[other.success.length];
        System.arraycopy(other.success, 0, success, 0, other.success.length);
      }
      if (other.isSetUserException()) {
        this.userException = new com.evernote.edam.error.EDAMUserException(other.userException);
      }
      if (other.isSetSystemException()) {
        this.systemException = new com.evernote.edam.error.EDAMSystemException(other.systemException);
      }
      if (other.isSetNotFoundException()) {
        this.notFoundException = new com.evernote.edam.error.EDAMNotFoundException(other.notFoundException);
      }
    }

    public getResourceAlternateData_result deepCopy() {
      return new getResourceAlternateData_result(this);
    }

    @Deprecated
    public getResourceAlternateData_result clone() {
      return new getResourceAlternateData_result(this);
    }

    public byte[] getSuccess() {
      return this.success;
    }

    public void setSuccess(byte[] success) {
      this.success = success;
    }

    public void unsetSuccess() {
      this.success = null;
    }

    /** Returns true if field success is set (has been asigned a value) and false otherwise */
    public boolean isSetSuccess() {
      return this.success != null;
    }

    public void setSuccessIsSet(boolean value) {
      if (!value) {
        this.success = null;
      }
    }

    public com.evernote.edam.error.EDAMUserException getUserException() {
      return this.userException;
    }

    public void setUserException(com.evernote.edam.error.EDAMUserException userException) {
      this.userException = userException;
    }

    public void unsetUserException() {
      this.userException = null;
    }

    /** Returns true if field userException is set (has been asigned a value) and false otherwise */
    public boolean isSetUserException() {
      return this.userException != null;
    }

    public void setUserExceptionIsSet(boolean value) {
      if (!value) {
        this.userException = null;
      }
    }

    public com.evernote.edam.error.EDAMSystemException getSystemException() {
      return this.systemException;
    }

    public void setSystemException(com.evernote.edam.error.EDAMSystemException systemException) {
      this.systemException = systemException;
    }

    public void unsetSystemException() {
      this.systemException = null;
    }

    /** Returns true if field systemException is set (has been asigned a value) and false otherwise */
    public boolean isSetSystemException() {
      return this.systemException != null;
    }

    public void setSystemExceptionIsSet(boolean value) {
      if (!value) {
        this.systemException = null;
      }
    }

    public com.evernote.edam.error.EDAMNotFoundException getNotFoundException() {
      return this.notFoundException;
    }

    public void setNotFoundException(com.evernote.edam.error.EDAMNotFoundException notFoundException) {
      this.notFoundException = notFoundException;
    }

    public void unsetNotFoundException() {
      this.notFoundException = null;
    }

    /** Returns true if field notFoundException is set (has been asigned a value) and false otherwise */
    public boolean isSetNotFoundException() {
      return this.notFoundException != null;
    }

    public void setNotFoundExceptionIsSet(boolean value) {
      if (!value) {
        this.notFoundException = null;
      }
    }

    public void setFieldValue(_Fields field, Object value) {
      switch (field) {
      case SUCCESS:
        if (value == null) {
          unsetSuccess();
        } else {
          setSuccess((byte[])value);
        }
        break;

      case USER_EXCEPTION:
        if (value == null) {
          unsetUserException();
        } else {
          setUserException((com.evernote.edam.error.EDAMUserException)value);
        }
        break;

      case SYSTEM_EXCEPTION:
        if (value == null) {
          unsetSystemException();
        } else {
          setSystemException((com.evernote.edam.error.EDAMSystemException)value);
        }
        break;

      case NOT_FOUND_EXCEPTION:
        if (value == null) {
          unsetNotFoundException();
        } else {
          setNotFoundException((com.evernote.edam.error.EDAMNotFoundException)value);
        }
        break;

      }
    }

    public void setFieldValue(int fieldID, Object value) {
      setFieldValue(_Fields.findByThriftIdOrThrow(fieldID), value);
    }

    public Object getFieldValue(_Fields field) {
      switch (field) {
      case SUCCESS:
        return getSuccess();

      case USER_EXCEPTION:
        return getUserException();

      case SYSTEM_EXCEPTION:
        return getSystemException();

      case NOT_FOUND_EXCEPTION:
        return getNotFoundException();

      }
      throw new IllegalStateException();
    }

    public Object getFieldValue(int fieldId) {
      return getFieldValue(_Fields.findByThriftIdOrThrow(fieldId));
    }

    /** Returns true if field corresponding to fieldID is set (has been asigned a value) and false otherwise */
    public boolean isSet(_Fields field) {
      switch (field) {
      case SUCCESS:
        return isSetSuccess();
      case USER_EXCEPTION:
        return isSetUserException();
      case SYSTEM_EXCEPTION:
        return isSetSystemException();
      case NOT_FOUND_EXCEPTION:
        return isSetNotFoundException();
      }
      throw new IllegalStateException();
    }

    public boolean isSet(int fieldID) {
      return isSet(_Fields.findByThriftIdOrThrow(fieldID));
    }

    public boolean equals(Object that) {
      if (that == null)
        return false;
      if (that instanceof getResourceAlternateData_result)
        return this.equals((getResourceAlternateData_result)that);
      return false;
    }

    public boolean equals(getResourceAlternateData_result that) {
      if (that == null)
        return false;

      boolean this_present_success = true && this.isSetSuccess();
      boolean that_present_success = true && that.isSetSuccess();
      if (this_present_success || that_present_success) {
        if (!(this_present_success && that_present_success))
          return false;
        if (!java.util.Arrays.equals(this.success, that.success))
          return false;
      }

      boolean this_present_userException = true && this.isSetUserException();
      boolean that_present_userException = true && that.isSetUserException();
      if (this_present_userException || that_present_userException) {
        if (!(this_present_userException && that_present_userException))
          return false;
        if (!this.userException.equals(that.userException))
          return false;
      }

      boolean this_present_systemException = true && this.isSetSystemException();
      boolean that_present_systemException = true && that.isSetSystemException();
      if (this_present_systemException || that_present_systemException) {
        if (!(this_present_systemException && that_present_systemException))
          return false;
        if (!this.systemException.equals(that.systemException))
          return false;
      }

      boolean this_present_notFoundException = true && this.isSetNotFoundException();
      boolean that_present_notFoundException = true && that.isSetNotFoundException();
      if (this_present_notFoundException || that_present_notFoundException) {
        if (!(this_present_notFoundException && that_present_notFoundException))
          return false;
        if (!this.notFoundException.equals(that.notFoundException))
          return false;
      }

      return true;
    }

    public int hashCode() {
      return 0;
    }

    public int compareTo(getResourceAlternateData_result other) {
      if (!getClass().equals(other.getClass())) {
        return getClass().getName().compareTo(other.getClass().getName());
      }

      int lastComparison = 0;
      getResourceAlternateData_result typedOther = (getResourceAlternateData_result)other;

      lastComparison = Boolean.valueOf(isSetSuccess()).compareTo(isSetSuccess());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(success, typedOther.success);
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = Boolean.valueOf(isSetUserException()).compareTo(isSetUserException());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(userException, typedOther.userException);
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = Boolean.valueOf(isSetSystemException()).compareTo(isSetSystemException());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(systemException, typedOther.systemException);
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = Boolean.valueOf(isSetNotFoundException()).compareTo(isSetNotFoundException());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(notFoundException, typedOther.notFoundException);
      if (lastComparison != 0) {
        return lastComparison;
      }
      return 0;
    }

    public void read(TProtocol iprot) throws TException {
      TField field;
      iprot.readStructBegin();
      while (true)
      {
        field = iprot.readFieldBegin();
        if (field.type == TType.STOP) { 
          break;
        }
        _Fields fieldId = _Fields.findByThriftId(field.id);
        if (fieldId == null) {
          TProtocolUtil.skip(iprot, field.type);
        } else {
          switch (fieldId) {
            case SUCCESS:
              if (field.type == TType.STRING) {
                this.success = iprot.readBinary();
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
            case USER_EXCEPTION:
              if (field.type == TType.STRUCT) {
                this.userException = new com.evernote.edam.error.EDAMUserException();
                this.userException.read(iprot);
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
            case SYSTEM_EXCEPTION:
              if (field.type == TType.STRUCT) {
                this.systemException = new com.evernote.edam.error.EDAMSystemException();
                this.systemException.read(iprot);
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
            case NOT_FOUND_EXCEPTION:
              if (field.type == TType.STRUCT) {
                this.notFoundException = new com.evernote.edam.error.EDAMNotFoundException();
                this.notFoundException.read(iprot);
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
          }
          iprot.readFieldEnd();
        }
      }
      iprot.readStructEnd();
      validate();
    }

    public void write(TProtocol oprot) throws TException {
      oprot.writeStructBegin(STRUCT_DESC);

      if (this.isSetSuccess()) {
        oprot.writeFieldBegin(SUCCESS_FIELD_DESC);
        oprot.writeBinary(this.success);
        oprot.writeFieldEnd();
      } else if (this.isSetUserException()) {
        oprot.writeFieldBegin(USER_EXCEPTION_FIELD_DESC);
        this.userException.write(oprot);
        oprot.writeFieldEnd();
      } else if (this.isSetSystemException()) {
        oprot.writeFieldBegin(SYSTEM_EXCEPTION_FIELD_DESC);
        this.systemException.write(oprot);
        oprot.writeFieldEnd();
      } else if (this.isSetNotFoundException()) {
        oprot.writeFieldBegin(NOT_FOUND_EXCEPTION_FIELD_DESC);
        this.notFoundException.write(oprot);
        oprot.writeFieldEnd();
      }
      oprot.writeFieldStop();
      oprot.writeStructEnd();
    }

    public String toString() {
      StringBuilder sb = new StringBuilder("getResourceAlternateData_result(");
      boolean first = true;

      sb.append("success:");
      if (this.success == null) {
        sb.append("null");
      } else {
          int __success_size = Math.min(this.success.length, 128);
          for (int i = 0; i < __success_size; i++) {
            if (i != 0) sb.append(" ");
            sb.append(Integer.toHexString(this.success[i]).length() > 1 ? Integer.toHexString(this.success[i]).substring(Integer.toHexString(this.success[i]).length() - 2).toUpperCase() : "0" + Integer.toHexString(this.success[i]).toUpperCase());
          }
          if (this.success.length > 128) sb.append(" ...");
      }
      first = false;
      if (!first) sb.append(", ");
      sb.append("userException:");
      if (this.userException == null) {
        sb.append("null");
      } else {
        sb.append(this.userException);
      }
      first = false;
      if (!first) sb.append(", ");
      sb.append("systemException:");
      if (this.systemException == null) {
        sb.append("null");
      } else {
        sb.append(this.systemException);
      }
      first = false;
      if (!first) sb.append(", ");
      sb.append("notFoundException:");
      if (this.notFoundException == null) {
        sb.append("null");
      } else {
        sb.append(this.notFoundException);
      }
      first = false;
      sb.append(")");
      return sb.toString();
    }

    public void validate() throws TException {
      // check for required fields
    }

  }

  public static class getResourceAttributes_args implements TBase<getResourceAttributes_args._Fields>, java.io.Serializable, Cloneable, Comparable<getResourceAttributes_args>   {
    private static final TStruct STRUCT_DESC = new TStruct("getResourceAttributes_args");

    private static final TField AUTHENTICATION_TOKEN_FIELD_DESC = new TField("authenticationToken", TType.STRING, (short)1);
    private static final TField GUID_FIELD_DESC = new TField("guid", TType.STRING, (short)2);

    private String authenticationToken;
    private String guid;

    /** The set of fields this struct contains, along with convenience methods for finding and manipulating them. */
    public enum _Fields implements TFieldIdEnum {
      AUTHENTICATION_TOKEN((short)1, "authenticationToken"),
      GUID((short)2, "guid");

      private static final Map<Integer, _Fields> byId = new HashMap<Integer, _Fields>();
      private static final Map<String, _Fields> byName = new HashMap<String, _Fields>();

      static {
        for (_Fields field : EnumSet.allOf(_Fields.class)) {
          byId.put((int)field._thriftId, field);
          byName.put(field.getFieldName(), field);
        }
      }

      /**
       * Find the _Fields constant that matches fieldId, or null if its not found.
       */
      public static _Fields findByThriftId(int fieldId) {
        return byId.get(fieldId);
      }

      /**
       * Find the _Fields constant that matches fieldId, throwing an exception
       * if it is not found.
       */
      public static _Fields findByThriftIdOrThrow(int fieldId) {
        _Fields fields = findByThriftId(fieldId);
        if (fields == null) throw new IllegalArgumentException("Field " + fieldId + " doesn't exist!");
        return fields;
      }

      /**
       * Find the _Fields constant that matches name, or null if its not found.
       */
      public static _Fields findByName(String name) {
        return byName.get(name);
      }

      private final short _thriftId;
      private final String _fieldName;

      _Fields(short thriftId, String fieldName) {
        _thriftId = thriftId;
        _fieldName = fieldName;
      }

      public short getThriftFieldId() {
        return _thriftId;
      }

      public String getFieldName() {
        return _fieldName;
      }
    }

    // isset id assignments

    public static final Map<_Fields, FieldMetaData> metaDataMap = Collections.unmodifiableMap(new EnumMap<_Fields, FieldMetaData>(_Fields.class) {{
      put(_Fields.AUTHENTICATION_TOKEN, new FieldMetaData("authenticationToken", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.STRING)));
      put(_Fields.GUID, new FieldMetaData("guid", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.STRING)));
    }});

    static {
      FieldMetaData.addStructMetaDataMap(getResourceAttributes_args.class, metaDataMap);
    }

    public getResourceAttributes_args() {
    }

    public getResourceAttributes_args(
      String authenticationToken,
      String guid)
    {
      this();
      this.authenticationToken = authenticationToken;
      this.guid = guid;
    }

    /**
     * Performs a deep copy on <i>other</i>.
     */
    public getResourceAttributes_args(getResourceAttributes_args other) {
      if (other.isSetAuthenticationToken()) {
        this.authenticationToken = other.authenticationToken;
      }
      if (other.isSetGuid()) {
        this.guid = other.guid;
      }
    }

    public getResourceAttributes_args deepCopy() {
      return new getResourceAttributes_args(this);
    }

    @Deprecated
    public getResourceAttributes_args clone() {
      return new getResourceAttributes_args(this);
    }

    public String getAuthenticationToken() {
      return this.authenticationToken;
    }

    public void setAuthenticationToken(String authenticationToken) {
      this.authenticationToken = authenticationToken;
    }

    public void unsetAuthenticationToken() {
      this.authenticationToken = null;
    }

    /** Returns true if field authenticationToken is set (has been asigned a value) and false otherwise */
    public boolean isSetAuthenticationToken() {
      return this.authenticationToken != null;
    }

    public void setAuthenticationTokenIsSet(boolean value) {
      if (!value) {
        this.authenticationToken = null;
      }
    }

    public String getGuid() {
      return this.guid;
    }

    public void setGuid(String guid) {
      this.guid = guid;
    }

    public void unsetGuid() {
      this.guid = null;
    }

    /** Returns true if field guid is set (has been asigned a value) and false otherwise */
    public boolean isSetGuid() {
      return this.guid != null;
    }

    public void setGuidIsSet(boolean value) {
      if (!value) {
        this.guid = null;
      }
    }

    public void setFieldValue(_Fields field, Object value) {
      switch (field) {
      case AUTHENTICATION_TOKEN:
        if (value == null) {
          unsetAuthenticationToken();
        } else {
          setAuthenticationToken((String)value);
        }
        break;

      case GUID:
        if (value == null) {
          unsetGuid();
        } else {
          setGuid((String)value);
        }
        break;

      }
    }

    public void setFieldValue(int fieldID, Object value) {
      setFieldValue(_Fields.findByThriftIdOrThrow(fieldID), value);
    }

    public Object getFieldValue(_Fields field) {
      switch (field) {
      case AUTHENTICATION_TOKEN:
        return getAuthenticationToken();

      case GUID:
        return getGuid();

      }
      throw new IllegalStateException();
    }

    public Object getFieldValue(int fieldId) {
      return getFieldValue(_Fields.findByThriftIdOrThrow(fieldId));
    }

    /** Returns true if field corresponding to fieldID is set (has been asigned a value) and false otherwise */
    public boolean isSet(_Fields field) {
      switch (field) {
      case AUTHENTICATION_TOKEN:
        return isSetAuthenticationToken();
      case GUID:
        return isSetGuid();
      }
      throw new IllegalStateException();
    }

    public boolean isSet(int fieldID) {
      return isSet(_Fields.findByThriftIdOrThrow(fieldID));
    }

    public boolean equals(Object that) {
      if (that == null)
        return false;
      if (that instanceof getResourceAttributes_args)
        return this.equals((getResourceAttributes_args)that);
      return false;
    }

    public boolean equals(getResourceAttributes_args that) {
      if (that == null)
        return false;

      boolean this_present_authenticationToken = true && this.isSetAuthenticationToken();
      boolean that_present_authenticationToken = true && that.isSetAuthenticationToken();
      if (this_present_authenticationToken || that_present_authenticationToken) {
        if (!(this_present_authenticationToken && that_present_authenticationToken))
          return false;
        if (!this.authenticationToken.equals(that.authenticationToken))
          return false;
      }

      boolean this_present_guid = true && this.isSetGuid();
      boolean that_present_guid = true && that.isSetGuid();
      if (this_present_guid || that_present_guid) {
        if (!(this_present_guid && that_present_guid))
          return false;
        if (!this.guid.equals(that.guid))
          return false;
      }

      return true;
    }

    public int hashCode() {
      return 0;
    }

    public int compareTo(getResourceAttributes_args other) {
      if (!getClass().equals(other.getClass())) {
        return getClass().getName().compareTo(other.getClass().getName());
      }

      int lastComparison = 0;
      getResourceAttributes_args typedOther = (getResourceAttributes_args)other;

      lastComparison = Boolean.valueOf(isSetAuthenticationToken()).compareTo(isSetAuthenticationToken());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(authenticationToken, typedOther.authenticationToken);
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = Boolean.valueOf(isSetGuid()).compareTo(isSetGuid());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(guid, typedOther.guid);
      if (lastComparison != 0) {
        return lastComparison;
      }
      return 0;
    }

    public void read(TProtocol iprot) throws TException {
      TField field;
      iprot.readStructBegin();
      while (true)
      {
        field = iprot.readFieldBegin();
        if (field.type == TType.STOP) { 
          break;
        }
        _Fields fieldId = _Fields.findByThriftId(field.id);
        if (fieldId == null) {
          TProtocolUtil.skip(iprot, field.type);
        } else {
          switch (fieldId) {
            case AUTHENTICATION_TOKEN:
              if (field.type == TType.STRING) {
                this.authenticationToken = iprot.readString();
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
            case GUID:
              if (field.type == TType.STRING) {
                this.guid = iprot.readString();
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
          }
          iprot.readFieldEnd();
        }
      }
      iprot.readStructEnd();
      validate();
    }

    public void write(TProtocol oprot) throws TException {
      validate();

      oprot.writeStructBegin(STRUCT_DESC);
      if (this.authenticationToken != null) {
        oprot.writeFieldBegin(AUTHENTICATION_TOKEN_FIELD_DESC);
        oprot.writeString(this.authenticationToken);
        oprot.writeFieldEnd();
      }
      if (this.guid != null) {
        oprot.writeFieldBegin(GUID_FIELD_DESC);
        oprot.writeString(this.guid);
        oprot.writeFieldEnd();
      }
      oprot.writeFieldStop();
      oprot.writeStructEnd();
    }

    public String toString() {
      StringBuilder sb = new StringBuilder("getResourceAttributes_args(");
      boolean first = true;

      sb.append("authenticationToken:");
      if (this.authenticationToken == null) {
        sb.append("null");
      } else {
        sb.append(this.authenticationToken);
      }
      first = false;
      if (!first) sb.append(", ");
      sb.append("guid:");
      if (this.guid == null) {
        sb.append("null");
      } else {
        sb.append(this.guid);
      }
      first = false;
      sb.append(")");
      return sb.toString();
    }

    public void validate() throws TException {
      // check for required fields
    }

  }

  public static class getResourceAttributes_result implements TBase<getResourceAttributes_result._Fields>, java.io.Serializable, Cloneable, Comparable<getResourceAttributes_result>   {
    private static final TStruct STRUCT_DESC = new TStruct("getResourceAttributes_result");

    private static final TField SUCCESS_FIELD_DESC = new TField("success", TType.STRUCT, (short)0);
    private static final TField USER_EXCEPTION_FIELD_DESC = new TField("userException", TType.STRUCT, (short)1);
    private static final TField SYSTEM_EXCEPTION_FIELD_DESC = new TField("systemException", TType.STRUCT, (short)2);
    private static final TField NOT_FOUND_EXCEPTION_FIELD_DESC = new TField("notFoundException", TType.STRUCT, (short)3);

    private com.evernote.edam.type.ResourceAttributes success;
    private com.evernote.edam.error.EDAMUserException userException;
    private com.evernote.edam.error.EDAMSystemException systemException;
    private com.evernote.edam.error.EDAMNotFoundException notFoundException;

    /** The set of fields this struct contains, along with convenience methods for finding and manipulating them. */
    public enum _Fields implements TFieldIdEnum {
      SUCCESS((short)0, "success"),
      USER_EXCEPTION((short)1, "userException"),
      SYSTEM_EXCEPTION((short)2, "systemException"),
      NOT_FOUND_EXCEPTION((short)3, "notFoundException");

      private static final Map<Integer, _Fields> byId = new HashMap<Integer, _Fields>();
      private static final Map<String, _Fields> byName = new HashMap<String, _Fields>();

      static {
        for (_Fields field : EnumSet.allOf(_Fields.class)) {
          byId.put((int)field._thriftId, field);
          byName.put(field.getFieldName(), field);
        }
      }

      /**
       * Find the _Fields constant that matches fieldId, or null if its not found.
       */
      public static _Fields findByThriftId(int fieldId) {
        return byId.get(fieldId);
      }

      /**
       * Find the _Fields constant that matches fieldId, throwing an exception
       * if it is not found.
       */
      public static _Fields findByThriftIdOrThrow(int fieldId) {
        _Fields fields = findByThriftId(fieldId);
        if (fields == null) throw new IllegalArgumentException("Field " + fieldId + " doesn't exist!");
        return fields;
      }

      /**
       * Find the _Fields constant that matches name, or null if its not found.
       */
      public static _Fields findByName(String name) {
        return byName.get(name);
      }

      private final short _thriftId;
      private final String _fieldName;

      _Fields(short thriftId, String fieldName) {
        _thriftId = thriftId;
        _fieldName = fieldName;
      }

      public short getThriftFieldId() {
        return _thriftId;
      }

      public String getFieldName() {
        return _fieldName;
      }
    }

    // isset id assignments

    public static final Map<_Fields, FieldMetaData> metaDataMap = Collections.unmodifiableMap(new EnumMap<_Fields, FieldMetaData>(_Fields.class) {{
      put(_Fields.SUCCESS, new FieldMetaData("success", TFieldRequirementType.DEFAULT, 
          new StructMetaData(TType.STRUCT, com.evernote.edam.type.ResourceAttributes.class)));
      put(_Fields.USER_EXCEPTION, new FieldMetaData("userException", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.STRUCT)));
      put(_Fields.SYSTEM_EXCEPTION, new FieldMetaData("systemException", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.STRUCT)));
      put(_Fields.NOT_FOUND_EXCEPTION, new FieldMetaData("notFoundException", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.STRUCT)));
    }});

    static {
      FieldMetaData.addStructMetaDataMap(getResourceAttributes_result.class, metaDataMap);
    }

    public getResourceAttributes_result() {
    }

    public getResourceAttributes_result(
      com.evernote.edam.type.ResourceAttributes success,
      com.evernote.edam.error.EDAMUserException userException,
      com.evernote.edam.error.EDAMSystemException systemException,
      com.evernote.edam.error.EDAMNotFoundException notFoundException)
    {
      this();
      this.success = success;
      this.userException = userException;
      this.systemException = systemException;
      this.notFoundException = notFoundException;
    }

    /**
     * Performs a deep copy on <i>other</i>.
     */
    public getResourceAttributes_result(getResourceAttributes_result other) {
      if (other.isSetSuccess()) {
        this.success = new com.evernote.edam.type.ResourceAttributes(other.success);
      }
      if (other.isSetUserException()) {
        this.userException = new com.evernote.edam.error.EDAMUserException(other.userException);
      }
      if (other.isSetSystemException()) {
        this.systemException = new com.evernote.edam.error.EDAMSystemException(other.systemException);
      }
      if (other.isSetNotFoundException()) {
        this.notFoundException = new com.evernote.edam.error.EDAMNotFoundException(other.notFoundException);
      }
    }

    public getResourceAttributes_result deepCopy() {
      return new getResourceAttributes_result(this);
    }

    @Deprecated
    public getResourceAttributes_result clone() {
      return new getResourceAttributes_result(this);
    }

    public com.evernote.edam.type.ResourceAttributes getSuccess() {
      return this.success;
    }

    public void setSuccess(com.evernote.edam.type.ResourceAttributes success) {
      this.success = success;
    }

    public void unsetSuccess() {
      this.success = null;
    }

    /** Returns true if field success is set (has been asigned a value) and false otherwise */
    public boolean isSetSuccess() {
      return this.success != null;
    }

    public void setSuccessIsSet(boolean value) {
      if (!value) {
        this.success = null;
      }
    }

    public com.evernote.edam.error.EDAMUserException getUserException() {
      return this.userException;
    }

    public void setUserException(com.evernote.edam.error.EDAMUserException userException) {
      this.userException = userException;
    }

    public void unsetUserException() {
      this.userException = null;
    }

    /** Returns true if field userException is set (has been asigned a value) and false otherwise */
    public boolean isSetUserException() {
      return this.userException != null;
    }

    public void setUserExceptionIsSet(boolean value) {
      if (!value) {
        this.userException = null;
      }
    }

    public com.evernote.edam.error.EDAMSystemException getSystemException() {
      return this.systemException;
    }

    public void setSystemException(com.evernote.edam.error.EDAMSystemException systemException) {
      this.systemException = systemException;
    }

    public void unsetSystemException() {
      this.systemException = null;
    }

    /** Returns true if field systemException is set (has been asigned a value) and false otherwise */
    public boolean isSetSystemException() {
      return this.systemException != null;
    }

    public void setSystemExceptionIsSet(boolean value) {
      if (!value) {
        this.systemException = null;
      }
    }

    public com.evernote.edam.error.EDAMNotFoundException getNotFoundException() {
      return this.notFoundException;
    }

    public void setNotFoundException(com.evernote.edam.error.EDAMNotFoundException notFoundException) {
      this.notFoundException = notFoundException;
    }

    public void unsetNotFoundException() {
      this.notFoundException = null;
    }

    /** Returns true if field notFoundException is set (has been asigned a value) and false otherwise */
    public boolean isSetNotFoundException() {
      return this.notFoundException != null;
    }

    public void setNotFoundExceptionIsSet(boolean value) {
      if (!value) {
        this.notFoundException = null;
      }
    }

    public void setFieldValue(_Fields field, Object value) {
      switch (field) {
      case SUCCESS:
        if (value == null) {
          unsetSuccess();
        } else {
          setSuccess((com.evernote.edam.type.ResourceAttributes)value);
        }
        break;

      case USER_EXCEPTION:
        if (value == null) {
          unsetUserException();
        } else {
          setUserException((com.evernote.edam.error.EDAMUserException)value);
        }
        break;

      case SYSTEM_EXCEPTION:
        if (value == null) {
          unsetSystemException();
        } else {
          setSystemException((com.evernote.edam.error.EDAMSystemException)value);
        }
        break;

      case NOT_FOUND_EXCEPTION:
        if (value == null) {
          unsetNotFoundException();
        } else {
          setNotFoundException((com.evernote.edam.error.EDAMNotFoundException)value);
        }
        break;

      }
    }

    public void setFieldValue(int fieldID, Object value) {
      setFieldValue(_Fields.findByThriftIdOrThrow(fieldID), value);
    }

    public Object getFieldValue(_Fields field) {
      switch (field) {
      case SUCCESS:
        return getSuccess();

      case USER_EXCEPTION:
        return getUserException();

      case SYSTEM_EXCEPTION:
        return getSystemException();

      case NOT_FOUND_EXCEPTION:
        return getNotFoundException();

      }
      throw new IllegalStateException();
    }

    public Object getFieldValue(int fieldId) {
      return getFieldValue(_Fields.findByThriftIdOrThrow(fieldId));
    }

    /** Returns true if field corresponding to fieldID is set (has been asigned a value) and false otherwise */
    public boolean isSet(_Fields field) {
      switch (field) {
      case SUCCESS:
        return isSetSuccess();
      case USER_EXCEPTION:
        return isSetUserException();
      case SYSTEM_EXCEPTION:
        return isSetSystemException();
      case NOT_FOUND_EXCEPTION:
        return isSetNotFoundException();
      }
      throw new IllegalStateException();
    }

    public boolean isSet(int fieldID) {
      return isSet(_Fields.findByThriftIdOrThrow(fieldID));
    }

    public boolean equals(Object that) {
      if (that == null)
        return false;
      if (that instanceof getResourceAttributes_result)
        return this.equals((getResourceAttributes_result)that);
      return false;
    }

    public boolean equals(getResourceAttributes_result that) {
      if (that == null)
        return false;

      boolean this_present_success = true && this.isSetSuccess();
      boolean that_present_success = true && that.isSetSuccess();
      if (this_present_success || that_present_success) {
        if (!(this_present_success && that_present_success))
          return false;
        if (!this.success.equals(that.success))
          return false;
      }

      boolean this_present_userException = true && this.isSetUserException();
      boolean that_present_userException = true && that.isSetUserException();
      if (this_present_userException || that_present_userException) {
        if (!(this_present_userException && that_present_userException))
          return false;
        if (!this.userException.equals(that.userException))
          return false;
      }

      boolean this_present_systemException = true && this.isSetSystemException();
      boolean that_present_systemException = true && that.isSetSystemException();
      if (this_present_systemException || that_present_systemException) {
        if (!(this_present_systemException && that_present_systemException))
          return false;
        if (!this.systemException.equals(that.systemException))
          return false;
      }

      boolean this_present_notFoundException = true && this.isSetNotFoundException();
      boolean that_present_notFoundException = true && that.isSetNotFoundException();
      if (this_present_notFoundException || that_present_notFoundException) {
        if (!(this_present_notFoundException && that_present_notFoundException))
          return false;
        if (!this.notFoundException.equals(that.notFoundException))
          return false;
      }

      return true;
    }

    public int hashCode() {
      return 0;
    }

    public int compareTo(getResourceAttributes_result other) {
      if (!getClass().equals(other.getClass())) {
        return getClass().getName().compareTo(other.getClass().getName());
      }

      int lastComparison = 0;
      getResourceAttributes_result typedOther = (getResourceAttributes_result)other;

      lastComparison = Boolean.valueOf(isSetSuccess()).compareTo(isSetSuccess());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(success, typedOther.success);
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = Boolean.valueOf(isSetUserException()).compareTo(isSetUserException());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(userException, typedOther.userException);
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = Boolean.valueOf(isSetSystemException()).compareTo(isSetSystemException());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(systemException, typedOther.systemException);
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = Boolean.valueOf(isSetNotFoundException()).compareTo(isSetNotFoundException());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(notFoundException, typedOther.notFoundException);
      if (lastComparison != 0) {
        return lastComparison;
      }
      return 0;
    }

    public void read(TProtocol iprot) throws TException {
      TField field;
      iprot.readStructBegin();
      while (true)
      {
        field = iprot.readFieldBegin();
        if (field.type == TType.STOP) { 
          break;
        }
        _Fields fieldId = _Fields.findByThriftId(field.id);
        if (fieldId == null) {
          TProtocolUtil.skip(iprot, field.type);
        } else {
          switch (fieldId) {
            case SUCCESS:
              if (field.type == TType.STRUCT) {
                this.success = new com.evernote.edam.type.ResourceAttributes();
                this.success.read(iprot);
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
            case USER_EXCEPTION:
              if (field.type == TType.STRUCT) {
                this.userException = new com.evernote.edam.error.EDAMUserException();
                this.userException.read(iprot);
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
            case SYSTEM_EXCEPTION:
              if (field.type == TType.STRUCT) {
                this.systemException = new com.evernote.edam.error.EDAMSystemException();
                this.systemException.read(iprot);
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
            case NOT_FOUND_EXCEPTION:
              if (field.type == TType.STRUCT) {
                this.notFoundException = new com.evernote.edam.error.EDAMNotFoundException();
                this.notFoundException.read(iprot);
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
          }
          iprot.readFieldEnd();
        }
      }
      iprot.readStructEnd();
      validate();
    }

    public void write(TProtocol oprot) throws TException {
      oprot.writeStructBegin(STRUCT_DESC);

      if (this.isSetSuccess()) {
        oprot.writeFieldBegin(SUCCESS_FIELD_DESC);
        this.success.write(oprot);
        oprot.writeFieldEnd();
      } else if (this.isSetUserException()) {
        oprot.writeFieldBegin(USER_EXCEPTION_FIELD_DESC);
        this.userException.write(oprot);
        oprot.writeFieldEnd();
      } else if (this.isSetSystemException()) {
        oprot.writeFieldBegin(SYSTEM_EXCEPTION_FIELD_DESC);
        this.systemException.write(oprot);
        oprot.writeFieldEnd();
      } else if (this.isSetNotFoundException()) {
        oprot.writeFieldBegin(NOT_FOUND_EXCEPTION_FIELD_DESC);
        this.notFoundException.write(oprot);
        oprot.writeFieldEnd();
      }
      oprot.writeFieldStop();
      oprot.writeStructEnd();
    }

    public String toString() {
      StringBuilder sb = new StringBuilder("getResourceAttributes_result(");
      boolean first = true;

      sb.append("success:");
      if (this.success == null) {
        sb.append("null");
      } else {
        sb.append(this.success);
      }
      first = false;
      if (!first) sb.append(", ");
      sb.append("userException:");
      if (this.userException == null) {
        sb.append("null");
      } else {
        sb.append(this.userException);
      }
      first = false;
      if (!first) sb.append(", ");
      sb.append("systemException:");
      if (this.systemException == null) {
        sb.append("null");
      } else {
        sb.append(this.systemException);
      }
      first = false;
      if (!first) sb.append(", ");
      sb.append("notFoundException:");
      if (this.notFoundException == null) {
        sb.append("null");
      } else {
        sb.append(this.notFoundException);
      }
      first = false;
      sb.append(")");
      return sb.toString();
    }

    public void validate() throws TException {
      // check for required fields
    }

  }

  public static class getAccountSize_args implements TBase<getAccountSize_args._Fields>, java.io.Serializable, Cloneable, Comparable<getAccountSize_args>   {
    private static final TStruct STRUCT_DESC = new TStruct("getAccountSize_args");

    private static final TField AUTHENTICATION_TOKEN_FIELD_DESC = new TField("authenticationToken", TType.STRING, (short)1);

    private String authenticationToken;

    /** The set of fields this struct contains, along with convenience methods for finding and manipulating them. */
    public enum _Fields implements TFieldIdEnum {
      AUTHENTICATION_TOKEN((short)1, "authenticationToken");

      private static final Map<Integer, _Fields> byId = new HashMap<Integer, _Fields>();
      private static final Map<String, _Fields> byName = new HashMap<String, _Fields>();

      static {
        for (_Fields field : EnumSet.allOf(_Fields.class)) {
          byId.put((int)field._thriftId, field);
          byName.put(field.getFieldName(), field);
        }
      }

      /**
       * Find the _Fields constant that matches fieldId, or null if its not found.
       */
      public static _Fields findByThriftId(int fieldId) {
        return byId.get(fieldId);
      }

      /**
       * Find the _Fields constant that matches fieldId, throwing an exception
       * if it is not found.
       */
      public static _Fields findByThriftIdOrThrow(int fieldId) {
        _Fields fields = findByThriftId(fieldId);
        if (fields == null) throw new IllegalArgumentException("Field " + fieldId + " doesn't exist!");
        return fields;
      }

      /**
       * Find the _Fields constant that matches name, or null if its not found.
       */
      public static _Fields findByName(String name) {
        return byName.get(name);
      }

      private final short _thriftId;
      private final String _fieldName;

      _Fields(short thriftId, String fieldName) {
        _thriftId = thriftId;
        _fieldName = fieldName;
      }

      public short getThriftFieldId() {
        return _thriftId;
      }

      public String getFieldName() {
        return _fieldName;
      }
    }

    // isset id assignments

    public static final Map<_Fields, FieldMetaData> metaDataMap = Collections.unmodifiableMap(new EnumMap<_Fields, FieldMetaData>(_Fields.class) {{
      put(_Fields.AUTHENTICATION_TOKEN, new FieldMetaData("authenticationToken", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.STRING)));
    }});

    static {
      FieldMetaData.addStructMetaDataMap(getAccountSize_args.class, metaDataMap);
    }

    public getAccountSize_args() {
    }

    public getAccountSize_args(
      String authenticationToken)
    {
      this();
      this.authenticationToken = authenticationToken;
    }

    /**
     * Performs a deep copy on <i>other</i>.
     */
    public getAccountSize_args(getAccountSize_args other) {
      if (other.isSetAuthenticationToken()) {
        this.authenticationToken = other.authenticationToken;
      }
    }

    public getAccountSize_args deepCopy() {
      return new getAccountSize_args(this);
    }

    @Deprecated
    public getAccountSize_args clone() {
      return new getAccountSize_args(this);
    }

    public String getAuthenticationToken() {
      return this.authenticationToken;
    }

    public void setAuthenticationToken(String authenticationToken) {
      this.authenticationToken = authenticationToken;
    }

    public void unsetAuthenticationToken() {
      this.authenticationToken = null;
    }

    /** Returns true if field authenticationToken is set (has been asigned a value) and false otherwise */
    public boolean isSetAuthenticationToken() {
      return this.authenticationToken != null;
    }

    public void setAuthenticationTokenIsSet(boolean value) {
      if (!value) {
        this.authenticationToken = null;
      }
    }

    public void setFieldValue(_Fields field, Object value) {
      switch (field) {
      case AUTHENTICATION_TOKEN:
        if (value == null) {
          unsetAuthenticationToken();
        } else {
          setAuthenticationToken((String)value);
        }
        break;

      }
    }

    public void setFieldValue(int fieldID, Object value) {
      setFieldValue(_Fields.findByThriftIdOrThrow(fieldID), value);
    }

    public Object getFieldValue(_Fields field) {
      switch (field) {
      case AUTHENTICATION_TOKEN:
        return getAuthenticationToken();

      }
      throw new IllegalStateException();
    }

    public Object getFieldValue(int fieldId) {
      return getFieldValue(_Fields.findByThriftIdOrThrow(fieldId));
    }

    /** Returns true if field corresponding to fieldID is set (has been asigned a value) and false otherwise */
    public boolean isSet(_Fields field) {
      switch (field) {
      case AUTHENTICATION_TOKEN:
        return isSetAuthenticationToken();
      }
      throw new IllegalStateException();
    }

    public boolean isSet(int fieldID) {
      return isSet(_Fields.findByThriftIdOrThrow(fieldID));
    }

    public boolean equals(Object that) {
      if (that == null)
        return false;
      if (that instanceof getAccountSize_args)
        return this.equals((getAccountSize_args)that);
      return false;
    }

    public boolean equals(getAccountSize_args that) {
      if (that == null)
        return false;

      boolean this_present_authenticationToken = true && this.isSetAuthenticationToken();
      boolean that_present_authenticationToken = true && that.isSetAuthenticationToken();
      if (this_present_authenticationToken || that_present_authenticationToken) {
        if (!(this_present_authenticationToken && that_present_authenticationToken))
          return false;
        if (!this.authenticationToken.equals(that.authenticationToken))
          return false;
      }

      return true;
    }

    public int hashCode() {
      return 0;
    }

    public int compareTo(getAccountSize_args other) {
      if (!getClass().equals(other.getClass())) {
        return getClass().getName().compareTo(other.getClass().getName());
      }

      int lastComparison = 0;
      getAccountSize_args typedOther = (getAccountSize_args)other;

      lastComparison = Boolean.valueOf(isSetAuthenticationToken()).compareTo(isSetAuthenticationToken());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(authenticationToken, typedOther.authenticationToken);
      if (lastComparison != 0) {
        return lastComparison;
      }
      return 0;
    }

    public void read(TProtocol iprot) throws TException {
      TField field;
      iprot.readStructBegin();
      while (true)
      {
        field = iprot.readFieldBegin();
        if (field.type == TType.STOP) { 
          break;
        }
        _Fields fieldId = _Fields.findByThriftId(field.id);
        if (fieldId == null) {
          TProtocolUtil.skip(iprot, field.type);
        } else {
          switch (fieldId) {
            case AUTHENTICATION_TOKEN:
              if (field.type == TType.STRING) {
                this.authenticationToken = iprot.readString();
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
          }
          iprot.readFieldEnd();
        }
      }
      iprot.readStructEnd();
      validate();
    }

    public void write(TProtocol oprot) throws TException {
      validate();

      oprot.writeStructBegin(STRUCT_DESC);
      if (this.authenticationToken != null) {
        oprot.writeFieldBegin(AUTHENTICATION_TOKEN_FIELD_DESC);
        oprot.writeString(this.authenticationToken);
        oprot.writeFieldEnd();
      }
      oprot.writeFieldStop();
      oprot.writeStructEnd();
    }

    public String toString() {
      StringBuilder sb = new StringBuilder("getAccountSize_args(");
      boolean first = true;

      sb.append("authenticationToken:");
      if (this.authenticationToken == null) {
        sb.append("null");
      } else {
        sb.append(this.authenticationToken);
      }
      first = false;
      sb.append(")");
      return sb.toString();
    }

    public void validate() throws TException {
      // check for required fields
    }

  }

  public static class getAccountSize_result implements TBase<getAccountSize_result._Fields>, java.io.Serializable, Cloneable, Comparable<getAccountSize_result>   {
    private static final TStruct STRUCT_DESC = new TStruct("getAccountSize_result");

    private static final TField SUCCESS_FIELD_DESC = new TField("success", TType.I64, (short)0);
    private static final TField USER_EXCEPTION_FIELD_DESC = new TField("userException", TType.STRUCT, (short)1);
    private static final TField SYSTEM_EXCEPTION_FIELD_DESC = new TField("systemException", TType.STRUCT, (short)2);

    private long success;
    private com.evernote.edam.error.EDAMUserException userException;
    private com.evernote.edam.error.EDAMSystemException systemException;

    /** The set of fields this struct contains, along with convenience methods for finding and manipulating them. */
    public enum _Fields implements TFieldIdEnum {
      SUCCESS((short)0, "success"),
      USER_EXCEPTION((short)1, "userException"),
      SYSTEM_EXCEPTION((short)2, "systemException");

      private static final Map<Integer, _Fields> byId = new HashMap<Integer, _Fields>();
      private static final Map<String, _Fields> byName = new HashMap<String, _Fields>();

      static {
        for (_Fields field : EnumSet.allOf(_Fields.class)) {
          byId.put((int)field._thriftId, field);
          byName.put(field.getFieldName(), field);
        }
      }

      /**
       * Find the _Fields constant that matches fieldId, or null if its not found.
       */
      public static _Fields findByThriftId(int fieldId) {
        return byId.get(fieldId);
      }

      /**
       * Find the _Fields constant that matches fieldId, throwing an exception
       * if it is not found.
       */
      public static _Fields findByThriftIdOrThrow(int fieldId) {
        _Fields fields = findByThriftId(fieldId);
        if (fields == null) throw new IllegalArgumentException("Field " + fieldId + " doesn't exist!");
        return fields;
      }

      /**
       * Find the _Fields constant that matches name, or null if its not found.
       */
      public static _Fields findByName(String name) {
        return byName.get(name);
      }

      private final short _thriftId;
      private final String _fieldName;

      _Fields(short thriftId, String fieldName) {
        _thriftId = thriftId;
        _fieldName = fieldName;
      }

      public short getThriftFieldId() {
        return _thriftId;
      }

      public String getFieldName() {
        return _fieldName;
      }
    }

    // isset id assignments
    private static final int __SUCCESS_ISSET_ID = 0;
    private BitSet __isset_bit_vector = new BitSet(1);

    public static final Map<_Fields, FieldMetaData> metaDataMap = Collections.unmodifiableMap(new EnumMap<_Fields, FieldMetaData>(_Fields.class) {{
      put(_Fields.SUCCESS, new FieldMetaData("success", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.I64)));
      put(_Fields.USER_EXCEPTION, new FieldMetaData("userException", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.STRUCT)));
      put(_Fields.SYSTEM_EXCEPTION, new FieldMetaData("systemException", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.STRUCT)));
    }});

    static {
      FieldMetaData.addStructMetaDataMap(getAccountSize_result.class, metaDataMap);
    }

    public getAccountSize_result() {
    }

    public getAccountSize_result(
      long success,
      com.evernote.edam.error.EDAMUserException userException,
      com.evernote.edam.error.EDAMSystemException systemException)
    {
      this();
      this.success = success;
      setSuccessIsSet(true);
      this.userException = userException;
      this.systemException = systemException;
    }

    /**
     * Performs a deep copy on <i>other</i>.
     */
    public getAccountSize_result(getAccountSize_result other) {
      __isset_bit_vector.clear();
      __isset_bit_vector.or(other.__isset_bit_vector);
      this.success = other.success;
      if (other.isSetUserException()) {
        this.userException = new com.evernote.edam.error.EDAMUserException(other.userException);
      }
      if (other.isSetSystemException()) {
        this.systemException = new com.evernote.edam.error.EDAMSystemException(other.systemException);
      }
    }

    public getAccountSize_result deepCopy() {
      return new getAccountSize_result(this);
    }

    @Deprecated
    public getAccountSize_result clone() {
      return new getAccountSize_result(this);
    }

    public long getSuccess() {
      return this.success;
    }

    public void setSuccess(long success) {
      this.success = success;
      setSuccessIsSet(true);
    }

    public void unsetSuccess() {
      __isset_bit_vector.clear(__SUCCESS_ISSET_ID);
    }

    /** Returns true if field success is set (has been asigned a value) and false otherwise */
    public boolean isSetSuccess() {
      return __isset_bit_vector.get(__SUCCESS_ISSET_ID);
    }

    public void setSuccessIsSet(boolean value) {
      __isset_bit_vector.set(__SUCCESS_ISSET_ID, value);
    }

    public com.evernote.edam.error.EDAMUserException getUserException() {
      return this.userException;
    }

    public void setUserException(com.evernote.edam.error.EDAMUserException userException) {
      this.userException = userException;
    }

    public void unsetUserException() {
      this.userException = null;
    }

    /** Returns true if field userException is set (has been asigned a value) and false otherwise */
    public boolean isSetUserException() {
      return this.userException != null;
    }

    public void setUserExceptionIsSet(boolean value) {
      if (!value) {
        this.userException = null;
      }
    }

    public com.evernote.edam.error.EDAMSystemException getSystemException() {
      return this.systemException;
    }

    public void setSystemException(com.evernote.edam.error.EDAMSystemException systemException) {
      this.systemException = systemException;
    }

    public void unsetSystemException() {
      this.systemException = null;
    }

    /** Returns true if field systemException is set (has been asigned a value) and false otherwise */
    public boolean isSetSystemException() {
      return this.systemException != null;
    }

    public void setSystemExceptionIsSet(boolean value) {
      if (!value) {
        this.systemException = null;
      }
    }

    public void setFieldValue(_Fields field, Object value) {
      switch (field) {
      case SUCCESS:
        if (value == null) {
          unsetSuccess();
        } else {
          setSuccess((Long)value);
        }
        break;

      case USER_EXCEPTION:
        if (value == null) {
          unsetUserException();
        } else {
          setUserException((com.evernote.edam.error.EDAMUserException)value);
        }
        break;

      case SYSTEM_EXCEPTION:
        if (value == null) {
          unsetSystemException();
        } else {
          setSystemException((com.evernote.edam.error.EDAMSystemException)value);
        }
        break;

      }
    }

    public void setFieldValue(int fieldID, Object value) {
      setFieldValue(_Fields.findByThriftIdOrThrow(fieldID), value);
    }

    public Object getFieldValue(_Fields field) {
      switch (field) {
      case SUCCESS:
        return new Long(getSuccess());

      case USER_EXCEPTION:
        return getUserException();

      case SYSTEM_EXCEPTION:
        return getSystemException();

      }
      throw new IllegalStateException();
    }

    public Object getFieldValue(int fieldId) {
      return getFieldValue(_Fields.findByThriftIdOrThrow(fieldId));
    }

    /** Returns true if field corresponding to fieldID is set (has been asigned a value) and false otherwise */
    public boolean isSet(_Fields field) {
      switch (field) {
      case SUCCESS:
        return isSetSuccess();
      case USER_EXCEPTION:
        return isSetUserException();
      case SYSTEM_EXCEPTION:
        return isSetSystemException();
      }
      throw new IllegalStateException();
    }

    public boolean isSet(int fieldID) {
      return isSet(_Fields.findByThriftIdOrThrow(fieldID));
    }

    public boolean equals(Object that) {
      if (that == null)
        return false;
      if (that instanceof getAccountSize_result)
        return this.equals((getAccountSize_result)that);
      return false;
    }

    public boolean equals(getAccountSize_result that) {
      if (that == null)
        return false;

      boolean this_present_success = true;
      boolean that_present_success = true;
      if (this_present_success || that_present_success) {
        if (!(this_present_success && that_present_success))
          return false;
        if (this.success != that.success)
          return false;
      }

      boolean this_present_userException = true && this.isSetUserException();
      boolean that_present_userException = true && that.isSetUserException();
      if (this_present_userException || that_present_userException) {
        if (!(this_present_userException && that_present_userException))
          return false;
        if (!this.userException.equals(that.userException))
          return false;
      }

      boolean this_present_systemException = true && this.isSetSystemException();
      boolean that_present_systemException = true && that.isSetSystemException();
      if (this_present_systemException || that_present_systemException) {
        if (!(this_present_systemException && that_present_systemException))
          return false;
        if (!this.systemException.equals(that.systemException))
          return false;
      }

      return true;
    }

    public int hashCode() {
      return 0;
    }

    public int compareTo(getAccountSize_result other) {
      if (!getClass().equals(other.getClass())) {
        return getClass().getName().compareTo(other.getClass().getName());
      }

      int lastComparison = 0;
      getAccountSize_result typedOther = (getAccountSize_result)other;

      lastComparison = Boolean.valueOf(isSetSuccess()).compareTo(isSetSuccess());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(success, typedOther.success);
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = Boolean.valueOf(isSetUserException()).compareTo(isSetUserException());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(userException, typedOther.userException);
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = Boolean.valueOf(isSetSystemException()).compareTo(isSetSystemException());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(systemException, typedOther.systemException);
      if (lastComparison != 0) {
        return lastComparison;
      }
      return 0;
    }

    public void read(TProtocol iprot) throws TException {
      TField field;
      iprot.readStructBegin();
      while (true)
      {
        field = iprot.readFieldBegin();
        if (field.type == TType.STOP) { 
          break;
        }
        _Fields fieldId = _Fields.findByThriftId(field.id);
        if (fieldId == null) {
          TProtocolUtil.skip(iprot, field.type);
        } else {
          switch (fieldId) {
            case SUCCESS:
              if (field.type == TType.I64) {
                this.success = iprot.readI64();
                setSuccessIsSet(true);
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
            case USER_EXCEPTION:
              if (field.type == TType.STRUCT) {
                this.userException = new com.evernote.edam.error.EDAMUserException();
                this.userException.read(iprot);
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
            case SYSTEM_EXCEPTION:
              if (field.type == TType.STRUCT) {
                this.systemException = new com.evernote.edam.error.EDAMSystemException();
                this.systemException.read(iprot);
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
          }
          iprot.readFieldEnd();
        }
      }
      iprot.readStructEnd();
      validate();
    }

    public void write(TProtocol oprot) throws TException {
      oprot.writeStructBegin(STRUCT_DESC);

      if (this.isSetSuccess()) {
        oprot.writeFieldBegin(SUCCESS_FIELD_DESC);
        oprot.writeI64(this.success);
        oprot.writeFieldEnd();
      } else if (this.isSetUserException()) {
        oprot.writeFieldBegin(USER_EXCEPTION_FIELD_DESC);
        this.userException.write(oprot);
        oprot.writeFieldEnd();
      } else if (this.isSetSystemException()) {
        oprot.writeFieldBegin(SYSTEM_EXCEPTION_FIELD_DESC);
        this.systemException.write(oprot);
        oprot.writeFieldEnd();
      }
      oprot.writeFieldStop();
      oprot.writeStructEnd();
    }

    public String toString() {
      StringBuilder sb = new StringBuilder("getAccountSize_result(");
      boolean first = true;

      sb.append("success:");
      sb.append(this.success);
      first = false;
      if (!first) sb.append(", ");
      sb.append("userException:");
      if (this.userException == null) {
        sb.append("null");
      } else {
        sb.append(this.userException);
      }
      first = false;
      if (!first) sb.append(", ");
      sb.append("systemException:");
      if (this.systemException == null) {
        sb.append("null");
      } else {
        sb.append(this.systemException);
      }
      first = false;
      sb.append(")");
      return sb.toString();
    }

    public void validate() throws TException {
      // check for required fields
    }

  }

  public static class getAds_args implements TBase<getAds_args._Fields>, java.io.Serializable, Cloneable   {
    private static final TStruct STRUCT_DESC = new TStruct("getAds_args");

    private static final TField AUTHENTICATION_TOKEN_FIELD_DESC = new TField("authenticationToken", TType.STRING, (short)1);
    private static final TField AD_PARAMETERS_FIELD_DESC = new TField("adParameters", TType.STRUCT, (short)2);

    private String authenticationToken;
    private AdParameters adParameters;

    /** The set of fields this struct contains, along with convenience methods for finding and manipulating them. */
    public enum _Fields implements TFieldIdEnum {
      AUTHENTICATION_TOKEN((short)1, "authenticationToken"),
      AD_PARAMETERS((short)2, "adParameters");

      private static final Map<Integer, _Fields> byId = new HashMap<Integer, _Fields>();
      private static final Map<String, _Fields> byName = new HashMap<String, _Fields>();

      static {
        for (_Fields field : EnumSet.allOf(_Fields.class)) {
          byId.put((int)field._thriftId, field);
          byName.put(field.getFieldName(), field);
        }
      }

      /**
       * Find the _Fields constant that matches fieldId, or null if its not found.
       */
      public static _Fields findByThriftId(int fieldId) {
        return byId.get(fieldId);
      }

      /**
       * Find the _Fields constant that matches fieldId, throwing an exception
       * if it is not found.
       */
      public static _Fields findByThriftIdOrThrow(int fieldId) {
        _Fields fields = findByThriftId(fieldId);
        if (fields == null) throw new IllegalArgumentException("Field " + fieldId + " doesn't exist!");
        return fields;
      }

      /**
       * Find the _Fields constant that matches name, or null if its not found.
       */
      public static _Fields findByName(String name) {
        return byName.get(name);
      }

      private final short _thriftId;
      private final String _fieldName;

      _Fields(short thriftId, String fieldName) {
        _thriftId = thriftId;
        _fieldName = fieldName;
      }

      public short getThriftFieldId() {
        return _thriftId;
      }

      public String getFieldName() {
        return _fieldName;
      }
    }

    // isset id assignments

    public static final Map<_Fields, FieldMetaData> metaDataMap = Collections.unmodifiableMap(new EnumMap<_Fields, FieldMetaData>(_Fields.class) {{
      put(_Fields.AUTHENTICATION_TOKEN, new FieldMetaData("authenticationToken", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.STRING)));
      put(_Fields.AD_PARAMETERS, new FieldMetaData("adParameters", TFieldRequirementType.DEFAULT, 
          new StructMetaData(TType.STRUCT, AdParameters.class)));
    }});

    static {
      FieldMetaData.addStructMetaDataMap(getAds_args.class, metaDataMap);
    }

    public getAds_args() {
    }

    public getAds_args(
      String authenticationToken,
      AdParameters adParameters)
    {
      this();
      this.authenticationToken = authenticationToken;
      this.adParameters = adParameters;
    }

    /**
     * Performs a deep copy on <i>other</i>.
     */
    public getAds_args(getAds_args other) {
      if (other.isSetAuthenticationToken()) {
        this.authenticationToken = other.authenticationToken;
      }
      if (other.isSetAdParameters()) {
        this.adParameters = new AdParameters(other.adParameters);
      }
    }

    public getAds_args deepCopy() {
      return new getAds_args(this);
    }

    @Deprecated
    public getAds_args clone() {
      return new getAds_args(this);
    }

    public String getAuthenticationToken() {
      return this.authenticationToken;
    }

    public void setAuthenticationToken(String authenticationToken) {
      this.authenticationToken = authenticationToken;
    }

    public void unsetAuthenticationToken() {
      this.authenticationToken = null;
    }

    /** Returns true if field authenticationToken is set (has been asigned a value) and false otherwise */
    public boolean isSetAuthenticationToken() {
      return this.authenticationToken != null;
    }

    public void setAuthenticationTokenIsSet(boolean value) {
      if (!value) {
        this.authenticationToken = null;
      }
    }

    public AdParameters getAdParameters() {
      return this.adParameters;
    }

    public void setAdParameters(AdParameters adParameters) {
      this.adParameters = adParameters;
    }

    public void unsetAdParameters() {
      this.adParameters = null;
    }

    /** Returns true if field adParameters is set (has been asigned a value) and false otherwise */
    public boolean isSetAdParameters() {
      return this.adParameters != null;
    }

    public void setAdParametersIsSet(boolean value) {
      if (!value) {
        this.adParameters = null;
      }
    }

    public void setFieldValue(_Fields field, Object value) {
      switch (field) {
      case AUTHENTICATION_TOKEN:
        if (value == null) {
          unsetAuthenticationToken();
        } else {
          setAuthenticationToken((String)value);
        }
        break;

      case AD_PARAMETERS:
        if (value == null) {
          unsetAdParameters();
        } else {
          setAdParameters((AdParameters)value);
        }
        break;

      }
    }

    public void setFieldValue(int fieldID, Object value) {
      setFieldValue(_Fields.findByThriftIdOrThrow(fieldID), value);
    }

    public Object getFieldValue(_Fields field) {
      switch (field) {
      case AUTHENTICATION_TOKEN:
        return getAuthenticationToken();

      case AD_PARAMETERS:
        return getAdParameters();

      }
      throw new IllegalStateException();
    }

    public Object getFieldValue(int fieldId) {
      return getFieldValue(_Fields.findByThriftIdOrThrow(fieldId));
    }

    /** Returns true if field corresponding to fieldID is set (has been asigned a value) and false otherwise */
    public boolean isSet(_Fields field) {
      switch (field) {
      case AUTHENTICATION_TOKEN:
        return isSetAuthenticationToken();
      case AD_PARAMETERS:
        return isSetAdParameters();
      }
      throw new IllegalStateException();
    }

    public boolean isSet(int fieldID) {
      return isSet(_Fields.findByThriftIdOrThrow(fieldID));
    }

    public boolean equals(Object that) {
      if (that == null)
        return false;
      if (that instanceof getAds_args)
        return this.equals((getAds_args)that);
      return false;
    }

    public boolean equals(getAds_args that) {
      if (that == null)
        return false;

      boolean this_present_authenticationToken = true && this.isSetAuthenticationToken();
      boolean that_present_authenticationToken = true && that.isSetAuthenticationToken();
      if (this_present_authenticationToken || that_present_authenticationToken) {
        if (!(this_present_authenticationToken && that_present_authenticationToken))
          return false;
        if (!this.authenticationToken.equals(that.authenticationToken))
          return false;
      }

      boolean this_present_adParameters = true && this.isSetAdParameters();
      boolean that_present_adParameters = true && that.isSetAdParameters();
      if (this_present_adParameters || that_present_adParameters) {
        if (!(this_present_adParameters && that_present_adParameters))
          return false;
        if (!this.adParameters.equals(that.adParameters))
          return false;
      }

      return true;
    }

    public int hashCode() {
      return 0;
    }

    public void read(TProtocol iprot) throws TException {
      TField field;
      iprot.readStructBegin();
      while (true)
      {
        field = iprot.readFieldBegin();
        if (field.type == TType.STOP) { 
          break;
        }
        _Fields fieldId = _Fields.findByThriftId(field.id);
        if (fieldId == null) {
          TProtocolUtil.skip(iprot, field.type);
        } else {
          switch (fieldId) {
            case AUTHENTICATION_TOKEN:
              if (field.type == TType.STRING) {
                this.authenticationToken = iprot.readString();
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
            case AD_PARAMETERS:
              if (field.type == TType.STRUCT) {
                this.adParameters = new AdParameters();
                this.adParameters.read(iprot);
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
          }
          iprot.readFieldEnd();
        }
      }
      iprot.readStructEnd();
      validate();
    }

    public void write(TProtocol oprot) throws TException {
      validate();

      oprot.writeStructBegin(STRUCT_DESC);
      if (this.authenticationToken != null) {
        oprot.writeFieldBegin(AUTHENTICATION_TOKEN_FIELD_DESC);
        oprot.writeString(this.authenticationToken);
        oprot.writeFieldEnd();
      }
      if (this.adParameters != null) {
        oprot.writeFieldBegin(AD_PARAMETERS_FIELD_DESC);
        this.adParameters.write(oprot);
        oprot.writeFieldEnd();
      }
      oprot.writeFieldStop();
      oprot.writeStructEnd();
    }

    public String toString() {
      StringBuilder sb = new StringBuilder("getAds_args(");
      boolean first = true;

      sb.append("authenticationToken:");
      if (this.authenticationToken == null) {
        sb.append("null");
      } else {
        sb.append(this.authenticationToken);
      }
      first = false;
      if (!first) sb.append(", ");
      sb.append("adParameters:");
      if (this.adParameters == null) {
        sb.append("null");
      } else {
        sb.append(this.adParameters);
      }
      first = false;
      sb.append(")");
      return sb.toString();
    }

    public void validate() throws TException {
      // check for required fields
    }

  }

  public static class getAds_result implements TBase<getAds_result._Fields>, java.io.Serializable, Cloneable, Comparable<getAds_result>   {
    private static final TStruct STRUCT_DESC = new TStruct("getAds_result");

    private static final TField SUCCESS_FIELD_DESC = new TField("success", TType.LIST, (short)0);
    private static final TField USER_EXCEPTION_FIELD_DESC = new TField("userException", TType.STRUCT, (short)1);
    private static final TField SYSTEM_EXCEPTION_FIELD_DESC = new TField("systemException", TType.STRUCT, (short)2);

    private List<com.evernote.edam.type.Ad> success;
    private com.evernote.edam.error.EDAMUserException userException;
    private com.evernote.edam.error.EDAMSystemException systemException;

    /** The set of fields this struct contains, along with convenience methods for finding and manipulating them. */
    public enum _Fields implements TFieldIdEnum {
      SUCCESS((short)0, "success"),
      USER_EXCEPTION((short)1, "userException"),
      SYSTEM_EXCEPTION((short)2, "systemException");

      private static final Map<Integer, _Fields> byId = new HashMap<Integer, _Fields>();
      private static final Map<String, _Fields> byName = new HashMap<String, _Fields>();

      static {
        for (_Fields field : EnumSet.allOf(_Fields.class)) {
          byId.put((int)field._thriftId, field);
          byName.put(field.getFieldName(), field);
        }
      }

      /**
       * Find the _Fields constant that matches fieldId, or null if its not found.
       */
      public static _Fields findByThriftId(int fieldId) {
        return byId.get(fieldId);
      }

      /**
       * Find the _Fields constant that matches fieldId, throwing an exception
       * if it is not found.
       */
      public static _Fields findByThriftIdOrThrow(int fieldId) {
        _Fields fields = findByThriftId(fieldId);
        if (fields == null) throw new IllegalArgumentException("Field " + fieldId + " doesn't exist!");
        return fields;
      }

      /**
       * Find the _Fields constant that matches name, or null if its not found.
       */
      public static _Fields findByName(String name) {
        return byName.get(name);
      }

      private final short _thriftId;
      private final String _fieldName;

      _Fields(short thriftId, String fieldName) {
        _thriftId = thriftId;
        _fieldName = fieldName;
      }

      public short getThriftFieldId() {
        return _thriftId;
      }

      public String getFieldName() {
        return _fieldName;
      }
    }

    // isset id assignments

    public static final Map<_Fields, FieldMetaData> metaDataMap = Collections.unmodifiableMap(new EnumMap<_Fields, FieldMetaData>(_Fields.class) {{
      put(_Fields.SUCCESS, new FieldMetaData("success", TFieldRequirementType.DEFAULT, 
          new ListMetaData(TType.LIST, 
              new StructMetaData(TType.STRUCT, com.evernote.edam.type.Ad.class))));
      put(_Fields.USER_EXCEPTION, new FieldMetaData("userException", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.STRUCT)));
      put(_Fields.SYSTEM_EXCEPTION, new FieldMetaData("systemException", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.STRUCT)));
    }});

    static {
      FieldMetaData.addStructMetaDataMap(getAds_result.class, metaDataMap);
    }

    public getAds_result() {
    }

    public getAds_result(
      List<com.evernote.edam.type.Ad> success,
      com.evernote.edam.error.EDAMUserException userException,
      com.evernote.edam.error.EDAMSystemException systemException)
    {
      this();
      this.success = success;
      this.userException = userException;
      this.systemException = systemException;
    }

    /**
     * Performs a deep copy on <i>other</i>.
     */
    public getAds_result(getAds_result other) {
      if (other.isSetSuccess()) {
        List<com.evernote.edam.type.Ad> __this__success = new ArrayList<com.evernote.edam.type.Ad>();
        for (com.evernote.edam.type.Ad other_element : other.success) {
          __this__success.add(new com.evernote.edam.type.Ad(other_element));
        }
        this.success = __this__success;
      }
      if (other.isSetUserException()) {
        this.userException = new com.evernote.edam.error.EDAMUserException(other.userException);
      }
      if (other.isSetSystemException()) {
        this.systemException = new com.evernote.edam.error.EDAMSystemException(other.systemException);
      }
    }

    public getAds_result deepCopy() {
      return new getAds_result(this);
    }

    @Deprecated
    public getAds_result clone() {
      return new getAds_result(this);
    }

    public int getSuccessSize() {
      return (this.success == null) ? 0 : this.success.size();
    }

    public java.util.Iterator<com.evernote.edam.type.Ad> getSuccessIterator() {
      return (this.success == null) ? null : this.success.iterator();
    }

    public void addToSuccess(com.evernote.edam.type.Ad elem) {
      if (this.success == null) {
        this.success = new ArrayList<com.evernote.edam.type.Ad>();
      }
      this.success.add(elem);
    }

    public List<com.evernote.edam.type.Ad> getSuccess() {
      return this.success;
    }

    public void setSuccess(List<com.evernote.edam.type.Ad> success) {
      this.success = success;
    }

    public void unsetSuccess() {
      this.success = null;
    }

    /** Returns true if field success is set (has been asigned a value) and false otherwise */
    public boolean isSetSuccess() {
      return this.success != null;
    }

    public void setSuccessIsSet(boolean value) {
      if (!value) {
        this.success = null;
      }
    }

    public com.evernote.edam.error.EDAMUserException getUserException() {
      return this.userException;
    }

    public void setUserException(com.evernote.edam.error.EDAMUserException userException) {
      this.userException = userException;
    }

    public void unsetUserException() {
      this.userException = null;
    }

    /** Returns true if field userException is set (has been asigned a value) and false otherwise */
    public boolean isSetUserException() {
      return this.userException != null;
    }

    public void setUserExceptionIsSet(boolean value) {
      if (!value) {
        this.userException = null;
      }
    }

    public com.evernote.edam.error.EDAMSystemException getSystemException() {
      return this.systemException;
    }

    public void setSystemException(com.evernote.edam.error.EDAMSystemException systemException) {
      this.systemException = systemException;
    }

    public void unsetSystemException() {
      this.systemException = null;
    }

    /** Returns true if field systemException is set (has been asigned a value) and false otherwise */
    public boolean isSetSystemException() {
      return this.systemException != null;
    }

    public void setSystemExceptionIsSet(boolean value) {
      if (!value) {
        this.systemException = null;
      }
    }

    public void setFieldValue(_Fields field, Object value) {
      switch (field) {
      case SUCCESS:
        if (value == null) {
          unsetSuccess();
        } else {
          setSuccess((List<com.evernote.edam.type.Ad>)value);
        }
        break;

      case USER_EXCEPTION:
        if (value == null) {
          unsetUserException();
        } else {
          setUserException((com.evernote.edam.error.EDAMUserException)value);
        }
        break;

      case SYSTEM_EXCEPTION:
        if (value == null) {
          unsetSystemException();
        } else {
          setSystemException((com.evernote.edam.error.EDAMSystemException)value);
        }
        break;

      }
    }

    public void setFieldValue(int fieldID, Object value) {
      setFieldValue(_Fields.findByThriftIdOrThrow(fieldID), value);
    }

    public Object getFieldValue(_Fields field) {
      switch (field) {
      case SUCCESS:
        return getSuccess();

      case USER_EXCEPTION:
        return getUserException();

      case SYSTEM_EXCEPTION:
        return getSystemException();

      }
      throw new IllegalStateException();
    }

    public Object getFieldValue(int fieldId) {
      return getFieldValue(_Fields.findByThriftIdOrThrow(fieldId));
    }

    /** Returns true if field corresponding to fieldID is set (has been asigned a value) and false otherwise */
    public boolean isSet(_Fields field) {
      switch (field) {
      case SUCCESS:
        return isSetSuccess();
      case USER_EXCEPTION:
        return isSetUserException();
      case SYSTEM_EXCEPTION:
        return isSetSystemException();
      }
      throw new IllegalStateException();
    }

    public boolean isSet(int fieldID) {
      return isSet(_Fields.findByThriftIdOrThrow(fieldID));
    }

    public boolean equals(Object that) {
      if (that == null)
        return false;
      if (that instanceof getAds_result)
        return this.equals((getAds_result)that);
      return false;
    }

    public boolean equals(getAds_result that) {
      if (that == null)
        return false;

      boolean this_present_success = true && this.isSetSuccess();
      boolean that_present_success = true && that.isSetSuccess();
      if (this_present_success || that_present_success) {
        if (!(this_present_success && that_present_success))
          return false;
        if (!this.success.equals(that.success))
          return false;
      }

      boolean this_present_userException = true && this.isSetUserException();
      boolean that_present_userException = true && that.isSetUserException();
      if (this_present_userException || that_present_userException) {
        if (!(this_present_userException && that_present_userException))
          return false;
        if (!this.userException.equals(that.userException))
          return false;
      }

      boolean this_present_systemException = true && this.isSetSystemException();
      boolean that_present_systemException = true && that.isSetSystemException();
      if (this_present_systemException || that_present_systemException) {
        if (!(this_present_systemException && that_present_systemException))
          return false;
        if (!this.systemException.equals(that.systemException))
          return false;
      }

      return true;
    }

    public int hashCode() {
      return 0;
    }

    public int compareTo(getAds_result other) {
      if (!getClass().equals(other.getClass())) {
        return getClass().getName().compareTo(other.getClass().getName());
      }

      int lastComparison = 0;
      getAds_result typedOther = (getAds_result)other;

      lastComparison = Boolean.valueOf(isSetSuccess()).compareTo(isSetSuccess());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(success, typedOther.success);
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = Boolean.valueOf(isSetUserException()).compareTo(isSetUserException());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(userException, typedOther.userException);
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = Boolean.valueOf(isSetSystemException()).compareTo(isSetSystemException());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(systemException, typedOther.systemException);
      if (lastComparison != 0) {
        return lastComparison;
      }
      return 0;
    }

    public void read(TProtocol iprot) throws TException {
      TField field;
      iprot.readStructBegin();
      while (true)
      {
        field = iprot.readFieldBegin();
        if (field.type == TType.STOP) { 
          break;
        }
        _Fields fieldId = _Fields.findByThriftId(field.id);
        if (fieldId == null) {
          TProtocolUtil.skip(iprot, field.type);
        } else {
          switch (fieldId) {
            case SUCCESS:
              if (field.type == TType.LIST) {
                {
                  TList _list107 = iprot.readListBegin();
                  this.success = new ArrayList<com.evernote.edam.type.Ad>(_list107.size);
                  for (int _i108 = 0; _i108 < _list107.size; ++_i108)
                  {
                    com.evernote.edam.type.Ad _elem109;
                    _elem109 = new com.evernote.edam.type.Ad();
                    _elem109.read(iprot);
                    this.success.add(_elem109);
                  }
                  iprot.readListEnd();
                }
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
            case USER_EXCEPTION:
              if (field.type == TType.STRUCT) {
                this.userException = new com.evernote.edam.error.EDAMUserException();
                this.userException.read(iprot);
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
            case SYSTEM_EXCEPTION:
              if (field.type == TType.STRUCT) {
                this.systemException = new com.evernote.edam.error.EDAMSystemException();
                this.systemException.read(iprot);
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
          }
          iprot.readFieldEnd();
        }
      }
      iprot.readStructEnd();
      validate();
    }

    public void write(TProtocol oprot) throws TException {
      oprot.writeStructBegin(STRUCT_DESC);

      if (this.isSetSuccess()) {
        oprot.writeFieldBegin(SUCCESS_FIELD_DESC);
        {
          oprot.writeListBegin(new TList(TType.STRUCT, this.success.size()));
          for (com.evernote.edam.type.Ad _iter110 : this.success)
          {
            _iter110.write(oprot);
          }
          oprot.writeListEnd();
        }
        oprot.writeFieldEnd();
      } else if (this.isSetUserException()) {
        oprot.writeFieldBegin(USER_EXCEPTION_FIELD_DESC);
        this.userException.write(oprot);
        oprot.writeFieldEnd();
      } else if (this.isSetSystemException()) {
        oprot.writeFieldBegin(SYSTEM_EXCEPTION_FIELD_DESC);
        this.systemException.write(oprot);
        oprot.writeFieldEnd();
      }
      oprot.writeFieldStop();
      oprot.writeStructEnd();
    }

    public String toString() {
      StringBuilder sb = new StringBuilder("getAds_result(");
      boolean first = true;

      sb.append("success:");
      if (this.success == null) {
        sb.append("null");
      } else {
        sb.append(this.success);
      }
      first = false;
      if (!first) sb.append(", ");
      sb.append("userException:");
      if (this.userException == null) {
        sb.append("null");
      } else {
        sb.append(this.userException);
      }
      first = false;
      if (!first) sb.append(", ");
      sb.append("systemException:");
      if (this.systemException == null) {
        sb.append("null");
      } else {
        sb.append(this.systemException);
      }
      first = false;
      sb.append(")");
      return sb.toString();
    }

    public void validate() throws TException {
      // check for required fields
    }

  }

  public static class getRandomAd_args implements TBase<getRandomAd_args._Fields>, java.io.Serializable, Cloneable   {
    private static final TStruct STRUCT_DESC = new TStruct("getRandomAd_args");

    private static final TField AUTHENTICATION_TOKEN_FIELD_DESC = new TField("authenticationToken", TType.STRING, (short)1);
    private static final TField AD_PARAMETERS_FIELD_DESC = new TField("adParameters", TType.STRUCT, (short)2);

    private String authenticationToken;
    private AdParameters adParameters;

    /** The set of fields this struct contains, along with convenience methods for finding and manipulating them. */
    public enum _Fields implements TFieldIdEnum {
      AUTHENTICATION_TOKEN((short)1, "authenticationToken"),
      AD_PARAMETERS((short)2, "adParameters");

      private static final Map<Integer, _Fields> byId = new HashMap<Integer, _Fields>();
      private static final Map<String, _Fields> byName = new HashMap<String, _Fields>();

      static {
        for (_Fields field : EnumSet.allOf(_Fields.class)) {
          byId.put((int)field._thriftId, field);
          byName.put(field.getFieldName(), field);
        }
      }

      /**
       * Find the _Fields constant that matches fieldId, or null if its not found.
       */
      public static _Fields findByThriftId(int fieldId) {
        return byId.get(fieldId);
      }

      /**
       * Find the _Fields constant that matches fieldId, throwing an exception
       * if it is not found.
       */
      public static _Fields findByThriftIdOrThrow(int fieldId) {
        _Fields fields = findByThriftId(fieldId);
        if (fields == null) throw new IllegalArgumentException("Field " + fieldId + " doesn't exist!");
        return fields;
      }

      /**
       * Find the _Fields constant that matches name, or null if its not found.
       */
      public static _Fields findByName(String name) {
        return byName.get(name);
      }

      private final short _thriftId;
      private final String _fieldName;

      _Fields(short thriftId, String fieldName) {
        _thriftId = thriftId;
        _fieldName = fieldName;
      }

      public short getThriftFieldId() {
        return _thriftId;
      }

      public String getFieldName() {
        return _fieldName;
      }
    }

    // isset id assignments

    public static final Map<_Fields, FieldMetaData> metaDataMap = Collections.unmodifiableMap(new EnumMap<_Fields, FieldMetaData>(_Fields.class) {{
      put(_Fields.AUTHENTICATION_TOKEN, new FieldMetaData("authenticationToken", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.STRING)));
      put(_Fields.AD_PARAMETERS, new FieldMetaData("adParameters", TFieldRequirementType.DEFAULT, 
          new StructMetaData(TType.STRUCT, AdParameters.class)));
    }});

    static {
      FieldMetaData.addStructMetaDataMap(getRandomAd_args.class, metaDataMap);
    }

    public getRandomAd_args() {
    }

    public getRandomAd_args(
      String authenticationToken,
      AdParameters adParameters)
    {
      this();
      this.authenticationToken = authenticationToken;
      this.adParameters = adParameters;
    }

    /**
     * Performs a deep copy on <i>other</i>.
     */
    public getRandomAd_args(getRandomAd_args other) {
      if (other.isSetAuthenticationToken()) {
        this.authenticationToken = other.authenticationToken;
      }
      if (other.isSetAdParameters()) {
        this.adParameters = new AdParameters(other.adParameters);
      }
    }

    public getRandomAd_args deepCopy() {
      return new getRandomAd_args(this);
    }

    @Deprecated
    public getRandomAd_args clone() {
      return new getRandomAd_args(this);
    }

    public String getAuthenticationToken() {
      return this.authenticationToken;
    }

    public void setAuthenticationToken(String authenticationToken) {
      this.authenticationToken = authenticationToken;
    }

    public void unsetAuthenticationToken() {
      this.authenticationToken = null;
    }

    /** Returns true if field authenticationToken is set (has been asigned a value) and false otherwise */
    public boolean isSetAuthenticationToken() {
      return this.authenticationToken != null;
    }

    public void setAuthenticationTokenIsSet(boolean value) {
      if (!value) {
        this.authenticationToken = null;
      }
    }

    public AdParameters getAdParameters() {
      return this.adParameters;
    }

    public void setAdParameters(AdParameters adParameters) {
      this.adParameters = adParameters;
    }

    public void unsetAdParameters() {
      this.adParameters = null;
    }

    /** Returns true if field adParameters is set (has been asigned a value) and false otherwise */
    public boolean isSetAdParameters() {
      return this.adParameters != null;
    }

    public void setAdParametersIsSet(boolean value) {
      if (!value) {
        this.adParameters = null;
      }
    }

    public void setFieldValue(_Fields field, Object value) {
      switch (field) {
      case AUTHENTICATION_TOKEN:
        if (value == null) {
          unsetAuthenticationToken();
        } else {
          setAuthenticationToken((String)value);
        }
        break;

      case AD_PARAMETERS:
        if (value == null) {
          unsetAdParameters();
        } else {
          setAdParameters((AdParameters)value);
        }
        break;

      }
    }

    public void setFieldValue(int fieldID, Object value) {
      setFieldValue(_Fields.findByThriftIdOrThrow(fieldID), value);
    }

    public Object getFieldValue(_Fields field) {
      switch (field) {
      case AUTHENTICATION_TOKEN:
        return getAuthenticationToken();

      case AD_PARAMETERS:
        return getAdParameters();

      }
      throw new IllegalStateException();
    }

    public Object getFieldValue(int fieldId) {
      return getFieldValue(_Fields.findByThriftIdOrThrow(fieldId));
    }

    /** Returns true if field corresponding to fieldID is set (has been asigned a value) and false otherwise */
    public boolean isSet(_Fields field) {
      switch (field) {
      case AUTHENTICATION_TOKEN:
        return isSetAuthenticationToken();
      case AD_PARAMETERS:
        return isSetAdParameters();
      }
      throw new IllegalStateException();
    }

    public boolean isSet(int fieldID) {
      return isSet(_Fields.findByThriftIdOrThrow(fieldID));
    }

    public boolean equals(Object that) {
      if (that == null)
        return false;
      if (that instanceof getRandomAd_args)
        return this.equals((getRandomAd_args)that);
      return false;
    }

    public boolean equals(getRandomAd_args that) {
      if (that == null)
        return false;

      boolean this_present_authenticationToken = true && this.isSetAuthenticationToken();
      boolean that_present_authenticationToken = true && that.isSetAuthenticationToken();
      if (this_present_authenticationToken || that_present_authenticationToken) {
        if (!(this_present_authenticationToken && that_present_authenticationToken))
          return false;
        if (!this.authenticationToken.equals(that.authenticationToken))
          return false;
      }

      boolean this_present_adParameters = true && this.isSetAdParameters();
      boolean that_present_adParameters = true && that.isSetAdParameters();
      if (this_present_adParameters || that_present_adParameters) {
        if (!(this_present_adParameters && that_present_adParameters))
          return false;
        if (!this.adParameters.equals(that.adParameters))
          return false;
      }

      return true;
    }

    public int hashCode() {
      return 0;
    }

    public void read(TProtocol iprot) throws TException {
      TField field;
      iprot.readStructBegin();
      while (true)
      {
        field = iprot.readFieldBegin();
        if (field.type == TType.STOP) { 
          break;
        }
        _Fields fieldId = _Fields.findByThriftId(field.id);
        if (fieldId == null) {
          TProtocolUtil.skip(iprot, field.type);
        } else {
          switch (fieldId) {
            case AUTHENTICATION_TOKEN:
              if (field.type == TType.STRING) {
                this.authenticationToken = iprot.readString();
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
            case AD_PARAMETERS:
              if (field.type == TType.STRUCT) {
                this.adParameters = new AdParameters();
                this.adParameters.read(iprot);
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
          }
          iprot.readFieldEnd();
        }
      }
      iprot.readStructEnd();
      validate();
    }

    public void write(TProtocol oprot) throws TException {
      validate();

      oprot.writeStructBegin(STRUCT_DESC);
      if (this.authenticationToken != null) {
        oprot.writeFieldBegin(AUTHENTICATION_TOKEN_FIELD_DESC);
        oprot.writeString(this.authenticationToken);
        oprot.writeFieldEnd();
      }
      if (this.adParameters != null) {
        oprot.writeFieldBegin(AD_PARAMETERS_FIELD_DESC);
        this.adParameters.write(oprot);
        oprot.writeFieldEnd();
      }
      oprot.writeFieldStop();
      oprot.writeStructEnd();
    }

    public String toString() {
      StringBuilder sb = new StringBuilder("getRandomAd_args(");
      boolean first = true;

      sb.append("authenticationToken:");
      if (this.authenticationToken == null) {
        sb.append("null");
      } else {
        sb.append(this.authenticationToken);
      }
      first = false;
      if (!first) sb.append(", ");
      sb.append("adParameters:");
      if (this.adParameters == null) {
        sb.append("null");
      } else {
        sb.append(this.adParameters);
      }
      first = false;
      sb.append(")");
      return sb.toString();
    }

    public void validate() throws TException {
      // check for required fields
    }

  }

  public static class getRandomAd_result implements TBase<getRandomAd_result._Fields>, java.io.Serializable, Cloneable, Comparable<getRandomAd_result>   {
    private static final TStruct STRUCT_DESC = new TStruct("getRandomAd_result");

    private static final TField SUCCESS_FIELD_DESC = new TField("success", TType.STRUCT, (short)0);
    private static final TField USER_EXCEPTION_FIELD_DESC = new TField("userException", TType.STRUCT, (short)1);
    private static final TField SYSTEM_EXCEPTION_FIELD_DESC = new TField("systemException", TType.STRUCT, (short)2);

    private com.evernote.edam.type.Ad success;
    private com.evernote.edam.error.EDAMUserException userException;
    private com.evernote.edam.error.EDAMSystemException systemException;

    /** The set of fields this struct contains, along with convenience methods for finding and manipulating them. */
    public enum _Fields implements TFieldIdEnum {
      SUCCESS((short)0, "success"),
      USER_EXCEPTION((short)1, "userException"),
      SYSTEM_EXCEPTION((short)2, "systemException");

      private static final Map<Integer, _Fields> byId = new HashMap<Integer, _Fields>();
      private static final Map<String, _Fields> byName = new HashMap<String, _Fields>();

      static {
        for (_Fields field : EnumSet.allOf(_Fields.class)) {
          byId.put((int)field._thriftId, field);
          byName.put(field.getFieldName(), field);
        }
      }

      /**
       * Find the _Fields constant that matches fieldId, or null if its not found.
       */
      public static _Fields findByThriftId(int fieldId) {
        return byId.get(fieldId);
      }

      /**
       * Find the _Fields constant that matches fieldId, throwing an exception
       * if it is not found.
       */
      public static _Fields findByThriftIdOrThrow(int fieldId) {
        _Fields fields = findByThriftId(fieldId);
        if (fields == null) throw new IllegalArgumentException("Field " + fieldId + " doesn't exist!");
        return fields;
      }

      /**
       * Find the _Fields constant that matches name, or null if its not found.
       */
      public static _Fields findByName(String name) {
        return byName.get(name);
      }

      private final short _thriftId;
      private final String _fieldName;

      _Fields(short thriftId, String fieldName) {
        _thriftId = thriftId;
        _fieldName = fieldName;
      }

      public short getThriftFieldId() {
        return _thriftId;
      }

      public String getFieldName() {
        return _fieldName;
      }
    }

    // isset id assignments

    public static final Map<_Fields, FieldMetaData> metaDataMap = Collections.unmodifiableMap(new EnumMap<_Fields, FieldMetaData>(_Fields.class) {{
      put(_Fields.SUCCESS, new FieldMetaData("success", TFieldRequirementType.DEFAULT, 
          new StructMetaData(TType.STRUCT, com.evernote.edam.type.Ad.class)));
      put(_Fields.USER_EXCEPTION, new FieldMetaData("userException", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.STRUCT)));
      put(_Fields.SYSTEM_EXCEPTION, new FieldMetaData("systemException", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.STRUCT)));
    }});

    static {
      FieldMetaData.addStructMetaDataMap(getRandomAd_result.class, metaDataMap);
    }

    public getRandomAd_result() {
    }

    public getRandomAd_result(
      com.evernote.edam.type.Ad success,
      com.evernote.edam.error.EDAMUserException userException,
      com.evernote.edam.error.EDAMSystemException systemException)
    {
      this();
      this.success = success;
      this.userException = userException;
      this.systemException = systemException;
    }

    /**
     * Performs a deep copy on <i>other</i>.
     */
    public getRandomAd_result(getRandomAd_result other) {
      if (other.isSetSuccess()) {
        this.success = new com.evernote.edam.type.Ad(other.success);
      }
      if (other.isSetUserException()) {
        this.userException = new com.evernote.edam.error.EDAMUserException(other.userException);
      }
      if (other.isSetSystemException()) {
        this.systemException = new com.evernote.edam.error.EDAMSystemException(other.systemException);
      }
    }

    public getRandomAd_result deepCopy() {
      return new getRandomAd_result(this);
    }

    @Deprecated
    public getRandomAd_result clone() {
      return new getRandomAd_result(this);
    }

    public com.evernote.edam.type.Ad getSuccess() {
      return this.success;
    }

    public void setSuccess(com.evernote.edam.type.Ad success) {
      this.success = success;
    }

    public void unsetSuccess() {
      this.success = null;
    }

    /** Returns true if field success is set (has been asigned a value) and false otherwise */
    public boolean isSetSuccess() {
      return this.success != null;
    }

    public void setSuccessIsSet(boolean value) {
      if (!value) {
        this.success = null;
      }
    }

    public com.evernote.edam.error.EDAMUserException getUserException() {
      return this.userException;
    }

    public void setUserException(com.evernote.edam.error.EDAMUserException userException) {
      this.userException = userException;
    }

    public void unsetUserException() {
      this.userException = null;
    }

    /** Returns true if field userException is set (has been asigned a value) and false otherwise */
    public boolean isSetUserException() {
      return this.userException != null;
    }

    public void setUserExceptionIsSet(boolean value) {
      if (!value) {
        this.userException = null;
      }
    }

    public com.evernote.edam.error.EDAMSystemException getSystemException() {
      return this.systemException;
    }

    public void setSystemException(com.evernote.edam.error.EDAMSystemException systemException) {
      this.systemException = systemException;
    }

    public void unsetSystemException() {
      this.systemException = null;
    }

    /** Returns true if field systemException is set (has been asigned a value) and false otherwise */
    public boolean isSetSystemException() {
      return this.systemException != null;
    }

    public void setSystemExceptionIsSet(boolean value) {
      if (!value) {
        this.systemException = null;
      }
    }

    public void setFieldValue(_Fields field, Object value) {
      switch (field) {
      case SUCCESS:
        if (value == null) {
          unsetSuccess();
        } else {
          setSuccess((com.evernote.edam.type.Ad)value);
        }
        break;

      case USER_EXCEPTION:
        if (value == null) {
          unsetUserException();
        } else {
          setUserException((com.evernote.edam.error.EDAMUserException)value);
        }
        break;

      case SYSTEM_EXCEPTION:
        if (value == null) {
          unsetSystemException();
        } else {
          setSystemException((com.evernote.edam.error.EDAMSystemException)value);
        }
        break;

      }
    }

    public void setFieldValue(int fieldID, Object value) {
      setFieldValue(_Fields.findByThriftIdOrThrow(fieldID), value);
    }

    public Object getFieldValue(_Fields field) {
      switch (field) {
      case SUCCESS:
        return getSuccess();

      case USER_EXCEPTION:
        return getUserException();

      case SYSTEM_EXCEPTION:
        return getSystemException();

      }
      throw new IllegalStateException();
    }

    public Object getFieldValue(int fieldId) {
      return getFieldValue(_Fields.findByThriftIdOrThrow(fieldId));
    }

    /** Returns true if field corresponding to fieldID is set (has been asigned a value) and false otherwise */
    public boolean isSet(_Fields field) {
      switch (field) {
      case SUCCESS:
        return isSetSuccess();
      case USER_EXCEPTION:
        return isSetUserException();
      case SYSTEM_EXCEPTION:
        return isSetSystemException();
      }
      throw new IllegalStateException();
    }

    public boolean isSet(int fieldID) {
      return isSet(_Fields.findByThriftIdOrThrow(fieldID));
    }

    public boolean equals(Object that) {
      if (that == null)
        return false;
      if (that instanceof getRandomAd_result)
        return this.equals((getRandomAd_result)that);
      return false;
    }

    public boolean equals(getRandomAd_result that) {
      if (that == null)
        return false;

      boolean this_present_success = true && this.isSetSuccess();
      boolean that_present_success = true && that.isSetSuccess();
      if (this_present_success || that_present_success) {
        if (!(this_present_success && that_present_success))
          return false;
        if (!this.success.equals(that.success))
          return false;
      }

      boolean this_present_userException = true && this.isSetUserException();
      boolean that_present_userException = true && that.isSetUserException();
      if (this_present_userException || that_present_userException) {
        if (!(this_present_userException && that_present_userException))
          return false;
        if (!this.userException.equals(that.userException))
          return false;
      }

      boolean this_present_systemException = true && this.isSetSystemException();
      boolean that_present_systemException = true && that.isSetSystemException();
      if (this_present_systemException || that_present_systemException) {
        if (!(this_present_systemException && that_present_systemException))
          return false;
        if (!this.systemException.equals(that.systemException))
          return false;
      }

      return true;
    }

    public int hashCode() {
      return 0;
    }

    public int compareTo(getRandomAd_result other) {
      if (!getClass().equals(other.getClass())) {
        return getClass().getName().compareTo(other.getClass().getName());
      }

      int lastComparison = 0;
      getRandomAd_result typedOther = (getRandomAd_result)other;

      lastComparison = Boolean.valueOf(isSetSuccess()).compareTo(isSetSuccess());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(success, typedOther.success);
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = Boolean.valueOf(isSetUserException()).compareTo(isSetUserException());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(userException, typedOther.userException);
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = Boolean.valueOf(isSetSystemException()).compareTo(isSetSystemException());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(systemException, typedOther.systemException);
      if (lastComparison != 0) {
        return lastComparison;
      }
      return 0;
    }

    public void read(TProtocol iprot) throws TException {
      TField field;
      iprot.readStructBegin();
      while (true)
      {
        field = iprot.readFieldBegin();
        if (field.type == TType.STOP) { 
          break;
        }
        _Fields fieldId = _Fields.findByThriftId(field.id);
        if (fieldId == null) {
          TProtocolUtil.skip(iprot, field.type);
        } else {
          switch (fieldId) {
            case SUCCESS:
              if (field.type == TType.STRUCT) {
                this.success = new com.evernote.edam.type.Ad();
                this.success.read(iprot);
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
            case USER_EXCEPTION:
              if (field.type == TType.STRUCT) {
                this.userException = new com.evernote.edam.error.EDAMUserException();
                this.userException.read(iprot);
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
            case SYSTEM_EXCEPTION:
              if (field.type == TType.STRUCT) {
                this.systemException = new com.evernote.edam.error.EDAMSystemException();
                this.systemException.read(iprot);
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
          }
          iprot.readFieldEnd();
        }
      }
      iprot.readStructEnd();
      validate();
    }

    public void write(TProtocol oprot) throws TException {
      oprot.writeStructBegin(STRUCT_DESC);

      if (this.isSetSuccess()) {
        oprot.writeFieldBegin(SUCCESS_FIELD_DESC);
        this.success.write(oprot);
        oprot.writeFieldEnd();
      } else if (this.isSetUserException()) {
        oprot.writeFieldBegin(USER_EXCEPTION_FIELD_DESC);
        this.userException.write(oprot);
        oprot.writeFieldEnd();
      } else if (this.isSetSystemException()) {
        oprot.writeFieldBegin(SYSTEM_EXCEPTION_FIELD_DESC);
        this.systemException.write(oprot);
        oprot.writeFieldEnd();
      }
      oprot.writeFieldStop();
      oprot.writeStructEnd();
    }

    public String toString() {
      StringBuilder sb = new StringBuilder("getRandomAd_result(");
      boolean first = true;

      sb.append("success:");
      if (this.success == null) {
        sb.append("null");
      } else {
        sb.append(this.success);
      }
      first = false;
      if (!first) sb.append(", ");
      sb.append("userException:");
      if (this.userException == null) {
        sb.append("null");
      } else {
        sb.append(this.userException);
      }
      first = false;
      if (!first) sb.append(", ");
      sb.append("systemException:");
      if (this.systemException == null) {
        sb.append("null");
      } else {
        sb.append(this.systemException);
      }
      first = false;
      sb.append(")");
      return sb.toString();
    }

    public void validate() throws TException {
      // check for required fields
    }

  }

  public static class getPublicNotebook_args implements TBase<getPublicNotebook_args._Fields>, java.io.Serializable, Cloneable, Comparable<getPublicNotebook_args>   {
    private static final TStruct STRUCT_DESC = new TStruct("getPublicNotebook_args");

    private static final TField USER_ID_FIELD_DESC = new TField("userId", TType.I32, (short)1);
    private static final TField PUBLIC_URI_FIELD_DESC = new TField("publicUri", TType.STRING, (short)2);

    private int userId;
    private String publicUri;

    /** The set of fields this struct contains, along with convenience methods for finding and manipulating them. */
    public enum _Fields implements TFieldIdEnum {
      USER_ID((short)1, "userId"),
      PUBLIC_URI((short)2, "publicUri");

      private static final Map<Integer, _Fields> byId = new HashMap<Integer, _Fields>();
      private static final Map<String, _Fields> byName = new HashMap<String, _Fields>();

      static {
        for (_Fields field : EnumSet.allOf(_Fields.class)) {
          byId.put((int)field._thriftId, field);
          byName.put(field.getFieldName(), field);
        }
      }

      /**
       * Find the _Fields constant that matches fieldId, or null if its not found.
       */
      public static _Fields findByThriftId(int fieldId) {
        return byId.get(fieldId);
      }

      /**
       * Find the _Fields constant that matches fieldId, throwing an exception
       * if it is not found.
       */
      public static _Fields findByThriftIdOrThrow(int fieldId) {
        _Fields fields = findByThriftId(fieldId);
        if (fields == null) throw new IllegalArgumentException("Field " + fieldId + " doesn't exist!");
        return fields;
      }

      /**
       * Find the _Fields constant that matches name, or null if its not found.
       */
      public static _Fields findByName(String name) {
        return byName.get(name);
      }

      private final short _thriftId;
      private final String _fieldName;

      _Fields(short thriftId, String fieldName) {
        _thriftId = thriftId;
        _fieldName = fieldName;
      }

      public short getThriftFieldId() {
        return _thriftId;
      }

      public String getFieldName() {
        return _fieldName;
      }
    }

    // isset id assignments
    private static final int __USERID_ISSET_ID = 0;
    private BitSet __isset_bit_vector = new BitSet(1);

    public static final Map<_Fields, FieldMetaData> metaDataMap = Collections.unmodifiableMap(new EnumMap<_Fields, FieldMetaData>(_Fields.class) {{
      put(_Fields.USER_ID, new FieldMetaData("userId", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.I32)));
      put(_Fields.PUBLIC_URI, new FieldMetaData("publicUri", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.STRING)));
    }});

    static {
      FieldMetaData.addStructMetaDataMap(getPublicNotebook_args.class, metaDataMap);
    }

    public getPublicNotebook_args() {
    }

    public getPublicNotebook_args(
      int userId,
      String publicUri)
    {
      this();
      this.userId = userId;
      setUserIdIsSet(true);
      this.publicUri = publicUri;
    }

    /**
     * Performs a deep copy on <i>other</i>.
     */
    public getPublicNotebook_args(getPublicNotebook_args other) {
      __isset_bit_vector.clear();
      __isset_bit_vector.or(other.__isset_bit_vector);
      this.userId = other.userId;
      if (other.isSetPublicUri()) {
        this.publicUri = other.publicUri;
      }
    }

    public getPublicNotebook_args deepCopy() {
      return new getPublicNotebook_args(this);
    }

    @Deprecated
    public getPublicNotebook_args clone() {
      return new getPublicNotebook_args(this);
    }

    public int getUserId() {
      return this.userId;
    }

    public void setUserId(int userId) {
      this.userId = userId;
      setUserIdIsSet(true);
    }

    public void unsetUserId() {
      __isset_bit_vector.clear(__USERID_ISSET_ID);
    }

    /** Returns true if field userId is set (has been asigned a value) and false otherwise */
    public boolean isSetUserId() {
      return __isset_bit_vector.get(__USERID_ISSET_ID);
    }

    public void setUserIdIsSet(boolean value) {
      __isset_bit_vector.set(__USERID_ISSET_ID, value);
    }

    public String getPublicUri() {
      return this.publicUri;
    }

    public void setPublicUri(String publicUri) {
      this.publicUri = publicUri;
    }

    public void unsetPublicUri() {
      this.publicUri = null;
    }

    /** Returns true if field publicUri is set (has been asigned a value) and false otherwise */
    public boolean isSetPublicUri() {
      return this.publicUri != null;
    }

    public void setPublicUriIsSet(boolean value) {
      if (!value) {
        this.publicUri = null;
      }
    }

    public void setFieldValue(_Fields field, Object value) {
      switch (field) {
      case USER_ID:
        if (value == null) {
          unsetUserId();
        } else {
          setUserId((Integer)value);
        }
        break;

      case PUBLIC_URI:
        if (value == null) {
          unsetPublicUri();
        } else {
          setPublicUri((String)value);
        }
        break;

      }
    }

    public void setFieldValue(int fieldID, Object value) {
      setFieldValue(_Fields.findByThriftIdOrThrow(fieldID), value);
    }

    public Object getFieldValue(_Fields field) {
      switch (field) {
      case USER_ID:
        return new Integer(getUserId());

      case PUBLIC_URI:
        return getPublicUri();

      }
      throw new IllegalStateException();
    }

    public Object getFieldValue(int fieldId) {
      return getFieldValue(_Fields.findByThriftIdOrThrow(fieldId));
    }

    /** Returns true if field corresponding to fieldID is set (has been asigned a value) and false otherwise */
    public boolean isSet(_Fields field) {
      switch (field) {
      case USER_ID:
        return isSetUserId();
      case PUBLIC_URI:
        return isSetPublicUri();
      }
      throw new IllegalStateException();
    }

    public boolean isSet(int fieldID) {
      return isSet(_Fields.findByThriftIdOrThrow(fieldID));
    }

    public boolean equals(Object that) {
      if (that == null)
        return false;
      if (that instanceof getPublicNotebook_args)
        return this.equals((getPublicNotebook_args)that);
      return false;
    }

    public boolean equals(getPublicNotebook_args that) {
      if (that == null)
        return false;

      boolean this_present_userId = true;
      boolean that_present_userId = true;
      if (this_present_userId || that_present_userId) {
        if (!(this_present_userId && that_present_userId))
          return false;
        if (this.userId != that.userId)
          return false;
      }

      boolean this_present_publicUri = true && this.isSetPublicUri();
      boolean that_present_publicUri = true && that.isSetPublicUri();
      if (this_present_publicUri || that_present_publicUri) {
        if (!(this_present_publicUri && that_present_publicUri))
          return false;
        if (!this.publicUri.equals(that.publicUri))
          return false;
      }

      return true;
    }

    public int hashCode() {
      return 0;
    }

    public int compareTo(getPublicNotebook_args other) {
      if (!getClass().equals(other.getClass())) {
        return getClass().getName().compareTo(other.getClass().getName());
      }

      int lastComparison = 0;
      getPublicNotebook_args typedOther = (getPublicNotebook_args)other;

      lastComparison = Boolean.valueOf(isSetUserId()).compareTo(isSetUserId());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(userId, typedOther.userId);
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = Boolean.valueOf(isSetPublicUri()).compareTo(isSetPublicUri());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(publicUri, typedOther.publicUri);
      if (lastComparison != 0) {
        return lastComparison;
      }
      return 0;
    }

    public void read(TProtocol iprot) throws TException {
      TField field;
      iprot.readStructBegin();
      while (true)
      {
        field = iprot.readFieldBegin();
        if (field.type == TType.STOP) { 
          break;
        }
        _Fields fieldId = _Fields.findByThriftId(field.id);
        if (fieldId == null) {
          TProtocolUtil.skip(iprot, field.type);
        } else {
          switch (fieldId) {
            case USER_ID:
              if (field.type == TType.I32) {
                this.userId = iprot.readI32();
                setUserIdIsSet(true);
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
            case PUBLIC_URI:
              if (field.type == TType.STRING) {
                this.publicUri = iprot.readString();
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
          }
          iprot.readFieldEnd();
        }
      }
      iprot.readStructEnd();
      validate();
    }

    public void write(TProtocol oprot) throws TException {
      validate();

      oprot.writeStructBegin(STRUCT_DESC);
      oprot.writeFieldBegin(USER_ID_FIELD_DESC);
      oprot.writeI32(this.userId);
      oprot.writeFieldEnd();
      if (this.publicUri != null) {
        oprot.writeFieldBegin(PUBLIC_URI_FIELD_DESC);
        oprot.writeString(this.publicUri);
        oprot.writeFieldEnd();
      }
      oprot.writeFieldStop();
      oprot.writeStructEnd();
    }

    public String toString() {
      StringBuilder sb = new StringBuilder("getPublicNotebook_args(");
      boolean first = true;

      sb.append("userId:");
      sb.append(this.userId);
      first = false;
      if (!first) sb.append(", ");
      sb.append("publicUri:");
      if (this.publicUri == null) {
        sb.append("null");
      } else {
        sb.append(this.publicUri);
      }
      first = false;
      sb.append(")");
      return sb.toString();
    }

    public void validate() throws TException {
      // check for required fields
    }

  }

  public static class getPublicNotebook_result implements TBase<getPublicNotebook_result._Fields>, java.io.Serializable, Cloneable, Comparable<getPublicNotebook_result>   {
    private static final TStruct STRUCT_DESC = new TStruct("getPublicNotebook_result");

    private static final TField SUCCESS_FIELD_DESC = new TField("success", TType.STRUCT, (short)0);
    private static final TField SYSTEM_EXCEPTION_FIELD_DESC = new TField("systemException", TType.STRUCT, (short)1);
    private static final TField NOT_FOUND_EXCEPTION_FIELD_DESC = new TField("notFoundException", TType.STRUCT, (short)2);

    private com.evernote.edam.type.Notebook success;
    private com.evernote.edam.error.EDAMSystemException systemException;
    private com.evernote.edam.error.EDAMNotFoundException notFoundException;

    /** The set of fields this struct contains, along with convenience methods for finding and manipulating them. */
    public enum _Fields implements TFieldIdEnum {
      SUCCESS((short)0, "success"),
      SYSTEM_EXCEPTION((short)1, "systemException"),
      NOT_FOUND_EXCEPTION((short)2, "notFoundException");

      private static final Map<Integer, _Fields> byId = new HashMap<Integer, _Fields>();
      private static final Map<String, _Fields> byName = new HashMap<String, _Fields>();

      static {
        for (_Fields field : EnumSet.allOf(_Fields.class)) {
          byId.put((int)field._thriftId, field);
          byName.put(field.getFieldName(), field);
        }
      }

      /**
       * Find the _Fields constant that matches fieldId, or null if its not found.
       */
      public static _Fields findByThriftId(int fieldId) {
        return byId.get(fieldId);
      }

      /**
       * Find the _Fields constant that matches fieldId, throwing an exception
       * if it is not found.
       */
      public static _Fields findByThriftIdOrThrow(int fieldId) {
        _Fields fields = findByThriftId(fieldId);
        if (fields == null) throw new IllegalArgumentException("Field " + fieldId + " doesn't exist!");
        return fields;
      }

      /**
       * Find the _Fields constant that matches name, or null if its not found.
       */
      public static _Fields findByName(String name) {
        return byName.get(name);
      }

      private final short _thriftId;
      private final String _fieldName;

      _Fields(short thriftId, String fieldName) {
        _thriftId = thriftId;
        _fieldName = fieldName;
      }

      public short getThriftFieldId() {
        return _thriftId;
      }

      public String getFieldName() {
        return _fieldName;
      }
    }

    // isset id assignments

    public static final Map<_Fields, FieldMetaData> metaDataMap = Collections.unmodifiableMap(new EnumMap<_Fields, FieldMetaData>(_Fields.class) {{
      put(_Fields.SUCCESS, new FieldMetaData("success", TFieldRequirementType.DEFAULT, 
          new StructMetaData(TType.STRUCT, com.evernote.edam.type.Notebook.class)));
      put(_Fields.SYSTEM_EXCEPTION, new FieldMetaData("systemException", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.STRUCT)));
      put(_Fields.NOT_FOUND_EXCEPTION, new FieldMetaData("notFoundException", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.STRUCT)));
    }});

    static {
      FieldMetaData.addStructMetaDataMap(getPublicNotebook_result.class, metaDataMap);
    }

    public getPublicNotebook_result() {
    }

    public getPublicNotebook_result(
      com.evernote.edam.type.Notebook success,
      com.evernote.edam.error.EDAMSystemException systemException,
      com.evernote.edam.error.EDAMNotFoundException notFoundException)
    {
      this();
      this.success = success;
      this.systemException = systemException;
      this.notFoundException = notFoundException;
    }

    /**
     * Performs a deep copy on <i>other</i>.
     */
    public getPublicNotebook_result(getPublicNotebook_result other) {
      if (other.isSetSuccess()) {
        this.success = new com.evernote.edam.type.Notebook(other.success);
      }
      if (other.isSetSystemException()) {
        this.systemException = new com.evernote.edam.error.EDAMSystemException(other.systemException);
      }
      if (other.isSetNotFoundException()) {
        this.notFoundException = new com.evernote.edam.error.EDAMNotFoundException(other.notFoundException);
      }
    }

    public getPublicNotebook_result deepCopy() {
      return new getPublicNotebook_result(this);
    }

    @Deprecated
    public getPublicNotebook_result clone() {
      return new getPublicNotebook_result(this);
    }

    public com.evernote.edam.type.Notebook getSuccess() {
      return this.success;
    }

    public void setSuccess(com.evernote.edam.type.Notebook success) {
      this.success = success;
    }

    public void unsetSuccess() {
      this.success = null;
    }

    /** Returns true if field success is set (has been asigned a value) and false otherwise */
    public boolean isSetSuccess() {
      return this.success != null;
    }

    public void setSuccessIsSet(boolean value) {
      if (!value) {
        this.success = null;
      }
    }

    public com.evernote.edam.error.EDAMSystemException getSystemException() {
      return this.systemException;
    }

    public void setSystemException(com.evernote.edam.error.EDAMSystemException systemException) {
      this.systemException = systemException;
    }

    public void unsetSystemException() {
      this.systemException = null;
    }

    /** Returns true if field systemException is set (has been asigned a value) and false otherwise */
    public boolean isSetSystemException() {
      return this.systemException != null;
    }

    public void setSystemExceptionIsSet(boolean value) {
      if (!value) {
        this.systemException = null;
      }
    }

    public com.evernote.edam.error.EDAMNotFoundException getNotFoundException() {
      return this.notFoundException;
    }

    public void setNotFoundException(com.evernote.edam.error.EDAMNotFoundException notFoundException) {
      this.notFoundException = notFoundException;
    }

    public void unsetNotFoundException() {
      this.notFoundException = null;
    }

    /** Returns true if field notFoundException is set (has been asigned a value) and false otherwise */
    public boolean isSetNotFoundException() {
      return this.notFoundException != null;
    }

    public void setNotFoundExceptionIsSet(boolean value) {
      if (!value) {
        this.notFoundException = null;
      }
    }

    public void setFieldValue(_Fields field, Object value) {
      switch (field) {
      case SUCCESS:
        if (value == null) {
          unsetSuccess();
        } else {
          setSuccess((com.evernote.edam.type.Notebook)value);
        }
        break;

      case SYSTEM_EXCEPTION:
        if (value == null) {
          unsetSystemException();
        } else {
          setSystemException((com.evernote.edam.error.EDAMSystemException)value);
        }
        break;

      case NOT_FOUND_EXCEPTION:
        if (value == null) {
          unsetNotFoundException();
        } else {
          setNotFoundException((com.evernote.edam.error.EDAMNotFoundException)value);
        }
        break;

      }
    }

    public void setFieldValue(int fieldID, Object value) {
      setFieldValue(_Fields.findByThriftIdOrThrow(fieldID), value);
    }

    public Object getFieldValue(_Fields field) {
      switch (field) {
      case SUCCESS:
        return getSuccess();

      case SYSTEM_EXCEPTION:
        return getSystemException();

      case NOT_FOUND_EXCEPTION:
        return getNotFoundException();

      }
      throw new IllegalStateException();
    }

    public Object getFieldValue(int fieldId) {
      return getFieldValue(_Fields.findByThriftIdOrThrow(fieldId));
    }

    /** Returns true if field corresponding to fieldID is set (has been asigned a value) and false otherwise */
    public boolean isSet(_Fields field) {
      switch (field) {
      case SUCCESS:
        return isSetSuccess();
      case SYSTEM_EXCEPTION:
        return isSetSystemException();
      case NOT_FOUND_EXCEPTION:
        return isSetNotFoundException();
      }
      throw new IllegalStateException();
    }

    public boolean isSet(int fieldID) {
      return isSet(_Fields.findByThriftIdOrThrow(fieldID));
    }

    public boolean equals(Object that) {
      if (that == null)
        return false;
      if (that instanceof getPublicNotebook_result)
        return this.equals((getPublicNotebook_result)that);
      return false;
    }

    public boolean equals(getPublicNotebook_result that) {
      if (that == null)
        return false;

      boolean this_present_success = true && this.isSetSuccess();
      boolean that_present_success = true && that.isSetSuccess();
      if (this_present_success || that_present_success) {
        if (!(this_present_success && that_present_success))
          return false;
        if (!this.success.equals(that.success))
          return false;
      }

      boolean this_present_systemException = true && this.isSetSystemException();
      boolean that_present_systemException = true && that.isSetSystemException();
      if (this_present_systemException || that_present_systemException) {
        if (!(this_present_systemException && that_present_systemException))
          return false;
        if (!this.systemException.equals(that.systemException))
          return false;
      }

      boolean this_present_notFoundException = true && this.isSetNotFoundException();
      boolean that_present_notFoundException = true && that.isSetNotFoundException();
      if (this_present_notFoundException || that_present_notFoundException) {
        if (!(this_present_notFoundException && that_present_notFoundException))
          return false;
        if (!this.notFoundException.equals(that.notFoundException))
          return false;
      }

      return true;
    }

    public int hashCode() {
      return 0;
    }

    public int compareTo(getPublicNotebook_result other) {
      if (!getClass().equals(other.getClass())) {
        return getClass().getName().compareTo(other.getClass().getName());
      }

      int lastComparison = 0;
      getPublicNotebook_result typedOther = (getPublicNotebook_result)other;

      lastComparison = Boolean.valueOf(isSetSuccess()).compareTo(isSetSuccess());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(success, typedOther.success);
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = Boolean.valueOf(isSetSystemException()).compareTo(isSetSystemException());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(systemException, typedOther.systemException);
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = Boolean.valueOf(isSetNotFoundException()).compareTo(isSetNotFoundException());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(notFoundException, typedOther.notFoundException);
      if (lastComparison != 0) {
        return lastComparison;
      }
      return 0;
    }

    public void read(TProtocol iprot) throws TException {
      TField field;
      iprot.readStructBegin();
      while (true)
      {
        field = iprot.readFieldBegin();
        if (field.type == TType.STOP) { 
          break;
        }
        _Fields fieldId = _Fields.findByThriftId(field.id);
        if (fieldId == null) {
          TProtocolUtil.skip(iprot, field.type);
        } else {
          switch (fieldId) {
            case SUCCESS:
              if (field.type == TType.STRUCT) {
                this.success = new com.evernote.edam.type.Notebook();
                this.success.read(iprot);
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
            case SYSTEM_EXCEPTION:
              if (field.type == TType.STRUCT) {
                this.systemException = new com.evernote.edam.error.EDAMSystemException();
                this.systemException.read(iprot);
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
            case NOT_FOUND_EXCEPTION:
              if (field.type == TType.STRUCT) {
                this.notFoundException = new com.evernote.edam.error.EDAMNotFoundException();
                this.notFoundException.read(iprot);
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
          }
          iprot.readFieldEnd();
        }
      }
      iprot.readStructEnd();
      validate();
    }

    public void write(TProtocol oprot) throws TException {
      oprot.writeStructBegin(STRUCT_DESC);

      if (this.isSetSuccess()) {
        oprot.writeFieldBegin(SUCCESS_FIELD_DESC);
        this.success.write(oprot);
        oprot.writeFieldEnd();
      } else if (this.isSetSystemException()) {
        oprot.writeFieldBegin(SYSTEM_EXCEPTION_FIELD_DESC);
        this.systemException.write(oprot);
        oprot.writeFieldEnd();
      } else if (this.isSetNotFoundException()) {
        oprot.writeFieldBegin(NOT_FOUND_EXCEPTION_FIELD_DESC);
        this.notFoundException.write(oprot);
        oprot.writeFieldEnd();
      }
      oprot.writeFieldStop();
      oprot.writeStructEnd();
    }

    public String toString() {
      StringBuilder sb = new StringBuilder("getPublicNotebook_result(");
      boolean first = true;

      sb.append("success:");
      if (this.success == null) {
        sb.append("null");
      } else {
        sb.append(this.success);
      }
      first = false;
      if (!first) sb.append(", ");
      sb.append("systemException:");
      if (this.systemException == null) {
        sb.append("null");
      } else {
        sb.append(this.systemException);
      }
      first = false;
      if (!first) sb.append(", ");
      sb.append("notFoundException:");
      if (this.notFoundException == null) {
        sb.append("null");
      } else {
        sb.append(this.notFoundException);
      }
      first = false;
      sb.append(")");
      return sb.toString();
    }

    public void validate() throws TException {
      // check for required fields
    }

  }

  public static class createSharedNotebook_args implements TBase<createSharedNotebook_args._Fields>, java.io.Serializable, Cloneable, Comparable<createSharedNotebook_args>   {
    private static final TStruct STRUCT_DESC = new TStruct("createSharedNotebook_args");

    private static final TField AUTHENTICATION_TOKEN_FIELD_DESC = new TField("authenticationToken", TType.STRING, (short)1);
    private static final TField SHARED_NOTEBOOK_FIELD_DESC = new TField("sharedNotebook", TType.STRUCT, (short)2);

    private String authenticationToken;
    private com.evernote.edam.type.SharedNotebook sharedNotebook;

    /** The set of fields this struct contains, along with convenience methods for finding and manipulating them. */
    public enum _Fields implements TFieldIdEnum {
      AUTHENTICATION_TOKEN((short)1, "authenticationToken"),
      SHARED_NOTEBOOK((short)2, "sharedNotebook");

      private static final Map<Integer, _Fields> byId = new HashMap<Integer, _Fields>();
      private static final Map<String, _Fields> byName = new HashMap<String, _Fields>();

      static {
        for (_Fields field : EnumSet.allOf(_Fields.class)) {
          byId.put((int)field._thriftId, field);
          byName.put(field.getFieldName(), field);
        }
      }

      /**
       * Find the _Fields constant that matches fieldId, or null if its not found.
       */
      public static _Fields findByThriftId(int fieldId) {
        return byId.get(fieldId);
      }

      /**
       * Find the _Fields constant that matches fieldId, throwing an exception
       * if it is not found.
       */
      public static _Fields findByThriftIdOrThrow(int fieldId) {
        _Fields fields = findByThriftId(fieldId);
        if (fields == null) throw new IllegalArgumentException("Field " + fieldId + " doesn't exist!");
        return fields;
      }

      /**
       * Find the _Fields constant that matches name, or null if its not found.
       */
      public static _Fields findByName(String name) {
        return byName.get(name);
      }

      private final short _thriftId;
      private final String _fieldName;

      _Fields(short thriftId, String fieldName) {
        _thriftId = thriftId;
        _fieldName = fieldName;
      }

      public short getThriftFieldId() {
        return _thriftId;
      }

      public String getFieldName() {
        return _fieldName;
      }
    }

    // isset id assignments

    public static final Map<_Fields, FieldMetaData> metaDataMap = Collections.unmodifiableMap(new EnumMap<_Fields, FieldMetaData>(_Fields.class) {{
      put(_Fields.AUTHENTICATION_TOKEN, new FieldMetaData("authenticationToken", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.STRING)));
      put(_Fields.SHARED_NOTEBOOK, new FieldMetaData("sharedNotebook", TFieldRequirementType.DEFAULT, 
          new StructMetaData(TType.STRUCT, com.evernote.edam.type.SharedNotebook.class)));
    }});

    static {
      FieldMetaData.addStructMetaDataMap(createSharedNotebook_args.class, metaDataMap);
    }

    public createSharedNotebook_args() {
    }

    public createSharedNotebook_args(
      String authenticationToken,
      com.evernote.edam.type.SharedNotebook sharedNotebook)
    {
      this();
      this.authenticationToken = authenticationToken;
      this.sharedNotebook = sharedNotebook;
    }

    /**
     * Performs a deep copy on <i>other</i>.
     */
    public createSharedNotebook_args(createSharedNotebook_args other) {
      if (other.isSetAuthenticationToken()) {
        this.authenticationToken = other.authenticationToken;
      }
      if (other.isSetSharedNotebook()) {
        this.sharedNotebook = new com.evernote.edam.type.SharedNotebook(other.sharedNotebook);
      }
    }

    public createSharedNotebook_args deepCopy() {
      return new createSharedNotebook_args(this);
    }

    @Deprecated
    public createSharedNotebook_args clone() {
      return new createSharedNotebook_args(this);
    }

    public String getAuthenticationToken() {
      return this.authenticationToken;
    }

    public void setAuthenticationToken(String authenticationToken) {
      this.authenticationToken = authenticationToken;
    }

    public void unsetAuthenticationToken() {
      this.authenticationToken = null;
    }

    /** Returns true if field authenticationToken is set (has been asigned a value) and false otherwise */
    public boolean isSetAuthenticationToken() {
      return this.authenticationToken != null;
    }

    public void setAuthenticationTokenIsSet(boolean value) {
      if (!value) {
        this.authenticationToken = null;
      }
    }

    public com.evernote.edam.type.SharedNotebook getSharedNotebook() {
      return this.sharedNotebook;
    }

    public void setSharedNotebook(com.evernote.edam.type.SharedNotebook sharedNotebook) {
      this.sharedNotebook = sharedNotebook;
    }

    public void unsetSharedNotebook() {
      this.sharedNotebook = null;
    }

    /** Returns true if field sharedNotebook is set (has been asigned a value) and false otherwise */
    public boolean isSetSharedNotebook() {
      return this.sharedNotebook != null;
    }

    public void setSharedNotebookIsSet(boolean value) {
      if (!value) {
        this.sharedNotebook = null;
      }
    }

    public void setFieldValue(_Fields field, Object value) {
      switch (field) {
      case AUTHENTICATION_TOKEN:
        if (value == null) {
          unsetAuthenticationToken();
        } else {
          setAuthenticationToken((String)value);
        }
        break;

      case SHARED_NOTEBOOK:
        if (value == null) {
          unsetSharedNotebook();
        } else {
          setSharedNotebook((com.evernote.edam.type.SharedNotebook)value);
        }
        break;

      }
    }

    public void setFieldValue(int fieldID, Object value) {
      setFieldValue(_Fields.findByThriftIdOrThrow(fieldID), value);
    }

    public Object getFieldValue(_Fields field) {
      switch (field) {
      case AUTHENTICATION_TOKEN:
        return getAuthenticationToken();

      case SHARED_NOTEBOOK:
        return getSharedNotebook();

      }
      throw new IllegalStateException();
    }

    public Object getFieldValue(int fieldId) {
      return getFieldValue(_Fields.findByThriftIdOrThrow(fieldId));
    }

    /** Returns true if field corresponding to fieldID is set (has been asigned a value) and false otherwise */
    public boolean isSet(_Fields field) {
      switch (field) {
      case AUTHENTICATION_TOKEN:
        return isSetAuthenticationToken();
      case SHARED_NOTEBOOK:
        return isSetSharedNotebook();
      }
      throw new IllegalStateException();
    }

    public boolean isSet(int fieldID) {
      return isSet(_Fields.findByThriftIdOrThrow(fieldID));
    }

    public boolean equals(Object that) {
      if (that == null)
        return false;
      if (that instanceof createSharedNotebook_args)
        return this.equals((createSharedNotebook_args)that);
      return false;
    }

    public boolean equals(createSharedNotebook_args that) {
      if (that == null)
        return false;

      boolean this_present_authenticationToken = true && this.isSetAuthenticationToken();
      boolean that_present_authenticationToken = true && that.isSetAuthenticationToken();
      if (this_present_authenticationToken || that_present_authenticationToken) {
        if (!(this_present_authenticationToken && that_present_authenticationToken))
          return false;
        if (!this.authenticationToken.equals(that.authenticationToken))
          return false;
      }

      boolean this_present_sharedNotebook = true && this.isSetSharedNotebook();
      boolean that_present_sharedNotebook = true && that.isSetSharedNotebook();
      if (this_present_sharedNotebook || that_present_sharedNotebook) {
        if (!(this_present_sharedNotebook && that_present_sharedNotebook))
          return false;
        if (!this.sharedNotebook.equals(that.sharedNotebook))
          return false;
      }

      return true;
    }

    public int hashCode() {
      return 0;
    }

    public int compareTo(createSharedNotebook_args other) {
      if (!getClass().equals(other.getClass())) {
        return getClass().getName().compareTo(other.getClass().getName());
      }

      int lastComparison = 0;
      createSharedNotebook_args typedOther = (createSharedNotebook_args)other;

      lastComparison = Boolean.valueOf(isSetAuthenticationToken()).compareTo(isSetAuthenticationToken());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(authenticationToken, typedOther.authenticationToken);
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = Boolean.valueOf(isSetSharedNotebook()).compareTo(isSetSharedNotebook());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(sharedNotebook, typedOther.sharedNotebook);
      if (lastComparison != 0) {
        return lastComparison;
      }
      return 0;
    }

    public void read(TProtocol iprot) throws TException {
      TField field;
      iprot.readStructBegin();
      while (true)
      {
        field = iprot.readFieldBegin();
        if (field.type == TType.STOP) { 
          break;
        }
        _Fields fieldId = _Fields.findByThriftId(field.id);
        if (fieldId == null) {
          TProtocolUtil.skip(iprot, field.type);
        } else {
          switch (fieldId) {
            case AUTHENTICATION_TOKEN:
              if (field.type == TType.STRING) {
                this.authenticationToken = iprot.readString();
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
            case SHARED_NOTEBOOK:
              if (field.type == TType.STRUCT) {
                this.sharedNotebook = new com.evernote.edam.type.SharedNotebook();
                this.sharedNotebook.read(iprot);
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
          }
          iprot.readFieldEnd();
        }
      }
      iprot.readStructEnd();
      validate();
    }

    public void write(TProtocol oprot) throws TException {
      validate();

      oprot.writeStructBegin(STRUCT_DESC);
      if (this.authenticationToken != null) {
        oprot.writeFieldBegin(AUTHENTICATION_TOKEN_FIELD_DESC);
        oprot.writeString(this.authenticationToken);
        oprot.writeFieldEnd();
      }
      if (this.sharedNotebook != null) {
        oprot.writeFieldBegin(SHARED_NOTEBOOK_FIELD_DESC);
        this.sharedNotebook.write(oprot);
        oprot.writeFieldEnd();
      }
      oprot.writeFieldStop();
      oprot.writeStructEnd();
    }

    public String toString() {
      StringBuilder sb = new StringBuilder("createSharedNotebook_args(");
      boolean first = true;

      sb.append("authenticationToken:");
      if (this.authenticationToken == null) {
        sb.append("null");
      } else {
        sb.append(this.authenticationToken);
      }
      first = false;
      if (!first) sb.append(", ");
      sb.append("sharedNotebook:");
      if (this.sharedNotebook == null) {
        sb.append("null");
      } else {
        sb.append(this.sharedNotebook);
      }
      first = false;
      sb.append(")");
      return sb.toString();
    }

    public void validate() throws TException {
      // check for required fields
    }

  }

  public static class createSharedNotebook_result implements TBase<createSharedNotebook_result._Fields>, java.io.Serializable, Cloneable, Comparable<createSharedNotebook_result>   {
    private static final TStruct STRUCT_DESC = new TStruct("createSharedNotebook_result");

    private static final TField SUCCESS_FIELD_DESC = new TField("success", TType.STRUCT, (short)0);
    private static final TField USER_EXCEPTION_FIELD_DESC = new TField("userException", TType.STRUCT, (short)1);
    private static final TField NOT_FOUND_EXCEPTION_FIELD_DESC = new TField("notFoundException", TType.STRUCT, (short)2);
    private static final TField SYSTEM_EXCEPTION_FIELD_DESC = new TField("systemException", TType.STRUCT, (short)3);

    private com.evernote.edam.type.SharedNotebook success;
    private com.evernote.edam.error.EDAMUserException userException;
    private com.evernote.edam.error.EDAMNotFoundException notFoundException;
    private com.evernote.edam.error.EDAMSystemException systemException;

    /** The set of fields this struct contains, along with convenience methods for finding and manipulating them. */
    public enum _Fields implements TFieldIdEnum {
      SUCCESS((short)0, "success"),
      USER_EXCEPTION((short)1, "userException"),
      NOT_FOUND_EXCEPTION((short)2, "notFoundException"),
      SYSTEM_EXCEPTION((short)3, "systemException");

      private static final Map<Integer, _Fields> byId = new HashMap<Integer, _Fields>();
      private static final Map<String, _Fields> byName = new HashMap<String, _Fields>();

      static {
        for (_Fields field : EnumSet.allOf(_Fields.class)) {
          byId.put((int)field._thriftId, field);
          byName.put(field.getFieldName(), field);
        }
      }

      /**
       * Find the _Fields constant that matches fieldId, or null if its not found.
       */
      public static _Fields findByThriftId(int fieldId) {
        return byId.get(fieldId);
      }

      /**
       * Find the _Fields constant that matches fieldId, throwing an exception
       * if it is not found.
       */
      public static _Fields findByThriftIdOrThrow(int fieldId) {
        _Fields fields = findByThriftId(fieldId);
        if (fields == null) throw new IllegalArgumentException("Field " + fieldId + " doesn't exist!");
        return fields;
      }

      /**
       * Find the _Fields constant that matches name, or null if its not found.
       */
      public static _Fields findByName(String name) {
        return byName.get(name);
      }

      private final short _thriftId;
      private final String _fieldName;

      _Fields(short thriftId, String fieldName) {
        _thriftId = thriftId;
        _fieldName = fieldName;
      }

      public short getThriftFieldId() {
        return _thriftId;
      }

      public String getFieldName() {
        return _fieldName;
      }
    }

    // isset id assignments

    public static final Map<_Fields, FieldMetaData> metaDataMap = Collections.unmodifiableMap(new EnumMap<_Fields, FieldMetaData>(_Fields.class) {{
      put(_Fields.SUCCESS, new FieldMetaData("success", TFieldRequirementType.DEFAULT, 
          new StructMetaData(TType.STRUCT, com.evernote.edam.type.SharedNotebook.class)));
      put(_Fields.USER_EXCEPTION, new FieldMetaData("userException", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.STRUCT)));
      put(_Fields.NOT_FOUND_EXCEPTION, new FieldMetaData("notFoundException", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.STRUCT)));
      put(_Fields.SYSTEM_EXCEPTION, new FieldMetaData("systemException", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.STRUCT)));
    }});

    static {
      FieldMetaData.addStructMetaDataMap(createSharedNotebook_result.class, metaDataMap);
    }

    public createSharedNotebook_result() {
    }

    public createSharedNotebook_result(
      com.evernote.edam.type.SharedNotebook success,
      com.evernote.edam.error.EDAMUserException userException,
      com.evernote.edam.error.EDAMNotFoundException notFoundException,
      com.evernote.edam.error.EDAMSystemException systemException)
    {
      this();
      this.success = success;
      this.userException = userException;
      this.notFoundException = notFoundException;
      this.systemException = systemException;
    }

    /**
     * Performs a deep copy on <i>other</i>.
     */
    public createSharedNotebook_result(createSharedNotebook_result other) {
      if (other.isSetSuccess()) {
        this.success = new com.evernote.edam.type.SharedNotebook(other.success);
      }
      if (other.isSetUserException()) {
        this.userException = new com.evernote.edam.error.EDAMUserException(other.userException);
      }
      if (other.isSetNotFoundException()) {
        this.notFoundException = new com.evernote.edam.error.EDAMNotFoundException(other.notFoundException);
      }
      if (other.isSetSystemException()) {
        this.systemException = new com.evernote.edam.error.EDAMSystemException(other.systemException);
      }
    }

    public createSharedNotebook_result deepCopy() {
      return new createSharedNotebook_result(this);
    }

    @Deprecated
    public createSharedNotebook_result clone() {
      return new createSharedNotebook_result(this);
    }

    public com.evernote.edam.type.SharedNotebook getSuccess() {
      return this.success;
    }

    public void setSuccess(com.evernote.edam.type.SharedNotebook success) {
      this.success = success;
    }

    public void unsetSuccess() {
      this.success = null;
    }

    /** Returns true if field success is set (has been asigned a value) and false otherwise */
    public boolean isSetSuccess() {
      return this.success != null;
    }

    public void setSuccessIsSet(boolean value) {
      if (!value) {
        this.success = null;
      }
    }

    public com.evernote.edam.error.EDAMUserException getUserException() {
      return this.userException;
    }

    public void setUserException(com.evernote.edam.error.EDAMUserException userException) {
      this.userException = userException;
    }

    public void unsetUserException() {
      this.userException = null;
    }

    /** Returns true if field userException is set (has been asigned a value) and false otherwise */
    public boolean isSetUserException() {
      return this.userException != null;
    }

    public void setUserExceptionIsSet(boolean value) {
      if (!value) {
        this.userException = null;
      }
    }

    public com.evernote.edam.error.EDAMNotFoundException getNotFoundException() {
      return this.notFoundException;
    }

    public void setNotFoundException(com.evernote.edam.error.EDAMNotFoundException notFoundException) {
      this.notFoundException = notFoundException;
    }

    public void unsetNotFoundException() {
      this.notFoundException = null;
    }

    /** Returns true if field notFoundException is set (has been asigned a value) and false otherwise */
    public boolean isSetNotFoundException() {
      return this.notFoundException != null;
    }

    public void setNotFoundExceptionIsSet(boolean value) {
      if (!value) {
        this.notFoundException = null;
      }
    }

    public com.evernote.edam.error.EDAMSystemException getSystemException() {
      return this.systemException;
    }

    public void setSystemException(com.evernote.edam.error.EDAMSystemException systemException) {
      this.systemException = systemException;
    }

    public void unsetSystemException() {
      this.systemException = null;
    }

    /** Returns true if field systemException is set (has been asigned a value) and false otherwise */
    public boolean isSetSystemException() {
      return this.systemException != null;
    }

    public void setSystemExceptionIsSet(boolean value) {
      if (!value) {
        this.systemException = null;
      }
    }

    public void setFieldValue(_Fields field, Object value) {
      switch (field) {
      case SUCCESS:
        if (value == null) {
          unsetSuccess();
        } else {
          setSuccess((com.evernote.edam.type.SharedNotebook)value);
        }
        break;

      case USER_EXCEPTION:
        if (value == null) {
          unsetUserException();
        } else {
          setUserException((com.evernote.edam.error.EDAMUserException)value);
        }
        break;

      case NOT_FOUND_EXCEPTION:
        if (value == null) {
          unsetNotFoundException();
        } else {
          setNotFoundException((com.evernote.edam.error.EDAMNotFoundException)value);
        }
        break;

      case SYSTEM_EXCEPTION:
        if (value == null) {
          unsetSystemException();
        } else {
          setSystemException((com.evernote.edam.error.EDAMSystemException)value);
        }
        break;

      }
    }

    public void setFieldValue(int fieldID, Object value) {
      setFieldValue(_Fields.findByThriftIdOrThrow(fieldID), value);
    }

    public Object getFieldValue(_Fields field) {
      switch (field) {
      case SUCCESS:
        return getSuccess();

      case USER_EXCEPTION:
        return getUserException();

      case NOT_FOUND_EXCEPTION:
        return getNotFoundException();

      case SYSTEM_EXCEPTION:
        return getSystemException();

      }
      throw new IllegalStateException();
    }

    public Object getFieldValue(int fieldId) {
      return getFieldValue(_Fields.findByThriftIdOrThrow(fieldId));
    }

    /** Returns true if field corresponding to fieldID is set (has been asigned a value) and false otherwise */
    public boolean isSet(_Fields field) {
      switch (field) {
      case SUCCESS:
        return isSetSuccess();
      case USER_EXCEPTION:
        return isSetUserException();
      case NOT_FOUND_EXCEPTION:
        return isSetNotFoundException();
      case SYSTEM_EXCEPTION:
        return isSetSystemException();
      }
      throw new IllegalStateException();
    }

    public boolean isSet(int fieldID) {
      return isSet(_Fields.findByThriftIdOrThrow(fieldID));
    }

    public boolean equals(Object that) {
      if (that == null)
        return false;
      if (that instanceof createSharedNotebook_result)
        return this.equals((createSharedNotebook_result)that);
      return false;
    }

    public boolean equals(createSharedNotebook_result that) {
      if (that == null)
        return false;

      boolean this_present_success = true && this.isSetSuccess();
      boolean that_present_success = true && that.isSetSuccess();
      if (this_present_success || that_present_success) {
        if (!(this_present_success && that_present_success))
          return false;
        if (!this.success.equals(that.success))
          return false;
      }

      boolean this_present_userException = true && this.isSetUserException();
      boolean that_present_userException = true && that.isSetUserException();
      if (this_present_userException || that_present_userException) {
        if (!(this_present_userException && that_present_userException))
          return false;
        if (!this.userException.equals(that.userException))
          return false;
      }

      boolean this_present_notFoundException = true && this.isSetNotFoundException();
      boolean that_present_notFoundException = true && that.isSetNotFoundException();
      if (this_present_notFoundException || that_present_notFoundException) {
        if (!(this_present_notFoundException && that_present_notFoundException))
          return false;
        if (!this.notFoundException.equals(that.notFoundException))
          return false;
      }

      boolean this_present_systemException = true && this.isSetSystemException();
      boolean that_present_systemException = true && that.isSetSystemException();
      if (this_present_systemException || that_present_systemException) {
        if (!(this_present_systemException && that_present_systemException))
          return false;
        if (!this.systemException.equals(that.systemException))
          return false;
      }

      return true;
    }

    public int hashCode() {
      return 0;
    }

    public int compareTo(createSharedNotebook_result other) {
      if (!getClass().equals(other.getClass())) {
        return getClass().getName().compareTo(other.getClass().getName());
      }

      int lastComparison = 0;
      createSharedNotebook_result typedOther = (createSharedNotebook_result)other;

      lastComparison = Boolean.valueOf(isSetSuccess()).compareTo(isSetSuccess());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(success, typedOther.success);
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = Boolean.valueOf(isSetUserException()).compareTo(isSetUserException());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(userException, typedOther.userException);
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = Boolean.valueOf(isSetNotFoundException()).compareTo(isSetNotFoundException());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(notFoundException, typedOther.notFoundException);
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = Boolean.valueOf(isSetSystemException()).compareTo(isSetSystemException());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(systemException, typedOther.systemException);
      if (lastComparison != 0) {
        return lastComparison;
      }
      return 0;
    }

    public void read(TProtocol iprot) throws TException {
      TField field;
      iprot.readStructBegin();
      while (true)
      {
        field = iprot.readFieldBegin();
        if (field.type == TType.STOP) { 
          break;
        }
        _Fields fieldId = _Fields.findByThriftId(field.id);
        if (fieldId == null) {
          TProtocolUtil.skip(iprot, field.type);
        } else {
          switch (fieldId) {
            case SUCCESS:
              if (field.type == TType.STRUCT) {
                this.success = new com.evernote.edam.type.SharedNotebook();
                this.success.read(iprot);
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
            case USER_EXCEPTION:
              if (field.type == TType.STRUCT) {
                this.userException = new com.evernote.edam.error.EDAMUserException();
                this.userException.read(iprot);
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
            case NOT_FOUND_EXCEPTION:
              if (field.type == TType.STRUCT) {
                this.notFoundException = new com.evernote.edam.error.EDAMNotFoundException();
                this.notFoundException.read(iprot);
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
            case SYSTEM_EXCEPTION:
              if (field.type == TType.STRUCT) {
                this.systemException = new com.evernote.edam.error.EDAMSystemException();
                this.systemException.read(iprot);
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
          }
          iprot.readFieldEnd();
        }
      }
      iprot.readStructEnd();
      validate();
    }

    public void write(TProtocol oprot) throws TException {
      oprot.writeStructBegin(STRUCT_DESC);

      if (this.isSetSuccess()) {
        oprot.writeFieldBegin(SUCCESS_FIELD_DESC);
        this.success.write(oprot);
        oprot.writeFieldEnd();
      } else if (this.isSetUserException()) {
        oprot.writeFieldBegin(USER_EXCEPTION_FIELD_DESC);
        this.userException.write(oprot);
        oprot.writeFieldEnd();
      } else if (this.isSetNotFoundException()) {
        oprot.writeFieldBegin(NOT_FOUND_EXCEPTION_FIELD_DESC);
        this.notFoundException.write(oprot);
        oprot.writeFieldEnd();
      } else if (this.isSetSystemException()) {
        oprot.writeFieldBegin(SYSTEM_EXCEPTION_FIELD_DESC);
        this.systemException.write(oprot);
        oprot.writeFieldEnd();
      }
      oprot.writeFieldStop();
      oprot.writeStructEnd();
    }

    public String toString() {
      StringBuilder sb = new StringBuilder("createSharedNotebook_result(");
      boolean first = true;

      sb.append("success:");
      if (this.success == null) {
        sb.append("null");
      } else {
        sb.append(this.success);
      }
      first = false;
      if (!first) sb.append(", ");
      sb.append("userException:");
      if (this.userException == null) {
        sb.append("null");
      } else {
        sb.append(this.userException);
      }
      first = false;
      if (!first) sb.append(", ");
      sb.append("notFoundException:");
      if (this.notFoundException == null) {
        sb.append("null");
      } else {
        sb.append(this.notFoundException);
      }
      first = false;
      if (!first) sb.append(", ");
      sb.append("systemException:");
      if (this.systemException == null) {
        sb.append("null");
      } else {
        sb.append(this.systemException);
      }
      first = false;
      sb.append(")");
      return sb.toString();
    }

    public void validate() throws TException {
      // check for required fields
    }

  }

  public static class listSharedNotebooks_args implements TBase<listSharedNotebooks_args._Fields>, java.io.Serializable, Cloneable, Comparable<listSharedNotebooks_args>   {
    private static final TStruct STRUCT_DESC = new TStruct("listSharedNotebooks_args");

    private static final TField AUTHENTICATION_TOKEN_FIELD_DESC = new TField("authenticationToken", TType.STRING, (short)1);

    private String authenticationToken;

    /** The set of fields this struct contains, along with convenience methods for finding and manipulating them. */
    public enum _Fields implements TFieldIdEnum {
      AUTHENTICATION_TOKEN((short)1, "authenticationToken");

      private static final Map<Integer, _Fields> byId = new HashMap<Integer, _Fields>();
      private static final Map<String, _Fields> byName = new HashMap<String, _Fields>();

      static {
        for (_Fields field : EnumSet.allOf(_Fields.class)) {
          byId.put((int)field._thriftId, field);
          byName.put(field.getFieldName(), field);
        }
      }

      /**
       * Find the _Fields constant that matches fieldId, or null if its not found.
       */
      public static _Fields findByThriftId(int fieldId) {
        return byId.get(fieldId);
      }

      /**
       * Find the _Fields constant that matches fieldId, throwing an exception
       * if it is not found.
       */
      public static _Fields findByThriftIdOrThrow(int fieldId) {
        _Fields fields = findByThriftId(fieldId);
        if (fields == null) throw new IllegalArgumentException("Field " + fieldId + " doesn't exist!");
        return fields;
      }

      /**
       * Find the _Fields constant that matches name, or null if its not found.
       */
      public static _Fields findByName(String name) {
        return byName.get(name);
      }

      private final short _thriftId;
      private final String _fieldName;

      _Fields(short thriftId, String fieldName) {
        _thriftId = thriftId;
        _fieldName = fieldName;
      }

      public short getThriftFieldId() {
        return _thriftId;
      }

      public String getFieldName() {
        return _fieldName;
      }
    }

    // isset id assignments

    public static final Map<_Fields, FieldMetaData> metaDataMap = Collections.unmodifiableMap(new EnumMap<_Fields, FieldMetaData>(_Fields.class) {{
      put(_Fields.AUTHENTICATION_TOKEN, new FieldMetaData("authenticationToken", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.STRING)));
    }});

    static {
      FieldMetaData.addStructMetaDataMap(listSharedNotebooks_args.class, metaDataMap);
    }

    public listSharedNotebooks_args() {
    }

    public listSharedNotebooks_args(
      String authenticationToken)
    {
      this();
      this.authenticationToken = authenticationToken;
    }

    /**
     * Performs a deep copy on <i>other</i>.
     */
    public listSharedNotebooks_args(listSharedNotebooks_args other) {
      if (other.isSetAuthenticationToken()) {
        this.authenticationToken = other.authenticationToken;
      }
    }

    public listSharedNotebooks_args deepCopy() {
      return new listSharedNotebooks_args(this);
    }

    @Deprecated
    public listSharedNotebooks_args clone() {
      return new listSharedNotebooks_args(this);
    }

    public String getAuthenticationToken() {
      return this.authenticationToken;
    }

    public void setAuthenticationToken(String authenticationToken) {
      this.authenticationToken = authenticationToken;
    }

    public void unsetAuthenticationToken() {
      this.authenticationToken = null;
    }

    /** Returns true if field authenticationToken is set (has been asigned a value) and false otherwise */
    public boolean isSetAuthenticationToken() {
      return this.authenticationToken != null;
    }

    public void setAuthenticationTokenIsSet(boolean value) {
      if (!value) {
        this.authenticationToken = null;
      }
    }

    public void setFieldValue(_Fields field, Object value) {
      switch (field) {
      case AUTHENTICATION_TOKEN:
        if (value == null) {
          unsetAuthenticationToken();
        } else {
          setAuthenticationToken((String)value);
        }
        break;

      }
    }

    public void setFieldValue(int fieldID, Object value) {
      setFieldValue(_Fields.findByThriftIdOrThrow(fieldID), value);
    }

    public Object getFieldValue(_Fields field) {
      switch (field) {
      case AUTHENTICATION_TOKEN:
        return getAuthenticationToken();

      }
      throw new IllegalStateException();
    }

    public Object getFieldValue(int fieldId) {
      return getFieldValue(_Fields.findByThriftIdOrThrow(fieldId));
    }

    /** Returns true if field corresponding to fieldID is set (has been asigned a value) and false otherwise */
    public boolean isSet(_Fields field) {
      switch (field) {
      case AUTHENTICATION_TOKEN:
        return isSetAuthenticationToken();
      }
      throw new IllegalStateException();
    }

    public boolean isSet(int fieldID) {
      return isSet(_Fields.findByThriftIdOrThrow(fieldID));
    }

    public boolean equals(Object that) {
      if (that == null)
        return false;
      if (that instanceof listSharedNotebooks_args)
        return this.equals((listSharedNotebooks_args)that);
      return false;
    }

    public boolean equals(listSharedNotebooks_args that) {
      if (that == null)
        return false;

      boolean this_present_authenticationToken = true && this.isSetAuthenticationToken();
      boolean that_present_authenticationToken = true && that.isSetAuthenticationToken();
      if (this_present_authenticationToken || that_present_authenticationToken) {
        if (!(this_present_authenticationToken && that_present_authenticationToken))
          return false;
        if (!this.authenticationToken.equals(that.authenticationToken))
          return false;
      }

      return true;
    }

    public int hashCode() {
      return 0;
    }

    public int compareTo(listSharedNotebooks_args other) {
      if (!getClass().equals(other.getClass())) {
        return getClass().getName().compareTo(other.getClass().getName());
      }

      int lastComparison = 0;
      listSharedNotebooks_args typedOther = (listSharedNotebooks_args)other;

      lastComparison = Boolean.valueOf(isSetAuthenticationToken()).compareTo(isSetAuthenticationToken());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(authenticationToken, typedOther.authenticationToken);
      if (lastComparison != 0) {
        return lastComparison;
      }
      return 0;
    }

    public void read(TProtocol iprot) throws TException {
      TField field;
      iprot.readStructBegin();
      while (true)
      {
        field = iprot.readFieldBegin();
        if (field.type == TType.STOP) { 
          break;
        }
        _Fields fieldId = _Fields.findByThriftId(field.id);
        if (fieldId == null) {
          TProtocolUtil.skip(iprot, field.type);
        } else {
          switch (fieldId) {
            case AUTHENTICATION_TOKEN:
              if (field.type == TType.STRING) {
                this.authenticationToken = iprot.readString();
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
          }
          iprot.readFieldEnd();
        }
      }
      iprot.readStructEnd();
      validate();
    }

    public void write(TProtocol oprot) throws TException {
      validate();

      oprot.writeStructBegin(STRUCT_DESC);
      if (this.authenticationToken != null) {
        oprot.writeFieldBegin(AUTHENTICATION_TOKEN_FIELD_DESC);
        oprot.writeString(this.authenticationToken);
        oprot.writeFieldEnd();
      }
      oprot.writeFieldStop();
      oprot.writeStructEnd();
    }

    public String toString() {
      StringBuilder sb = new StringBuilder("listSharedNotebooks_args(");
      boolean first = true;

      sb.append("authenticationToken:");
      if (this.authenticationToken == null) {
        sb.append("null");
      } else {
        sb.append(this.authenticationToken);
      }
      first = false;
      sb.append(")");
      return sb.toString();
    }

    public void validate() throws TException {
      // check for required fields
    }

  }

  public static class listSharedNotebooks_result implements TBase<listSharedNotebooks_result._Fields>, java.io.Serializable, Cloneable, Comparable<listSharedNotebooks_result>   {
    private static final TStruct STRUCT_DESC = new TStruct("listSharedNotebooks_result");

    private static final TField SUCCESS_FIELD_DESC = new TField("success", TType.LIST, (short)0);
    private static final TField USER_EXCEPTION_FIELD_DESC = new TField("userException", TType.STRUCT, (short)1);
    private static final TField NOT_FOUND_EXCEPTION_FIELD_DESC = new TField("notFoundException", TType.STRUCT, (short)2);
    private static final TField SYSTEM_EXCEPTION_FIELD_DESC = new TField("systemException", TType.STRUCT, (short)3);

    private List<com.evernote.edam.type.SharedNotebook> success;
    private com.evernote.edam.error.EDAMUserException userException;
    private com.evernote.edam.error.EDAMNotFoundException notFoundException;
    private com.evernote.edam.error.EDAMSystemException systemException;

    /** The set of fields this struct contains, along with convenience methods for finding and manipulating them. */
    public enum _Fields implements TFieldIdEnum {
      SUCCESS((short)0, "success"),
      USER_EXCEPTION((short)1, "userException"),
      NOT_FOUND_EXCEPTION((short)2, "notFoundException"),
      SYSTEM_EXCEPTION((short)3, "systemException");

      private static final Map<Integer, _Fields> byId = new HashMap<Integer, _Fields>();
      private static final Map<String, _Fields> byName = new HashMap<String, _Fields>();

      static {
        for (_Fields field : EnumSet.allOf(_Fields.class)) {
          byId.put((int)field._thriftId, field);
          byName.put(field.getFieldName(), field);
        }
      }

      /**
       * Find the _Fields constant that matches fieldId, or null if its not found.
       */
      public static _Fields findByThriftId(int fieldId) {
        return byId.get(fieldId);
      }

      /**
       * Find the _Fields constant that matches fieldId, throwing an exception
       * if it is not found.
       */
      public static _Fields findByThriftIdOrThrow(int fieldId) {
        _Fields fields = findByThriftId(fieldId);
        if (fields == null) throw new IllegalArgumentException("Field " + fieldId + " doesn't exist!");
        return fields;
      }

      /**
       * Find the _Fields constant that matches name, or null if its not found.
       */
      public static _Fields findByName(String name) {
        return byName.get(name);
      }

      private final short _thriftId;
      private final String _fieldName;

      _Fields(short thriftId, String fieldName) {
        _thriftId = thriftId;
        _fieldName = fieldName;
      }

      public short getThriftFieldId() {
        return _thriftId;
      }

      public String getFieldName() {
        return _fieldName;
      }
    }

    // isset id assignments

    public static final Map<_Fields, FieldMetaData> metaDataMap = Collections.unmodifiableMap(new EnumMap<_Fields, FieldMetaData>(_Fields.class) {{
      put(_Fields.SUCCESS, new FieldMetaData("success", TFieldRequirementType.DEFAULT, 
          new ListMetaData(TType.LIST, 
              new StructMetaData(TType.STRUCT, com.evernote.edam.type.SharedNotebook.class))));
      put(_Fields.USER_EXCEPTION, new FieldMetaData("userException", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.STRUCT)));
      put(_Fields.NOT_FOUND_EXCEPTION, new FieldMetaData("notFoundException", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.STRUCT)));
      put(_Fields.SYSTEM_EXCEPTION, new FieldMetaData("systemException", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.STRUCT)));
    }});

    static {
      FieldMetaData.addStructMetaDataMap(listSharedNotebooks_result.class, metaDataMap);
    }

    public listSharedNotebooks_result() {
    }

    public listSharedNotebooks_result(
      List<com.evernote.edam.type.SharedNotebook> success,
      com.evernote.edam.error.EDAMUserException userException,
      com.evernote.edam.error.EDAMNotFoundException notFoundException,
      com.evernote.edam.error.EDAMSystemException systemException)
    {
      this();
      this.success = success;
      this.userException = userException;
      this.notFoundException = notFoundException;
      this.systemException = systemException;
    }

    /**
     * Performs a deep copy on <i>other</i>.
     */
    public listSharedNotebooks_result(listSharedNotebooks_result other) {
      if (other.isSetSuccess()) {
        List<com.evernote.edam.type.SharedNotebook> __this__success = new ArrayList<com.evernote.edam.type.SharedNotebook>();
        for (com.evernote.edam.type.SharedNotebook other_element : other.success) {
          __this__success.add(new com.evernote.edam.type.SharedNotebook(other_element));
        }
        this.success = __this__success;
      }
      if (other.isSetUserException()) {
        this.userException = new com.evernote.edam.error.EDAMUserException(other.userException);
      }
      if (other.isSetNotFoundException()) {
        this.notFoundException = new com.evernote.edam.error.EDAMNotFoundException(other.notFoundException);
      }
      if (other.isSetSystemException()) {
        this.systemException = new com.evernote.edam.error.EDAMSystemException(other.systemException);
      }
    }

    public listSharedNotebooks_result deepCopy() {
      return new listSharedNotebooks_result(this);
    }

    @Deprecated
    public listSharedNotebooks_result clone() {
      return new listSharedNotebooks_result(this);
    }

    public int getSuccessSize() {
      return (this.success == null) ? 0 : this.success.size();
    }

    public java.util.Iterator<com.evernote.edam.type.SharedNotebook> getSuccessIterator() {
      return (this.success == null) ? null : this.success.iterator();
    }

    public void addToSuccess(com.evernote.edam.type.SharedNotebook elem) {
      if (this.success == null) {
        this.success = new ArrayList<com.evernote.edam.type.SharedNotebook>();
      }
      this.success.add(elem);
    }

    public List<com.evernote.edam.type.SharedNotebook> getSuccess() {
      return this.success;
    }

    public void setSuccess(List<com.evernote.edam.type.SharedNotebook> success) {
      this.success = success;
    }

    public void unsetSuccess() {
      this.success = null;
    }

    /** Returns true if field success is set (has been asigned a value) and false otherwise */
    public boolean isSetSuccess() {
      return this.success != null;
    }

    public void setSuccessIsSet(boolean value) {
      if (!value) {
        this.success = null;
      }
    }

    public com.evernote.edam.error.EDAMUserException getUserException() {
      return this.userException;
    }

    public void setUserException(com.evernote.edam.error.EDAMUserException userException) {
      this.userException = userException;
    }

    public void unsetUserException() {
      this.userException = null;
    }

    /** Returns true if field userException is set (has been asigned a value) and false otherwise */
    public boolean isSetUserException() {
      return this.userException != null;
    }

    public void setUserExceptionIsSet(boolean value) {
      if (!value) {
        this.userException = null;
      }
    }

    public com.evernote.edam.error.EDAMNotFoundException getNotFoundException() {
      return this.notFoundException;
    }

    public void setNotFoundException(com.evernote.edam.error.EDAMNotFoundException notFoundException) {
      this.notFoundException = notFoundException;
    }

    public void unsetNotFoundException() {
      this.notFoundException = null;
    }

    /** Returns true if field notFoundException is set (has been asigned a value) and false otherwise */
    public boolean isSetNotFoundException() {
      return this.notFoundException != null;
    }

    public void setNotFoundExceptionIsSet(boolean value) {
      if (!value) {
        this.notFoundException = null;
      }
    }

    public com.evernote.edam.error.EDAMSystemException getSystemException() {
      return this.systemException;
    }

    public void setSystemException(com.evernote.edam.error.EDAMSystemException systemException) {
      this.systemException = systemException;
    }

    public void unsetSystemException() {
      this.systemException = null;
    }

    /** Returns true if field systemException is set (has been asigned a value) and false otherwise */
    public boolean isSetSystemException() {
      return this.systemException != null;
    }

    public void setSystemExceptionIsSet(boolean value) {
      if (!value) {
        this.systemException = null;
      }
    }

    public void setFieldValue(_Fields field, Object value) {
      switch (field) {
      case SUCCESS:
        if (value == null) {
          unsetSuccess();
        } else {
          setSuccess((List<com.evernote.edam.type.SharedNotebook>)value);
        }
        break;

      case USER_EXCEPTION:
        if (value == null) {
          unsetUserException();
        } else {
          setUserException((com.evernote.edam.error.EDAMUserException)value);
        }
        break;

      case NOT_FOUND_EXCEPTION:
        if (value == null) {
          unsetNotFoundException();
        } else {
          setNotFoundException((com.evernote.edam.error.EDAMNotFoundException)value);
        }
        break;

      case SYSTEM_EXCEPTION:
        if (value == null) {
          unsetSystemException();
        } else {
          setSystemException((com.evernote.edam.error.EDAMSystemException)value);
        }
        break;

      }
    }

    public void setFieldValue(int fieldID, Object value) {
      setFieldValue(_Fields.findByThriftIdOrThrow(fieldID), value);
    }

    public Object getFieldValue(_Fields field) {
      switch (field) {
      case SUCCESS:
        return getSuccess();

      case USER_EXCEPTION:
        return getUserException();

      case NOT_FOUND_EXCEPTION:
        return getNotFoundException();

      case SYSTEM_EXCEPTION:
        return getSystemException();

      }
      throw new IllegalStateException();
    }

    public Object getFieldValue(int fieldId) {
      return getFieldValue(_Fields.findByThriftIdOrThrow(fieldId));
    }

    /** Returns true if field corresponding to fieldID is set (has been asigned a value) and false otherwise */
    public boolean isSet(_Fields field) {
      switch (field) {
      case SUCCESS:
        return isSetSuccess();
      case USER_EXCEPTION:
        return isSetUserException();
      case NOT_FOUND_EXCEPTION:
        return isSetNotFoundException();
      case SYSTEM_EXCEPTION:
        return isSetSystemException();
      }
      throw new IllegalStateException();
    }

    public boolean isSet(int fieldID) {
      return isSet(_Fields.findByThriftIdOrThrow(fieldID));
    }

    public boolean equals(Object that) {
      if (that == null)
        return false;
      if (that instanceof listSharedNotebooks_result)
        return this.equals((listSharedNotebooks_result)that);
      return false;
    }

    public boolean equals(listSharedNotebooks_result that) {
      if (that == null)
        return false;

      boolean this_present_success = true && this.isSetSuccess();
      boolean that_present_success = true && that.isSetSuccess();
      if (this_present_success || that_present_success) {
        if (!(this_present_success && that_present_success))
          return false;
        if (!this.success.equals(that.success))
          return false;
      }

      boolean this_present_userException = true && this.isSetUserException();
      boolean that_present_userException = true && that.isSetUserException();
      if (this_present_userException || that_present_userException) {
        if (!(this_present_userException && that_present_userException))
          return false;
        if (!this.userException.equals(that.userException))
          return false;
      }

      boolean this_present_notFoundException = true && this.isSetNotFoundException();
      boolean that_present_notFoundException = true && that.isSetNotFoundException();
      if (this_present_notFoundException || that_present_notFoundException) {
        if (!(this_present_notFoundException && that_present_notFoundException))
          return false;
        if (!this.notFoundException.equals(that.notFoundException))
          return false;
      }

      boolean this_present_systemException = true && this.isSetSystemException();
      boolean that_present_systemException = true && that.isSetSystemException();
      if (this_present_systemException || that_present_systemException) {
        if (!(this_present_systemException && that_present_systemException))
          return false;
        if (!this.systemException.equals(that.systemException))
          return false;
      }

      return true;
    }

    public int hashCode() {
      return 0;
    }

    public int compareTo(listSharedNotebooks_result other) {
      if (!getClass().equals(other.getClass())) {
        return getClass().getName().compareTo(other.getClass().getName());
      }

      int lastComparison = 0;
      listSharedNotebooks_result typedOther = (listSharedNotebooks_result)other;

      lastComparison = Boolean.valueOf(isSetSuccess()).compareTo(isSetSuccess());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(success, typedOther.success);
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = Boolean.valueOf(isSetUserException()).compareTo(isSetUserException());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(userException, typedOther.userException);
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = Boolean.valueOf(isSetNotFoundException()).compareTo(isSetNotFoundException());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(notFoundException, typedOther.notFoundException);
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = Boolean.valueOf(isSetSystemException()).compareTo(isSetSystemException());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(systemException, typedOther.systemException);
      if (lastComparison != 0) {
        return lastComparison;
      }
      return 0;
    }

    public void read(TProtocol iprot) throws TException {
      TField field;
      iprot.readStructBegin();
      while (true)
      {
        field = iprot.readFieldBegin();
        if (field.type == TType.STOP) { 
          break;
        }
        _Fields fieldId = _Fields.findByThriftId(field.id);
        if (fieldId == null) {
          TProtocolUtil.skip(iprot, field.type);
        } else {
          switch (fieldId) {
            case SUCCESS:
              if (field.type == TType.LIST) {
                {
                  TList _list111 = iprot.readListBegin();
                  this.success = new ArrayList<com.evernote.edam.type.SharedNotebook>(_list111.size);
                  for (int _i112 = 0; _i112 < _list111.size; ++_i112)
                  {
                    com.evernote.edam.type.SharedNotebook _elem113;
                    _elem113 = new com.evernote.edam.type.SharedNotebook();
                    _elem113.read(iprot);
                    this.success.add(_elem113);
                  }
                  iprot.readListEnd();
                }
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
            case USER_EXCEPTION:
              if (field.type == TType.STRUCT) {
                this.userException = new com.evernote.edam.error.EDAMUserException();
                this.userException.read(iprot);
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
            case NOT_FOUND_EXCEPTION:
              if (field.type == TType.STRUCT) {
                this.notFoundException = new com.evernote.edam.error.EDAMNotFoundException();
                this.notFoundException.read(iprot);
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
            case SYSTEM_EXCEPTION:
              if (field.type == TType.STRUCT) {
                this.systemException = new com.evernote.edam.error.EDAMSystemException();
                this.systemException.read(iprot);
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
          }
          iprot.readFieldEnd();
        }
      }
      iprot.readStructEnd();
      validate();
    }

    public void write(TProtocol oprot) throws TException {
      oprot.writeStructBegin(STRUCT_DESC);

      if (this.isSetSuccess()) {
        oprot.writeFieldBegin(SUCCESS_FIELD_DESC);
        {
          oprot.writeListBegin(new TList(TType.STRUCT, this.success.size()));
          for (com.evernote.edam.type.SharedNotebook _iter114 : this.success)
          {
            _iter114.write(oprot);
          }
          oprot.writeListEnd();
        }
        oprot.writeFieldEnd();
      } else if (this.isSetUserException()) {
        oprot.writeFieldBegin(USER_EXCEPTION_FIELD_DESC);
        this.userException.write(oprot);
        oprot.writeFieldEnd();
      } else if (this.isSetNotFoundException()) {
        oprot.writeFieldBegin(NOT_FOUND_EXCEPTION_FIELD_DESC);
        this.notFoundException.write(oprot);
        oprot.writeFieldEnd();
      } else if (this.isSetSystemException()) {
        oprot.writeFieldBegin(SYSTEM_EXCEPTION_FIELD_DESC);
        this.systemException.write(oprot);
        oprot.writeFieldEnd();
      }
      oprot.writeFieldStop();
      oprot.writeStructEnd();
    }

    public String toString() {
      StringBuilder sb = new StringBuilder("listSharedNotebooks_result(");
      boolean first = true;

      sb.append("success:");
      if (this.success == null) {
        sb.append("null");
      } else {
        sb.append(this.success);
      }
      first = false;
      if (!first) sb.append(", ");
      sb.append("userException:");
      if (this.userException == null) {
        sb.append("null");
      } else {
        sb.append(this.userException);
      }
      first = false;
      if (!first) sb.append(", ");
      sb.append("notFoundException:");
      if (this.notFoundException == null) {
        sb.append("null");
      } else {
        sb.append(this.notFoundException);
      }
      first = false;
      if (!first) sb.append(", ");
      sb.append("systemException:");
      if (this.systemException == null) {
        sb.append("null");
      } else {
        sb.append(this.systemException);
      }
      first = false;
      sb.append(")");
      return sb.toString();
    }

    public void validate() throws TException {
      // check for required fields
    }

  }

  public static class expungeSharedNotebooks_args implements TBase<expungeSharedNotebooks_args._Fields>, java.io.Serializable, Cloneable, Comparable<expungeSharedNotebooks_args>   {
    private static final TStruct STRUCT_DESC = new TStruct("expungeSharedNotebooks_args");

    private static final TField AUTHENTICATION_TOKEN_FIELD_DESC = new TField("authenticationToken", TType.STRING, (short)1);
    private static final TField SHARED_NOTEBOOK_IDS_FIELD_DESC = new TField("sharedNotebookIds", TType.LIST, (short)2);

    private String authenticationToken;
    private List<Long> sharedNotebookIds;

    /** The set of fields this struct contains, along with convenience methods for finding and manipulating them. */
    public enum _Fields implements TFieldIdEnum {
      AUTHENTICATION_TOKEN((short)1, "authenticationToken"),
      SHARED_NOTEBOOK_IDS((short)2, "sharedNotebookIds");

      private static final Map<Integer, _Fields> byId = new HashMap<Integer, _Fields>();
      private static final Map<String, _Fields> byName = new HashMap<String, _Fields>();

      static {
        for (_Fields field : EnumSet.allOf(_Fields.class)) {
          byId.put((int)field._thriftId, field);
          byName.put(field.getFieldName(), field);
        }
      }

      /**
       * Find the _Fields constant that matches fieldId, or null if its not found.
       */
      public static _Fields findByThriftId(int fieldId) {
        return byId.get(fieldId);
      }

      /**
       * Find the _Fields constant that matches fieldId, throwing an exception
       * if it is not found.
       */
      public static _Fields findByThriftIdOrThrow(int fieldId) {
        _Fields fields = findByThriftId(fieldId);
        if (fields == null) throw new IllegalArgumentException("Field " + fieldId + " doesn't exist!");
        return fields;
      }

      /**
       * Find the _Fields constant that matches name, or null if its not found.
       */
      public static _Fields findByName(String name) {
        return byName.get(name);
      }

      private final short _thriftId;
      private final String _fieldName;

      _Fields(short thriftId, String fieldName) {
        _thriftId = thriftId;
        _fieldName = fieldName;
      }

      public short getThriftFieldId() {
        return _thriftId;
      }

      public String getFieldName() {
        return _fieldName;
      }
    }

    // isset id assignments

    public static final Map<_Fields, FieldMetaData> metaDataMap = Collections.unmodifiableMap(new EnumMap<_Fields, FieldMetaData>(_Fields.class) {{
      put(_Fields.AUTHENTICATION_TOKEN, new FieldMetaData("authenticationToken", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.STRING)));
      put(_Fields.SHARED_NOTEBOOK_IDS, new FieldMetaData("sharedNotebookIds", TFieldRequirementType.DEFAULT, 
          new ListMetaData(TType.LIST, 
              new FieldValueMetaData(TType.I64))));
    }});

    static {
      FieldMetaData.addStructMetaDataMap(expungeSharedNotebooks_args.class, metaDataMap);
    }

    public expungeSharedNotebooks_args() {
    }

    public expungeSharedNotebooks_args(
      String authenticationToken,
      List<Long> sharedNotebookIds)
    {
      this();
      this.authenticationToken = authenticationToken;
      this.sharedNotebookIds = sharedNotebookIds;
    }

    /**
     * Performs a deep copy on <i>other</i>.
     */
    public expungeSharedNotebooks_args(expungeSharedNotebooks_args other) {
      if (other.isSetAuthenticationToken()) {
        this.authenticationToken = other.authenticationToken;
      }
      if (other.isSetSharedNotebookIds()) {
        List<Long> __this__sharedNotebookIds = new ArrayList<Long>();
        for (Long other_element : other.sharedNotebookIds) {
          __this__sharedNotebookIds.add(other_element);
        }
        this.sharedNotebookIds = __this__sharedNotebookIds;
      }
    }

    public expungeSharedNotebooks_args deepCopy() {
      return new expungeSharedNotebooks_args(this);
    }

    @Deprecated
    public expungeSharedNotebooks_args clone() {
      return new expungeSharedNotebooks_args(this);
    }

    public String getAuthenticationToken() {
      return this.authenticationToken;
    }

    public void setAuthenticationToken(String authenticationToken) {
      this.authenticationToken = authenticationToken;
    }

    public void unsetAuthenticationToken() {
      this.authenticationToken = null;
    }

    /** Returns true if field authenticationToken is set (has been asigned a value) and false otherwise */
    public boolean isSetAuthenticationToken() {
      return this.authenticationToken != null;
    }

    public void setAuthenticationTokenIsSet(boolean value) {
      if (!value) {
        this.authenticationToken = null;
      }
    }

    public int getSharedNotebookIdsSize() {
      return (this.sharedNotebookIds == null) ? 0 : this.sharedNotebookIds.size();
    }

    public java.util.Iterator<Long> getSharedNotebookIdsIterator() {
      return (this.sharedNotebookIds == null) ? null : this.sharedNotebookIds.iterator();
    }

    public void addToSharedNotebookIds(long elem) {
      if (this.sharedNotebookIds == null) {
        this.sharedNotebookIds = new ArrayList<Long>();
      }
      this.sharedNotebookIds.add(elem);
    }

    public List<Long> getSharedNotebookIds() {
      return this.sharedNotebookIds;
    }

    public void setSharedNotebookIds(List<Long> sharedNotebookIds) {
      this.sharedNotebookIds = sharedNotebookIds;
    }

    public void unsetSharedNotebookIds() {
      this.sharedNotebookIds = null;
    }

    /** Returns true if field sharedNotebookIds is set (has been asigned a value) and false otherwise */
    public boolean isSetSharedNotebookIds() {
      return this.sharedNotebookIds != null;
    }

    public void setSharedNotebookIdsIsSet(boolean value) {
      if (!value) {
        this.sharedNotebookIds = null;
      }
    }

    public void setFieldValue(_Fields field, Object value) {
      switch (field) {
      case AUTHENTICATION_TOKEN:
        if (value == null) {
          unsetAuthenticationToken();
        } else {
          setAuthenticationToken((String)value);
        }
        break;

      case SHARED_NOTEBOOK_IDS:
        if (value == null) {
          unsetSharedNotebookIds();
        } else {
          setSharedNotebookIds((List<Long>)value);
        }
        break;

      }
    }

    public void setFieldValue(int fieldID, Object value) {
      setFieldValue(_Fields.findByThriftIdOrThrow(fieldID), value);
    }

    public Object getFieldValue(_Fields field) {
      switch (field) {
      case AUTHENTICATION_TOKEN:
        return getAuthenticationToken();

      case SHARED_NOTEBOOK_IDS:
        return getSharedNotebookIds();

      }
      throw new IllegalStateException();
    }

    public Object getFieldValue(int fieldId) {
      return getFieldValue(_Fields.findByThriftIdOrThrow(fieldId));
    }

    /** Returns true if field corresponding to fieldID is set (has been asigned a value) and false otherwise */
    public boolean isSet(_Fields field) {
      switch (field) {
      case AUTHENTICATION_TOKEN:
        return isSetAuthenticationToken();
      case SHARED_NOTEBOOK_IDS:
        return isSetSharedNotebookIds();
      }
      throw new IllegalStateException();
    }

    public boolean isSet(int fieldID) {
      return isSet(_Fields.findByThriftIdOrThrow(fieldID));
    }

    public boolean equals(Object that) {
      if (that == null)
        return false;
      if (that instanceof expungeSharedNotebooks_args)
        return this.equals((expungeSharedNotebooks_args)that);
      return false;
    }

    public boolean equals(expungeSharedNotebooks_args that) {
      if (that == null)
        return false;

      boolean this_present_authenticationToken = true && this.isSetAuthenticationToken();
      boolean that_present_authenticationToken = true && that.isSetAuthenticationToken();
      if (this_present_authenticationToken || that_present_authenticationToken) {
        if (!(this_present_authenticationToken && that_present_authenticationToken))
          return false;
        if (!this.authenticationToken.equals(that.authenticationToken))
          return false;
      }

      boolean this_present_sharedNotebookIds = true && this.isSetSharedNotebookIds();
      boolean that_present_sharedNotebookIds = true && that.isSetSharedNotebookIds();
      if (this_present_sharedNotebookIds || that_present_sharedNotebookIds) {
        if (!(this_present_sharedNotebookIds && that_present_sharedNotebookIds))
          return false;
        if (!this.sharedNotebookIds.equals(that.sharedNotebookIds))
          return false;
      }

      return true;
    }

    public int hashCode() {
      return 0;
    }

    public int compareTo(expungeSharedNotebooks_args other) {
      if (!getClass().equals(other.getClass())) {
        return getClass().getName().compareTo(other.getClass().getName());
      }

      int lastComparison = 0;
      expungeSharedNotebooks_args typedOther = (expungeSharedNotebooks_args)other;

      lastComparison = Boolean.valueOf(isSetAuthenticationToken()).compareTo(isSetAuthenticationToken());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(authenticationToken, typedOther.authenticationToken);
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = Boolean.valueOf(isSetSharedNotebookIds()).compareTo(isSetSharedNotebookIds());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(sharedNotebookIds, typedOther.sharedNotebookIds);
      if (lastComparison != 0) {
        return lastComparison;
      }
      return 0;
    }

    public void read(TProtocol iprot) throws TException {
      TField field;
      iprot.readStructBegin();
      while (true)
      {
        field = iprot.readFieldBegin();
        if (field.type == TType.STOP) { 
          break;
        }
        _Fields fieldId = _Fields.findByThriftId(field.id);
        if (fieldId == null) {
          TProtocolUtil.skip(iprot, field.type);
        } else {
          switch (fieldId) {
            case AUTHENTICATION_TOKEN:
              if (field.type == TType.STRING) {
                this.authenticationToken = iprot.readString();
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
            case SHARED_NOTEBOOK_IDS:
              if (field.type == TType.LIST) {
                {
                  TList _list115 = iprot.readListBegin();
                  this.sharedNotebookIds = new ArrayList<Long>(_list115.size);
                  for (int _i116 = 0; _i116 < _list115.size; ++_i116)
                  {
                    long _elem117;
                    _elem117 = iprot.readI64();
                    this.sharedNotebookIds.add(_elem117);
                  }
                  iprot.readListEnd();
                }
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
          }
          iprot.readFieldEnd();
        }
      }
      iprot.readStructEnd();
      validate();
    }

    public void write(TProtocol oprot) throws TException {
      validate();

      oprot.writeStructBegin(STRUCT_DESC);
      if (this.authenticationToken != null) {
        oprot.writeFieldBegin(AUTHENTICATION_TOKEN_FIELD_DESC);
        oprot.writeString(this.authenticationToken);
        oprot.writeFieldEnd();
      }
      if (this.sharedNotebookIds != null) {
        oprot.writeFieldBegin(SHARED_NOTEBOOK_IDS_FIELD_DESC);
        {
          oprot.writeListBegin(new TList(TType.I64, this.sharedNotebookIds.size()));
          for (long _iter118 : this.sharedNotebookIds)
          {
            oprot.writeI64(_iter118);
          }
          oprot.writeListEnd();
        }
        oprot.writeFieldEnd();
      }
      oprot.writeFieldStop();
      oprot.writeStructEnd();
    }

    public String toString() {
      StringBuilder sb = new StringBuilder("expungeSharedNotebooks_args(");
      boolean first = true;

      sb.append("authenticationToken:");
      if (this.authenticationToken == null) {
        sb.append("null");
      } else {
        sb.append(this.authenticationToken);
      }
      first = false;
      if (!first) sb.append(", ");
      sb.append("sharedNotebookIds:");
      if (this.sharedNotebookIds == null) {
        sb.append("null");
      } else {
        sb.append(this.sharedNotebookIds);
      }
      first = false;
      sb.append(")");
      return sb.toString();
    }

    public void validate() throws TException {
      // check for required fields
    }

  }

  public static class expungeSharedNotebooks_result implements TBase<expungeSharedNotebooks_result._Fields>, java.io.Serializable, Cloneable, Comparable<expungeSharedNotebooks_result>   {
    private static final TStruct STRUCT_DESC = new TStruct("expungeSharedNotebooks_result");

    private static final TField SUCCESS_FIELD_DESC = new TField("success", TType.I32, (short)0);
    private static final TField USER_EXCEPTION_FIELD_DESC = new TField("userException", TType.STRUCT, (short)1);
    private static final TField NOT_FOUND_EXCEPTION_FIELD_DESC = new TField("notFoundException", TType.STRUCT, (short)2);
    private static final TField SYSTEM_EXCEPTION_FIELD_DESC = new TField("systemException", TType.STRUCT, (short)3);

    private int success;
    private com.evernote.edam.error.EDAMUserException userException;
    private com.evernote.edam.error.EDAMNotFoundException notFoundException;
    private com.evernote.edam.error.EDAMSystemException systemException;

    /** The set of fields this struct contains, along with convenience methods for finding and manipulating them. */
    public enum _Fields implements TFieldIdEnum {
      SUCCESS((short)0, "success"),
      USER_EXCEPTION((short)1, "userException"),
      NOT_FOUND_EXCEPTION((short)2, "notFoundException"),
      SYSTEM_EXCEPTION((short)3, "systemException");

      private static final Map<Integer, _Fields> byId = new HashMap<Integer, _Fields>();
      private static final Map<String, _Fields> byName = new HashMap<String, _Fields>();

      static {
        for (_Fields field : EnumSet.allOf(_Fields.class)) {
          byId.put((int)field._thriftId, field);
          byName.put(field.getFieldName(), field);
        }
      }

      /**
       * Find the _Fields constant that matches fieldId, or null if its not found.
       */
      public static _Fields findByThriftId(int fieldId) {
        return byId.get(fieldId);
      }

      /**
       * Find the _Fields constant that matches fieldId, throwing an exception
       * if it is not found.
       */
      public static _Fields findByThriftIdOrThrow(int fieldId) {
        _Fields fields = findByThriftId(fieldId);
        if (fields == null) throw new IllegalArgumentException("Field " + fieldId + " doesn't exist!");
        return fields;
      }

      /**
       * Find the _Fields constant that matches name, or null if its not found.
       */
      public static _Fields findByName(String name) {
        return byName.get(name);
      }

      private final short _thriftId;
      private final String _fieldName;

      _Fields(short thriftId, String fieldName) {
        _thriftId = thriftId;
        _fieldName = fieldName;
      }

      public short getThriftFieldId() {
        return _thriftId;
      }

      public String getFieldName() {
        return _fieldName;
      }
    }

    // isset id assignments
    private static final int __SUCCESS_ISSET_ID = 0;
    private BitSet __isset_bit_vector = new BitSet(1);

    public static final Map<_Fields, FieldMetaData> metaDataMap = Collections.unmodifiableMap(new EnumMap<_Fields, FieldMetaData>(_Fields.class) {{
      put(_Fields.SUCCESS, new FieldMetaData("success", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.I32)));
      put(_Fields.USER_EXCEPTION, new FieldMetaData("userException", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.STRUCT)));
      put(_Fields.NOT_FOUND_EXCEPTION, new FieldMetaData("notFoundException", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.STRUCT)));
      put(_Fields.SYSTEM_EXCEPTION, new FieldMetaData("systemException", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.STRUCT)));
    }});

    static {
      FieldMetaData.addStructMetaDataMap(expungeSharedNotebooks_result.class, metaDataMap);
    }

    public expungeSharedNotebooks_result() {
    }

    public expungeSharedNotebooks_result(
      int success,
      com.evernote.edam.error.EDAMUserException userException,
      com.evernote.edam.error.EDAMNotFoundException notFoundException,
      com.evernote.edam.error.EDAMSystemException systemException)
    {
      this();
      this.success = success;
      setSuccessIsSet(true);
      this.userException = userException;
      this.notFoundException = notFoundException;
      this.systemException = systemException;
    }

    /**
     * Performs a deep copy on <i>other</i>.
     */
    public expungeSharedNotebooks_result(expungeSharedNotebooks_result other) {
      __isset_bit_vector.clear();
      __isset_bit_vector.or(other.__isset_bit_vector);
      this.success = other.success;
      if (other.isSetUserException()) {
        this.userException = new com.evernote.edam.error.EDAMUserException(other.userException);
      }
      if (other.isSetNotFoundException()) {
        this.notFoundException = new com.evernote.edam.error.EDAMNotFoundException(other.notFoundException);
      }
      if (other.isSetSystemException()) {
        this.systemException = new com.evernote.edam.error.EDAMSystemException(other.systemException);
      }
    }

    public expungeSharedNotebooks_result deepCopy() {
      return new expungeSharedNotebooks_result(this);
    }

    @Deprecated
    public expungeSharedNotebooks_result clone() {
      return new expungeSharedNotebooks_result(this);
    }

    public int getSuccess() {
      return this.success;
    }

    public void setSuccess(int success) {
      this.success = success;
      setSuccessIsSet(true);
    }

    public void unsetSuccess() {
      __isset_bit_vector.clear(__SUCCESS_ISSET_ID);
    }

    /** Returns true if field success is set (has been asigned a value) and false otherwise */
    public boolean isSetSuccess() {
      return __isset_bit_vector.get(__SUCCESS_ISSET_ID);
    }

    public void setSuccessIsSet(boolean value) {
      __isset_bit_vector.set(__SUCCESS_ISSET_ID, value);
    }

    public com.evernote.edam.error.EDAMUserException getUserException() {
      return this.userException;
    }

    public void setUserException(com.evernote.edam.error.EDAMUserException userException) {
      this.userException = userException;
    }

    public void unsetUserException() {
      this.userException = null;
    }

    /** Returns true if field userException is set (has been asigned a value) and false otherwise */
    public boolean isSetUserException() {
      return this.userException != null;
    }

    public void setUserExceptionIsSet(boolean value) {
      if (!value) {
        this.userException = null;
      }
    }

    public com.evernote.edam.error.EDAMNotFoundException getNotFoundException() {
      return this.notFoundException;
    }

    public void setNotFoundException(com.evernote.edam.error.EDAMNotFoundException notFoundException) {
      this.notFoundException = notFoundException;
    }

    public void unsetNotFoundException() {
      this.notFoundException = null;
    }

    /** Returns true if field notFoundException is set (has been asigned a value) and false otherwise */
    public boolean isSetNotFoundException() {
      return this.notFoundException != null;
    }

    public void setNotFoundExceptionIsSet(boolean value) {
      if (!value) {
        this.notFoundException = null;
      }
    }

    public com.evernote.edam.error.EDAMSystemException getSystemException() {
      return this.systemException;
    }

    public void setSystemException(com.evernote.edam.error.EDAMSystemException systemException) {
      this.systemException = systemException;
    }

    public void unsetSystemException() {
      this.systemException = null;
    }

    /** Returns true if field systemException is set (has been asigned a value) and false otherwise */
    public boolean isSetSystemException() {
      return this.systemException != null;
    }

    public void setSystemExceptionIsSet(boolean value) {
      if (!value) {
        this.systemException = null;
      }
    }

    public void setFieldValue(_Fields field, Object value) {
      switch (field) {
      case SUCCESS:
        if (value == null) {
          unsetSuccess();
        } else {
          setSuccess((Integer)value);
        }
        break;

      case USER_EXCEPTION:
        if (value == null) {
          unsetUserException();
        } else {
          setUserException((com.evernote.edam.error.EDAMUserException)value);
        }
        break;

      case NOT_FOUND_EXCEPTION:
        if (value == null) {
          unsetNotFoundException();
        } else {
          setNotFoundException((com.evernote.edam.error.EDAMNotFoundException)value);
        }
        break;

      case SYSTEM_EXCEPTION:
        if (value == null) {
          unsetSystemException();
        } else {
          setSystemException((com.evernote.edam.error.EDAMSystemException)value);
        }
        break;

      }
    }

    public void setFieldValue(int fieldID, Object value) {
      setFieldValue(_Fields.findByThriftIdOrThrow(fieldID), value);
    }

    public Object getFieldValue(_Fields field) {
      switch (field) {
      case SUCCESS:
        return new Integer(getSuccess());

      case USER_EXCEPTION:
        return getUserException();

      case NOT_FOUND_EXCEPTION:
        return getNotFoundException();

      case SYSTEM_EXCEPTION:
        return getSystemException();

      }
      throw new IllegalStateException();
    }

    public Object getFieldValue(int fieldId) {
      return getFieldValue(_Fields.findByThriftIdOrThrow(fieldId));
    }

    /** Returns true if field corresponding to fieldID is set (has been asigned a value) and false otherwise */
    public boolean isSet(_Fields field) {
      switch (field) {
      case SUCCESS:
        return isSetSuccess();
      case USER_EXCEPTION:
        return isSetUserException();
      case NOT_FOUND_EXCEPTION:
        return isSetNotFoundException();
      case SYSTEM_EXCEPTION:
        return isSetSystemException();
      }
      throw new IllegalStateException();
    }

    public boolean isSet(int fieldID) {
      return isSet(_Fields.findByThriftIdOrThrow(fieldID));
    }

    public boolean equals(Object that) {
      if (that == null)
        return false;
      if (that instanceof expungeSharedNotebooks_result)
        return this.equals((expungeSharedNotebooks_result)that);
      return false;
    }

    public boolean equals(expungeSharedNotebooks_result that) {
      if (that == null)
        return false;

      boolean this_present_success = true;
      boolean that_present_success = true;
      if (this_present_success || that_present_success) {
        if (!(this_present_success && that_present_success))
          return false;
        if (this.success != that.success)
          return false;
      }

      boolean this_present_userException = true && this.isSetUserException();
      boolean that_present_userException = true && that.isSetUserException();
      if (this_present_userException || that_present_userException) {
        if (!(this_present_userException && that_present_userException))
          return false;
        if (!this.userException.equals(that.userException))
          return false;
      }

      boolean this_present_notFoundException = true && this.isSetNotFoundException();
      boolean that_present_notFoundException = true && that.isSetNotFoundException();
      if (this_present_notFoundException || that_present_notFoundException) {
        if (!(this_present_notFoundException && that_present_notFoundException))
          return false;
        if (!this.notFoundException.equals(that.notFoundException))
          return false;
      }

      boolean this_present_systemException = true && this.isSetSystemException();
      boolean that_present_systemException = true && that.isSetSystemException();
      if (this_present_systemException || that_present_systemException) {
        if (!(this_present_systemException && that_present_systemException))
          return false;
        if (!this.systemException.equals(that.systemException))
          return false;
      }

      return true;
    }

    public int hashCode() {
      return 0;
    }

    public int compareTo(expungeSharedNotebooks_result other) {
      if (!getClass().equals(other.getClass())) {
        return getClass().getName().compareTo(other.getClass().getName());
      }

      int lastComparison = 0;
      expungeSharedNotebooks_result typedOther = (expungeSharedNotebooks_result)other;

      lastComparison = Boolean.valueOf(isSetSuccess()).compareTo(isSetSuccess());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(success, typedOther.success);
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = Boolean.valueOf(isSetUserException()).compareTo(isSetUserException());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(userException, typedOther.userException);
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = Boolean.valueOf(isSetNotFoundException()).compareTo(isSetNotFoundException());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(notFoundException, typedOther.notFoundException);
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = Boolean.valueOf(isSetSystemException()).compareTo(isSetSystemException());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(systemException, typedOther.systemException);
      if (lastComparison != 0) {
        return lastComparison;
      }
      return 0;
    }

    public void read(TProtocol iprot) throws TException {
      TField field;
      iprot.readStructBegin();
      while (true)
      {
        field = iprot.readFieldBegin();
        if (field.type == TType.STOP) { 
          break;
        }
        _Fields fieldId = _Fields.findByThriftId(field.id);
        if (fieldId == null) {
          TProtocolUtil.skip(iprot, field.type);
        } else {
          switch (fieldId) {
            case SUCCESS:
              if (field.type == TType.I32) {
                this.success = iprot.readI32();
                setSuccessIsSet(true);
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
            case USER_EXCEPTION:
              if (field.type == TType.STRUCT) {
                this.userException = new com.evernote.edam.error.EDAMUserException();
                this.userException.read(iprot);
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
            case NOT_FOUND_EXCEPTION:
              if (field.type == TType.STRUCT) {
                this.notFoundException = new com.evernote.edam.error.EDAMNotFoundException();
                this.notFoundException.read(iprot);
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
            case SYSTEM_EXCEPTION:
              if (field.type == TType.STRUCT) {
                this.systemException = new com.evernote.edam.error.EDAMSystemException();
                this.systemException.read(iprot);
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
          }
          iprot.readFieldEnd();
        }
      }
      iprot.readStructEnd();
      validate();
    }

    public void write(TProtocol oprot) throws TException {
      oprot.writeStructBegin(STRUCT_DESC);

      if (this.isSetSuccess()) {
        oprot.writeFieldBegin(SUCCESS_FIELD_DESC);
        oprot.writeI32(this.success);
        oprot.writeFieldEnd();
      } else if (this.isSetUserException()) {
        oprot.writeFieldBegin(USER_EXCEPTION_FIELD_DESC);
        this.userException.write(oprot);
        oprot.writeFieldEnd();
      } else if (this.isSetNotFoundException()) {
        oprot.writeFieldBegin(NOT_FOUND_EXCEPTION_FIELD_DESC);
        this.notFoundException.write(oprot);
        oprot.writeFieldEnd();
      } else if (this.isSetSystemException()) {
        oprot.writeFieldBegin(SYSTEM_EXCEPTION_FIELD_DESC);
        this.systemException.write(oprot);
        oprot.writeFieldEnd();
      }
      oprot.writeFieldStop();
      oprot.writeStructEnd();
    }

    public String toString() {
      StringBuilder sb = new StringBuilder("expungeSharedNotebooks_result(");
      boolean first = true;

      sb.append("success:");
      sb.append(this.success);
      first = false;
      if (!first) sb.append(", ");
      sb.append("userException:");
      if (this.userException == null) {
        sb.append("null");
      } else {
        sb.append(this.userException);
      }
      first = false;
      if (!first) sb.append(", ");
      sb.append("notFoundException:");
      if (this.notFoundException == null) {
        sb.append("null");
      } else {
        sb.append(this.notFoundException);
      }
      first = false;
      if (!first) sb.append(", ");
      sb.append("systemException:");
      if (this.systemException == null) {
        sb.append("null");
      } else {
        sb.append(this.systemException);
      }
      first = false;
      sb.append(")");
      return sb.toString();
    }

    public void validate() throws TException {
      // check for required fields
    }

  }

  public static class createLinkedNotebook_args implements TBase<createLinkedNotebook_args._Fields>, java.io.Serializable, Cloneable, Comparable<createLinkedNotebook_args>   {
    private static final TStruct STRUCT_DESC = new TStruct("createLinkedNotebook_args");

    private static final TField AUTHENTICATION_TOKEN_FIELD_DESC = new TField("authenticationToken", TType.STRING, (short)1);
    private static final TField LINKED_NOTEBOOK_FIELD_DESC = new TField("linkedNotebook", TType.STRUCT, (short)2);

    private String authenticationToken;
    private com.evernote.edam.type.LinkedNotebook linkedNotebook;

    /** The set of fields this struct contains, along with convenience methods for finding and manipulating them. */
    public enum _Fields implements TFieldIdEnum {
      AUTHENTICATION_TOKEN((short)1, "authenticationToken"),
      LINKED_NOTEBOOK((short)2, "linkedNotebook");

      private static final Map<Integer, _Fields> byId = new HashMap<Integer, _Fields>();
      private static final Map<String, _Fields> byName = new HashMap<String, _Fields>();

      static {
        for (_Fields field : EnumSet.allOf(_Fields.class)) {
          byId.put((int)field._thriftId, field);
          byName.put(field.getFieldName(), field);
        }
      }

      /**
       * Find the _Fields constant that matches fieldId, or null if its not found.
       */
      public static _Fields findByThriftId(int fieldId) {
        return byId.get(fieldId);
      }

      /**
       * Find the _Fields constant that matches fieldId, throwing an exception
       * if it is not found.
       */
      public static _Fields findByThriftIdOrThrow(int fieldId) {
        _Fields fields = findByThriftId(fieldId);
        if (fields == null) throw new IllegalArgumentException("Field " + fieldId + " doesn't exist!");
        return fields;
      }

      /**
       * Find the _Fields constant that matches name, or null if its not found.
       */
      public static _Fields findByName(String name) {
        return byName.get(name);
      }

      private final short _thriftId;
      private final String _fieldName;

      _Fields(short thriftId, String fieldName) {
        _thriftId = thriftId;
        _fieldName = fieldName;
      }

      public short getThriftFieldId() {
        return _thriftId;
      }

      public String getFieldName() {
        return _fieldName;
      }
    }

    // isset id assignments

    public static final Map<_Fields, FieldMetaData> metaDataMap = Collections.unmodifiableMap(new EnumMap<_Fields, FieldMetaData>(_Fields.class) {{
      put(_Fields.AUTHENTICATION_TOKEN, new FieldMetaData("authenticationToken", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.STRING)));
      put(_Fields.LINKED_NOTEBOOK, new FieldMetaData("linkedNotebook", TFieldRequirementType.DEFAULT, 
          new StructMetaData(TType.STRUCT, com.evernote.edam.type.LinkedNotebook.class)));
    }});

    static {
      FieldMetaData.addStructMetaDataMap(createLinkedNotebook_args.class, metaDataMap);
    }

    public createLinkedNotebook_args() {
    }

    public createLinkedNotebook_args(
      String authenticationToken,
      com.evernote.edam.type.LinkedNotebook linkedNotebook)
    {
      this();
      this.authenticationToken = authenticationToken;
      this.linkedNotebook = linkedNotebook;
    }

    /**
     * Performs a deep copy on <i>other</i>.
     */
    public createLinkedNotebook_args(createLinkedNotebook_args other) {
      if (other.isSetAuthenticationToken()) {
        this.authenticationToken = other.authenticationToken;
      }
      if (other.isSetLinkedNotebook()) {
        this.linkedNotebook = new com.evernote.edam.type.LinkedNotebook(other.linkedNotebook);
      }
    }

    public createLinkedNotebook_args deepCopy() {
      return new createLinkedNotebook_args(this);
    }

    @Deprecated
    public createLinkedNotebook_args clone() {
      return new createLinkedNotebook_args(this);
    }

    public String getAuthenticationToken() {
      return this.authenticationToken;
    }

    public void setAuthenticationToken(String authenticationToken) {
      this.authenticationToken = authenticationToken;
    }

    public void unsetAuthenticationToken() {
      this.authenticationToken = null;
    }

    /** Returns true if field authenticationToken is set (has been asigned a value) and false otherwise */
    public boolean isSetAuthenticationToken() {
      return this.authenticationToken != null;
    }

    public void setAuthenticationTokenIsSet(boolean value) {
      if (!value) {
        this.authenticationToken = null;
      }
    }

    public com.evernote.edam.type.LinkedNotebook getLinkedNotebook() {
      return this.linkedNotebook;
    }

    public void setLinkedNotebook(com.evernote.edam.type.LinkedNotebook linkedNotebook) {
      this.linkedNotebook = linkedNotebook;
    }

    public void unsetLinkedNotebook() {
      this.linkedNotebook = null;
    }

    /** Returns true if field linkedNotebook is set (has been asigned a value) and false otherwise */
    public boolean isSetLinkedNotebook() {
      return this.linkedNotebook != null;
    }

    public void setLinkedNotebookIsSet(boolean value) {
      if (!value) {
        this.linkedNotebook = null;
      }
    }

    public void setFieldValue(_Fields field, Object value) {
      switch (field) {
      case AUTHENTICATION_TOKEN:
        if (value == null) {
          unsetAuthenticationToken();
        } else {
          setAuthenticationToken((String)value);
        }
        break;

      case LINKED_NOTEBOOK:
        if (value == null) {
          unsetLinkedNotebook();
        } else {
          setLinkedNotebook((com.evernote.edam.type.LinkedNotebook)value);
        }
        break;

      }
    }

    public void setFieldValue(int fieldID, Object value) {
      setFieldValue(_Fields.findByThriftIdOrThrow(fieldID), value);
    }

    public Object getFieldValue(_Fields field) {
      switch (field) {
      case AUTHENTICATION_TOKEN:
        return getAuthenticationToken();

      case LINKED_NOTEBOOK:
        return getLinkedNotebook();

      }
      throw new IllegalStateException();
    }

    public Object getFieldValue(int fieldId) {
      return getFieldValue(_Fields.findByThriftIdOrThrow(fieldId));
    }

    /** Returns true if field corresponding to fieldID is set (has been asigned a value) and false otherwise */
    public boolean isSet(_Fields field) {
      switch (field) {
      case AUTHENTICATION_TOKEN:
        return isSetAuthenticationToken();
      case LINKED_NOTEBOOK:
        return isSetLinkedNotebook();
      }
      throw new IllegalStateException();
    }

    public boolean isSet(int fieldID) {
      return isSet(_Fields.findByThriftIdOrThrow(fieldID));
    }

    public boolean equals(Object that) {
      if (that == null)
        return false;
      if (that instanceof createLinkedNotebook_args)
        return this.equals((createLinkedNotebook_args)that);
      return false;
    }

    public boolean equals(createLinkedNotebook_args that) {
      if (that == null)
        return false;

      boolean this_present_authenticationToken = true && this.isSetAuthenticationToken();
      boolean that_present_authenticationToken = true && that.isSetAuthenticationToken();
      if (this_present_authenticationToken || that_present_authenticationToken) {
        if (!(this_present_authenticationToken && that_present_authenticationToken))
          return false;
        if (!this.authenticationToken.equals(that.authenticationToken))
          return false;
      }

      boolean this_present_linkedNotebook = true && this.isSetLinkedNotebook();
      boolean that_present_linkedNotebook = true && that.isSetLinkedNotebook();
      if (this_present_linkedNotebook || that_present_linkedNotebook) {
        if (!(this_present_linkedNotebook && that_present_linkedNotebook))
          return false;
        if (!this.linkedNotebook.equals(that.linkedNotebook))
          return false;
      }

      return true;
    }

    public int hashCode() {
      return 0;
    }

    public int compareTo(createLinkedNotebook_args other) {
      if (!getClass().equals(other.getClass())) {
        return getClass().getName().compareTo(other.getClass().getName());
      }

      int lastComparison = 0;
      createLinkedNotebook_args typedOther = (createLinkedNotebook_args)other;

      lastComparison = Boolean.valueOf(isSetAuthenticationToken()).compareTo(isSetAuthenticationToken());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(authenticationToken, typedOther.authenticationToken);
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = Boolean.valueOf(isSetLinkedNotebook()).compareTo(isSetLinkedNotebook());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(linkedNotebook, typedOther.linkedNotebook);
      if (lastComparison != 0) {
        return lastComparison;
      }
      return 0;
    }

    public void read(TProtocol iprot) throws TException {
      TField field;
      iprot.readStructBegin();
      while (true)
      {
        field = iprot.readFieldBegin();
        if (field.type == TType.STOP) { 
          break;
        }
        _Fields fieldId = _Fields.findByThriftId(field.id);
        if (fieldId == null) {
          TProtocolUtil.skip(iprot, field.type);
        } else {
          switch (fieldId) {
            case AUTHENTICATION_TOKEN:
              if (field.type == TType.STRING) {
                this.authenticationToken = iprot.readString();
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
            case LINKED_NOTEBOOK:
              if (field.type == TType.STRUCT) {
                this.linkedNotebook = new com.evernote.edam.type.LinkedNotebook();
                this.linkedNotebook.read(iprot);
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
          }
          iprot.readFieldEnd();
        }
      }
      iprot.readStructEnd();
      validate();
    }

    public void write(TProtocol oprot) throws TException {
      validate();

      oprot.writeStructBegin(STRUCT_DESC);
      if (this.authenticationToken != null) {
        oprot.writeFieldBegin(AUTHENTICATION_TOKEN_FIELD_DESC);
        oprot.writeString(this.authenticationToken);
        oprot.writeFieldEnd();
      }
      if (this.linkedNotebook != null) {
        oprot.writeFieldBegin(LINKED_NOTEBOOK_FIELD_DESC);
        this.linkedNotebook.write(oprot);
        oprot.writeFieldEnd();
      }
      oprot.writeFieldStop();
      oprot.writeStructEnd();
    }

    public String toString() {
      StringBuilder sb = new StringBuilder("createLinkedNotebook_args(");
      boolean first = true;

      sb.append("authenticationToken:");
      if (this.authenticationToken == null) {
        sb.append("null");
      } else {
        sb.append(this.authenticationToken);
      }
      first = false;
      if (!first) sb.append(", ");
      sb.append("linkedNotebook:");
      if (this.linkedNotebook == null) {
        sb.append("null");
      } else {
        sb.append(this.linkedNotebook);
      }
      first = false;
      sb.append(")");
      return sb.toString();
    }

    public void validate() throws TException {
      // check for required fields
    }

  }

  public static class createLinkedNotebook_result implements TBase<createLinkedNotebook_result._Fields>, java.io.Serializable, Cloneable, Comparable<createLinkedNotebook_result>   {
    private static final TStruct STRUCT_DESC = new TStruct("createLinkedNotebook_result");

    private static final TField SUCCESS_FIELD_DESC = new TField("success", TType.STRUCT, (short)0);
    private static final TField USER_EXCEPTION_FIELD_DESC = new TField("userException", TType.STRUCT, (short)1);
    private static final TField NOT_FOUND_EXCEPTION_FIELD_DESC = new TField("notFoundException", TType.STRUCT, (short)2);
    private static final TField SYSTEM_EXCEPTION_FIELD_DESC = new TField("systemException", TType.STRUCT, (short)3);

    private com.evernote.edam.type.LinkedNotebook success;
    private com.evernote.edam.error.EDAMUserException userException;
    private com.evernote.edam.error.EDAMNotFoundException notFoundException;
    private com.evernote.edam.error.EDAMSystemException systemException;

    /** The set of fields this struct contains, along with convenience methods for finding and manipulating them. */
    public enum _Fields implements TFieldIdEnum {
      SUCCESS((short)0, "success"),
      USER_EXCEPTION((short)1, "userException"),
      NOT_FOUND_EXCEPTION((short)2, "notFoundException"),
      SYSTEM_EXCEPTION((short)3, "systemException");

      private static final Map<Integer, _Fields> byId = new HashMap<Integer, _Fields>();
      private static final Map<String, _Fields> byName = new HashMap<String, _Fields>();

      static {
        for (_Fields field : EnumSet.allOf(_Fields.class)) {
          byId.put((int)field._thriftId, field);
          byName.put(field.getFieldName(), field);
        }
      }

      /**
       * Find the _Fields constant that matches fieldId, or null if its not found.
       */
      public static _Fields findByThriftId(int fieldId) {
        return byId.get(fieldId);
      }

      /**
       * Find the _Fields constant that matches fieldId, throwing an exception
       * if it is not found.
       */
      public static _Fields findByThriftIdOrThrow(int fieldId) {
        _Fields fields = findByThriftId(fieldId);
        if (fields == null) throw new IllegalArgumentException("Field " + fieldId + " doesn't exist!");
        return fields;
      }

      /**
       * Find the _Fields constant that matches name, or null if its not found.
       */
      public static _Fields findByName(String name) {
        return byName.get(name);
      }

      private final short _thriftId;
      private final String _fieldName;

      _Fields(short thriftId, String fieldName) {
        _thriftId = thriftId;
        _fieldName = fieldName;
      }

      public short getThriftFieldId() {
        return _thriftId;
      }

      public String getFieldName() {
        return _fieldName;
      }
    }

    // isset id assignments

    public static final Map<_Fields, FieldMetaData> metaDataMap = Collections.unmodifiableMap(new EnumMap<_Fields, FieldMetaData>(_Fields.class) {{
      put(_Fields.SUCCESS, new FieldMetaData("success", TFieldRequirementType.DEFAULT, 
          new StructMetaData(TType.STRUCT, com.evernote.edam.type.LinkedNotebook.class)));
      put(_Fields.USER_EXCEPTION, new FieldMetaData("userException", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.STRUCT)));
      put(_Fields.NOT_FOUND_EXCEPTION, new FieldMetaData("notFoundException", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.STRUCT)));
      put(_Fields.SYSTEM_EXCEPTION, new FieldMetaData("systemException", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.STRUCT)));
    }});

    static {
      FieldMetaData.addStructMetaDataMap(createLinkedNotebook_result.class, metaDataMap);
    }

    public createLinkedNotebook_result() {
    }

    public createLinkedNotebook_result(
      com.evernote.edam.type.LinkedNotebook success,
      com.evernote.edam.error.EDAMUserException userException,
      com.evernote.edam.error.EDAMNotFoundException notFoundException,
      com.evernote.edam.error.EDAMSystemException systemException)
    {
      this();
      this.success = success;
      this.userException = userException;
      this.notFoundException = notFoundException;
      this.systemException = systemException;
    }

    /**
     * Performs a deep copy on <i>other</i>.
     */
    public createLinkedNotebook_result(createLinkedNotebook_result other) {
      if (other.isSetSuccess()) {
        this.success = new com.evernote.edam.type.LinkedNotebook(other.success);
      }
      if (other.isSetUserException()) {
        this.userException = new com.evernote.edam.error.EDAMUserException(other.userException);
      }
      if (other.isSetNotFoundException()) {
        this.notFoundException = new com.evernote.edam.error.EDAMNotFoundException(other.notFoundException);
      }
      if (other.isSetSystemException()) {
        this.systemException = new com.evernote.edam.error.EDAMSystemException(other.systemException);
      }
    }

    public createLinkedNotebook_result deepCopy() {
      return new createLinkedNotebook_result(this);
    }

    @Deprecated
    public createLinkedNotebook_result clone() {
      return new createLinkedNotebook_result(this);
    }

    public com.evernote.edam.type.LinkedNotebook getSuccess() {
      return this.success;
    }

    public void setSuccess(com.evernote.edam.type.LinkedNotebook success) {
      this.success = success;
    }

    public void unsetSuccess() {
      this.success = null;
    }

    /** Returns true if field success is set (has been asigned a value) and false otherwise */
    public boolean isSetSuccess() {
      return this.success != null;
    }

    public void setSuccessIsSet(boolean value) {
      if (!value) {
        this.success = null;
      }
    }

    public com.evernote.edam.error.EDAMUserException getUserException() {
      return this.userException;
    }

    public void setUserException(com.evernote.edam.error.EDAMUserException userException) {
      this.userException = userException;
    }

    public void unsetUserException() {
      this.userException = null;
    }

    /** Returns true if field userException is set (has been asigned a value) and false otherwise */
    public boolean isSetUserException() {
      return this.userException != null;
    }

    public void setUserExceptionIsSet(boolean value) {
      if (!value) {
        this.userException = null;
      }
    }

    public com.evernote.edam.error.EDAMNotFoundException getNotFoundException() {
      return this.notFoundException;
    }

    public void setNotFoundException(com.evernote.edam.error.EDAMNotFoundException notFoundException) {
      this.notFoundException = notFoundException;
    }

    public void unsetNotFoundException() {
      this.notFoundException = null;
    }

    /** Returns true if field notFoundException is set (has been asigned a value) and false otherwise */
    public boolean isSetNotFoundException() {
      return this.notFoundException != null;
    }

    public void setNotFoundExceptionIsSet(boolean value) {
      if (!value) {
        this.notFoundException = null;
      }
    }

    public com.evernote.edam.error.EDAMSystemException getSystemException() {
      return this.systemException;
    }

    public void setSystemException(com.evernote.edam.error.EDAMSystemException systemException) {
      this.systemException = systemException;
    }

    public void unsetSystemException() {
      this.systemException = null;
    }

    /** Returns true if field systemException is set (has been asigned a value) and false otherwise */
    public boolean isSetSystemException() {
      return this.systemException != null;
    }

    public void setSystemExceptionIsSet(boolean value) {
      if (!value) {
        this.systemException = null;
      }
    }

    public void setFieldValue(_Fields field, Object value) {
      switch (field) {
      case SUCCESS:
        if (value == null) {
          unsetSuccess();
        } else {
          setSuccess((com.evernote.edam.type.LinkedNotebook)value);
        }
        break;

      case USER_EXCEPTION:
        if (value == null) {
          unsetUserException();
        } else {
          setUserException((com.evernote.edam.error.EDAMUserException)value);
        }
        break;

      case NOT_FOUND_EXCEPTION:
        if (value == null) {
          unsetNotFoundException();
        } else {
          setNotFoundException((com.evernote.edam.error.EDAMNotFoundException)value);
        }
        break;

      case SYSTEM_EXCEPTION:
        if (value == null) {
          unsetSystemException();
        } else {
          setSystemException((com.evernote.edam.error.EDAMSystemException)value);
        }
        break;

      }
    }

    public void setFieldValue(int fieldID, Object value) {
      setFieldValue(_Fields.findByThriftIdOrThrow(fieldID), value);
    }

    public Object getFieldValue(_Fields field) {
      switch (field) {
      case SUCCESS:
        return getSuccess();

      case USER_EXCEPTION:
        return getUserException();

      case NOT_FOUND_EXCEPTION:
        return getNotFoundException();

      case SYSTEM_EXCEPTION:
        return getSystemException();

      }
      throw new IllegalStateException();
    }

    public Object getFieldValue(int fieldId) {
      return getFieldValue(_Fields.findByThriftIdOrThrow(fieldId));
    }

    /** Returns true if field corresponding to fieldID is set (has been asigned a value) and false otherwise */
    public boolean isSet(_Fields field) {
      switch (field) {
      case SUCCESS:
        return isSetSuccess();
      case USER_EXCEPTION:
        return isSetUserException();
      case NOT_FOUND_EXCEPTION:
        return isSetNotFoundException();
      case SYSTEM_EXCEPTION:
        return isSetSystemException();
      }
      throw new IllegalStateException();
    }

    public boolean isSet(int fieldID) {
      return isSet(_Fields.findByThriftIdOrThrow(fieldID));
    }

    public boolean equals(Object that) {
      if (that == null)
        return false;
      if (that instanceof createLinkedNotebook_result)
        return this.equals((createLinkedNotebook_result)that);
      return false;
    }

    public boolean equals(createLinkedNotebook_result that) {
      if (that == null)
        return false;

      boolean this_present_success = true && this.isSetSuccess();
      boolean that_present_success = true && that.isSetSuccess();
      if (this_present_success || that_present_success) {
        if (!(this_present_success && that_present_success))
          return false;
        if (!this.success.equals(that.success))
          return false;
      }

      boolean this_present_userException = true && this.isSetUserException();
      boolean that_present_userException = true && that.isSetUserException();
      if (this_present_userException || that_present_userException) {
        if (!(this_present_userException && that_present_userException))
          return false;
        if (!this.userException.equals(that.userException))
          return false;
      }

      boolean this_present_notFoundException = true && this.isSetNotFoundException();
      boolean that_present_notFoundException = true && that.isSetNotFoundException();
      if (this_present_notFoundException || that_present_notFoundException) {
        if (!(this_present_notFoundException && that_present_notFoundException))
          return false;
        if (!this.notFoundException.equals(that.notFoundException))
          return false;
      }

      boolean this_present_systemException = true && this.isSetSystemException();
      boolean that_present_systemException = true && that.isSetSystemException();
      if (this_present_systemException || that_present_systemException) {
        if (!(this_present_systemException && that_present_systemException))
          return false;
        if (!this.systemException.equals(that.systemException))
          return false;
      }

      return true;
    }

    public int hashCode() {
      return 0;
    }

    public int compareTo(createLinkedNotebook_result other) {
      if (!getClass().equals(other.getClass())) {
        return getClass().getName().compareTo(other.getClass().getName());
      }

      int lastComparison = 0;
      createLinkedNotebook_result typedOther = (createLinkedNotebook_result)other;

      lastComparison = Boolean.valueOf(isSetSuccess()).compareTo(isSetSuccess());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(success, typedOther.success);
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = Boolean.valueOf(isSetUserException()).compareTo(isSetUserException());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(userException, typedOther.userException);
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = Boolean.valueOf(isSetNotFoundException()).compareTo(isSetNotFoundException());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(notFoundException, typedOther.notFoundException);
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = Boolean.valueOf(isSetSystemException()).compareTo(isSetSystemException());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(systemException, typedOther.systemException);
      if (lastComparison != 0) {
        return lastComparison;
      }
      return 0;
    }

    public void read(TProtocol iprot) throws TException {
      TField field;
      iprot.readStructBegin();
      while (true)
      {
        field = iprot.readFieldBegin();
        if (field.type == TType.STOP) { 
          break;
        }
        _Fields fieldId = _Fields.findByThriftId(field.id);
        if (fieldId == null) {
          TProtocolUtil.skip(iprot, field.type);
        } else {
          switch (fieldId) {
            case SUCCESS:
              if (field.type == TType.STRUCT) {
                this.success = new com.evernote.edam.type.LinkedNotebook();
                this.success.read(iprot);
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
            case USER_EXCEPTION:
              if (field.type == TType.STRUCT) {
                this.userException = new com.evernote.edam.error.EDAMUserException();
                this.userException.read(iprot);
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
            case NOT_FOUND_EXCEPTION:
              if (field.type == TType.STRUCT) {
                this.notFoundException = new com.evernote.edam.error.EDAMNotFoundException();
                this.notFoundException.read(iprot);
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
            case SYSTEM_EXCEPTION:
              if (field.type == TType.STRUCT) {
                this.systemException = new com.evernote.edam.error.EDAMSystemException();
                this.systemException.read(iprot);
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
          }
          iprot.readFieldEnd();
        }
      }
      iprot.readStructEnd();
      validate();
    }

    public void write(TProtocol oprot) throws TException {
      oprot.writeStructBegin(STRUCT_DESC);

      if (this.isSetSuccess()) {
        oprot.writeFieldBegin(SUCCESS_FIELD_DESC);
        this.success.write(oprot);
        oprot.writeFieldEnd();
      } else if (this.isSetUserException()) {
        oprot.writeFieldBegin(USER_EXCEPTION_FIELD_DESC);
        this.userException.write(oprot);
        oprot.writeFieldEnd();
      } else if (this.isSetNotFoundException()) {
        oprot.writeFieldBegin(NOT_FOUND_EXCEPTION_FIELD_DESC);
        this.notFoundException.write(oprot);
        oprot.writeFieldEnd();
      } else if (this.isSetSystemException()) {
        oprot.writeFieldBegin(SYSTEM_EXCEPTION_FIELD_DESC);
        this.systemException.write(oprot);
        oprot.writeFieldEnd();
      }
      oprot.writeFieldStop();
      oprot.writeStructEnd();
    }

    public String toString() {
      StringBuilder sb = new StringBuilder("createLinkedNotebook_result(");
      boolean first = true;

      sb.append("success:");
      if (this.success == null) {
        sb.append("null");
      } else {
        sb.append(this.success);
      }
      first = false;
      if (!first) sb.append(", ");
      sb.append("userException:");
      if (this.userException == null) {
        sb.append("null");
      } else {
        sb.append(this.userException);
      }
      first = false;
      if (!first) sb.append(", ");
      sb.append("notFoundException:");
      if (this.notFoundException == null) {
        sb.append("null");
      } else {
        sb.append(this.notFoundException);
      }
      first = false;
      if (!first) sb.append(", ");
      sb.append("systemException:");
      if (this.systemException == null) {
        sb.append("null");
      } else {
        sb.append(this.systemException);
      }
      first = false;
      sb.append(")");
      return sb.toString();
    }

    public void validate() throws TException {
      // check for required fields
    }

  }

  public static class updateLinkedNotebook_args implements TBase<updateLinkedNotebook_args._Fields>, java.io.Serializable, Cloneable, Comparable<updateLinkedNotebook_args>   {
    private static final TStruct STRUCT_DESC = new TStruct("updateLinkedNotebook_args");

    private static final TField AUTHENTICATION_TOKEN_FIELD_DESC = new TField("authenticationToken", TType.STRING, (short)1);
    private static final TField LINKED_NOTEBOOK_FIELD_DESC = new TField("linkedNotebook", TType.STRUCT, (short)2);

    private String authenticationToken;
    private com.evernote.edam.type.LinkedNotebook linkedNotebook;

    /** The set of fields this struct contains, along with convenience methods for finding and manipulating them. */
    public enum _Fields implements TFieldIdEnum {
      AUTHENTICATION_TOKEN((short)1, "authenticationToken"),
      LINKED_NOTEBOOK((short)2, "linkedNotebook");

      private static final Map<Integer, _Fields> byId = new HashMap<Integer, _Fields>();
      private static final Map<String, _Fields> byName = new HashMap<String, _Fields>();

      static {
        for (_Fields field : EnumSet.allOf(_Fields.class)) {
          byId.put((int)field._thriftId, field);
          byName.put(field.getFieldName(), field);
        }
      }

      /**
       * Find the _Fields constant that matches fieldId, or null if its not found.
       */
      public static _Fields findByThriftId(int fieldId) {
        return byId.get(fieldId);
      }

      /**
       * Find the _Fields constant that matches fieldId, throwing an exception
       * if it is not found.
       */
      public static _Fields findByThriftIdOrThrow(int fieldId) {
        _Fields fields = findByThriftId(fieldId);
        if (fields == null) throw new IllegalArgumentException("Field " + fieldId + " doesn't exist!");
        return fields;
      }

      /**
       * Find the _Fields constant that matches name, or null if its not found.
       */
      public static _Fields findByName(String name) {
        return byName.get(name);
      }

      private final short _thriftId;
      private final String _fieldName;

      _Fields(short thriftId, String fieldName) {
        _thriftId = thriftId;
        _fieldName = fieldName;
      }

      public short getThriftFieldId() {
        return _thriftId;
      }

      public String getFieldName() {
        return _fieldName;
      }
    }

    // isset id assignments

    public static final Map<_Fields, FieldMetaData> metaDataMap = Collections.unmodifiableMap(new EnumMap<_Fields, FieldMetaData>(_Fields.class) {{
      put(_Fields.AUTHENTICATION_TOKEN, new FieldMetaData("authenticationToken", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.STRING)));
      put(_Fields.LINKED_NOTEBOOK, new FieldMetaData("linkedNotebook", TFieldRequirementType.DEFAULT, 
          new StructMetaData(TType.STRUCT, com.evernote.edam.type.LinkedNotebook.class)));
    }});

    static {
      FieldMetaData.addStructMetaDataMap(updateLinkedNotebook_args.class, metaDataMap);
    }

    public updateLinkedNotebook_args() {
    }

    public updateLinkedNotebook_args(
      String authenticationToken,
      com.evernote.edam.type.LinkedNotebook linkedNotebook)
    {
      this();
      this.authenticationToken = authenticationToken;
      this.linkedNotebook = linkedNotebook;
    }

    /**
     * Performs a deep copy on <i>other</i>.
     */
    public updateLinkedNotebook_args(updateLinkedNotebook_args other) {
      if (other.isSetAuthenticationToken()) {
        this.authenticationToken = other.authenticationToken;
      }
      if (other.isSetLinkedNotebook()) {
        this.linkedNotebook = new com.evernote.edam.type.LinkedNotebook(other.linkedNotebook);
      }
    }

    public updateLinkedNotebook_args deepCopy() {
      return new updateLinkedNotebook_args(this);
    }

    @Deprecated
    public updateLinkedNotebook_args clone() {
      return new updateLinkedNotebook_args(this);
    }

    public String getAuthenticationToken() {
      return this.authenticationToken;
    }

    public void setAuthenticationToken(String authenticationToken) {
      this.authenticationToken = authenticationToken;
    }

    public void unsetAuthenticationToken() {
      this.authenticationToken = null;
    }

    /** Returns true if field authenticationToken is set (has been asigned a value) and false otherwise */
    public boolean isSetAuthenticationToken() {
      return this.authenticationToken != null;
    }

    public void setAuthenticationTokenIsSet(boolean value) {
      if (!value) {
        this.authenticationToken = null;
      }
    }

    public com.evernote.edam.type.LinkedNotebook getLinkedNotebook() {
      return this.linkedNotebook;
    }

    public void setLinkedNotebook(com.evernote.edam.type.LinkedNotebook linkedNotebook) {
      this.linkedNotebook = linkedNotebook;
    }

    public void unsetLinkedNotebook() {
      this.linkedNotebook = null;
    }

    /** Returns true if field linkedNotebook is set (has been asigned a value) and false otherwise */
    public boolean isSetLinkedNotebook() {
      return this.linkedNotebook != null;
    }

    public void setLinkedNotebookIsSet(boolean value) {
      if (!value) {
        this.linkedNotebook = null;
      }
    }

    public void setFieldValue(_Fields field, Object value) {
      switch (field) {
      case AUTHENTICATION_TOKEN:
        if (value == null) {
          unsetAuthenticationToken();
        } else {
          setAuthenticationToken((String)value);
        }
        break;

      case LINKED_NOTEBOOK:
        if (value == null) {
          unsetLinkedNotebook();
        } else {
          setLinkedNotebook((com.evernote.edam.type.LinkedNotebook)value);
        }
        break;

      }
    }

    public void setFieldValue(int fieldID, Object value) {
      setFieldValue(_Fields.findByThriftIdOrThrow(fieldID), value);
    }

    public Object getFieldValue(_Fields field) {
      switch (field) {
      case AUTHENTICATION_TOKEN:
        return getAuthenticationToken();

      case LINKED_NOTEBOOK:
        return getLinkedNotebook();

      }
      throw new IllegalStateException();
    }

    public Object getFieldValue(int fieldId) {
      return getFieldValue(_Fields.findByThriftIdOrThrow(fieldId));
    }

    /** Returns true if field corresponding to fieldID is set (has been asigned a value) and false otherwise */
    public boolean isSet(_Fields field) {
      switch (field) {
      case AUTHENTICATION_TOKEN:
        return isSetAuthenticationToken();
      case LINKED_NOTEBOOK:
        return isSetLinkedNotebook();
      }
      throw new IllegalStateException();
    }

    public boolean isSet(int fieldID) {
      return isSet(_Fields.findByThriftIdOrThrow(fieldID));
    }

    public boolean equals(Object that) {
      if (that == null)
        return false;
      if (that instanceof updateLinkedNotebook_args)
        return this.equals((updateLinkedNotebook_args)that);
      return false;
    }

    public boolean equals(updateLinkedNotebook_args that) {
      if (that == null)
        return false;

      boolean this_present_authenticationToken = true && this.isSetAuthenticationToken();
      boolean that_present_authenticationToken = true && that.isSetAuthenticationToken();
      if (this_present_authenticationToken || that_present_authenticationToken) {
        if (!(this_present_authenticationToken && that_present_authenticationToken))
          return false;
        if (!this.authenticationToken.equals(that.authenticationToken))
          return false;
      }

      boolean this_present_linkedNotebook = true && this.isSetLinkedNotebook();
      boolean that_present_linkedNotebook = true && that.isSetLinkedNotebook();
      if (this_present_linkedNotebook || that_present_linkedNotebook) {
        if (!(this_present_linkedNotebook && that_present_linkedNotebook))
          return false;
        if (!this.linkedNotebook.equals(that.linkedNotebook))
          return false;
      }

      return true;
    }

    public int hashCode() {
      return 0;
    }

    public int compareTo(updateLinkedNotebook_args other) {
      if (!getClass().equals(other.getClass())) {
        return getClass().getName().compareTo(other.getClass().getName());
      }

      int lastComparison = 0;
      updateLinkedNotebook_args typedOther = (updateLinkedNotebook_args)other;

      lastComparison = Boolean.valueOf(isSetAuthenticationToken()).compareTo(isSetAuthenticationToken());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(authenticationToken, typedOther.authenticationToken);
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = Boolean.valueOf(isSetLinkedNotebook()).compareTo(isSetLinkedNotebook());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(linkedNotebook, typedOther.linkedNotebook);
      if (lastComparison != 0) {
        return lastComparison;
      }
      return 0;
    }

    public void read(TProtocol iprot) throws TException {
      TField field;
      iprot.readStructBegin();
      while (true)
      {
        field = iprot.readFieldBegin();
        if (field.type == TType.STOP) { 
          break;
        }
        _Fields fieldId = _Fields.findByThriftId(field.id);
        if (fieldId == null) {
          TProtocolUtil.skip(iprot, field.type);
        } else {
          switch (fieldId) {
            case AUTHENTICATION_TOKEN:
              if (field.type == TType.STRING) {
                this.authenticationToken = iprot.readString();
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
            case LINKED_NOTEBOOK:
              if (field.type == TType.STRUCT) {
                this.linkedNotebook = new com.evernote.edam.type.LinkedNotebook();
                this.linkedNotebook.read(iprot);
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
          }
          iprot.readFieldEnd();
        }
      }
      iprot.readStructEnd();
      validate();
    }

    public void write(TProtocol oprot) throws TException {
      validate();

      oprot.writeStructBegin(STRUCT_DESC);
      if (this.authenticationToken != null) {
        oprot.writeFieldBegin(AUTHENTICATION_TOKEN_FIELD_DESC);
        oprot.writeString(this.authenticationToken);
        oprot.writeFieldEnd();
      }
      if (this.linkedNotebook != null) {
        oprot.writeFieldBegin(LINKED_NOTEBOOK_FIELD_DESC);
        this.linkedNotebook.write(oprot);
        oprot.writeFieldEnd();
      }
      oprot.writeFieldStop();
      oprot.writeStructEnd();
    }

    public String toString() {
      StringBuilder sb = new StringBuilder("updateLinkedNotebook_args(");
      boolean first = true;

      sb.append("authenticationToken:");
      if (this.authenticationToken == null) {
        sb.append("null");
      } else {
        sb.append(this.authenticationToken);
      }
      first = false;
      if (!first) sb.append(", ");
      sb.append("linkedNotebook:");
      if (this.linkedNotebook == null) {
        sb.append("null");
      } else {
        sb.append(this.linkedNotebook);
      }
      first = false;
      sb.append(")");
      return sb.toString();
    }

    public void validate() throws TException {
      // check for required fields
    }

  }

  public static class updateLinkedNotebook_result implements TBase<updateLinkedNotebook_result._Fields>, java.io.Serializable, Cloneable, Comparable<updateLinkedNotebook_result>   {
    private static final TStruct STRUCT_DESC = new TStruct("updateLinkedNotebook_result");

    private static final TField SUCCESS_FIELD_DESC = new TField("success", TType.STRUCT, (short)0);
    private static final TField USER_EXCEPTION_FIELD_DESC = new TField("userException", TType.STRUCT, (short)1);
    private static final TField NOT_FOUND_EXCEPTION_FIELD_DESC = new TField("notFoundException", TType.STRUCT, (short)2);
    private static final TField SYSTEM_EXCEPTION_FIELD_DESC = new TField("systemException", TType.STRUCT, (short)3);

    private com.evernote.edam.type.LinkedNotebook success;
    private com.evernote.edam.error.EDAMUserException userException;
    private com.evernote.edam.error.EDAMNotFoundException notFoundException;
    private com.evernote.edam.error.EDAMSystemException systemException;

    /** The set of fields this struct contains, along with convenience methods for finding and manipulating them. */
    public enum _Fields implements TFieldIdEnum {
      SUCCESS((short)0, "success"),
      USER_EXCEPTION((short)1, "userException"),
      NOT_FOUND_EXCEPTION((short)2, "notFoundException"),
      SYSTEM_EXCEPTION((short)3, "systemException");

      private static final Map<Integer, _Fields> byId = new HashMap<Integer, _Fields>();
      private static final Map<String, _Fields> byName = new HashMap<String, _Fields>();

      static {
        for (_Fields field : EnumSet.allOf(_Fields.class)) {
          byId.put((int)field._thriftId, field);
          byName.put(field.getFieldName(), field);
        }
      }

      /**
       * Find the _Fields constant that matches fieldId, or null if its not found.
       */
      public static _Fields findByThriftId(int fieldId) {
        return byId.get(fieldId);
      }

      /**
       * Find the _Fields constant that matches fieldId, throwing an exception
       * if it is not found.
       */
      public static _Fields findByThriftIdOrThrow(int fieldId) {
        _Fields fields = findByThriftId(fieldId);
        if (fields == null) throw new IllegalArgumentException("Field " + fieldId + " doesn't exist!");
        return fields;
      }

      /**
       * Find the _Fields constant that matches name, or null if its not found.
       */
      public static _Fields findByName(String name) {
        return byName.get(name);
      }

      private final short _thriftId;
      private final String _fieldName;

      _Fields(short thriftId, String fieldName) {
        _thriftId = thriftId;
        _fieldName = fieldName;
      }

      public short getThriftFieldId() {
        return _thriftId;
      }

      public String getFieldName() {
        return _fieldName;
      }
    }

    // isset id assignments

    public static final Map<_Fields, FieldMetaData> metaDataMap = Collections.unmodifiableMap(new EnumMap<_Fields, FieldMetaData>(_Fields.class) {{
      put(_Fields.SUCCESS, new FieldMetaData("success", TFieldRequirementType.DEFAULT, 
          new StructMetaData(TType.STRUCT, com.evernote.edam.type.LinkedNotebook.class)));
      put(_Fields.USER_EXCEPTION, new FieldMetaData("userException", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.STRUCT)));
      put(_Fields.NOT_FOUND_EXCEPTION, new FieldMetaData("notFoundException", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.STRUCT)));
      put(_Fields.SYSTEM_EXCEPTION, new FieldMetaData("systemException", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.STRUCT)));
    }});

    static {
      FieldMetaData.addStructMetaDataMap(updateLinkedNotebook_result.class, metaDataMap);
    }

    public updateLinkedNotebook_result() {
    }

    public updateLinkedNotebook_result(
      com.evernote.edam.type.LinkedNotebook success,
      com.evernote.edam.error.EDAMUserException userException,
      com.evernote.edam.error.EDAMNotFoundException notFoundException,
      com.evernote.edam.error.EDAMSystemException systemException)
    {
      this();
      this.success = success;
      this.userException = userException;
      this.notFoundException = notFoundException;
      this.systemException = systemException;
    }

    /**
     * Performs a deep copy on <i>other</i>.
     */
    public updateLinkedNotebook_result(updateLinkedNotebook_result other) {
      if (other.isSetSuccess()) {
        this.success = new com.evernote.edam.type.LinkedNotebook(other.success);
      }
      if (other.isSetUserException()) {
        this.userException = new com.evernote.edam.error.EDAMUserException(other.userException);
      }
      if (other.isSetNotFoundException()) {
        this.notFoundException = new com.evernote.edam.error.EDAMNotFoundException(other.notFoundException);
      }
      if (other.isSetSystemException()) {
        this.systemException = new com.evernote.edam.error.EDAMSystemException(other.systemException);
      }
    }

    public updateLinkedNotebook_result deepCopy() {
      return new updateLinkedNotebook_result(this);
    }

    @Deprecated
    public updateLinkedNotebook_result clone() {
      return new updateLinkedNotebook_result(this);
    }

    public com.evernote.edam.type.LinkedNotebook getSuccess() {
      return this.success;
    }

    public void setSuccess(com.evernote.edam.type.LinkedNotebook success) {
      this.success = success;
    }

    public void unsetSuccess() {
      this.success = null;
    }

    /** Returns true if field success is set (has been asigned a value) and false otherwise */
    public boolean isSetSuccess() {
      return this.success != null;
    }

    public void setSuccessIsSet(boolean value) {
      if (!value) {
        this.success = null;
      }
    }

    public com.evernote.edam.error.EDAMUserException getUserException() {
      return this.userException;
    }

    public void setUserException(com.evernote.edam.error.EDAMUserException userException) {
      this.userException = userException;
    }

    public void unsetUserException() {
      this.userException = null;
    }

    /** Returns true if field userException is set (has been asigned a value) and false otherwise */
    public boolean isSetUserException() {
      return this.userException != null;
    }

    public void setUserExceptionIsSet(boolean value) {
      if (!value) {
        this.userException = null;
      }
    }

    public com.evernote.edam.error.EDAMNotFoundException getNotFoundException() {
      return this.notFoundException;
    }

    public void setNotFoundException(com.evernote.edam.error.EDAMNotFoundException notFoundException) {
      this.notFoundException = notFoundException;
    }

    public void unsetNotFoundException() {
      this.notFoundException = null;
    }

    /** Returns true if field notFoundException is set (has been asigned a value) and false otherwise */
    public boolean isSetNotFoundException() {
      return this.notFoundException != null;
    }

    public void setNotFoundExceptionIsSet(boolean value) {
      if (!value) {
        this.notFoundException = null;
      }
    }

    public com.evernote.edam.error.EDAMSystemException getSystemException() {
      return this.systemException;
    }

    public void setSystemException(com.evernote.edam.error.EDAMSystemException systemException) {
      this.systemException = systemException;
    }

    public void unsetSystemException() {
      this.systemException = null;
    }

    /** Returns true if field systemException is set (has been asigned a value) and false otherwise */
    public boolean isSetSystemException() {
      return this.systemException != null;
    }

    public void setSystemExceptionIsSet(boolean value) {
      if (!value) {
        this.systemException = null;
      }
    }

    public void setFieldValue(_Fields field, Object value) {
      switch (field) {
      case SUCCESS:
        if (value == null) {
          unsetSuccess();
        } else {
          setSuccess((com.evernote.edam.type.LinkedNotebook)value);
        }
        break;

      case USER_EXCEPTION:
        if (value == null) {
          unsetUserException();
        } else {
          setUserException((com.evernote.edam.error.EDAMUserException)value);
        }
        break;

      case NOT_FOUND_EXCEPTION:
        if (value == null) {
          unsetNotFoundException();
        } else {
          setNotFoundException((com.evernote.edam.error.EDAMNotFoundException)value);
        }
        break;

      case SYSTEM_EXCEPTION:
        if (value == null) {
          unsetSystemException();
        } else {
          setSystemException((com.evernote.edam.error.EDAMSystemException)value);
        }
        break;

      }
    }

    public void setFieldValue(int fieldID, Object value) {
      setFieldValue(_Fields.findByThriftIdOrThrow(fieldID), value);
    }

    public Object getFieldValue(_Fields field) {
      switch (field) {
      case SUCCESS:
        return getSuccess();

      case USER_EXCEPTION:
        return getUserException();

      case NOT_FOUND_EXCEPTION:
        return getNotFoundException();

      case SYSTEM_EXCEPTION:
        return getSystemException();

      }
      throw new IllegalStateException();
    }

    public Object getFieldValue(int fieldId) {
      return getFieldValue(_Fields.findByThriftIdOrThrow(fieldId));
    }

    /** Returns true if field corresponding to fieldID is set (has been asigned a value) and false otherwise */
    public boolean isSet(_Fields field) {
      switch (field) {
      case SUCCESS:
        return isSetSuccess();
      case USER_EXCEPTION:
        return isSetUserException();
      case NOT_FOUND_EXCEPTION:
        return isSetNotFoundException();
      case SYSTEM_EXCEPTION:
        return isSetSystemException();
      }
      throw new IllegalStateException();
    }

    public boolean isSet(int fieldID) {
      return isSet(_Fields.findByThriftIdOrThrow(fieldID));
    }

    public boolean equals(Object that) {
      if (that == null)
        return false;
      if (that instanceof updateLinkedNotebook_result)
        return this.equals((updateLinkedNotebook_result)that);
      return false;
    }

    public boolean equals(updateLinkedNotebook_result that) {
      if (that == null)
        return false;

      boolean this_present_success = true && this.isSetSuccess();
      boolean that_present_success = true && that.isSetSuccess();
      if (this_present_success || that_present_success) {
        if (!(this_present_success && that_present_success))
          return false;
        if (!this.success.equals(that.success))
          return false;
      }

      boolean this_present_userException = true && this.isSetUserException();
      boolean that_present_userException = true && that.isSetUserException();
      if (this_present_userException || that_present_userException) {
        if (!(this_present_userException && that_present_userException))
          return false;
        if (!this.userException.equals(that.userException))
          return false;
      }

      boolean this_present_notFoundException = true && this.isSetNotFoundException();
      boolean that_present_notFoundException = true && that.isSetNotFoundException();
      if (this_present_notFoundException || that_present_notFoundException) {
        if (!(this_present_notFoundException && that_present_notFoundException))
          return false;
        if (!this.notFoundException.equals(that.notFoundException))
          return false;
      }

      boolean this_present_systemException = true && this.isSetSystemException();
      boolean that_present_systemException = true && that.isSetSystemException();
      if (this_present_systemException || that_present_systemException) {
        if (!(this_present_systemException && that_present_systemException))
          return false;
        if (!this.systemException.equals(that.systemException))
          return false;
      }

      return true;
    }

    public int hashCode() {
      return 0;
    }

    public int compareTo(updateLinkedNotebook_result other) {
      if (!getClass().equals(other.getClass())) {
        return getClass().getName().compareTo(other.getClass().getName());
      }

      int lastComparison = 0;
      updateLinkedNotebook_result typedOther = (updateLinkedNotebook_result)other;

      lastComparison = Boolean.valueOf(isSetSuccess()).compareTo(isSetSuccess());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(success, typedOther.success);
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = Boolean.valueOf(isSetUserException()).compareTo(isSetUserException());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(userException, typedOther.userException);
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = Boolean.valueOf(isSetNotFoundException()).compareTo(isSetNotFoundException());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(notFoundException, typedOther.notFoundException);
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = Boolean.valueOf(isSetSystemException()).compareTo(isSetSystemException());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(systemException, typedOther.systemException);
      if (lastComparison != 0) {
        return lastComparison;
      }
      return 0;
    }

    public void read(TProtocol iprot) throws TException {
      TField field;
      iprot.readStructBegin();
      while (true)
      {
        field = iprot.readFieldBegin();
        if (field.type == TType.STOP) { 
          break;
        }
        _Fields fieldId = _Fields.findByThriftId(field.id);
        if (fieldId == null) {
          TProtocolUtil.skip(iprot, field.type);
        } else {
          switch (fieldId) {
            case SUCCESS:
              if (field.type == TType.STRUCT) {
                this.success = new com.evernote.edam.type.LinkedNotebook();
                this.success.read(iprot);
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
            case USER_EXCEPTION:
              if (field.type == TType.STRUCT) {
                this.userException = new com.evernote.edam.error.EDAMUserException();
                this.userException.read(iprot);
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
            case NOT_FOUND_EXCEPTION:
              if (field.type == TType.STRUCT) {
                this.notFoundException = new com.evernote.edam.error.EDAMNotFoundException();
                this.notFoundException.read(iprot);
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
            case SYSTEM_EXCEPTION:
              if (field.type == TType.STRUCT) {
                this.systemException = new com.evernote.edam.error.EDAMSystemException();
                this.systemException.read(iprot);
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
          }
          iprot.readFieldEnd();
        }
      }
      iprot.readStructEnd();
      validate();
    }

    public void write(TProtocol oprot) throws TException {
      oprot.writeStructBegin(STRUCT_DESC);

      if (this.isSetSuccess()) {
        oprot.writeFieldBegin(SUCCESS_FIELD_DESC);
        this.success.write(oprot);
        oprot.writeFieldEnd();
      } else if (this.isSetUserException()) {
        oprot.writeFieldBegin(USER_EXCEPTION_FIELD_DESC);
        this.userException.write(oprot);
        oprot.writeFieldEnd();
      } else if (this.isSetNotFoundException()) {
        oprot.writeFieldBegin(NOT_FOUND_EXCEPTION_FIELD_DESC);
        this.notFoundException.write(oprot);
        oprot.writeFieldEnd();
      } else if (this.isSetSystemException()) {
        oprot.writeFieldBegin(SYSTEM_EXCEPTION_FIELD_DESC);
        this.systemException.write(oprot);
        oprot.writeFieldEnd();
      }
      oprot.writeFieldStop();
      oprot.writeStructEnd();
    }

    public String toString() {
      StringBuilder sb = new StringBuilder("updateLinkedNotebook_result(");
      boolean first = true;

      sb.append("success:");
      if (this.success == null) {
        sb.append("null");
      } else {
        sb.append(this.success);
      }
      first = false;
      if (!first) sb.append(", ");
      sb.append("userException:");
      if (this.userException == null) {
        sb.append("null");
      } else {
        sb.append(this.userException);
      }
      first = false;
      if (!first) sb.append(", ");
      sb.append("notFoundException:");
      if (this.notFoundException == null) {
        sb.append("null");
      } else {
        sb.append(this.notFoundException);
      }
      first = false;
      if (!first) sb.append(", ");
      sb.append("systemException:");
      if (this.systemException == null) {
        sb.append("null");
      } else {
        sb.append(this.systemException);
      }
      first = false;
      sb.append(")");
      return sb.toString();
    }

    public void validate() throws TException {
      // check for required fields
    }

  }

  public static class listLinkedNotebooks_args implements TBase<listLinkedNotebooks_args._Fields>, java.io.Serializable, Cloneable, Comparable<listLinkedNotebooks_args>   {
    private static final TStruct STRUCT_DESC = new TStruct("listLinkedNotebooks_args");

    private static final TField AUTHENTICATION_TOKEN_FIELD_DESC = new TField("authenticationToken", TType.STRING, (short)1);

    private String authenticationToken;

    /** The set of fields this struct contains, along with convenience methods for finding and manipulating them. */
    public enum _Fields implements TFieldIdEnum {
      AUTHENTICATION_TOKEN((short)1, "authenticationToken");

      private static final Map<Integer, _Fields> byId = new HashMap<Integer, _Fields>();
      private static final Map<String, _Fields> byName = new HashMap<String, _Fields>();

      static {
        for (_Fields field : EnumSet.allOf(_Fields.class)) {
          byId.put((int)field._thriftId, field);
          byName.put(field.getFieldName(), field);
        }
      }

      /**
       * Find the _Fields constant that matches fieldId, or null if its not found.
       */
      public static _Fields findByThriftId(int fieldId) {
        return byId.get(fieldId);
      }

      /**
       * Find the _Fields constant that matches fieldId, throwing an exception
       * if it is not found.
       */
      public static _Fields findByThriftIdOrThrow(int fieldId) {
        _Fields fields = findByThriftId(fieldId);
        if (fields == null) throw new IllegalArgumentException("Field " + fieldId + " doesn't exist!");
        return fields;
      }

      /**
       * Find the _Fields constant that matches name, or null if its not found.
       */
      public static _Fields findByName(String name) {
        return byName.get(name);
      }

      private final short _thriftId;
      private final String _fieldName;

      _Fields(short thriftId, String fieldName) {
        _thriftId = thriftId;
        _fieldName = fieldName;
      }

      public short getThriftFieldId() {
        return _thriftId;
      }

      public String getFieldName() {
        return _fieldName;
      }
    }

    // isset id assignments

    public static final Map<_Fields, FieldMetaData> metaDataMap = Collections.unmodifiableMap(new EnumMap<_Fields, FieldMetaData>(_Fields.class) {{
      put(_Fields.AUTHENTICATION_TOKEN, new FieldMetaData("authenticationToken", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.STRING)));
    }});

    static {
      FieldMetaData.addStructMetaDataMap(listLinkedNotebooks_args.class, metaDataMap);
    }

    public listLinkedNotebooks_args() {
    }

    public listLinkedNotebooks_args(
      String authenticationToken)
    {
      this();
      this.authenticationToken = authenticationToken;
    }

    /**
     * Performs a deep copy on <i>other</i>.
     */
    public listLinkedNotebooks_args(listLinkedNotebooks_args other) {
      if (other.isSetAuthenticationToken()) {
        this.authenticationToken = other.authenticationToken;
      }
    }

    public listLinkedNotebooks_args deepCopy() {
      return new listLinkedNotebooks_args(this);
    }

    @Deprecated
    public listLinkedNotebooks_args clone() {
      return new listLinkedNotebooks_args(this);
    }

    public String getAuthenticationToken() {
      return this.authenticationToken;
    }

    public void setAuthenticationToken(String authenticationToken) {
      this.authenticationToken = authenticationToken;
    }

    public void unsetAuthenticationToken() {
      this.authenticationToken = null;
    }

    /** Returns true if field authenticationToken is set (has been asigned a value) and false otherwise */
    public boolean isSetAuthenticationToken() {
      return this.authenticationToken != null;
    }

    public void setAuthenticationTokenIsSet(boolean value) {
      if (!value) {
        this.authenticationToken = null;
      }
    }

    public void setFieldValue(_Fields field, Object value) {
      switch (field) {
      case AUTHENTICATION_TOKEN:
        if (value == null) {
          unsetAuthenticationToken();
        } else {
          setAuthenticationToken((String)value);
        }
        break;

      }
    }

    public void setFieldValue(int fieldID, Object value) {
      setFieldValue(_Fields.findByThriftIdOrThrow(fieldID), value);
    }

    public Object getFieldValue(_Fields field) {
      switch (field) {
      case AUTHENTICATION_TOKEN:
        return getAuthenticationToken();

      }
      throw new IllegalStateException();
    }

    public Object getFieldValue(int fieldId) {
      return getFieldValue(_Fields.findByThriftIdOrThrow(fieldId));
    }

    /** Returns true if field corresponding to fieldID is set (has been asigned a value) and false otherwise */
    public boolean isSet(_Fields field) {
      switch (field) {
      case AUTHENTICATION_TOKEN:
        return isSetAuthenticationToken();
      }
      throw new IllegalStateException();
    }

    public boolean isSet(int fieldID) {
      return isSet(_Fields.findByThriftIdOrThrow(fieldID));
    }

    public boolean equals(Object that) {
      if (that == null)
        return false;
      if (that instanceof listLinkedNotebooks_args)
        return this.equals((listLinkedNotebooks_args)that);
      return false;
    }

    public boolean equals(listLinkedNotebooks_args that) {
      if (that == null)
        return false;

      boolean this_present_authenticationToken = true && this.isSetAuthenticationToken();
      boolean that_present_authenticationToken = true && that.isSetAuthenticationToken();
      if (this_present_authenticationToken || that_present_authenticationToken) {
        if (!(this_present_authenticationToken && that_present_authenticationToken))
          return false;
        if (!this.authenticationToken.equals(that.authenticationToken))
          return false;
      }

      return true;
    }

    public int hashCode() {
      return 0;
    }

    public int compareTo(listLinkedNotebooks_args other) {
      if (!getClass().equals(other.getClass())) {
        return getClass().getName().compareTo(other.getClass().getName());
      }

      int lastComparison = 0;
      listLinkedNotebooks_args typedOther = (listLinkedNotebooks_args)other;

      lastComparison = Boolean.valueOf(isSetAuthenticationToken()).compareTo(isSetAuthenticationToken());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(authenticationToken, typedOther.authenticationToken);
      if (lastComparison != 0) {
        return lastComparison;
      }
      return 0;
    }

    public void read(TProtocol iprot) throws TException {
      TField field;
      iprot.readStructBegin();
      while (true)
      {
        field = iprot.readFieldBegin();
        if (field.type == TType.STOP) { 
          break;
        }
        _Fields fieldId = _Fields.findByThriftId(field.id);
        if (fieldId == null) {
          TProtocolUtil.skip(iprot, field.type);
        } else {
          switch (fieldId) {
            case AUTHENTICATION_TOKEN:
              if (field.type == TType.STRING) {
                this.authenticationToken = iprot.readString();
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
          }
          iprot.readFieldEnd();
        }
      }
      iprot.readStructEnd();
      validate();
    }

    public void write(TProtocol oprot) throws TException {
      validate();

      oprot.writeStructBegin(STRUCT_DESC);
      if (this.authenticationToken != null) {
        oprot.writeFieldBegin(AUTHENTICATION_TOKEN_FIELD_DESC);
        oprot.writeString(this.authenticationToken);
        oprot.writeFieldEnd();
      }
      oprot.writeFieldStop();
      oprot.writeStructEnd();
    }

    public String toString() {
      StringBuilder sb = new StringBuilder("listLinkedNotebooks_args(");
      boolean first = true;

      sb.append("authenticationToken:");
      if (this.authenticationToken == null) {
        sb.append("null");
      } else {
        sb.append(this.authenticationToken);
      }
      first = false;
      sb.append(")");
      return sb.toString();
    }

    public void validate() throws TException {
      // check for required fields
    }

  }

  public static class listLinkedNotebooks_result implements TBase<listLinkedNotebooks_result._Fields>, java.io.Serializable, Cloneable, Comparable<listLinkedNotebooks_result>   {
    private static final TStruct STRUCT_DESC = new TStruct("listLinkedNotebooks_result");

    private static final TField SUCCESS_FIELD_DESC = new TField("success", TType.LIST, (short)0);
    private static final TField USER_EXCEPTION_FIELD_DESC = new TField("userException", TType.STRUCT, (short)1);
    private static final TField NOT_FOUND_EXCEPTION_FIELD_DESC = new TField("notFoundException", TType.STRUCT, (short)2);
    private static final TField SYSTEM_EXCEPTION_FIELD_DESC = new TField("systemException", TType.STRUCT, (short)3);

    private List<com.evernote.edam.type.LinkedNotebook> success;
    private com.evernote.edam.error.EDAMUserException userException;
    private com.evernote.edam.error.EDAMNotFoundException notFoundException;
    private com.evernote.edam.error.EDAMSystemException systemException;

    /** The set of fields this struct contains, along with convenience methods for finding and manipulating them. */
    public enum _Fields implements TFieldIdEnum {
      SUCCESS((short)0, "success"),
      USER_EXCEPTION((short)1, "userException"),
      NOT_FOUND_EXCEPTION((short)2, "notFoundException"),
      SYSTEM_EXCEPTION((short)3, "systemException");

      private static final Map<Integer, _Fields> byId = new HashMap<Integer, _Fields>();
      private static final Map<String, _Fields> byName = new HashMap<String, _Fields>();

      static {
        for (_Fields field : EnumSet.allOf(_Fields.class)) {
          byId.put((int)field._thriftId, field);
          byName.put(field.getFieldName(), field);
        }
      }

      /**
       * Find the _Fields constant that matches fieldId, or null if its not found.
       */
      public static _Fields findByThriftId(int fieldId) {
        return byId.get(fieldId);
      }

      /**
       * Find the _Fields constant that matches fieldId, throwing an exception
       * if it is not found.
       */
      public static _Fields findByThriftIdOrThrow(int fieldId) {
        _Fields fields = findByThriftId(fieldId);
        if (fields == null) throw new IllegalArgumentException("Field " + fieldId + " doesn't exist!");
        return fields;
      }

      /**
       * Find the _Fields constant that matches name, or null if its not found.
       */
      public static _Fields findByName(String name) {
        return byName.get(name);
      }

      private final short _thriftId;
      private final String _fieldName;

      _Fields(short thriftId, String fieldName) {
        _thriftId = thriftId;
        _fieldName = fieldName;
      }

      public short getThriftFieldId() {
        return _thriftId;
      }

      public String getFieldName() {
        return _fieldName;
      }
    }

    // isset id assignments

    public static final Map<_Fields, FieldMetaData> metaDataMap = Collections.unmodifiableMap(new EnumMap<_Fields, FieldMetaData>(_Fields.class) {{
      put(_Fields.SUCCESS, new FieldMetaData("success", TFieldRequirementType.DEFAULT, 
          new ListMetaData(TType.LIST, 
              new StructMetaData(TType.STRUCT, com.evernote.edam.type.LinkedNotebook.class))));
      put(_Fields.USER_EXCEPTION, new FieldMetaData("userException", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.STRUCT)));
      put(_Fields.NOT_FOUND_EXCEPTION, new FieldMetaData("notFoundException", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.STRUCT)));
      put(_Fields.SYSTEM_EXCEPTION, new FieldMetaData("systemException", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.STRUCT)));
    }});

    static {
      FieldMetaData.addStructMetaDataMap(listLinkedNotebooks_result.class, metaDataMap);
    }

    public listLinkedNotebooks_result() {
    }

    public listLinkedNotebooks_result(
      List<com.evernote.edam.type.LinkedNotebook> success,
      com.evernote.edam.error.EDAMUserException userException,
      com.evernote.edam.error.EDAMNotFoundException notFoundException,
      com.evernote.edam.error.EDAMSystemException systemException)
    {
      this();
      this.success = success;
      this.userException = userException;
      this.notFoundException = notFoundException;
      this.systemException = systemException;
    }

    /**
     * Performs a deep copy on <i>other</i>.
     */
    public listLinkedNotebooks_result(listLinkedNotebooks_result other) {
      if (other.isSetSuccess()) {
        List<com.evernote.edam.type.LinkedNotebook> __this__success = new ArrayList<com.evernote.edam.type.LinkedNotebook>();
        for (com.evernote.edam.type.LinkedNotebook other_element : other.success) {
          __this__success.add(new com.evernote.edam.type.LinkedNotebook(other_element));
        }
        this.success = __this__success;
      }
      if (other.isSetUserException()) {
        this.userException = new com.evernote.edam.error.EDAMUserException(other.userException);
      }
      if (other.isSetNotFoundException()) {
        this.notFoundException = new com.evernote.edam.error.EDAMNotFoundException(other.notFoundException);
      }
      if (other.isSetSystemException()) {
        this.systemException = new com.evernote.edam.error.EDAMSystemException(other.systemException);
      }
    }

    public listLinkedNotebooks_result deepCopy() {
      return new listLinkedNotebooks_result(this);
    }

    @Deprecated
    public listLinkedNotebooks_result clone() {
      return new listLinkedNotebooks_result(this);
    }

    public int getSuccessSize() {
      return (this.success == null) ? 0 : this.success.size();
    }

    public java.util.Iterator<com.evernote.edam.type.LinkedNotebook> getSuccessIterator() {
      return (this.success == null) ? null : this.success.iterator();
    }

    public void addToSuccess(com.evernote.edam.type.LinkedNotebook elem) {
      if (this.success == null) {
        this.success = new ArrayList<com.evernote.edam.type.LinkedNotebook>();
      }
      this.success.add(elem);
    }

    public List<com.evernote.edam.type.LinkedNotebook> getSuccess() {
      return this.success;
    }

    public void setSuccess(List<com.evernote.edam.type.LinkedNotebook> success) {
      this.success = success;
    }

    public void unsetSuccess() {
      this.success = null;
    }

    /** Returns true if field success is set (has been asigned a value) and false otherwise */
    public boolean isSetSuccess() {
      return this.success != null;
    }

    public void setSuccessIsSet(boolean value) {
      if (!value) {
        this.success = null;
      }
    }

    public com.evernote.edam.error.EDAMUserException getUserException() {
      return this.userException;
    }

    public void setUserException(com.evernote.edam.error.EDAMUserException userException) {
      this.userException = userException;
    }

    public void unsetUserException() {
      this.userException = null;
    }

    /** Returns true if field userException is set (has been asigned a value) and false otherwise */
    public boolean isSetUserException() {
      return this.userException != null;
    }

    public void setUserExceptionIsSet(boolean value) {
      if (!value) {
        this.userException = null;
      }
    }

    public com.evernote.edam.error.EDAMNotFoundException getNotFoundException() {
      return this.notFoundException;
    }

    public void setNotFoundException(com.evernote.edam.error.EDAMNotFoundException notFoundException) {
      this.notFoundException = notFoundException;
    }

    public void unsetNotFoundException() {
      this.notFoundException = null;
    }

    /** Returns true if field notFoundException is set (has been asigned a value) and false otherwise */
    public boolean isSetNotFoundException() {
      return this.notFoundException != null;
    }

    public void setNotFoundExceptionIsSet(boolean value) {
      if (!value) {
        this.notFoundException = null;
      }
    }

    public com.evernote.edam.error.EDAMSystemException getSystemException() {
      return this.systemException;
    }

    public void setSystemException(com.evernote.edam.error.EDAMSystemException systemException) {
      this.systemException = systemException;
    }

    public void unsetSystemException() {
      this.systemException = null;
    }

    /** Returns true if field systemException is set (has been asigned a value) and false otherwise */
    public boolean isSetSystemException() {
      return this.systemException != null;
    }

    public void setSystemExceptionIsSet(boolean value) {
      if (!value) {
        this.systemException = null;
      }
    }

    public void setFieldValue(_Fields field, Object value) {
      switch (field) {
      case SUCCESS:
        if (value == null) {
          unsetSuccess();
        } else {
          setSuccess((List<com.evernote.edam.type.LinkedNotebook>)value);
        }
        break;

      case USER_EXCEPTION:
        if (value == null) {
          unsetUserException();
        } else {
          setUserException((com.evernote.edam.error.EDAMUserException)value);
        }
        break;

      case NOT_FOUND_EXCEPTION:
        if (value == null) {
          unsetNotFoundException();
        } else {
          setNotFoundException((com.evernote.edam.error.EDAMNotFoundException)value);
        }
        break;

      case SYSTEM_EXCEPTION:
        if (value == null) {
          unsetSystemException();
        } else {
          setSystemException((com.evernote.edam.error.EDAMSystemException)value);
        }
        break;

      }
    }

    public void setFieldValue(int fieldID, Object value) {
      setFieldValue(_Fields.findByThriftIdOrThrow(fieldID), value);
    }

    public Object getFieldValue(_Fields field) {
      switch (field) {
      case SUCCESS:
        return getSuccess();

      case USER_EXCEPTION:
        return getUserException();

      case NOT_FOUND_EXCEPTION:
        return getNotFoundException();

      case SYSTEM_EXCEPTION:
        return getSystemException();

      }
      throw new IllegalStateException();
    }

    public Object getFieldValue(int fieldId) {
      return getFieldValue(_Fields.findByThriftIdOrThrow(fieldId));
    }

    /** Returns true if field corresponding to fieldID is set (has been asigned a value) and false otherwise */
    public boolean isSet(_Fields field) {
      switch (field) {
      case SUCCESS:
        return isSetSuccess();
      case USER_EXCEPTION:
        return isSetUserException();
      case NOT_FOUND_EXCEPTION:
        return isSetNotFoundException();
      case SYSTEM_EXCEPTION:
        return isSetSystemException();
      }
      throw new IllegalStateException();
    }

    public boolean isSet(int fieldID) {
      return isSet(_Fields.findByThriftIdOrThrow(fieldID));
    }

    public boolean equals(Object that) {
      if (that == null)
        return false;
      if (that instanceof listLinkedNotebooks_result)
        return this.equals((listLinkedNotebooks_result)that);
      return false;
    }

    public boolean equals(listLinkedNotebooks_result that) {
      if (that == null)
        return false;

      boolean this_present_success = true && this.isSetSuccess();
      boolean that_present_success = true && that.isSetSuccess();
      if (this_present_success || that_present_success) {
        if (!(this_present_success && that_present_success))
          return false;
        if (!this.success.equals(that.success))
          return false;
      }

      boolean this_present_userException = true && this.isSetUserException();
      boolean that_present_userException = true && that.isSetUserException();
      if (this_present_userException || that_present_userException) {
        if (!(this_present_userException && that_present_userException))
          return false;
        if (!this.userException.equals(that.userException))
          return false;
      }

      boolean this_present_notFoundException = true && this.isSetNotFoundException();
      boolean that_present_notFoundException = true && that.isSetNotFoundException();
      if (this_present_notFoundException || that_present_notFoundException) {
        if (!(this_present_notFoundException && that_present_notFoundException))
          return false;
        if (!this.notFoundException.equals(that.notFoundException))
          return false;
      }

      boolean this_present_systemException = true && this.isSetSystemException();
      boolean that_present_systemException = true && that.isSetSystemException();
      if (this_present_systemException || that_present_systemException) {
        if (!(this_present_systemException && that_present_systemException))
          return false;
        if (!this.systemException.equals(that.systemException))
          return false;
      }

      return true;
    }

    public int hashCode() {
      return 0;
    }

    public int compareTo(listLinkedNotebooks_result other) {
      if (!getClass().equals(other.getClass())) {
        return getClass().getName().compareTo(other.getClass().getName());
      }

      int lastComparison = 0;
      listLinkedNotebooks_result typedOther = (listLinkedNotebooks_result)other;

      lastComparison = Boolean.valueOf(isSetSuccess()).compareTo(isSetSuccess());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(success, typedOther.success);
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = Boolean.valueOf(isSetUserException()).compareTo(isSetUserException());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(userException, typedOther.userException);
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = Boolean.valueOf(isSetNotFoundException()).compareTo(isSetNotFoundException());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(notFoundException, typedOther.notFoundException);
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = Boolean.valueOf(isSetSystemException()).compareTo(isSetSystemException());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(systemException, typedOther.systemException);
      if (lastComparison != 0) {
        return lastComparison;
      }
      return 0;
    }

    public void read(TProtocol iprot) throws TException {
      TField field;
      iprot.readStructBegin();
      while (true)
      {
        field = iprot.readFieldBegin();
        if (field.type == TType.STOP) { 
          break;
        }
        _Fields fieldId = _Fields.findByThriftId(field.id);
        if (fieldId == null) {
          TProtocolUtil.skip(iprot, field.type);
        } else {
          switch (fieldId) {
            case SUCCESS:
              if (field.type == TType.LIST) {
                {
                  TList _list119 = iprot.readListBegin();
                  this.success = new ArrayList<com.evernote.edam.type.LinkedNotebook>(_list119.size);
                  for (int _i120 = 0; _i120 < _list119.size; ++_i120)
                  {
                    com.evernote.edam.type.LinkedNotebook _elem121;
                    _elem121 = new com.evernote.edam.type.LinkedNotebook();
                    _elem121.read(iprot);
                    this.success.add(_elem121);
                  }
                  iprot.readListEnd();
                }
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
            case USER_EXCEPTION:
              if (field.type == TType.STRUCT) {
                this.userException = new com.evernote.edam.error.EDAMUserException();
                this.userException.read(iprot);
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
            case NOT_FOUND_EXCEPTION:
              if (field.type == TType.STRUCT) {
                this.notFoundException = new com.evernote.edam.error.EDAMNotFoundException();
                this.notFoundException.read(iprot);
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
            case SYSTEM_EXCEPTION:
              if (field.type == TType.STRUCT) {
                this.systemException = new com.evernote.edam.error.EDAMSystemException();
                this.systemException.read(iprot);
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
          }
          iprot.readFieldEnd();
        }
      }
      iprot.readStructEnd();
      validate();
    }

    public void write(TProtocol oprot) throws TException {
      oprot.writeStructBegin(STRUCT_DESC);

      if (this.isSetSuccess()) {
        oprot.writeFieldBegin(SUCCESS_FIELD_DESC);
        {
          oprot.writeListBegin(new TList(TType.STRUCT, this.success.size()));
          for (com.evernote.edam.type.LinkedNotebook _iter122 : this.success)
          {
            _iter122.write(oprot);
          }
          oprot.writeListEnd();
        }
        oprot.writeFieldEnd();
      } else if (this.isSetUserException()) {
        oprot.writeFieldBegin(USER_EXCEPTION_FIELD_DESC);
        this.userException.write(oprot);
        oprot.writeFieldEnd();
      } else if (this.isSetNotFoundException()) {
        oprot.writeFieldBegin(NOT_FOUND_EXCEPTION_FIELD_DESC);
        this.notFoundException.write(oprot);
        oprot.writeFieldEnd();
      } else if (this.isSetSystemException()) {
        oprot.writeFieldBegin(SYSTEM_EXCEPTION_FIELD_DESC);
        this.systemException.write(oprot);
        oprot.writeFieldEnd();
      }
      oprot.writeFieldStop();
      oprot.writeStructEnd();
    }

    public String toString() {
      StringBuilder sb = new StringBuilder("listLinkedNotebooks_result(");
      boolean first = true;

      sb.append("success:");
      if (this.success == null) {
        sb.append("null");
      } else {
        sb.append(this.success);
      }
      first = false;
      if (!first) sb.append(", ");
      sb.append("userException:");
      if (this.userException == null) {
        sb.append("null");
      } else {
        sb.append(this.userException);
      }
      first = false;
      if (!first) sb.append(", ");
      sb.append("notFoundException:");
      if (this.notFoundException == null) {
        sb.append("null");
      } else {
        sb.append(this.notFoundException);
      }
      first = false;
      if (!first) sb.append(", ");
      sb.append("systemException:");
      if (this.systemException == null) {
        sb.append("null");
      } else {
        sb.append(this.systemException);
      }
      first = false;
      sb.append(")");
      return sb.toString();
    }

    public void validate() throws TException {
      // check for required fields
    }

  }

  public static class expungeLinkedNotebook_args implements TBase<expungeLinkedNotebook_args._Fields>, java.io.Serializable, Cloneable, Comparable<expungeLinkedNotebook_args>   {
    private static final TStruct STRUCT_DESC = new TStruct("expungeLinkedNotebook_args");

    private static final TField AUTHENTICATION_TOKEN_FIELD_DESC = new TField("authenticationToken", TType.STRING, (short)1);
    private static final TField LINKED_NOTEBOOK_ID_FIELD_DESC = new TField("linkedNotebookId", TType.I64, (short)2);

    private String authenticationToken;
    private long linkedNotebookId;

    /** The set of fields this struct contains, along with convenience methods for finding and manipulating them. */
    public enum _Fields implements TFieldIdEnum {
      AUTHENTICATION_TOKEN((short)1, "authenticationToken"),
      LINKED_NOTEBOOK_ID((short)2, "linkedNotebookId");

      private static final Map<Integer, _Fields> byId = new HashMap<Integer, _Fields>();
      private static final Map<String, _Fields> byName = new HashMap<String, _Fields>();

      static {
        for (_Fields field : EnumSet.allOf(_Fields.class)) {
          byId.put((int)field._thriftId, field);
          byName.put(field.getFieldName(), field);
        }
      }

      /**
       * Find the _Fields constant that matches fieldId, or null if its not found.
       */
      public static _Fields findByThriftId(int fieldId) {
        return byId.get(fieldId);
      }

      /**
       * Find the _Fields constant that matches fieldId, throwing an exception
       * if it is not found.
       */
      public static _Fields findByThriftIdOrThrow(int fieldId) {
        _Fields fields = findByThriftId(fieldId);
        if (fields == null) throw new IllegalArgumentException("Field " + fieldId + " doesn't exist!");
        return fields;
      }

      /**
       * Find the _Fields constant that matches name, or null if its not found.
       */
      public static _Fields findByName(String name) {
        return byName.get(name);
      }

      private final short _thriftId;
      private final String _fieldName;

      _Fields(short thriftId, String fieldName) {
        _thriftId = thriftId;
        _fieldName = fieldName;
      }

      public short getThriftFieldId() {
        return _thriftId;
      }

      public String getFieldName() {
        return _fieldName;
      }
    }

    // isset id assignments
    private static final int __LINKEDNOTEBOOKID_ISSET_ID = 0;
    private BitSet __isset_bit_vector = new BitSet(1);

    public static final Map<_Fields, FieldMetaData> metaDataMap = Collections.unmodifiableMap(new EnumMap<_Fields, FieldMetaData>(_Fields.class) {{
      put(_Fields.AUTHENTICATION_TOKEN, new FieldMetaData("authenticationToken", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.STRING)));
      put(_Fields.LINKED_NOTEBOOK_ID, new FieldMetaData("linkedNotebookId", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.I64)));
    }});

    static {
      FieldMetaData.addStructMetaDataMap(expungeLinkedNotebook_args.class, metaDataMap);
    }

    public expungeLinkedNotebook_args() {
    }

    public expungeLinkedNotebook_args(
      String authenticationToken,
      long linkedNotebookId)
    {
      this();
      this.authenticationToken = authenticationToken;
      this.linkedNotebookId = linkedNotebookId;
      setLinkedNotebookIdIsSet(true);
    }

    /**
     * Performs a deep copy on <i>other</i>.
     */
    public expungeLinkedNotebook_args(expungeLinkedNotebook_args other) {
      __isset_bit_vector.clear();
      __isset_bit_vector.or(other.__isset_bit_vector);
      if (other.isSetAuthenticationToken()) {
        this.authenticationToken = other.authenticationToken;
      }
      this.linkedNotebookId = other.linkedNotebookId;
    }

    public expungeLinkedNotebook_args deepCopy() {
      return new expungeLinkedNotebook_args(this);
    }

    @Deprecated
    public expungeLinkedNotebook_args clone() {
      return new expungeLinkedNotebook_args(this);
    }

    public String getAuthenticationToken() {
      return this.authenticationToken;
    }

    public void setAuthenticationToken(String authenticationToken) {
      this.authenticationToken = authenticationToken;
    }

    public void unsetAuthenticationToken() {
      this.authenticationToken = null;
    }

    /** Returns true if field authenticationToken is set (has been asigned a value) and false otherwise */
    public boolean isSetAuthenticationToken() {
      return this.authenticationToken != null;
    }

    public void setAuthenticationTokenIsSet(boolean value) {
      if (!value) {
        this.authenticationToken = null;
      }
    }

    public long getLinkedNotebookId() {
      return this.linkedNotebookId;
    }

    public void setLinkedNotebookId(long linkedNotebookId) {
      this.linkedNotebookId = linkedNotebookId;
      setLinkedNotebookIdIsSet(true);
    }

    public void unsetLinkedNotebookId() {
      __isset_bit_vector.clear(__LINKEDNOTEBOOKID_ISSET_ID);
    }

    /** Returns true if field linkedNotebookId is set (has been asigned a value) and false otherwise */
    public boolean isSetLinkedNotebookId() {
      return __isset_bit_vector.get(__LINKEDNOTEBOOKID_ISSET_ID);
    }

    public void setLinkedNotebookIdIsSet(boolean value) {
      __isset_bit_vector.set(__LINKEDNOTEBOOKID_ISSET_ID, value);
    }

    public void setFieldValue(_Fields field, Object value) {
      switch (field) {
      case AUTHENTICATION_TOKEN:
        if (value == null) {
          unsetAuthenticationToken();
        } else {
          setAuthenticationToken((String)value);
        }
        break;

      case LINKED_NOTEBOOK_ID:
        if (value == null) {
          unsetLinkedNotebookId();
        } else {
          setLinkedNotebookId((Long)value);
        }
        break;

      }
    }

    public void setFieldValue(int fieldID, Object value) {
      setFieldValue(_Fields.findByThriftIdOrThrow(fieldID), value);
    }

    public Object getFieldValue(_Fields field) {
      switch (field) {
      case AUTHENTICATION_TOKEN:
        return getAuthenticationToken();

      case LINKED_NOTEBOOK_ID:
        return new Long(getLinkedNotebookId());

      }
      throw new IllegalStateException();
    }

    public Object getFieldValue(int fieldId) {
      return getFieldValue(_Fields.findByThriftIdOrThrow(fieldId));
    }

    /** Returns true if field corresponding to fieldID is set (has been asigned a value) and false otherwise */
    public boolean isSet(_Fields field) {
      switch (field) {
      case AUTHENTICATION_TOKEN:
        return isSetAuthenticationToken();
      case LINKED_NOTEBOOK_ID:
        return isSetLinkedNotebookId();
      }
      throw new IllegalStateException();
    }

    public boolean isSet(int fieldID) {
      return isSet(_Fields.findByThriftIdOrThrow(fieldID));
    }

    public boolean equals(Object that) {
      if (that == null)
        return false;
      if (that instanceof expungeLinkedNotebook_args)
        return this.equals((expungeLinkedNotebook_args)that);
      return false;
    }

    public boolean equals(expungeLinkedNotebook_args that) {
      if (that == null)
        return false;

      boolean this_present_authenticationToken = true && this.isSetAuthenticationToken();
      boolean that_present_authenticationToken = true && that.isSetAuthenticationToken();
      if (this_present_authenticationToken || that_present_authenticationToken) {
        if (!(this_present_authenticationToken && that_present_authenticationToken))
          return false;
        if (!this.authenticationToken.equals(that.authenticationToken))
          return false;
      }

      boolean this_present_linkedNotebookId = true;
      boolean that_present_linkedNotebookId = true;
      if (this_present_linkedNotebookId || that_present_linkedNotebookId) {
        if (!(this_present_linkedNotebookId && that_present_linkedNotebookId))
          return false;
        if (this.linkedNotebookId != that.linkedNotebookId)
          return false;
      }

      return true;
    }

    public int hashCode() {
      return 0;
    }

    public int compareTo(expungeLinkedNotebook_args other) {
      if (!getClass().equals(other.getClass())) {
        return getClass().getName().compareTo(other.getClass().getName());
      }

      int lastComparison = 0;
      expungeLinkedNotebook_args typedOther = (expungeLinkedNotebook_args)other;

      lastComparison = Boolean.valueOf(isSetAuthenticationToken()).compareTo(isSetAuthenticationToken());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(authenticationToken, typedOther.authenticationToken);
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = Boolean.valueOf(isSetLinkedNotebookId()).compareTo(isSetLinkedNotebookId());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(linkedNotebookId, typedOther.linkedNotebookId);
      if (lastComparison != 0) {
        return lastComparison;
      }
      return 0;
    }

    public void read(TProtocol iprot) throws TException {
      TField field;
      iprot.readStructBegin();
      while (true)
      {
        field = iprot.readFieldBegin();
        if (field.type == TType.STOP) { 
          break;
        }
        _Fields fieldId = _Fields.findByThriftId(field.id);
        if (fieldId == null) {
          TProtocolUtil.skip(iprot, field.type);
        } else {
          switch (fieldId) {
            case AUTHENTICATION_TOKEN:
              if (field.type == TType.STRING) {
                this.authenticationToken = iprot.readString();
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
            case LINKED_NOTEBOOK_ID:
              if (field.type == TType.I64) {
                this.linkedNotebookId = iprot.readI64();
                setLinkedNotebookIdIsSet(true);
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
          }
          iprot.readFieldEnd();
        }
      }
      iprot.readStructEnd();
      validate();
    }

    public void write(TProtocol oprot) throws TException {
      validate();

      oprot.writeStructBegin(STRUCT_DESC);
      if (this.authenticationToken != null) {
        oprot.writeFieldBegin(AUTHENTICATION_TOKEN_FIELD_DESC);
        oprot.writeString(this.authenticationToken);
        oprot.writeFieldEnd();
      }
      oprot.writeFieldBegin(LINKED_NOTEBOOK_ID_FIELD_DESC);
      oprot.writeI64(this.linkedNotebookId);
      oprot.writeFieldEnd();
      oprot.writeFieldStop();
      oprot.writeStructEnd();
    }

    public String toString() {
      StringBuilder sb = new StringBuilder("expungeLinkedNotebook_args(");
      boolean first = true;

      sb.append("authenticationToken:");
      if (this.authenticationToken == null) {
        sb.append("null");
      } else {
        sb.append(this.authenticationToken);
      }
      first = false;
      if (!first) sb.append(", ");
      sb.append("linkedNotebookId:");
      sb.append(this.linkedNotebookId);
      first = false;
      sb.append(")");
      return sb.toString();
    }

    public void validate() throws TException {
      // check for required fields
    }

  }

  public static class expungeLinkedNotebook_result implements TBase<expungeLinkedNotebook_result._Fields>, java.io.Serializable, Cloneable, Comparable<expungeLinkedNotebook_result>   {
    private static final TStruct STRUCT_DESC = new TStruct("expungeLinkedNotebook_result");

    private static final TField SUCCESS_FIELD_DESC = new TField("success", TType.I32, (short)0);
    private static final TField USER_EXCEPTION_FIELD_DESC = new TField("userException", TType.STRUCT, (short)1);
    private static final TField NOT_FOUND_EXCEPTION_FIELD_DESC = new TField("notFoundException", TType.STRUCT, (short)2);
    private static final TField SYSTEM_EXCEPTION_FIELD_DESC = new TField("systemException", TType.STRUCT, (short)3);

    private int success;
    private com.evernote.edam.error.EDAMUserException userException;
    private com.evernote.edam.error.EDAMNotFoundException notFoundException;
    private com.evernote.edam.error.EDAMSystemException systemException;

    /** The set of fields this struct contains, along with convenience methods for finding and manipulating them. */
    public enum _Fields implements TFieldIdEnum {
      SUCCESS((short)0, "success"),
      USER_EXCEPTION((short)1, "userException"),
      NOT_FOUND_EXCEPTION((short)2, "notFoundException"),
      SYSTEM_EXCEPTION((short)3, "systemException");

      private static final Map<Integer, _Fields> byId = new HashMap<Integer, _Fields>();
      private static final Map<String, _Fields> byName = new HashMap<String, _Fields>();

      static {
        for (_Fields field : EnumSet.allOf(_Fields.class)) {
          byId.put((int)field._thriftId, field);
          byName.put(field.getFieldName(), field);
        }
      }

      /**
       * Find the _Fields constant that matches fieldId, or null if its not found.
       */
      public static _Fields findByThriftId(int fieldId) {
        return byId.get(fieldId);
      }

      /**
       * Find the _Fields constant that matches fieldId, throwing an exception
       * if it is not found.
       */
      public static _Fields findByThriftIdOrThrow(int fieldId) {
        _Fields fields = findByThriftId(fieldId);
        if (fields == null) throw new IllegalArgumentException("Field " + fieldId + " doesn't exist!");
        return fields;
      }

      /**
       * Find the _Fields constant that matches name, or null if its not found.
       */
      public static _Fields findByName(String name) {
        return byName.get(name);
      }

      private final short _thriftId;
      private final String _fieldName;

      _Fields(short thriftId, String fieldName) {
        _thriftId = thriftId;
        _fieldName = fieldName;
      }

      public short getThriftFieldId() {
        return _thriftId;
      }

      public String getFieldName() {
        return _fieldName;
      }
    }

    // isset id assignments
    private static final int __SUCCESS_ISSET_ID = 0;
    private BitSet __isset_bit_vector = new BitSet(1);

    public static final Map<_Fields, FieldMetaData> metaDataMap = Collections.unmodifiableMap(new EnumMap<_Fields, FieldMetaData>(_Fields.class) {{
      put(_Fields.SUCCESS, new FieldMetaData("success", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.I32)));
      put(_Fields.USER_EXCEPTION, new FieldMetaData("userException", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.STRUCT)));
      put(_Fields.NOT_FOUND_EXCEPTION, new FieldMetaData("notFoundException", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.STRUCT)));
      put(_Fields.SYSTEM_EXCEPTION, new FieldMetaData("systemException", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.STRUCT)));
    }});

    static {
      FieldMetaData.addStructMetaDataMap(expungeLinkedNotebook_result.class, metaDataMap);
    }

    public expungeLinkedNotebook_result() {
    }

    public expungeLinkedNotebook_result(
      int success,
      com.evernote.edam.error.EDAMUserException userException,
      com.evernote.edam.error.EDAMNotFoundException notFoundException,
      com.evernote.edam.error.EDAMSystemException systemException)
    {
      this();
      this.success = success;
      setSuccessIsSet(true);
      this.userException = userException;
      this.notFoundException = notFoundException;
      this.systemException = systemException;
    }

    /**
     * Performs a deep copy on <i>other</i>.
     */
    public expungeLinkedNotebook_result(expungeLinkedNotebook_result other) {
      __isset_bit_vector.clear();
      __isset_bit_vector.or(other.__isset_bit_vector);
      this.success = other.success;
      if (other.isSetUserException()) {
        this.userException = new com.evernote.edam.error.EDAMUserException(other.userException);
      }
      if (other.isSetNotFoundException()) {
        this.notFoundException = new com.evernote.edam.error.EDAMNotFoundException(other.notFoundException);
      }
      if (other.isSetSystemException()) {
        this.systemException = new com.evernote.edam.error.EDAMSystemException(other.systemException);
      }
    }

    public expungeLinkedNotebook_result deepCopy() {
      return new expungeLinkedNotebook_result(this);
    }

    @Deprecated
    public expungeLinkedNotebook_result clone() {
      return new expungeLinkedNotebook_result(this);
    }

    public int getSuccess() {
      return this.success;
    }

    public void setSuccess(int success) {
      this.success = success;
      setSuccessIsSet(true);
    }

    public void unsetSuccess() {
      __isset_bit_vector.clear(__SUCCESS_ISSET_ID);
    }

    /** Returns true if field success is set (has been asigned a value) and false otherwise */
    public boolean isSetSuccess() {
      return __isset_bit_vector.get(__SUCCESS_ISSET_ID);
    }

    public void setSuccessIsSet(boolean value) {
      __isset_bit_vector.set(__SUCCESS_ISSET_ID, value);
    }

    public com.evernote.edam.error.EDAMUserException getUserException() {
      return this.userException;
    }

    public void setUserException(com.evernote.edam.error.EDAMUserException userException) {
      this.userException = userException;
    }

    public void unsetUserException() {
      this.userException = null;
    }

    /** Returns true if field userException is set (has been asigned a value) and false otherwise */
    public boolean isSetUserException() {
      return this.userException != null;
    }

    public void setUserExceptionIsSet(boolean value) {
      if (!value) {
        this.userException = null;
      }
    }

    public com.evernote.edam.error.EDAMNotFoundException getNotFoundException() {
      return this.notFoundException;
    }

    public void setNotFoundException(com.evernote.edam.error.EDAMNotFoundException notFoundException) {
      this.notFoundException = notFoundException;
    }

    public void unsetNotFoundException() {
      this.notFoundException = null;
    }

    /** Returns true if field notFoundException is set (has been asigned a value) and false otherwise */
    public boolean isSetNotFoundException() {
      return this.notFoundException != null;
    }

    public void setNotFoundExceptionIsSet(boolean value) {
      if (!value) {
        this.notFoundException = null;
      }
    }

    public com.evernote.edam.error.EDAMSystemException getSystemException() {
      return this.systemException;
    }

    public void setSystemException(com.evernote.edam.error.EDAMSystemException systemException) {
      this.systemException = systemException;
    }

    public void unsetSystemException() {
      this.systemException = null;
    }

    /** Returns true if field systemException is set (has been asigned a value) and false otherwise */
    public boolean isSetSystemException() {
      return this.systemException != null;
    }

    public void setSystemExceptionIsSet(boolean value) {
      if (!value) {
        this.systemException = null;
      }
    }

    public void setFieldValue(_Fields field, Object value) {
      switch (field) {
      case SUCCESS:
        if (value == null) {
          unsetSuccess();
        } else {
          setSuccess((Integer)value);
        }
        break;

      case USER_EXCEPTION:
        if (value == null) {
          unsetUserException();
        } else {
          setUserException((com.evernote.edam.error.EDAMUserException)value);
        }
        break;

      case NOT_FOUND_EXCEPTION:
        if (value == null) {
          unsetNotFoundException();
        } else {
          setNotFoundException((com.evernote.edam.error.EDAMNotFoundException)value);
        }
        break;

      case SYSTEM_EXCEPTION:
        if (value == null) {
          unsetSystemException();
        } else {
          setSystemException((com.evernote.edam.error.EDAMSystemException)value);
        }
        break;

      }
    }

    public void setFieldValue(int fieldID, Object value) {
      setFieldValue(_Fields.findByThriftIdOrThrow(fieldID), value);
    }

    public Object getFieldValue(_Fields field) {
      switch (field) {
      case SUCCESS:
        return new Integer(getSuccess());

      case USER_EXCEPTION:
        return getUserException();

      case NOT_FOUND_EXCEPTION:
        return getNotFoundException();

      case SYSTEM_EXCEPTION:
        return getSystemException();

      }
      throw new IllegalStateException();
    }

    public Object getFieldValue(int fieldId) {
      return getFieldValue(_Fields.findByThriftIdOrThrow(fieldId));
    }

    /** Returns true if field corresponding to fieldID is set (has been asigned a value) and false otherwise */
    public boolean isSet(_Fields field) {
      switch (field) {
      case SUCCESS:
        return isSetSuccess();
      case USER_EXCEPTION:
        return isSetUserException();
      case NOT_FOUND_EXCEPTION:
        return isSetNotFoundException();
      case SYSTEM_EXCEPTION:
        return isSetSystemException();
      }
      throw new IllegalStateException();
    }

    public boolean isSet(int fieldID) {
      return isSet(_Fields.findByThriftIdOrThrow(fieldID));
    }

    public boolean equals(Object that) {
      if (that == null)
        return false;
      if (that instanceof expungeLinkedNotebook_result)
        return this.equals((expungeLinkedNotebook_result)that);
      return false;
    }

    public boolean equals(expungeLinkedNotebook_result that) {
      if (that == null)
        return false;

      boolean this_present_success = true;
      boolean that_present_success = true;
      if (this_present_success || that_present_success) {
        if (!(this_present_success && that_present_success))
          return false;
        if (this.success != that.success)
          return false;
      }

      boolean this_present_userException = true && this.isSetUserException();
      boolean that_present_userException = true && that.isSetUserException();
      if (this_present_userException || that_present_userException) {
        if (!(this_present_userException && that_present_userException))
          return false;
        if (!this.userException.equals(that.userException))
          return false;
      }

      boolean this_present_notFoundException = true && this.isSetNotFoundException();
      boolean that_present_notFoundException = true && that.isSetNotFoundException();
      if (this_present_notFoundException || that_present_notFoundException) {
        if (!(this_present_notFoundException && that_present_notFoundException))
          return false;
        if (!this.notFoundException.equals(that.notFoundException))
          return false;
      }

      boolean this_present_systemException = true && this.isSetSystemException();
      boolean that_present_systemException = true && that.isSetSystemException();
      if (this_present_systemException || that_present_systemException) {
        if (!(this_present_systemException && that_present_systemException))
          return false;
        if (!this.systemException.equals(that.systemException))
          return false;
      }

      return true;
    }

    public int hashCode() {
      return 0;
    }

    public int compareTo(expungeLinkedNotebook_result other) {
      if (!getClass().equals(other.getClass())) {
        return getClass().getName().compareTo(other.getClass().getName());
      }

      int lastComparison = 0;
      expungeLinkedNotebook_result typedOther = (expungeLinkedNotebook_result)other;

      lastComparison = Boolean.valueOf(isSetSuccess()).compareTo(isSetSuccess());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(success, typedOther.success);
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = Boolean.valueOf(isSetUserException()).compareTo(isSetUserException());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(userException, typedOther.userException);
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = Boolean.valueOf(isSetNotFoundException()).compareTo(isSetNotFoundException());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(notFoundException, typedOther.notFoundException);
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = Boolean.valueOf(isSetSystemException()).compareTo(isSetSystemException());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(systemException, typedOther.systemException);
      if (lastComparison != 0) {
        return lastComparison;
      }
      return 0;
    }

    public void read(TProtocol iprot) throws TException {
      TField field;
      iprot.readStructBegin();
      while (true)
      {
        field = iprot.readFieldBegin();
        if (field.type == TType.STOP) { 
          break;
        }
        _Fields fieldId = _Fields.findByThriftId(field.id);
        if (fieldId == null) {
          TProtocolUtil.skip(iprot, field.type);
        } else {
          switch (fieldId) {
            case SUCCESS:
              if (field.type == TType.I32) {
                this.success = iprot.readI32();
                setSuccessIsSet(true);
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
            case USER_EXCEPTION:
              if (field.type == TType.STRUCT) {
                this.userException = new com.evernote.edam.error.EDAMUserException();
                this.userException.read(iprot);
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
            case NOT_FOUND_EXCEPTION:
              if (field.type == TType.STRUCT) {
                this.notFoundException = new com.evernote.edam.error.EDAMNotFoundException();
                this.notFoundException.read(iprot);
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
            case SYSTEM_EXCEPTION:
              if (field.type == TType.STRUCT) {
                this.systemException = new com.evernote.edam.error.EDAMSystemException();
                this.systemException.read(iprot);
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
          }
          iprot.readFieldEnd();
        }
      }
      iprot.readStructEnd();
      validate();
    }

    public void write(TProtocol oprot) throws TException {
      oprot.writeStructBegin(STRUCT_DESC);

      if (this.isSetSuccess()) {
        oprot.writeFieldBegin(SUCCESS_FIELD_DESC);
        oprot.writeI32(this.success);
        oprot.writeFieldEnd();
      } else if (this.isSetUserException()) {
        oprot.writeFieldBegin(USER_EXCEPTION_FIELD_DESC);
        this.userException.write(oprot);
        oprot.writeFieldEnd();
      } else if (this.isSetNotFoundException()) {
        oprot.writeFieldBegin(NOT_FOUND_EXCEPTION_FIELD_DESC);
        this.notFoundException.write(oprot);
        oprot.writeFieldEnd();
      } else if (this.isSetSystemException()) {
        oprot.writeFieldBegin(SYSTEM_EXCEPTION_FIELD_DESC);
        this.systemException.write(oprot);
        oprot.writeFieldEnd();
      }
      oprot.writeFieldStop();
      oprot.writeStructEnd();
    }

    public String toString() {
      StringBuilder sb = new StringBuilder("expungeLinkedNotebook_result(");
      boolean first = true;

      sb.append("success:");
      sb.append(this.success);
      first = false;
      if (!first) sb.append(", ");
      sb.append("userException:");
      if (this.userException == null) {
        sb.append("null");
      } else {
        sb.append(this.userException);
      }
      first = false;
      if (!first) sb.append(", ");
      sb.append("notFoundException:");
      if (this.notFoundException == null) {
        sb.append("null");
      } else {
        sb.append(this.notFoundException);
      }
      first = false;
      if (!first) sb.append(", ");
      sb.append("systemException:");
      if (this.systemException == null) {
        sb.append("null");
      } else {
        sb.append(this.systemException);
      }
      first = false;
      sb.append(")");
      return sb.toString();
    }

    public void validate() throws TException {
      // check for required fields
    }

  }

  public static class authenticateToSharedNotebook_args implements TBase<authenticateToSharedNotebook_args._Fields>, java.io.Serializable, Cloneable, Comparable<authenticateToSharedNotebook_args>   {
    private static final TStruct STRUCT_DESC = new TStruct("authenticateToSharedNotebook_args");

    private static final TField SHARE_KEY_FIELD_DESC = new TField("shareKey", TType.STRING, (short)1);
    private static final TField AUTHENTICATION_TOKEN_FIELD_DESC = new TField("authenticationToken", TType.STRING, (short)2);

    private String shareKey;
    private String authenticationToken;

    /** The set of fields this struct contains, along with convenience methods for finding and manipulating them. */
    public enum _Fields implements TFieldIdEnum {
      SHARE_KEY((short)1, "shareKey"),
      AUTHENTICATION_TOKEN((short)2, "authenticationToken");

      private static final Map<Integer, _Fields> byId = new HashMap<Integer, _Fields>();
      private static final Map<String, _Fields> byName = new HashMap<String, _Fields>();

      static {
        for (_Fields field : EnumSet.allOf(_Fields.class)) {
          byId.put((int)field._thriftId, field);
          byName.put(field.getFieldName(), field);
        }
      }

      /**
       * Find the _Fields constant that matches fieldId, or null if its not found.
       */
      public static _Fields findByThriftId(int fieldId) {
        return byId.get(fieldId);
      }

      /**
       * Find the _Fields constant that matches fieldId, throwing an exception
       * if it is not found.
       */
      public static _Fields findByThriftIdOrThrow(int fieldId) {
        _Fields fields = findByThriftId(fieldId);
        if (fields == null) throw new IllegalArgumentException("Field " + fieldId + " doesn't exist!");
        return fields;
      }

      /**
       * Find the _Fields constant that matches name, or null if its not found.
       */
      public static _Fields findByName(String name) {
        return byName.get(name);
      }

      private final short _thriftId;
      private final String _fieldName;

      _Fields(short thriftId, String fieldName) {
        _thriftId = thriftId;
        _fieldName = fieldName;
      }

      public short getThriftFieldId() {
        return _thriftId;
      }

      public String getFieldName() {
        return _fieldName;
      }
    }

    // isset id assignments

    public static final Map<_Fields, FieldMetaData> metaDataMap = Collections.unmodifiableMap(new EnumMap<_Fields, FieldMetaData>(_Fields.class) {{
      put(_Fields.SHARE_KEY, new FieldMetaData("shareKey", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.STRING)));
      put(_Fields.AUTHENTICATION_TOKEN, new FieldMetaData("authenticationToken", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.STRING)));
    }});

    static {
      FieldMetaData.addStructMetaDataMap(authenticateToSharedNotebook_args.class, metaDataMap);
    }

    public authenticateToSharedNotebook_args() {
    }

    public authenticateToSharedNotebook_args(
      String shareKey,
      String authenticationToken)
    {
      this();
      this.shareKey = shareKey;
      this.authenticationToken = authenticationToken;
    }

    /**
     * Performs a deep copy on <i>other</i>.
     */
    public authenticateToSharedNotebook_args(authenticateToSharedNotebook_args other) {
      if (other.isSetShareKey()) {
        this.shareKey = other.shareKey;
      }
      if (other.isSetAuthenticationToken()) {
        this.authenticationToken = other.authenticationToken;
      }
    }

    public authenticateToSharedNotebook_args deepCopy() {
      return new authenticateToSharedNotebook_args(this);
    }

    @Deprecated
    public authenticateToSharedNotebook_args clone() {
      return new authenticateToSharedNotebook_args(this);
    }

    public String getShareKey() {
      return this.shareKey;
    }

    public void setShareKey(String shareKey) {
      this.shareKey = shareKey;
    }

    public void unsetShareKey() {
      this.shareKey = null;
    }

    /** Returns true if field shareKey is set (has been asigned a value) and false otherwise */
    public boolean isSetShareKey() {
      return this.shareKey != null;
    }

    public void setShareKeyIsSet(boolean value) {
      if (!value) {
        this.shareKey = null;
      }
    }

    public String getAuthenticationToken() {
      return this.authenticationToken;
    }

    public void setAuthenticationToken(String authenticationToken) {
      this.authenticationToken = authenticationToken;
    }

    public void unsetAuthenticationToken() {
      this.authenticationToken = null;
    }

    /** Returns true if field authenticationToken is set (has been asigned a value) and false otherwise */
    public boolean isSetAuthenticationToken() {
      return this.authenticationToken != null;
    }

    public void setAuthenticationTokenIsSet(boolean value) {
      if (!value) {
        this.authenticationToken = null;
      }
    }

    public void setFieldValue(_Fields field, Object value) {
      switch (field) {
      case SHARE_KEY:
        if (value == null) {
          unsetShareKey();
        } else {
          setShareKey((String)value);
        }
        break;

      case AUTHENTICATION_TOKEN:
        if (value == null) {
          unsetAuthenticationToken();
        } else {
          setAuthenticationToken((String)value);
        }
        break;

      }
    }

    public void setFieldValue(int fieldID, Object value) {
      setFieldValue(_Fields.findByThriftIdOrThrow(fieldID), value);
    }

    public Object getFieldValue(_Fields field) {
      switch (field) {
      case SHARE_KEY:
        return getShareKey();

      case AUTHENTICATION_TOKEN:
        return getAuthenticationToken();

      }
      throw new IllegalStateException();
    }

    public Object getFieldValue(int fieldId) {
      return getFieldValue(_Fields.findByThriftIdOrThrow(fieldId));
    }

    /** Returns true if field corresponding to fieldID is set (has been asigned a value) and false otherwise */
    public boolean isSet(_Fields field) {
      switch (field) {
      case SHARE_KEY:
        return isSetShareKey();
      case AUTHENTICATION_TOKEN:
        return isSetAuthenticationToken();
      }
      throw new IllegalStateException();
    }

    public boolean isSet(int fieldID) {
      return isSet(_Fields.findByThriftIdOrThrow(fieldID));
    }

    public boolean equals(Object that) {
      if (that == null)
        return false;
      if (that instanceof authenticateToSharedNotebook_args)
        return this.equals((authenticateToSharedNotebook_args)that);
      return false;
    }

    public boolean equals(authenticateToSharedNotebook_args that) {
      if (that == null)
        return false;

      boolean this_present_shareKey = true && this.isSetShareKey();
      boolean that_present_shareKey = true && that.isSetShareKey();
      if (this_present_shareKey || that_present_shareKey) {
        if (!(this_present_shareKey && that_present_shareKey))
          return false;
        if (!this.shareKey.equals(that.shareKey))
          return false;
      }

      boolean this_present_authenticationToken = true && this.isSetAuthenticationToken();
      boolean that_present_authenticationToken = true && that.isSetAuthenticationToken();
      if (this_present_authenticationToken || that_present_authenticationToken) {
        if (!(this_present_authenticationToken && that_present_authenticationToken))
          return false;
        if (!this.authenticationToken.equals(that.authenticationToken))
          return false;
      }

      return true;
    }

    public int hashCode() {
      return 0;
    }

    public int compareTo(authenticateToSharedNotebook_args other) {
      if (!getClass().equals(other.getClass())) {
        return getClass().getName().compareTo(other.getClass().getName());
      }

      int lastComparison = 0;
      authenticateToSharedNotebook_args typedOther = (authenticateToSharedNotebook_args)other;

      lastComparison = Boolean.valueOf(isSetShareKey()).compareTo(isSetShareKey());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(shareKey, typedOther.shareKey);
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = Boolean.valueOf(isSetAuthenticationToken()).compareTo(isSetAuthenticationToken());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(authenticationToken, typedOther.authenticationToken);
      if (lastComparison != 0) {
        return lastComparison;
      }
      return 0;
    }

    public void read(TProtocol iprot) throws TException {
      TField field;
      iprot.readStructBegin();
      while (true)
      {
        field = iprot.readFieldBegin();
        if (field.type == TType.STOP) { 
          break;
        }
        _Fields fieldId = _Fields.findByThriftId(field.id);
        if (fieldId == null) {
          TProtocolUtil.skip(iprot, field.type);
        } else {
          switch (fieldId) {
            case SHARE_KEY:
              if (field.type == TType.STRING) {
                this.shareKey = iprot.readString();
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
            case AUTHENTICATION_TOKEN:
              if (field.type == TType.STRING) {
                this.authenticationToken = iprot.readString();
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
          }
          iprot.readFieldEnd();
        }
      }
      iprot.readStructEnd();
      validate();
    }

    public void write(TProtocol oprot) throws TException {
      validate();

      oprot.writeStructBegin(STRUCT_DESC);
      if (this.shareKey != null) {
        oprot.writeFieldBegin(SHARE_KEY_FIELD_DESC);
        oprot.writeString(this.shareKey);
        oprot.writeFieldEnd();
      }
      if (this.authenticationToken != null) {
        oprot.writeFieldBegin(AUTHENTICATION_TOKEN_FIELD_DESC);
        oprot.writeString(this.authenticationToken);
        oprot.writeFieldEnd();
      }
      oprot.writeFieldStop();
      oprot.writeStructEnd();
    }

    public String toString() {
      StringBuilder sb = new StringBuilder("authenticateToSharedNotebook_args(");
      boolean first = true;

      sb.append("shareKey:");
      if (this.shareKey == null) {
        sb.append("null");
      } else {
        sb.append(this.shareKey);
      }
      first = false;
      if (!first) sb.append(", ");
      sb.append("authenticationToken:");
      if (this.authenticationToken == null) {
        sb.append("null");
      } else {
        sb.append(this.authenticationToken);
      }
      first = false;
      sb.append(")");
      return sb.toString();
    }

    public void validate() throws TException {
      // check for required fields
    }

  }

  public static class authenticateToSharedNotebook_result implements TBase<authenticateToSharedNotebook_result._Fields>, java.io.Serializable, Cloneable, Comparable<authenticateToSharedNotebook_result>   {
    private static final TStruct STRUCT_DESC = new TStruct("authenticateToSharedNotebook_result");

    private static final TField SUCCESS_FIELD_DESC = new TField("success", TType.STRUCT, (short)0);
    private static final TField USER_EXCEPTION_FIELD_DESC = new TField("userException", TType.STRUCT, (short)1);
    private static final TField NOT_FOUND_EXCEPTION_FIELD_DESC = new TField("notFoundException", TType.STRUCT, (short)2);
    private static final TField SYSTEM_EXCEPTION_FIELD_DESC = new TField("systemException", TType.STRUCT, (short)3);

    private com.evernote.edam.userstore.AuthenticationResult success;
    private com.evernote.edam.error.EDAMUserException userException;
    private com.evernote.edam.error.EDAMNotFoundException notFoundException;
    private com.evernote.edam.error.EDAMSystemException systemException;

    /** The set of fields this struct contains, along with convenience methods for finding and manipulating them. */
    public enum _Fields implements TFieldIdEnum {
      SUCCESS((short)0, "success"),
      USER_EXCEPTION((short)1, "userException"),
      NOT_FOUND_EXCEPTION((short)2, "notFoundException"),
      SYSTEM_EXCEPTION((short)3, "systemException");

      private static final Map<Integer, _Fields> byId = new HashMap<Integer, _Fields>();
      private static final Map<String, _Fields> byName = new HashMap<String, _Fields>();

      static {
        for (_Fields field : EnumSet.allOf(_Fields.class)) {
          byId.put((int)field._thriftId, field);
          byName.put(field.getFieldName(), field);
        }
      }

      /**
       * Find the _Fields constant that matches fieldId, or null if its not found.
       */
      public static _Fields findByThriftId(int fieldId) {
        return byId.get(fieldId);
      }

      /**
       * Find the _Fields constant that matches fieldId, throwing an exception
       * if it is not found.
       */
      public static _Fields findByThriftIdOrThrow(int fieldId) {
        _Fields fields = findByThriftId(fieldId);
        if (fields == null) throw new IllegalArgumentException("Field " + fieldId + " doesn't exist!");
        return fields;
      }

      /**
       * Find the _Fields constant that matches name, or null if its not found.
       */
      public static _Fields findByName(String name) {
        return byName.get(name);
      }

      private final short _thriftId;
      private final String _fieldName;

      _Fields(short thriftId, String fieldName) {
        _thriftId = thriftId;
        _fieldName = fieldName;
      }

      public short getThriftFieldId() {
        return _thriftId;
      }

      public String getFieldName() {
        return _fieldName;
      }
    }

    // isset id assignments

    public static final Map<_Fields, FieldMetaData> metaDataMap = Collections.unmodifiableMap(new EnumMap<_Fields, FieldMetaData>(_Fields.class) {{
      put(_Fields.SUCCESS, new FieldMetaData("success", TFieldRequirementType.DEFAULT, 
          new StructMetaData(TType.STRUCT, com.evernote.edam.userstore.AuthenticationResult.class)));
      put(_Fields.USER_EXCEPTION, new FieldMetaData("userException", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.STRUCT)));
      put(_Fields.NOT_FOUND_EXCEPTION, new FieldMetaData("notFoundException", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.STRUCT)));
      put(_Fields.SYSTEM_EXCEPTION, new FieldMetaData("systemException", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.STRUCT)));
    }});

    static {
      FieldMetaData.addStructMetaDataMap(authenticateToSharedNotebook_result.class, metaDataMap);
    }

    public authenticateToSharedNotebook_result() {
    }

    public authenticateToSharedNotebook_result(
      com.evernote.edam.userstore.AuthenticationResult success,
      com.evernote.edam.error.EDAMUserException userException,
      com.evernote.edam.error.EDAMNotFoundException notFoundException,
      com.evernote.edam.error.EDAMSystemException systemException)
    {
      this();
      this.success = success;
      this.userException = userException;
      this.notFoundException = notFoundException;
      this.systemException = systemException;
    }

    /**
     * Performs a deep copy on <i>other</i>.
     */
    public authenticateToSharedNotebook_result(authenticateToSharedNotebook_result other) {
      if (other.isSetSuccess()) {
        this.success = new com.evernote.edam.userstore.AuthenticationResult(other.success);
      }
      if (other.isSetUserException()) {
        this.userException = new com.evernote.edam.error.EDAMUserException(other.userException);
      }
      if (other.isSetNotFoundException()) {
        this.notFoundException = new com.evernote.edam.error.EDAMNotFoundException(other.notFoundException);
      }
      if (other.isSetSystemException()) {
        this.systemException = new com.evernote.edam.error.EDAMSystemException(other.systemException);
      }
    }

    public authenticateToSharedNotebook_result deepCopy() {
      return new authenticateToSharedNotebook_result(this);
    }

    @Deprecated
    public authenticateToSharedNotebook_result clone() {
      return new authenticateToSharedNotebook_result(this);
    }

    public com.evernote.edam.userstore.AuthenticationResult getSuccess() {
      return this.success;
    }

    public void setSuccess(com.evernote.edam.userstore.AuthenticationResult success) {
      this.success = success;
    }

    public void unsetSuccess() {
      this.success = null;
    }

    /** Returns true if field success is set (has been asigned a value) and false otherwise */
    public boolean isSetSuccess() {
      return this.success != null;
    }

    public void setSuccessIsSet(boolean value) {
      if (!value) {
        this.success = null;
      }
    }

    public com.evernote.edam.error.EDAMUserException getUserException() {
      return this.userException;
    }

    public void setUserException(com.evernote.edam.error.EDAMUserException userException) {
      this.userException = userException;
    }

    public void unsetUserException() {
      this.userException = null;
    }

    /** Returns true if field userException is set (has been asigned a value) and false otherwise */
    public boolean isSetUserException() {
      return this.userException != null;
    }

    public void setUserExceptionIsSet(boolean value) {
      if (!value) {
        this.userException = null;
      }
    }

    public com.evernote.edam.error.EDAMNotFoundException getNotFoundException() {
      return this.notFoundException;
    }

    public void setNotFoundException(com.evernote.edam.error.EDAMNotFoundException notFoundException) {
      this.notFoundException = notFoundException;
    }

    public void unsetNotFoundException() {
      this.notFoundException = null;
    }

    /** Returns true if field notFoundException is set (has been asigned a value) and false otherwise */
    public boolean isSetNotFoundException() {
      return this.notFoundException != null;
    }

    public void setNotFoundExceptionIsSet(boolean value) {
      if (!value) {
        this.notFoundException = null;
      }
    }

    public com.evernote.edam.error.EDAMSystemException getSystemException() {
      return this.systemException;
    }

    public void setSystemException(com.evernote.edam.error.EDAMSystemException systemException) {
      this.systemException = systemException;
    }

    public void unsetSystemException() {
      this.systemException = null;
    }

    /** Returns true if field systemException is set (has been asigned a value) and false otherwise */
    public boolean isSetSystemException() {
      return this.systemException != null;
    }

    public void setSystemExceptionIsSet(boolean value) {
      if (!value) {
        this.systemException = null;
      }
    }

    public void setFieldValue(_Fields field, Object value) {
      switch (field) {
      case SUCCESS:
        if (value == null) {
          unsetSuccess();
        } else {
          setSuccess((com.evernote.edam.userstore.AuthenticationResult)value);
        }
        break;

      case USER_EXCEPTION:
        if (value == null) {
          unsetUserException();
        } else {
          setUserException((com.evernote.edam.error.EDAMUserException)value);
        }
        break;

      case NOT_FOUND_EXCEPTION:
        if (value == null) {
          unsetNotFoundException();
        } else {
          setNotFoundException((com.evernote.edam.error.EDAMNotFoundException)value);
        }
        break;

      case SYSTEM_EXCEPTION:
        if (value == null) {
          unsetSystemException();
        } else {
          setSystemException((com.evernote.edam.error.EDAMSystemException)value);
        }
        break;

      }
    }

    public void setFieldValue(int fieldID, Object value) {
      setFieldValue(_Fields.findByThriftIdOrThrow(fieldID), value);
    }

    public Object getFieldValue(_Fields field) {
      switch (field) {
      case SUCCESS:
        return getSuccess();

      case USER_EXCEPTION:
        return getUserException();

      case NOT_FOUND_EXCEPTION:
        return getNotFoundException();

      case SYSTEM_EXCEPTION:
        return getSystemException();

      }
      throw new IllegalStateException();
    }

    public Object getFieldValue(int fieldId) {
      return getFieldValue(_Fields.findByThriftIdOrThrow(fieldId));
    }

    /** Returns true if field corresponding to fieldID is set (has been asigned a value) and false otherwise */
    public boolean isSet(_Fields field) {
      switch (field) {
      case SUCCESS:
        return isSetSuccess();
      case USER_EXCEPTION:
        return isSetUserException();
      case NOT_FOUND_EXCEPTION:
        return isSetNotFoundException();
      case SYSTEM_EXCEPTION:
        return isSetSystemException();
      }
      throw new IllegalStateException();
    }

    public boolean isSet(int fieldID) {
      return isSet(_Fields.findByThriftIdOrThrow(fieldID));
    }

    public boolean equals(Object that) {
      if (that == null)
        return false;
      if (that instanceof authenticateToSharedNotebook_result)
        return this.equals((authenticateToSharedNotebook_result)that);
      return false;
    }

    public boolean equals(authenticateToSharedNotebook_result that) {
      if (that == null)
        return false;

      boolean this_present_success = true && this.isSetSuccess();
      boolean that_present_success = true && that.isSetSuccess();
      if (this_present_success || that_present_success) {
        if (!(this_present_success && that_present_success))
          return false;
        if (!this.success.equals(that.success))
          return false;
      }

      boolean this_present_userException = true && this.isSetUserException();
      boolean that_present_userException = true && that.isSetUserException();
      if (this_present_userException || that_present_userException) {
        if (!(this_present_userException && that_present_userException))
          return false;
        if (!this.userException.equals(that.userException))
          return false;
      }

      boolean this_present_notFoundException = true && this.isSetNotFoundException();
      boolean that_present_notFoundException = true && that.isSetNotFoundException();
      if (this_present_notFoundException || that_present_notFoundException) {
        if (!(this_present_notFoundException && that_present_notFoundException))
          return false;
        if (!this.notFoundException.equals(that.notFoundException))
          return false;
      }

      boolean this_present_systemException = true && this.isSetSystemException();
      boolean that_present_systemException = true && that.isSetSystemException();
      if (this_present_systemException || that_present_systemException) {
        if (!(this_present_systemException && that_present_systemException))
          return false;
        if (!this.systemException.equals(that.systemException))
          return false;
      }

      return true;
    }

    public int hashCode() {
      return 0;
    }

    public int compareTo(authenticateToSharedNotebook_result other) {
      if (!getClass().equals(other.getClass())) {
        return getClass().getName().compareTo(other.getClass().getName());
      }

      int lastComparison = 0;
      authenticateToSharedNotebook_result typedOther = (authenticateToSharedNotebook_result)other;

      lastComparison = Boolean.valueOf(isSetSuccess()).compareTo(isSetSuccess());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(success, typedOther.success);
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = Boolean.valueOf(isSetUserException()).compareTo(isSetUserException());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(userException, typedOther.userException);
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = Boolean.valueOf(isSetNotFoundException()).compareTo(isSetNotFoundException());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(notFoundException, typedOther.notFoundException);
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = Boolean.valueOf(isSetSystemException()).compareTo(isSetSystemException());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(systemException, typedOther.systemException);
      if (lastComparison != 0) {
        return lastComparison;
      }
      return 0;
    }

    public void read(TProtocol iprot) throws TException {
      TField field;
      iprot.readStructBegin();
      while (true)
      {
        field = iprot.readFieldBegin();
        if (field.type == TType.STOP) { 
          break;
        }
        _Fields fieldId = _Fields.findByThriftId(field.id);
        if (fieldId == null) {
          TProtocolUtil.skip(iprot, field.type);
        } else {
          switch (fieldId) {
            case SUCCESS:
              if (field.type == TType.STRUCT) {
                this.success = new com.evernote.edam.userstore.AuthenticationResult();
                this.success.read(iprot);
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
            case USER_EXCEPTION:
              if (field.type == TType.STRUCT) {
                this.userException = new com.evernote.edam.error.EDAMUserException();
                this.userException.read(iprot);
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
            case NOT_FOUND_EXCEPTION:
              if (field.type == TType.STRUCT) {
                this.notFoundException = new com.evernote.edam.error.EDAMNotFoundException();
                this.notFoundException.read(iprot);
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
            case SYSTEM_EXCEPTION:
              if (field.type == TType.STRUCT) {
                this.systemException = new com.evernote.edam.error.EDAMSystemException();
                this.systemException.read(iprot);
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
          }
          iprot.readFieldEnd();
        }
      }
      iprot.readStructEnd();
      validate();
    }

    public void write(TProtocol oprot) throws TException {
      oprot.writeStructBegin(STRUCT_DESC);

      if (this.isSetSuccess()) {
        oprot.writeFieldBegin(SUCCESS_FIELD_DESC);
        this.success.write(oprot);
        oprot.writeFieldEnd();
      } else if (this.isSetUserException()) {
        oprot.writeFieldBegin(USER_EXCEPTION_FIELD_DESC);
        this.userException.write(oprot);
        oprot.writeFieldEnd();
      } else if (this.isSetNotFoundException()) {
        oprot.writeFieldBegin(NOT_FOUND_EXCEPTION_FIELD_DESC);
        this.notFoundException.write(oprot);
        oprot.writeFieldEnd();
      } else if (this.isSetSystemException()) {
        oprot.writeFieldBegin(SYSTEM_EXCEPTION_FIELD_DESC);
        this.systemException.write(oprot);
        oprot.writeFieldEnd();
      }
      oprot.writeFieldStop();
      oprot.writeStructEnd();
    }

    public String toString() {
      StringBuilder sb = new StringBuilder("authenticateToSharedNotebook_result(");
      boolean first = true;

      sb.append("success:");
      if (this.success == null) {
        sb.append("null");
      } else {
        sb.append(this.success);
      }
      first = false;
      if (!first) sb.append(", ");
      sb.append("userException:");
      if (this.userException == null) {
        sb.append("null");
      } else {
        sb.append(this.userException);
      }
      first = false;
      if (!first) sb.append(", ");
      sb.append("notFoundException:");
      if (this.notFoundException == null) {
        sb.append("null");
      } else {
        sb.append(this.notFoundException);
      }
      first = false;
      if (!first) sb.append(", ");
      sb.append("systemException:");
      if (this.systemException == null) {
        sb.append("null");
      } else {
        sb.append(this.systemException);
      }
      first = false;
      sb.append(")");
      return sb.toString();
    }

    public void validate() throws TException {
      // check for required fields
    }

  }

  public static class getSharedNotebookByAuth_args implements TBase<getSharedNotebookByAuth_args._Fields>, java.io.Serializable, Cloneable, Comparable<getSharedNotebookByAuth_args>   {
    private static final TStruct STRUCT_DESC = new TStruct("getSharedNotebookByAuth_args");

    private static final TField AUTHENTICATION_TOKEN_FIELD_DESC = new TField("authenticationToken", TType.STRING, (short)1);

    private String authenticationToken;

    /** The set of fields this struct contains, along with convenience methods for finding and manipulating them. */
    public enum _Fields implements TFieldIdEnum {
      AUTHENTICATION_TOKEN((short)1, "authenticationToken");

      private static final Map<Integer, _Fields> byId = new HashMap<Integer, _Fields>();
      private static final Map<String, _Fields> byName = new HashMap<String, _Fields>();

      static {
        for (_Fields field : EnumSet.allOf(_Fields.class)) {
          byId.put((int)field._thriftId, field);
          byName.put(field.getFieldName(), field);
        }
      }

      /**
       * Find the _Fields constant that matches fieldId, or null if its not found.
       */
      public static _Fields findByThriftId(int fieldId) {
        return byId.get(fieldId);
      }

      /**
       * Find the _Fields constant that matches fieldId, throwing an exception
       * if it is not found.
       */
      public static _Fields findByThriftIdOrThrow(int fieldId) {
        _Fields fields = findByThriftId(fieldId);
        if (fields == null) throw new IllegalArgumentException("Field " + fieldId + " doesn't exist!");
        return fields;
      }

      /**
       * Find the _Fields constant that matches name, or null if its not found.
       */
      public static _Fields findByName(String name) {
        return byName.get(name);
      }

      private final short _thriftId;
      private final String _fieldName;

      _Fields(short thriftId, String fieldName) {
        _thriftId = thriftId;
        _fieldName = fieldName;
      }

      public short getThriftFieldId() {
        return _thriftId;
      }

      public String getFieldName() {
        return _fieldName;
      }
    }

    // isset id assignments

    public static final Map<_Fields, FieldMetaData> metaDataMap = Collections.unmodifiableMap(new EnumMap<_Fields, FieldMetaData>(_Fields.class) {{
      put(_Fields.AUTHENTICATION_TOKEN, new FieldMetaData("authenticationToken", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.STRING)));
    }});

    static {
      FieldMetaData.addStructMetaDataMap(getSharedNotebookByAuth_args.class, metaDataMap);
    }

    public getSharedNotebookByAuth_args() {
    }

    public getSharedNotebookByAuth_args(
      String authenticationToken)
    {
      this();
      this.authenticationToken = authenticationToken;
    }

    /**
     * Performs a deep copy on <i>other</i>.
     */
    public getSharedNotebookByAuth_args(getSharedNotebookByAuth_args other) {
      if (other.isSetAuthenticationToken()) {
        this.authenticationToken = other.authenticationToken;
      }
    }

    public getSharedNotebookByAuth_args deepCopy() {
      return new getSharedNotebookByAuth_args(this);
    }

    @Deprecated
    public getSharedNotebookByAuth_args clone() {
      return new getSharedNotebookByAuth_args(this);
    }

    public String getAuthenticationToken() {
      return this.authenticationToken;
    }

    public void setAuthenticationToken(String authenticationToken) {
      this.authenticationToken = authenticationToken;
    }

    public void unsetAuthenticationToken() {
      this.authenticationToken = null;
    }

    /** Returns true if field authenticationToken is set (has been asigned a value) and false otherwise */
    public boolean isSetAuthenticationToken() {
      return this.authenticationToken != null;
    }

    public void setAuthenticationTokenIsSet(boolean value) {
      if (!value) {
        this.authenticationToken = null;
      }
    }

    public void setFieldValue(_Fields field, Object value) {
      switch (field) {
      case AUTHENTICATION_TOKEN:
        if (value == null) {
          unsetAuthenticationToken();
        } else {
          setAuthenticationToken((String)value);
        }
        break;

      }
    }

    public void setFieldValue(int fieldID, Object value) {
      setFieldValue(_Fields.findByThriftIdOrThrow(fieldID), value);
    }

    public Object getFieldValue(_Fields field) {
      switch (field) {
      case AUTHENTICATION_TOKEN:
        return getAuthenticationToken();

      }
      throw new IllegalStateException();
    }

    public Object getFieldValue(int fieldId) {
      return getFieldValue(_Fields.findByThriftIdOrThrow(fieldId));
    }

    /** Returns true if field corresponding to fieldID is set (has been asigned a value) and false otherwise */
    public boolean isSet(_Fields field) {
      switch (field) {
      case AUTHENTICATION_TOKEN:
        return isSetAuthenticationToken();
      }
      throw new IllegalStateException();
    }

    public boolean isSet(int fieldID) {
      return isSet(_Fields.findByThriftIdOrThrow(fieldID));
    }

    public boolean equals(Object that) {
      if (that == null)
        return false;
      if (that instanceof getSharedNotebookByAuth_args)
        return this.equals((getSharedNotebookByAuth_args)that);
      return false;
    }

    public boolean equals(getSharedNotebookByAuth_args that) {
      if (that == null)
        return false;

      boolean this_present_authenticationToken = true && this.isSetAuthenticationToken();
      boolean that_present_authenticationToken = true && that.isSetAuthenticationToken();
      if (this_present_authenticationToken || that_present_authenticationToken) {
        if (!(this_present_authenticationToken && that_present_authenticationToken))
          return false;
        if (!this.authenticationToken.equals(that.authenticationToken))
          return false;
      }

      return true;
    }

    public int hashCode() {
      return 0;
    }

    public int compareTo(getSharedNotebookByAuth_args other) {
      if (!getClass().equals(other.getClass())) {
        return getClass().getName().compareTo(other.getClass().getName());
      }

      int lastComparison = 0;
      getSharedNotebookByAuth_args typedOther = (getSharedNotebookByAuth_args)other;

      lastComparison = Boolean.valueOf(isSetAuthenticationToken()).compareTo(isSetAuthenticationToken());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(authenticationToken, typedOther.authenticationToken);
      if (lastComparison != 0) {
        return lastComparison;
      }
      return 0;
    }

    public void read(TProtocol iprot) throws TException {
      TField field;
      iprot.readStructBegin();
      while (true)
      {
        field = iprot.readFieldBegin();
        if (field.type == TType.STOP) { 
          break;
        }
        _Fields fieldId = _Fields.findByThriftId(field.id);
        if (fieldId == null) {
          TProtocolUtil.skip(iprot, field.type);
        } else {
          switch (fieldId) {
            case AUTHENTICATION_TOKEN:
              if (field.type == TType.STRING) {
                this.authenticationToken = iprot.readString();
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
          }
          iprot.readFieldEnd();
        }
      }
      iprot.readStructEnd();
      validate();
    }

    public void write(TProtocol oprot) throws TException {
      validate();

      oprot.writeStructBegin(STRUCT_DESC);
      if (this.authenticationToken != null) {
        oprot.writeFieldBegin(AUTHENTICATION_TOKEN_FIELD_DESC);
        oprot.writeString(this.authenticationToken);
        oprot.writeFieldEnd();
      }
      oprot.writeFieldStop();
      oprot.writeStructEnd();
    }

    public String toString() {
      StringBuilder sb = new StringBuilder("getSharedNotebookByAuth_args(");
      boolean first = true;

      sb.append("authenticationToken:");
      if (this.authenticationToken == null) {
        sb.append("null");
      } else {
        sb.append(this.authenticationToken);
      }
      first = false;
      sb.append(")");
      return sb.toString();
    }

    public void validate() throws TException {
      // check for required fields
    }

  }

  public static class getSharedNotebookByAuth_result implements TBase<getSharedNotebookByAuth_result._Fields>, java.io.Serializable, Cloneable, Comparable<getSharedNotebookByAuth_result>   {
    private static final TStruct STRUCT_DESC = new TStruct("getSharedNotebookByAuth_result");

    private static final TField SUCCESS_FIELD_DESC = new TField("success", TType.STRUCT, (short)0);
    private static final TField USER_EXCEPTION_FIELD_DESC = new TField("userException", TType.STRUCT, (short)1);
    private static final TField NOT_FOUND_EXCEPTION_FIELD_DESC = new TField("notFoundException", TType.STRUCT, (short)2);
    private static final TField SYSTEM_EXCEPTION_FIELD_DESC = new TField("systemException", TType.STRUCT, (short)3);

    private com.evernote.edam.type.SharedNotebook success;
    private com.evernote.edam.error.EDAMUserException userException;
    private com.evernote.edam.error.EDAMNotFoundException notFoundException;
    private com.evernote.edam.error.EDAMSystemException systemException;

    /** The set of fields this struct contains, along with convenience methods for finding and manipulating them. */
    public enum _Fields implements TFieldIdEnum {
      SUCCESS((short)0, "success"),
      USER_EXCEPTION((short)1, "userException"),
      NOT_FOUND_EXCEPTION((short)2, "notFoundException"),
      SYSTEM_EXCEPTION((short)3, "systemException");

      private static final Map<Integer, _Fields> byId = new HashMap<Integer, _Fields>();
      private static final Map<String, _Fields> byName = new HashMap<String, _Fields>();

      static {
        for (_Fields field : EnumSet.allOf(_Fields.class)) {
          byId.put((int)field._thriftId, field);
          byName.put(field.getFieldName(), field);
        }
      }

      /**
       * Find the _Fields constant that matches fieldId, or null if its not found.
       */
      public static _Fields findByThriftId(int fieldId) {
        return byId.get(fieldId);
      }

      /**
       * Find the _Fields constant that matches fieldId, throwing an exception
       * if it is not found.
       */
      public static _Fields findByThriftIdOrThrow(int fieldId) {
        _Fields fields = findByThriftId(fieldId);
        if (fields == null) throw new IllegalArgumentException("Field " + fieldId + " doesn't exist!");
        return fields;
      }

      /**
       * Find the _Fields constant that matches name, or null if its not found.
       */
      public static _Fields findByName(String name) {
        return byName.get(name);
      }

      private final short _thriftId;
      private final String _fieldName;

      _Fields(short thriftId, String fieldName) {
        _thriftId = thriftId;
        _fieldName = fieldName;
      }

      public short getThriftFieldId() {
        return _thriftId;
      }

      public String getFieldName() {
        return _fieldName;
      }
    }

    // isset id assignments

    public static final Map<_Fields, FieldMetaData> metaDataMap = Collections.unmodifiableMap(new EnumMap<_Fields, FieldMetaData>(_Fields.class) {{
      put(_Fields.SUCCESS, new FieldMetaData("success", TFieldRequirementType.DEFAULT, 
          new StructMetaData(TType.STRUCT, com.evernote.edam.type.SharedNotebook.class)));
      put(_Fields.USER_EXCEPTION, new FieldMetaData("userException", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.STRUCT)));
      put(_Fields.NOT_FOUND_EXCEPTION, new FieldMetaData("notFoundException", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.STRUCT)));
      put(_Fields.SYSTEM_EXCEPTION, new FieldMetaData("systemException", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.STRUCT)));
    }});

    static {
      FieldMetaData.addStructMetaDataMap(getSharedNotebookByAuth_result.class, metaDataMap);
    }

    public getSharedNotebookByAuth_result() {
    }

    public getSharedNotebookByAuth_result(
      com.evernote.edam.type.SharedNotebook success,
      com.evernote.edam.error.EDAMUserException userException,
      com.evernote.edam.error.EDAMNotFoundException notFoundException,
      com.evernote.edam.error.EDAMSystemException systemException)
    {
      this();
      this.success = success;
      this.userException = userException;
      this.notFoundException = notFoundException;
      this.systemException = systemException;
    }

    /**
     * Performs a deep copy on <i>other</i>.
     */
    public getSharedNotebookByAuth_result(getSharedNotebookByAuth_result other) {
      if (other.isSetSuccess()) {
        this.success = new com.evernote.edam.type.SharedNotebook(other.success);
      }
      if (other.isSetUserException()) {
        this.userException = new com.evernote.edam.error.EDAMUserException(other.userException);
      }
      if (other.isSetNotFoundException()) {
        this.notFoundException = new com.evernote.edam.error.EDAMNotFoundException(other.notFoundException);
      }
      if (other.isSetSystemException()) {
        this.systemException = new com.evernote.edam.error.EDAMSystemException(other.systemException);
      }
    }

    public getSharedNotebookByAuth_result deepCopy() {
      return new getSharedNotebookByAuth_result(this);
    }

    @Deprecated
    public getSharedNotebookByAuth_result clone() {
      return new getSharedNotebookByAuth_result(this);
    }

    public com.evernote.edam.type.SharedNotebook getSuccess() {
      return this.success;
    }

    public void setSuccess(com.evernote.edam.type.SharedNotebook success) {
      this.success = success;
    }

    public void unsetSuccess() {
      this.success = null;
    }

    /** Returns true if field success is set (has been asigned a value) and false otherwise */
    public boolean isSetSuccess() {
      return this.success != null;
    }

    public void setSuccessIsSet(boolean value) {
      if (!value) {
        this.success = null;
      }
    }

    public com.evernote.edam.error.EDAMUserException getUserException() {
      return this.userException;
    }

    public void setUserException(com.evernote.edam.error.EDAMUserException userException) {
      this.userException = userException;
    }

    public void unsetUserException() {
      this.userException = null;
    }

    /** Returns true if field userException is set (has been asigned a value) and false otherwise */
    public boolean isSetUserException() {
      return this.userException != null;
    }

    public void setUserExceptionIsSet(boolean value) {
      if (!value) {
        this.userException = null;
      }
    }

    public com.evernote.edam.error.EDAMNotFoundException getNotFoundException() {
      return this.notFoundException;
    }

    public void setNotFoundException(com.evernote.edam.error.EDAMNotFoundException notFoundException) {
      this.notFoundException = notFoundException;
    }

    public void unsetNotFoundException() {
      this.notFoundException = null;
    }

    /** Returns true if field notFoundException is set (has been asigned a value) and false otherwise */
    public boolean isSetNotFoundException() {
      return this.notFoundException != null;
    }

    public void setNotFoundExceptionIsSet(boolean value) {
      if (!value) {
        this.notFoundException = null;
      }
    }

    public com.evernote.edam.error.EDAMSystemException getSystemException() {
      return this.systemException;
    }

    public void setSystemException(com.evernote.edam.error.EDAMSystemException systemException) {
      this.systemException = systemException;
    }

    public void unsetSystemException() {
      this.systemException = null;
    }

    /** Returns true if field systemException is set (has been asigned a value) and false otherwise */
    public boolean isSetSystemException() {
      return this.systemException != null;
    }

    public void setSystemExceptionIsSet(boolean value) {
      if (!value) {
        this.systemException = null;
      }
    }

    public void setFieldValue(_Fields field, Object value) {
      switch (field) {
      case SUCCESS:
        if (value == null) {
          unsetSuccess();
        } else {
          setSuccess((com.evernote.edam.type.SharedNotebook)value);
        }
        break;

      case USER_EXCEPTION:
        if (value == null) {
          unsetUserException();
        } else {
          setUserException((com.evernote.edam.error.EDAMUserException)value);
        }
        break;

      case NOT_FOUND_EXCEPTION:
        if (value == null) {
          unsetNotFoundException();
        } else {
          setNotFoundException((com.evernote.edam.error.EDAMNotFoundException)value);
        }
        break;

      case SYSTEM_EXCEPTION:
        if (value == null) {
          unsetSystemException();
        } else {
          setSystemException((com.evernote.edam.error.EDAMSystemException)value);
        }
        break;

      }
    }

    public void setFieldValue(int fieldID, Object value) {
      setFieldValue(_Fields.findByThriftIdOrThrow(fieldID), value);
    }

    public Object getFieldValue(_Fields field) {
      switch (field) {
      case SUCCESS:
        return getSuccess();

      case USER_EXCEPTION:
        return getUserException();

      case NOT_FOUND_EXCEPTION:
        return getNotFoundException();

      case SYSTEM_EXCEPTION:
        return getSystemException();

      }
      throw new IllegalStateException();
    }

    public Object getFieldValue(int fieldId) {
      return getFieldValue(_Fields.findByThriftIdOrThrow(fieldId));
    }

    /** Returns true if field corresponding to fieldID is set (has been asigned a value) and false otherwise */
    public boolean isSet(_Fields field) {
      switch (field) {
      case SUCCESS:
        return isSetSuccess();
      case USER_EXCEPTION:
        return isSetUserException();
      case NOT_FOUND_EXCEPTION:
        return isSetNotFoundException();
      case SYSTEM_EXCEPTION:
        return isSetSystemException();
      }
      throw new IllegalStateException();
    }

    public boolean isSet(int fieldID) {
      return isSet(_Fields.findByThriftIdOrThrow(fieldID));
    }

    public boolean equals(Object that) {
      if (that == null)
        return false;
      if (that instanceof getSharedNotebookByAuth_result)
        return this.equals((getSharedNotebookByAuth_result)that);
      return false;
    }

    public boolean equals(getSharedNotebookByAuth_result that) {
      if (that == null)
        return false;

      boolean this_present_success = true && this.isSetSuccess();
      boolean that_present_success = true && that.isSetSuccess();
      if (this_present_success || that_present_success) {
        if (!(this_present_success && that_present_success))
          return false;
        if (!this.success.equals(that.success))
          return false;
      }

      boolean this_present_userException = true && this.isSetUserException();
      boolean that_present_userException = true && that.isSetUserException();
      if (this_present_userException || that_present_userException) {
        if (!(this_present_userException && that_present_userException))
          return false;
        if (!this.userException.equals(that.userException))
          return false;
      }

      boolean this_present_notFoundException = true && this.isSetNotFoundException();
      boolean that_present_notFoundException = true && that.isSetNotFoundException();
      if (this_present_notFoundException || that_present_notFoundException) {
        if (!(this_present_notFoundException && that_present_notFoundException))
          return false;
        if (!this.notFoundException.equals(that.notFoundException))
          return false;
      }

      boolean this_present_systemException = true && this.isSetSystemException();
      boolean that_present_systemException = true && that.isSetSystemException();
      if (this_present_systemException || that_present_systemException) {
        if (!(this_present_systemException && that_present_systemException))
          return false;
        if (!this.systemException.equals(that.systemException))
          return false;
      }

      return true;
    }

    public int hashCode() {
      return 0;
    }

    public int compareTo(getSharedNotebookByAuth_result other) {
      if (!getClass().equals(other.getClass())) {
        return getClass().getName().compareTo(other.getClass().getName());
      }

      int lastComparison = 0;
      getSharedNotebookByAuth_result typedOther = (getSharedNotebookByAuth_result)other;

      lastComparison = Boolean.valueOf(isSetSuccess()).compareTo(isSetSuccess());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(success, typedOther.success);
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = Boolean.valueOf(isSetUserException()).compareTo(isSetUserException());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(userException, typedOther.userException);
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = Boolean.valueOf(isSetNotFoundException()).compareTo(isSetNotFoundException());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(notFoundException, typedOther.notFoundException);
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = Boolean.valueOf(isSetSystemException()).compareTo(isSetSystemException());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(systemException, typedOther.systemException);
      if (lastComparison != 0) {
        return lastComparison;
      }
      return 0;
    }

    public void read(TProtocol iprot) throws TException {
      TField field;
      iprot.readStructBegin();
      while (true)
      {
        field = iprot.readFieldBegin();
        if (field.type == TType.STOP) { 
          break;
        }
        _Fields fieldId = _Fields.findByThriftId(field.id);
        if (fieldId == null) {
          TProtocolUtil.skip(iprot, field.type);
        } else {
          switch (fieldId) {
            case SUCCESS:
              if (field.type == TType.STRUCT) {
                this.success = new com.evernote.edam.type.SharedNotebook();
                this.success.read(iprot);
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
            case USER_EXCEPTION:
              if (field.type == TType.STRUCT) {
                this.userException = new com.evernote.edam.error.EDAMUserException();
                this.userException.read(iprot);
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
            case NOT_FOUND_EXCEPTION:
              if (field.type == TType.STRUCT) {
                this.notFoundException = new com.evernote.edam.error.EDAMNotFoundException();
                this.notFoundException.read(iprot);
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
            case SYSTEM_EXCEPTION:
              if (field.type == TType.STRUCT) {
                this.systemException = new com.evernote.edam.error.EDAMSystemException();
                this.systemException.read(iprot);
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
          }
          iprot.readFieldEnd();
        }
      }
      iprot.readStructEnd();
      validate();
    }

    public void write(TProtocol oprot) throws TException {
      oprot.writeStructBegin(STRUCT_DESC);

      if (this.isSetSuccess()) {
        oprot.writeFieldBegin(SUCCESS_FIELD_DESC);
        this.success.write(oprot);
        oprot.writeFieldEnd();
      } else if (this.isSetUserException()) {
        oprot.writeFieldBegin(USER_EXCEPTION_FIELD_DESC);
        this.userException.write(oprot);
        oprot.writeFieldEnd();
      } else if (this.isSetNotFoundException()) {
        oprot.writeFieldBegin(NOT_FOUND_EXCEPTION_FIELD_DESC);
        this.notFoundException.write(oprot);
        oprot.writeFieldEnd();
      } else if (this.isSetSystemException()) {
        oprot.writeFieldBegin(SYSTEM_EXCEPTION_FIELD_DESC);
        this.systemException.write(oprot);
        oprot.writeFieldEnd();
      }
      oprot.writeFieldStop();
      oprot.writeStructEnd();
    }

    public String toString() {
      StringBuilder sb = new StringBuilder("getSharedNotebookByAuth_result(");
      boolean first = true;

      sb.append("success:");
      if (this.success == null) {
        sb.append("null");
      } else {
        sb.append(this.success);
      }
      first = false;
      if (!first) sb.append(", ");
      sb.append("userException:");
      if (this.userException == null) {
        sb.append("null");
      } else {
        sb.append(this.userException);
      }
      first = false;
      if (!first) sb.append(", ");
      sb.append("notFoundException:");
      if (this.notFoundException == null) {
        sb.append("null");
      } else {
        sb.append(this.notFoundException);
      }
      first = false;
      if (!first) sb.append(", ");
      sb.append("systemException:");
      if (this.systemException == null) {
        sb.append("null");
      } else {
        sb.append(this.systemException);
      }
      first = false;
      sb.append(")");
      return sb.toString();
    }

    public void validate() throws TException {
      // check for required fields
    }

  }

  public static class emailNote_args implements TBase<emailNote_args._Fields>, java.io.Serializable, Cloneable, Comparable<emailNote_args>   {
    private static final TStruct STRUCT_DESC = new TStruct("emailNote_args");

    private static final TField AUTHENTICATION_TOKEN_FIELD_DESC = new TField("authenticationToken", TType.STRING, (short)1);
    private static final TField PARAMETERS_FIELD_DESC = new TField("parameters", TType.STRUCT, (short)2);

    private String authenticationToken;
    private NoteEmailParameters parameters;

    /** The set of fields this struct contains, along with convenience methods for finding and manipulating them. */
    public enum _Fields implements TFieldIdEnum {
      AUTHENTICATION_TOKEN((short)1, "authenticationToken"),
      PARAMETERS((short)2, "parameters");

      private static final Map<Integer, _Fields> byId = new HashMap<Integer, _Fields>();
      private static final Map<String, _Fields> byName = new HashMap<String, _Fields>();

      static {
        for (_Fields field : EnumSet.allOf(_Fields.class)) {
          byId.put((int)field._thriftId, field);
          byName.put(field.getFieldName(), field);
        }
      }

      /**
       * Find the _Fields constant that matches fieldId, or null if its not found.
       */
      public static _Fields findByThriftId(int fieldId) {
        return byId.get(fieldId);
      }

      /**
       * Find the _Fields constant that matches fieldId, throwing an exception
       * if it is not found.
       */
      public static _Fields findByThriftIdOrThrow(int fieldId) {
        _Fields fields = findByThriftId(fieldId);
        if (fields == null) throw new IllegalArgumentException("Field " + fieldId + " doesn't exist!");
        return fields;
      }

      /**
       * Find the _Fields constant that matches name, or null if its not found.
       */
      public static _Fields findByName(String name) {
        return byName.get(name);
      }

      private final short _thriftId;
      private final String _fieldName;

      _Fields(short thriftId, String fieldName) {
        _thriftId = thriftId;
        _fieldName = fieldName;
      }

      public short getThriftFieldId() {
        return _thriftId;
      }

      public String getFieldName() {
        return _fieldName;
      }
    }

    // isset id assignments

    public static final Map<_Fields, FieldMetaData> metaDataMap = Collections.unmodifiableMap(new EnumMap<_Fields, FieldMetaData>(_Fields.class) {{
      put(_Fields.AUTHENTICATION_TOKEN, new FieldMetaData("authenticationToken", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.STRING)));
      put(_Fields.PARAMETERS, new FieldMetaData("parameters", TFieldRequirementType.DEFAULT, 
          new StructMetaData(TType.STRUCT, NoteEmailParameters.class)));
    }});

    static {
      FieldMetaData.addStructMetaDataMap(emailNote_args.class, metaDataMap);
    }

    public emailNote_args() {
    }

    public emailNote_args(
      String authenticationToken,
      NoteEmailParameters parameters)
    {
      this();
      this.authenticationToken = authenticationToken;
      this.parameters = parameters;
    }

    /**
     * Performs a deep copy on <i>other</i>.
     */
    public emailNote_args(emailNote_args other) {
      if (other.isSetAuthenticationToken()) {
        this.authenticationToken = other.authenticationToken;
      }
      if (other.isSetParameters()) {
        this.parameters = new NoteEmailParameters(other.parameters);
      }
    }

    public emailNote_args deepCopy() {
      return new emailNote_args(this);
    }

    @Deprecated
    public emailNote_args clone() {
      return new emailNote_args(this);
    }

    public String getAuthenticationToken() {
      return this.authenticationToken;
    }

    public void setAuthenticationToken(String authenticationToken) {
      this.authenticationToken = authenticationToken;
    }

    public void unsetAuthenticationToken() {
      this.authenticationToken = null;
    }

    /** Returns true if field authenticationToken is set (has been asigned a value) and false otherwise */
    public boolean isSetAuthenticationToken() {
      return this.authenticationToken != null;
    }

    public void setAuthenticationTokenIsSet(boolean value) {
      if (!value) {
        this.authenticationToken = null;
      }
    }

    public NoteEmailParameters getParameters() {
      return this.parameters;
    }

    public void setParameters(NoteEmailParameters parameters) {
      this.parameters = parameters;
    }

    public void unsetParameters() {
      this.parameters = null;
    }

    /** Returns true if field parameters is set (has been asigned a value) and false otherwise */
    public boolean isSetParameters() {
      return this.parameters != null;
    }

    public void setParametersIsSet(boolean value) {
      if (!value) {
        this.parameters = null;
      }
    }

    public void setFieldValue(_Fields field, Object value) {
      switch (field) {
      case AUTHENTICATION_TOKEN:
        if (value == null) {
          unsetAuthenticationToken();
        } else {
          setAuthenticationToken((String)value);
        }
        break;

      case PARAMETERS:
        if (value == null) {
          unsetParameters();
        } else {
          setParameters((NoteEmailParameters)value);
        }
        break;

      }
    }

    public void setFieldValue(int fieldID, Object value) {
      setFieldValue(_Fields.findByThriftIdOrThrow(fieldID), value);
    }

    public Object getFieldValue(_Fields field) {
      switch (field) {
      case AUTHENTICATION_TOKEN:
        return getAuthenticationToken();

      case PARAMETERS:
        return getParameters();

      }
      throw new IllegalStateException();
    }

    public Object getFieldValue(int fieldId) {
      return getFieldValue(_Fields.findByThriftIdOrThrow(fieldId));
    }

    /** Returns true if field corresponding to fieldID is set (has been asigned a value) and false otherwise */
    public boolean isSet(_Fields field) {
      switch (field) {
      case AUTHENTICATION_TOKEN:
        return isSetAuthenticationToken();
      case PARAMETERS:
        return isSetParameters();
      }
      throw new IllegalStateException();
    }

    public boolean isSet(int fieldID) {
      return isSet(_Fields.findByThriftIdOrThrow(fieldID));
    }

    public boolean equals(Object that) {
      if (that == null)
        return false;
      if (that instanceof emailNote_args)
        return this.equals((emailNote_args)that);
      return false;
    }

    public boolean equals(emailNote_args that) {
      if (that == null)
        return false;

      boolean this_present_authenticationToken = true && this.isSetAuthenticationToken();
      boolean that_present_authenticationToken = true && that.isSetAuthenticationToken();
      if (this_present_authenticationToken || that_present_authenticationToken) {
        if (!(this_present_authenticationToken && that_present_authenticationToken))
          return false;
        if (!this.authenticationToken.equals(that.authenticationToken))
          return false;
      }

      boolean this_present_parameters = true && this.isSetParameters();
      boolean that_present_parameters = true && that.isSetParameters();
      if (this_present_parameters || that_present_parameters) {
        if (!(this_present_parameters && that_present_parameters))
          return false;
        if (!this.parameters.equals(that.parameters))
          return false;
      }

      return true;
    }

    public int hashCode() {
      return 0;
    }

    public int compareTo(emailNote_args other) {
      if (!getClass().equals(other.getClass())) {
        return getClass().getName().compareTo(other.getClass().getName());
      }

      int lastComparison = 0;
      emailNote_args typedOther = (emailNote_args)other;

      lastComparison = Boolean.valueOf(isSetAuthenticationToken()).compareTo(isSetAuthenticationToken());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(authenticationToken, typedOther.authenticationToken);
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = Boolean.valueOf(isSetParameters()).compareTo(isSetParameters());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(parameters, typedOther.parameters);
      if (lastComparison != 0) {
        return lastComparison;
      }
      return 0;
    }

    public void read(TProtocol iprot) throws TException {
      TField field;
      iprot.readStructBegin();
      while (true)
      {
        field = iprot.readFieldBegin();
        if (field.type == TType.STOP) { 
          break;
        }
        _Fields fieldId = _Fields.findByThriftId(field.id);
        if (fieldId == null) {
          TProtocolUtil.skip(iprot, field.type);
        } else {
          switch (fieldId) {
            case AUTHENTICATION_TOKEN:
              if (field.type == TType.STRING) {
                this.authenticationToken = iprot.readString();
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
            case PARAMETERS:
              if (field.type == TType.STRUCT) {
                this.parameters = new NoteEmailParameters();
                this.parameters.read(iprot);
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
          }
          iprot.readFieldEnd();
        }
      }
      iprot.readStructEnd();
      validate();
    }

    public void write(TProtocol oprot) throws TException {
      validate();

      oprot.writeStructBegin(STRUCT_DESC);
      if (this.authenticationToken != null) {
        oprot.writeFieldBegin(AUTHENTICATION_TOKEN_FIELD_DESC);
        oprot.writeString(this.authenticationToken);
        oprot.writeFieldEnd();
      }
      if (this.parameters != null) {
        oprot.writeFieldBegin(PARAMETERS_FIELD_DESC);
        this.parameters.write(oprot);
        oprot.writeFieldEnd();
      }
      oprot.writeFieldStop();
      oprot.writeStructEnd();
    }

    public String toString() {
      StringBuilder sb = new StringBuilder("emailNote_args(");
      boolean first = true;

      sb.append("authenticationToken:");
      if (this.authenticationToken == null) {
        sb.append("null");
      } else {
        sb.append(this.authenticationToken);
      }
      first = false;
      if (!first) sb.append(", ");
      sb.append("parameters:");
      if (this.parameters == null) {
        sb.append("null");
      } else {
        sb.append(this.parameters);
      }
      first = false;
      sb.append(")");
      return sb.toString();
    }

    public void validate() throws TException {
      // check for required fields
    }

  }

  public static class emailNote_result implements TBase<emailNote_result._Fields>, java.io.Serializable, Cloneable, Comparable<emailNote_result>   {
    private static final TStruct STRUCT_DESC = new TStruct("emailNote_result");

    private static final TField USER_EXCEPTION_FIELD_DESC = new TField("userException", TType.STRUCT, (short)1);
    private static final TField NOT_FOUND_EXCEPTION_FIELD_DESC = new TField("notFoundException", TType.STRUCT, (short)2);
    private static final TField SYSTEM_EXCEPTION_FIELD_DESC = new TField("systemException", TType.STRUCT, (short)3);

    private com.evernote.edam.error.EDAMUserException userException;
    private com.evernote.edam.error.EDAMNotFoundException notFoundException;
    private com.evernote.edam.error.EDAMSystemException systemException;

    /** The set of fields this struct contains, along with convenience methods for finding and manipulating them. */
    public enum _Fields implements TFieldIdEnum {
      USER_EXCEPTION((short)1, "userException"),
      NOT_FOUND_EXCEPTION((short)2, "notFoundException"),
      SYSTEM_EXCEPTION((short)3, "systemException");

      private static final Map<Integer, _Fields> byId = new HashMap<Integer, _Fields>();
      private static final Map<String, _Fields> byName = new HashMap<String, _Fields>();

      static {
        for (_Fields field : EnumSet.allOf(_Fields.class)) {
          byId.put((int)field._thriftId, field);
          byName.put(field.getFieldName(), field);
        }
      }

      /**
       * Find the _Fields constant that matches fieldId, or null if its not found.
       */
      public static _Fields findByThriftId(int fieldId) {
        return byId.get(fieldId);
      }

      /**
       * Find the _Fields constant that matches fieldId, throwing an exception
       * if it is not found.
       */
      public static _Fields findByThriftIdOrThrow(int fieldId) {
        _Fields fields = findByThriftId(fieldId);
        if (fields == null) throw new IllegalArgumentException("Field " + fieldId + " doesn't exist!");
        return fields;
      }

      /**
       * Find the _Fields constant that matches name, or null if its not found.
       */
      public static _Fields findByName(String name) {
        return byName.get(name);
      }

      private final short _thriftId;
      private final String _fieldName;

      _Fields(short thriftId, String fieldName) {
        _thriftId = thriftId;
        _fieldName = fieldName;
      }

      public short getThriftFieldId() {
        return _thriftId;
      }

      public String getFieldName() {
        return _fieldName;
      }
    }

    // isset id assignments

    public static final Map<_Fields, FieldMetaData> metaDataMap = Collections.unmodifiableMap(new EnumMap<_Fields, FieldMetaData>(_Fields.class) {{
      put(_Fields.USER_EXCEPTION, new FieldMetaData("userException", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.STRUCT)));
      put(_Fields.NOT_FOUND_EXCEPTION, new FieldMetaData("notFoundException", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.STRUCT)));
      put(_Fields.SYSTEM_EXCEPTION, new FieldMetaData("systemException", TFieldRequirementType.DEFAULT, 
          new FieldValueMetaData(TType.STRUCT)));
    }});

    static {
      FieldMetaData.addStructMetaDataMap(emailNote_result.class, metaDataMap);
    }

    public emailNote_result() {
    }

    public emailNote_result(
      com.evernote.edam.error.EDAMUserException userException,
      com.evernote.edam.error.EDAMNotFoundException notFoundException,
      com.evernote.edam.error.EDAMSystemException systemException)
    {
      this();
      this.userException = userException;
      this.notFoundException = notFoundException;
      this.systemException = systemException;
    }

    /**
     * Performs a deep copy on <i>other</i>.
     */
    public emailNote_result(emailNote_result other) {
      if (other.isSetUserException()) {
        this.userException = new com.evernote.edam.error.EDAMUserException(other.userException);
      }
      if (other.isSetNotFoundException()) {
        this.notFoundException = new com.evernote.edam.error.EDAMNotFoundException(other.notFoundException);
      }
      if (other.isSetSystemException()) {
        this.systemException = new com.evernote.edam.error.EDAMSystemException(other.systemException);
      }
    }

    public emailNote_result deepCopy() {
      return new emailNote_result(this);
    }

    @Deprecated
    public emailNote_result clone() {
      return new emailNote_result(this);
    }

    public com.evernote.edam.error.EDAMUserException getUserException() {
      return this.userException;
    }

    public void setUserException(com.evernote.edam.error.EDAMUserException userException) {
      this.userException = userException;
    }

    public void unsetUserException() {
      this.userException = null;
    }

    /** Returns true if field userException is set (has been asigned a value) and false otherwise */
    public boolean isSetUserException() {
      return this.userException != null;
    }

    public void setUserExceptionIsSet(boolean value) {
      if (!value) {
        this.userException = null;
      }
    }

    public com.evernote.edam.error.EDAMNotFoundException getNotFoundException() {
      return this.notFoundException;
    }

    public void setNotFoundException(com.evernote.edam.error.EDAMNotFoundException notFoundException) {
      this.notFoundException = notFoundException;
    }

    public void unsetNotFoundException() {
      this.notFoundException = null;
    }

    /** Returns true if field notFoundException is set (has been asigned a value) and false otherwise */
    public boolean isSetNotFoundException() {
      return this.notFoundException != null;
    }

    public void setNotFoundExceptionIsSet(boolean value) {
      if (!value) {
        this.notFoundException = null;
      }
    }

    public com.evernote.edam.error.EDAMSystemException getSystemException() {
      return this.systemException;
    }

    public void setSystemException(com.evernote.edam.error.EDAMSystemException systemException) {
      this.systemException = systemException;
    }

    public void unsetSystemException() {
      this.systemException = null;
    }

    /** Returns true if field systemException is set (has been asigned a value) and false otherwise */
    public boolean isSetSystemException() {
      return this.systemException != null;
    }

    public void setSystemExceptionIsSet(boolean value) {
      if (!value) {
        this.systemException = null;
      }
    }

    public void setFieldValue(_Fields field, Object value) {
      switch (field) {
      case USER_EXCEPTION:
        if (value == null) {
          unsetUserException();
        } else {
          setUserException((com.evernote.edam.error.EDAMUserException)value);
        }
        break;

      case NOT_FOUND_EXCEPTION:
        if (value == null) {
          unsetNotFoundException();
        } else {
          setNotFoundException((com.evernote.edam.error.EDAMNotFoundException)value);
        }
        break;

      case SYSTEM_EXCEPTION:
        if (value == null) {
          unsetSystemException();
        } else {
          setSystemException((com.evernote.edam.error.EDAMSystemException)value);
        }
        break;

      }
    }

    public void setFieldValue(int fieldID, Object value) {
      setFieldValue(_Fields.findByThriftIdOrThrow(fieldID), value);
    }

    public Object getFieldValue(_Fields field) {
      switch (field) {
      case USER_EXCEPTION:
        return getUserException();

      case NOT_FOUND_EXCEPTION:
        return getNotFoundException();

      case SYSTEM_EXCEPTION:
        return getSystemException();

      }
      throw new IllegalStateException();
    }

    public Object getFieldValue(int fieldId) {
      return getFieldValue(_Fields.findByThriftIdOrThrow(fieldId));
    }

    /** Returns true if field corresponding to fieldID is set (has been asigned a value) and false otherwise */
    public boolean isSet(_Fields field) {
      switch (field) {
      case USER_EXCEPTION:
        return isSetUserException();
      case NOT_FOUND_EXCEPTION:
        return isSetNotFoundException();
      case SYSTEM_EXCEPTION:
        return isSetSystemException();
      }
      throw new IllegalStateException();
    }

    public boolean isSet(int fieldID) {
      return isSet(_Fields.findByThriftIdOrThrow(fieldID));
    }

    public boolean equals(Object that) {
      if (that == null)
        return false;
      if (that instanceof emailNote_result)
        return this.equals((emailNote_result)that);
      return false;
    }

    public boolean equals(emailNote_result that) {
      if (that == null)
        return false;

      boolean this_present_userException = true && this.isSetUserException();
      boolean that_present_userException = true && that.isSetUserException();
      if (this_present_userException || that_present_userException) {
        if (!(this_present_userException && that_present_userException))
          return false;
        if (!this.userException.equals(that.userException))
          return false;
      }

      boolean this_present_notFoundException = true && this.isSetNotFoundException();
      boolean that_present_notFoundException = true && that.isSetNotFoundException();
      if (this_present_notFoundException || that_present_notFoundException) {
        if (!(this_present_notFoundException && that_present_notFoundException))
          return false;
        if (!this.notFoundException.equals(that.notFoundException))
          return false;
      }

      boolean this_present_systemException = true && this.isSetSystemException();
      boolean that_present_systemException = true && that.isSetSystemException();
      if (this_present_systemException || that_present_systemException) {
        if (!(this_present_systemException && that_present_systemException))
          return false;
        if (!this.systemException.equals(that.systemException))
          return false;
      }

      return true;
    }

    public int hashCode() {
      return 0;
    }

    public int compareTo(emailNote_result other) {
      if (!getClass().equals(other.getClass())) {
        return getClass().getName().compareTo(other.getClass().getName());
      }

      int lastComparison = 0;
      emailNote_result typedOther = (emailNote_result)other;

      lastComparison = Boolean.valueOf(isSetUserException()).compareTo(isSetUserException());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(userException, typedOther.userException);
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = Boolean.valueOf(isSetNotFoundException()).compareTo(isSetNotFoundException());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(notFoundException, typedOther.notFoundException);
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = Boolean.valueOf(isSetSystemException()).compareTo(isSetSystemException());
      if (lastComparison != 0) {
        return lastComparison;
      }
      lastComparison = TBaseHelper.compareTo(systemException, typedOther.systemException);
      if (lastComparison != 0) {
        return lastComparison;
      }
      return 0;
    }

    public void read(TProtocol iprot) throws TException {
      TField field;
      iprot.readStructBegin();
      while (true)
      {
        field = iprot.readFieldBegin();
        if (field.type == TType.STOP) { 
          break;
        }
        _Fields fieldId = _Fields.findByThriftId(field.id);
        if (fieldId == null) {
          TProtocolUtil.skip(iprot, field.type);
        } else {
          switch (fieldId) {
            case USER_EXCEPTION:
              if (field.type == TType.STRUCT) {
                this.userException = new com.evernote.edam.error.EDAMUserException();
                this.userException.read(iprot);
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
            case NOT_FOUND_EXCEPTION:
              if (field.type == TType.STRUCT) {
                this.notFoundException = new com.evernote.edam.error.EDAMNotFoundException();
                this.notFoundException.read(iprot);
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
            case SYSTEM_EXCEPTION:
              if (field.type == TType.STRUCT) {
                this.systemException = new com.evernote.edam.error.EDAMSystemException();
                this.systemException.read(iprot);
              } else { 
                TProtocolUtil.skip(iprot, field.type);
              }
              break;
          }
          iprot.readFieldEnd();
        }
      }
      iprot.readStructEnd();
      validate();
    }

    public void write(TProtocol oprot) throws TException {
      oprot.writeStructBegin(STRUCT_DESC);

      if (this.isSetUserException()) {
        oprot.writeFieldBegin(USER_EXCEPTION_FIELD_DESC);
        this.userException.write(oprot);
        oprot.writeFieldEnd();
      } else if (this.isSetNotFoundException()) {
        oprot.writeFieldBegin(NOT_FOUND_EXCEPTION_FIELD_DESC);
        this.notFoundException.write(oprot);
        oprot.writeFieldEnd();
      } else if (this.isSetSystemException()) {
        oprot.writeFieldBegin(SYSTEM_EXCEPTION_FIELD_DESC);
        this.systemException.write(oprot);
        oprot.writeFieldEnd();
      }
      oprot.writeFieldStop();
      oprot.writeStructEnd();
    }

    public String toString() {
      StringBuilder sb = new StringBuilder("emailNote_result(");
      boolean first = true;

      sb.append("userException:");
      if (this.userException == null) {
        sb.append("null");
      } else {
        sb.append(this.userException);
      }
      first = false;
      if (!first) sb.append(", ");
      sb.append("notFoundException:");
      if (this.notFoundException == null) {
        sb.append("null");
      } else {
        sb.append(this.notFoundException);
      }
      first = false;
      if (!first) sb.append(", ");
      sb.append("systemException:");
      if (this.systemException == null) {
        sb.append("null");
      } else {
        sb.append(this.systemException);
      }
      first = false;
      sb.append(")");
      return sb.toString();
    }

    public void validate() throws TException {
      // check for required fields
    }

  }

}
